(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3147145,     115647]*)
(*NotebookOutlinePosition[   3148289,     115682]*)
(*  CellTagsIndexPosition[   3148245,     115678]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
A generator of quasiperiodic  tilings using an analytical formula \
\
\>", "Title",
  TextAlignment->Center],

Cell[BoxData[""], "Input"],

Cell[TextData[{
  StyleBox["This program generates quasiperiodic tilings in 2D and can be \
very easily generalized to 3D. The output is written in 2 files, both with \
the vertex positions, but one is just pure positions in floating point format \
(\"numbers\"), the other has the points written in the field of the star \
vectors. Drawings of the tilings are shown as a part of the calculation \
inside the software. Since the program is very general, many different \
tilings are obtained if one plays with the parameters and  star vectors, see \
documentation inside. In the default form, the program outputs the vertex \
positions of the Penrose tiling, but other isomorphism classes are available \
if the parameters are changed.\nIf other symmetries are desired, like \
octagonal  or dodecagonal tilings, one must change the star vectors. (If \
needed, a",
    FontSize->14],
  StyleBox["pproximants are obtained by",
    FontSize->14],
  StyleBox[" considering \"rational star vectors\", i.e., by changing the \
angles between star vectors, this corresponds to a rational angle of \
projection in the cut and project method)\nThe calculation is based in a very \
simple analytical formula for the vertex positions that we developed, which \
was published in: \nNaumis and Arag\[OAcute]n,",
    FontSize->14],
  StyleBox[", ",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox["\[OpenCurlyDoubleQuote]Analytic expressions for the vertex \
coordinates of quasiperiodic lattices\[CloseCurlyDoubleQuote], ",
    FontSize->14],
  StyleBox["Z.  Kristallogr.",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSize->14],
  StyleBox["218",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox[", 397 (2003).",
    FontSize->14],
  StyleBox["\nThis formula is just the generalization of the process made in \
a periodic lattice, i.e., one forms linear combinations of basis vectors, but \
in this case one has more than 3, which are called star vectors. The trick is \
that a floor function is used to select the right combinations. In fact, we \
obtained in that way the analytical expressions for the window function in \
the cut and projection method. This was done by finding an expression to the \
dual transformation in the GDM method. Using this formula, one can derive \
many analytical results.\nThe second part of the program, uses this formula \
to generate the average lattice, which contains a relevant part of the \
diffraction spectra, and which is fundamental to stabilize the lattice (see \
for example:G.G. Naumis, \[OpenCurlyDoubleQuote]Phason hierarchy and \
electronic stability of quasicrystals\[CloseCurlyDoubleQuote], ",
    FontSize->14],
  StyleBox["Phys, Rev.",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox[" B71, 144204 (2005)).\n",
    FontSize->14],
  "\n"
}], "Section",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["Utils", "Section",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["Cuts the array lattice up to a radius r", "Text"],

Cell[BoxData[
    \(SphericalCut[lattice_, r_] := 
      Select[lattice, # . # \[LessEqual] r\^2 &]\)], "Input",
  CellLabel->"In[1]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inserts a zero at z in array lts", "Text"],

Cell[BoxData[
    \(To3D[lst_] := Insert[lst, 0, 3]\)], "Input",
  CellLabel->"In[2]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Draws the tiling of list PTS with bondlenght RAD ant tolerance \
T\
\>", "Text"],

Cell[BoxData[
    \(tiling2D[pts_, rad_, t_:  Automatic] := 
      Module[{tol = t, bonds}, 
        dist[x_, y_] := \@\(\((x - y)\) . \((x - y)\)\); 
        drawbond[{p1_, p2_}] := 
          Line[{pts\[LeftDoubleBracket]p1\[RightDoubleBracket], 
              pts\[LeftDoubleBracket]p2\[RightDoubleBracket]}]; 
        If[t === Automatic, tol = 0.1]; 
        bonds = Select[
            Flatten[Table[
                If[Abs[dist[pts\[LeftDoubleBracket]i\[RightDoubleBracket], 
                          pts\[LeftDoubleBracket]j\[RightDoubleBracket]] - 
                        rad] < tol, {i, j}, {0, 0}], {i, 1, 
                  Length[pts] - 1}, {j, i + 1, Length[pts]}], 
              1], #1 \[NotEqual] {0, 0} &]; 
        Show[Graphics[drawbond /@ bonds], 
          AspectRatio \[Rule] Automatic]]\)], "Input",
  CellLabel->"In[3]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Draws the diffraction pattern: disks at position given by list PTS \
with radius given by INTS with a Gray Level of GRAY (white=1, black=0)\
\>", \
"Text"],

Cell[BoxData[
    \(DrawPattern[pts_, \ ins_, \ gray_] := \ 
      Show[Graphics[
          Table[{GrayLevel[gray], 
              Disk[{pts[\([i, 1]\)], \ pts[\([i, 2]\)]}, ins[\([i]\)]]}, {i, 
              Length[ins]}]], AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[4]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Extracts k-vectors (PTS) which fulfills Brag's condition \
(Indeterminate in the list of intensities INTS)\
\>", "Text"],

Cell[BoxData[
    \(ExtractBragg[lst_, \ ins_]\  := \ 
      Module[{pst = 
            Flatten[Position[ins, \ 
                Indeterminate]]}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ Return[
          Table[lst[\([pst[\([i]\)]]\)], {i, 
              Length[pst]}]]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ ]\)], "Input",
  CellLabel->"In[5]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Saves the list LST as a 3D .DAT file", "Text"],

Cell[BoxData[
    \(SaveDat[lst_, \ fname_]\  := \ 
      Module[{}, \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
Put[Length[lst], \ 
          fname]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ LTC3D = 
          Map[To3D, 
            lst]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ tosave = 
          PaddedForm[
            TableForm[Chop[LTC3D, 0.00001], TableSpacing \[Rule] {0, 2}], {7, 
              6}]; \[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ PutAppend[OutputForm[tosave], \ 
          fname]\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ ]\)], "Input",
  CellLabel->"In[6]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Star vectors. Equivalent to \"basis vectors\" in a crystal.", "Section",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[{
    \(\(e[1]\  = \ {1, 0};\)\), "\[IndentingNewLine]", 
    \(\(e[2]\  = \ {Cos[2\ \[Pi]/5], 
          Sin[2\ \[Pi]/5]};\)\), "\[IndentingNewLine]", 
    \(\(e[3]\  = \ {Cos[4\ \[Pi]/5], 
          Sin[4\ \[Pi]/5]};\)\), "\[IndentingNewLine]", 
    \(\(e[4]\  = \ {Cos[6\ \[Pi]/5], 
          Sin[6\ \[Pi]/5]};\)\), "\[IndentingNewLine]", 
    \(\(e[5]\  = \ {Cos[8\ \[Pi]/5], 
          Sin[8\ \[Pi]/5]};\)\), "\[IndentingNewLine]", 
    \(\(star\  = \ {e[1], \ e[2], \ e[3], \ e[4], \ e[5]};\)\)}], "Input",
  CellLabel->"In[7]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[star, Axes \[Rule] True, Prolog \[Rule] PointSize[0.05], 
      PlotRange\  \[Rule] \ {{\(-1.2\), 1.2}, {\(-1.2\), 1.2}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[13]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.416667 0.5 0.416667 [
[.08333 .4875 -6 -9 ]
[.08333 .4875 6 0 ]
[.29167 .4875 -12 -9 ]
[.29167 .4875 12 0 ]
[.70833 .4875 -9 -9 ]
[.70833 .4875 9 0 ]
[.91667 .4875 -3 -9 ]
[.91667 .4875 3 0 ]
[.4875 .08333 -12 -4.5 ]
[.4875 .08333 0 4.5 ]
[.4875 .29167 -24 -4.5 ]
[.4875 .29167 0 4.5 ]
[.4875 .70833 -18 -4.5 ]
[.4875 .70833 0 4.5 ]
[.4875 .91667 -6 -4.5 ]
[.4875 .91667 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 .5 m
.08333 .50625 L
s
[(-1)] .08333 .4875 0 1 Mshowa
.29167 .5 m
.29167 .50625 L
s
[(-0.5)] .29167 .4875 0 1 Mshowa
.70833 .5 m
.70833 .50625 L
s
[(0.5)] .70833 .4875 0 1 Mshowa
.91667 .5 m
.91667 .50625 L
s
[(1)] .91667 .4875 0 1 Mshowa
.125 Mabswid
.125 .5 m
.125 .50375 L
s
.16667 .5 m
.16667 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.33333 .5 m
.33333 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.66667 .5 m
.66667 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.83333 .5 m
.83333 .50375 L
s
.875 .5 m
.875 .50375 L
s
.04167 .5 m
.04167 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 .08333 m
.50625 .08333 L
s
[(-1)] .4875 .08333 1 0 Mshowa
.5 .29167 m
.50625 .29167 L
s
[(-0.5)] .4875 .29167 1 0 Mshowa
.5 .70833 m
.50625 .70833 L
s
[(0.5)] .4875 .70833 1 0 Mshowa
.5 .91667 m
.50625 .91667 L
s
[(1)] .4875 .91667 1 0 Mshowa
.125 Mabswid
.5 .125 m
.50375 .125 L
s
.5 .16667 m
.50375 .16667 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .33333 m
.50375 .33333 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .66667 m
.50375 .66667 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .83333 m
.50375 .83333 L
s
.5 .875 m
.50375 .875 L
s
.5 .04167 m
.50375 .04167 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.91667 .5 Mdot
.62876 .89627 Mdot
.16291 .74491 Mdot
.16291 .25509 Mdot
.62876 .10373 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oS`3oool0
0`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000
oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?oo
o`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?oo
o`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`00
0000oooo0?ooo`2>0?ooo`00S`3oool2000008l0oooo002?0?ooo`030000003oool0oooo08h0oooo
002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?oo
o`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000
003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0
oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo00260?ooo`D00000103oool00`000000
oooo0?ooo`2>0?ooo`00R03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08h0oooo
00280?ooo`030000003oool0oooo00@0oooo0`00000O0?ooo`H00000J@3oool00800oooo10000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07P3oool8000006P0oooo00280?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool:000006L0oooo00270?ooo`80
00001P3oool00`000000oooo0?ooo`0L0?ooo``00000IP3oool008l0oooo00<000000?ooo`3oool0
6`3oool=000006H0oooo002?0?ooo`030000003oool0oooo01/0oooo3P00001U0?ooo`00S`3oool0
0`000000oooo0?ooo`0K0?ooo`h00000I@3oool008l0oooo00<000000?ooo`3oool06`3oool>0000
06D0oooo002?0?ooo`030000003oool0oooo01/0oooo3P00001U0?ooo`00S`3oool00`000000oooo
0?ooo`0K0?ooo`d00000IP3oool008l0oooo00<000000?ooo`3oool0703oool<000006H0oooo002?
0?ooo`030000003oool0oooo01d0oooo2P00001W0?ooo`00S`3oool2000001l0oooo2000001X0?oo
o`00S`3oool00`000000oooo0?ooo`0O0?ooo`H00000J@3oool008l0oooo00<000000?ooo`3oool0
SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool0
08l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo
00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<00000
0?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3o
ool0SP3oool008l0oooo0P00002?0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool0
0`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000
oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?oo
o`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?oo
o`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00S`3oool2000008l0oooo002?0?ooo`030000003oool0oooo
08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo
002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?oo
o`030000003oool0oooo08h0oooo000/0?ooo`H00000G@3oool00`000000oooo0?ooo`2>0?ooo`00
:`3oool8000005`0oooo00<000000?ooo`3oool0SP3oool002X0oooo2P00001K0?ooo`030000003o
ool0oooo08h0oooo000Y0?ooo``00000FP3oool00`000000oooo0?ooo`2>0?ooo`00:03oool=0000
05X0oooo00<000000?ooo`3oool0SP3oool002P0oooo3P00001I0?ooo`800000S`3oool002P0oooo
3P00001I0?ooo`030000003oool0oooo08h0oooo000X0?ooo`h00000F@3oool00`000000oooo0?oo
o`2>0?ooo`00:03oool>000005T0oooo00<000000?ooo`3oool0SP3oool002P0oooo3@00001J0?oo
o`030000003oool0oooo08h0oooo000Y0?ooo``00000FP3oool00`000000oooo0?ooo`2>0?ooo`00
:P3oool:000005/0oooo00<000000?ooo`3oool0SP3oool002/0oooo2000001L0?ooo`030000003o
ool0oooo08h0oooo000/0?ooo`H00000G@3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`00
0000oooo0?ooo`2>0?ooo`00N`3oool2000000@0oooo0P0000040?ooo`8000001P3oool00`000000
oooo0?ooo`2>0?ooo`00NP3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0SP3oool007X0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`030?ooo`<00000SP3oool007@0oooo100000020?ooo`040000003oool0oooo0000
00T0oooo0P0000060?ooo`030000003oool0oooo08h0oooo001j0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2>0?ooo`00N`3oool2000000X0
oooo0`0000050?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo
002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?oo
o`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000
003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0
oooo08h0oooo002?0?ooo`800000S`3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo
00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<00000
0?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3o
ool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3o
ool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0
oooo00<000000?ooo`3oool0SP3oool008l0oooo0P00002?0?ooo`00S`3oool00`000000oooo0?oo
o`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?oo
o`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`00
0000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo
0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool2000008l0oooo002?0?oo
o`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000
003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0
oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0
oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?
0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo000H0?ooo`D0
0000<P3oool2000000@0oooo0P0000040?ooo`800000<P3oool2000003<0oooo0P0000040?ooo`80
0000103oool2000003<0oooo1@00000F0?ooo`006P3oool00`000000oooo0?ooo`0a0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000<@3oool00`000000oooo0?ooo`0a0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000=03oool00`000000oooo0?oo
o`0F0?ooo`006P3oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0F0?ooo`004P3oool4000000@0oooo00<0
00000?ooo`3oool0:`3oool400000080oooo00@000000?ooo`3oool000002@3oool200000380oooo
00<000000?ooo`3oool0<@3oool010000000oooo0?ooo`0000090?ooo`800000=@3oool00`000000
oooo0?ooo`0F0?ooo`006P3oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0F0?ooo`006@3oool2000003@0
oooo0P00000:0?ooo`<00000<@3oool00`000000oooo0?ooo`0b0?ooo`8000002P3oool3000003<0
oooo0P00000H0?ooo`00S`3oool00`000000oooo0?ooo`1b0?ooo`H000005P3oool008l0oooo00<0
00000?ooo`3oool0L@3oool8000001D0oooo002?0?ooo`030000003oool0oooo0700oooo2P00000D
0?ooo`00S`3oool00`000000oooo0?ooo`1_0?ooo``000004`3oool008l0oooo00<000000?ooo`3o
ool0KP3oool=000001<0oooo002?0?ooo`030000003oool0oooo06h0oooo3P00000B0?ooo`00o`00
000Q000000002`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00P3oool>000000D0oooo00<000000?ooo`3oool02P3oool001L0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0<P3oool>00000180oooo002?0?ooo`030000003oool0oooo06h0oooo3@00000C0?ooo`00
S`3oool00`000000oooo0?ooo`1_0?ooo``000004`3oool008l0oooo00<000000?ooo`3oool0L03o
ool:000001@0oooo002?0?ooo`030000003oool0oooo0740oooo2000000E0?ooo`00S`3oool00`00
0000oooo0?ooo`1b0?ooo`H000005P3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo
00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<00000
0?ooo`3oool0SP3oool008l0oooo0P00002?0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00
S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool0
0`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000
oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?oo
o`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?oo
o`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool2000008l0oooo002?0?ooo`030000003o
ool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo
08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo
002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?oo
o`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000
003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`800000S`3oool0
08l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo
00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<00000
0?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3o
ool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3o
ool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0
oooo0P00002?0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?oo
o`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?oo
o`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`00
0000oooo0?ooo`2>0?ooo`00N`3oool2000000@0oooo0P0000040?ooo`8000001P3oool00`000000
oooo0?ooo`2>0?ooo`00NP3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0SP3oool007X0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`030?ooo`<00000SP3oool007X0oooo00@000000?ooo`3oool000002@3oool20000
00H0oooo00<000000?ooo`3oool0SP3oool007X0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo08h0oooo001k0?ooo`8000002P3oool3000000D0
oooo00<000000?ooo`3oool0SP3oool002`0oooo1P00001M0?ooo`030000003oool0oooo08h0oooo
000[0?ooo`P00000G03oool00`000000oooo0?ooo`2>0?ooo`00:P3oool:000005/0oooo00<00000
0?ooo`3oool0SP3oool002T0oooo3000001J0?ooo`030000003oool0oooo08h0oooo000X0?ooo`d0
0000FP3oool00`000000oooo0?ooo`2>0?ooo`00:03oool>000005T0oooo00<000000?ooo`3oool0
SP3oool002P0oooo3P00001I0?ooo`030000003oool0oooo08h0oooo000X0?ooo`h00000F@3oool0
0`000000oooo0?ooo`2>0?ooo`00:03oool>000005T0oooo0P00002?0?ooo`00:03oool=000005X0
oooo00<000000?ooo`3oool0SP3oool002T0oooo3000001J0?ooo`030000003oool0oooo08h0oooo
000Z0?ooo`X00000F`3oool00`000000oooo0?ooo`2>0?ooo`00:`3oool8000005`0oooo00<00000
0?ooo`3oool0SP3oool002`0oooo1P00001M0?ooo`030000003oool0oooo08h0oooo002?0?ooo`03
0000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003o
ool0oooo08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`030000003oool0oooo
08h0oooo002?0?ooo`030000003oool0oooo08h0oooo002?0?ooo`800000S`3oool008l0oooo00<0
00000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?oo
o`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0
SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool0
08l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo
00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo0P00002?
0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00
S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool0
0`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000
oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?oo
o`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`0O0?oo
o`H00000J@3oool008l0oooo0P00000O0?ooo`P00000J03oool008l0oooo00<000000?ooo`3oool0
7@3oool:000006L0oooo002?0?ooo`030000003oool0oooo01`0oooo3000001V0?ooo`00S`3oool0
0`000000oooo0?ooo`0K0?ooo`d00000IP3oool008l0oooo00<000000?ooo`3oool06`3oool>0000
06D0oooo002?0?ooo`030000003oool0oooo01/0oooo3P00001U0?ooo`00S`3oool00`000000oooo
0?ooo`0K0?ooo`h00000I@3oool008l0oooo00<000000?ooo`3oool06`3oool>000006D0oooo002?
0?ooo`030000003oool0oooo01/0oooo3@00001V0?ooo`00S`3oool00`000000oooo0?ooo`0L0?oo
o``00000IP3oool008H0oooo1@0000040?ooo`030000003oool0oooo01d0oooo2P00001W0?ooo`00
R03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01h0oooo2000001X0?ooo`00R03o
ool00`000000oooo0?ooo`040?ooo`<000007`3oool6000006T0oooo00280?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0SP3oool008P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2>0?ooo`00Q`3oool2000000H0oooo00<000000?ooo`3oool0SP3oool008l0oooo
00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<00000
0?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3o
ool0SP3oool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo00<000000?ooo`3oool0SP3o
ool008l0oooo00<000000?ooo`3oool0SP3oool008l0oooo0P00002?0?ooo`00S`3oool00`000000
oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?oo
o`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?oo
o`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3o
ool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00S`3oool00`00
0000oooo0?ooo`2>0?ooo`00S`3oool00`000000oooo0?ooo`2>0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.20001, -1.20001, 0.00836245, \
0.00836245}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell[BoxData[
    \(\(a = 
        FullSimplify[Table[Det[{e[m], e[n]}], {m, 5}, {n, 5}]];\)\)], "Input",\

  CellLabel->"In[14]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[%]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              "0", \(1\/2\ \@\(1\/2\ \((5 + \@5)\)\)\), \(\@\(5\/8 - \@5\/8\)\
\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 - \@5)\)\)\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \
\((5 + \@5)\)\)\)},
            {\(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 + \@5)\)\)\), 
              "0", \(1\/2\ \@\(1\/2\ \((5 + \@5)\)\)\), \(\@\(5\/8 - \@5\/8\)\
\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 - \@5)\)\)\)},
            {\(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 - \@5)\)\)\), \(\(-\(1\/2\)\)\ \
\@\(1\/2\ \((5 + \@5)\)\)\), 
              "0", \(1\/2\ \@\(1\/2\ \((5 + \@5)\)\)\), \(\@\(5\/8 - \@5\/8\)\
\)},
            {\(\@\(5\/8 - \@5\/8\)\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 - \
\@5)\)\)\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 + \@5)\)\)\), 
              "0", \(1\/2\ \@\(1\/2\ \((5 + \@5)\)\)\)},
            {\(1\/2\ \@\(1\/2\ \((5 + \@5)\)\)\), \(\@\(5\/8 - \@5\/8\)\), \(\
\(-\(1\/2\)\)\ \@\(1\/2\ \((5 - \@5)\)\)\), \(\(-\(1\/2\)\)\ \@\(1\/2\ \((5 + \
\@5)\)\)\), "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[15]//MatrixForm="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The tiling", "Subtitle",
  Background->RGBColor[1, 0, 1]],

Cell[CellGroupData[{

Cell["Formulae for the quasilattice.", "Text",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(In\ my\ \(notes : \ 
          e\_k\%\[VerticalSeparator]\) = \ \((e\_k\%y, \ \(-e\_k\%x\))\), 
    e\_j\%\(\('\)\(\[VerticalSeparator]\)\) = \ \(\((\(-e\_j\%y\), \ 
              e\_j\%x)\) . \ 
            In\ the\ paper\ the\ notation\ was\ changed\ to\ b\_jl = \ \(e\_k\
\%\[VerticalSeparator] . 
            e\_l = \(epk[k] . 
                e[l]\ and\ b\_kl = \ \
\(e\_j\%\(\('\)\(\[VerticalSeparator]\)\) . e\_l = 
              epj[j] . e[l]\)\)\)\)\)], "DisplayFormula"],

Cell[BoxData[{
    \(epk[
        k_] := {\(e[
            k]\)[\([2]\)], \(-\(e[k]\)[\([1]\)]\)}\), "\[IndentingNewLine]", 
    \(epj[j_] := {\(-\(e[j]\)[\([2]\)]\), \(e[j]\)[\([1]\)]}\)}], "Input",
  CellLabel->"In[357]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equation (5) Acta. Cryst.:", "Text"],

Cell[BoxData[{
    \(xns[m_, s_]\  := \ 
      m\  + \ \ \[Alpha][\([s]\)]\ \), "\[IndentingNewLine]", 
    \(Myfrac[x_] := x - Floor[x]\)}], "Input",
  CellLabel->"In[359]:="],

Cell[CellGroupData[{

Cell["Gerardo's correction", "Text"],

Cell[BoxData[
    \(oldU[j_, \ k_, \ l_, \ m_, \ 
        n_, \ \[Alpha]_\ ] := \ \ \((xns[m, 
              j]\ epk[k] . e[l]\/a[\([j, k]\)]\  + \ 
          xns[n, k]\ epj[j] . e[l]\/a[\([j, k]\)]\  - \ \[Alpha][\([l]\)]\ \
)\)\)], "Input",
  CellLabel->"In[361]:="]
}, Open  ]],

Cell[BoxData[
    \(L[j_, \ k_, \ m_, \ n_, \ \ \[Alpha]_]\  := \ 
      m\ e[j]\  + \ 
        n\ e[k]\  + \ \[Sum]\+\(l = 1\)\%5 
            If[\((l != j)\) && \((l != 
                  k)\), \((Floor[oldU[j, k, l, m, n, \[Alpha]]] + 1)\)\ \ e[
                l], 0]\)], "Input",
  CellLabel->"In[362]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[AliasDelimiter]\)], "Input",
  CellLabel->"In[363]:="],

Cell[BoxData[
    \(\[AliasDelimiter]\)], "Output",
  CellLabel->"Out[363]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Parameters:\nThe following parameters control the local isomorphism class \
and the origin of the tiling. Please, refer to the original article by Naumis \
and Arag\[OAcute]n,",
  StyleBox[", ",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox["\[OpenCurlyDoubleQuote]Analytic expressions for the vertex \
coordinates of quasiperiodic lattices\[CloseCurlyDoubleQuote], ",
    FontSize->14],
  StyleBox["Z.  Kristallogr.",
    FontSize->14,
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSize->14],
  StyleBox["218",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox[", 397 (2003), ",
    FontSize->14],
  "or Levine and Steindhardt, Phys. Rev. B34, 596 (1986).\n\[Alpha] controls \
the origin of each grid. To avoid singularities, all entries must be \
different (see what happen for the singular case \[Alpha] =(0,0,0,0,0)).\n\
\[Beta] determines the local  isomorphism class. The default value is set to \
obtain the Penrose isomorphism class.\n\[Sigma] and \[Rho] are only used in \
the most sophisticated case of quasiperiodic grids. It is not used for this \
program; this is just a remanent of the more general case (see the \
corresponding software in our web page), which produces weird lattices.\nNp \
is the number of grids used. If one needs big tilings, one must modify this \
number to have vertex for very big radius.\nBUG of the program: if you change \
the parameters, please quit ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and run the program again!."
}], "Text",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[{
    \(\(\[Alpha]\  = \ {\(-0.01\), 0.01, \(-0.05\), 0.05, 
          0.0};\)\), "\[IndentingNewLine]", 
    \(\(Np\  = \ 5;\)\)}], "Input",
  CellLabel->"In[364]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lattices\ of\ t\^0\)], "Text"],

Cell[BoxData[{
    \(\(QL021 = \ 
        Flatten[Table[
            L[2, 1, m, \ n, \ \[Alpha]], {m, \(-Np\), Np}, {n, \(-Np\), Np}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL031 = \ 
        Flatten[Table[
            L[3, 1, m, \ n, \ \[Alpha]], {m, \(-Np\), Np}, {n, \(-Np\), Np}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL032 = \ 
        Flatten[Table[
            L[3, 2, m, \ n, \ \[Alpha]], {m, \(-Np\), Np}, {n, \(-Np\), Np}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL041 = \ 
        Flatten[Table[
            L[4, 1, m, \ n, \ \[Alpha]], {m, \(-Np\), Np}, {n, \(-Np\), Np}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL042 = \ 
        Flatten[Table[
            L[4, 2, m, \ n, \ \[Alpha]], {m, \(-Np\), Np}, {n, \(-Np\), Np}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL043 = \ 
        Flatten[Table[
            L[4, 3, m, \ n, \ \[Alpha]], {m, \(-Np\), Np}, {n, \(-Np\), Np}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL051 = \ 
        Flatten[Table[
            L[5, 1, m, \ n, \ \[Alpha]], {m, \(-Np\), Np}, {n, \(-Np\), Np}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL052 = \ 
        Flatten[Table[
            L[5, 2, m, \ n, \ \[Alpha]], {m, \(-Np\), Np}, {n, \(-Np\), Np}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL053 = \ 
        Flatten[Table[
            L[5, 3, m, \ n, \ \[Alpha]], {m, \(-Np\), Np}, {n, \(-Np\), Np}], 
          1];\)\), "\[IndentingNewLine]", 
    \(\(QL054 = \ 
        Flatten[Table[
            L[5, 4, m, \ n, \ \[Alpha]], {m, \(-Np\), Np}, {n, \(-Np\), Np}], 
          1];\)\)}], "Input",
  CellLabel->"In[366]:="]
}, Open  ]],

Cell[BoxData[
    \(\(QL0 = 
        Union[QL021, QL031, QL032, QL041, QL042, QL043, \ QL051, \ QL052, 
          QL053, QL054];\)\)], "Input",
  CellLabel->"In[376]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(f2 = 
      ListPlot[SphericalCut[N[QL0], 10], Axes \[Rule] True, 
        Prolog \[Rule] AbsolutePointSize[10.5], 
        AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[377]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00684 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.48751 0.0499615 0.503419 0.0499615 [
[.2377 .49092 -6 -9 ]
[.2377 .49092 6 0 ]
[.73732 .49092 -3 -9 ]
[.73732 .49092 3 0 ]
[.98712 .49092 -6 -9 ]
[.98712 .49092 6 0 ]
[.47501 .0038 -18 -4.5 ]
[.47501 .0038 0 4.5 ]
[.47501 .25361 -12 -4.5 ]
[.47501 .25361 0 4.5 ]
[.47501 .75323 -6 -4.5 ]
[.47501 .75323 0 4.5 ]
[.47501 1.00303 -12 -4.5 ]
[.47501 1.00303 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.00684 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2377 .50342 m
.2377 .50967 L
s
[(-5)] .2377 .49092 0 1 Mshowa
.73732 .50342 m
.73732 .50967 L
s
[(5)] .73732 .49092 0 1 Mshowa
.98712 .50342 m
.98712 .50967 L
s
[(10)] .98712 .49092 0 1 Mshowa
.125 Mabswid
.03786 .50342 m
.03786 .50717 L
s
.08782 .50342 m
.08782 .50717 L
s
.13778 .50342 m
.13778 .50717 L
s
.18774 .50342 m
.18774 .50717 L
s
.28766 .50342 m
.28766 .50717 L
s
.33763 .50342 m
.33763 .50717 L
s
.38759 .50342 m
.38759 .50717 L
s
.43755 .50342 m
.43755 .50717 L
s
.53747 .50342 m
.53747 .50717 L
s
.58743 .50342 m
.58743 .50717 L
s
.63739 .50342 m
.63739 .50717 L
s
.68736 .50342 m
.68736 .50717 L
s
.78728 .50342 m
.78728 .50717 L
s
.83724 .50342 m
.83724 .50717 L
s
.8872 .50342 m
.8872 .50717 L
s
.93716 .50342 m
.93716 .50717 L
s
.25 Mabswid
0 .50342 m
1 .50342 L
s
.48751 .0038 m
.49376 .0038 L
s
[(-10)] .47501 .0038 1 0 Mshowa
.48751 .25361 m
.49376 .25361 L
s
[(-5)] .47501 .25361 1 0 Mshowa
.48751 .75323 m
.49376 .75323 L
s
[(5)] .47501 .75323 1 0 Mshowa
.48751 1.00303 m
.49376 1.00303 L
s
[(10)] .47501 1.00303 1 0 Mshowa
.125 Mabswid
.48751 .05377 m
.49126 .05377 L
s
.48751 .10373 m
.49126 .10373 L
s
.48751 .15369 m
.49126 .15369 L
s
.48751 .20365 m
.49126 .20365 L
s
.48751 .30357 m
.49126 .30357 L
s
.48751 .35353 m
.49126 .35353 L
s
.48751 .4035 m
.49126 .4035 L
s
.48751 .45346 m
.49126 .45346 L
s
.48751 .55338 m
.49126 .55338 L
s
.48751 .60334 m
.49126 .60334 L
s
.48751 .6533 m
.49126 .6533 L
s
.48751 .70326 m
.49126 .70326 L
s
.48751 .80319 m
.49126 .80319 L
s
.48751 .85315 m
.49126 .85315 L
s
.48751 .90311 m
.49126 .90311 L
s
.48751 .95307 m
.49126 .95307 L
s
.25 Mabswid
.48751 0 m
.48751 1.00684 L
s
0 0 m
1 0 L
1 1.00684 L
0 1.00684 L
closepath
clip
newpath
10.5 Mabswid
.22591 .10086 Mdot
.22591 .90598 Mdot
.22591 .50342 Mdot
.44709 .53279 Mdot
.40667 .50342 Mdot
.49705 .53279 Mdot
.35671 .50342 Mdot
.31629 .47405 Mdot
.31629 .53279 Mdot
.31629 .13022 Mdot
.31629 .87662 Mdot
.21047 .4559 Mdot
.21047 .55093 Mdot
.21047 .85847 Mdot
.26043 .4559 Mdot
.26043 .2071 Mdot
.26043 .14837 Mdot
.26043 .85847 Mdot
.21047 .4559 Mdot
.21047 .55093 Mdot
.26043 .55093 Mdot
.75501 .17774 Mdot
.75501 .8291 Mdot
.12009 .17774 Mdot
.12009 .8291 Mdot
.17005 .17774 Mdot
.17005 .8291 Mdot
.07967 .39717 Mdot
.07967 .60967 Mdot
.30085 .17774 Mdot
.30085 .5803 Mdot
.30085 .8291 Mdot
.12009 .42654 Mdot
.12009 .5803 Mdot
.17005 .42654 Mdot
.17005 .5803 Mdot
.07967 .4559 Mdot
.07967 .55093 Mdot
.73957 .13022 Mdot
.78953 .13022 Mdot
.78953 .87662 Mdot
.06423 .65718 Mdot
.06423 .25462 Mdot
.06423 .75222 Mdot
.02381 .47405 Mdot
.02381 .53279 Mdot
.02381 .37902 Mdot
.02381 .62782 Mdot
.06423 .50342 Mdot
.55291 .4559 Mdot
.55291 .55093 Mdot
.46253 .42654 Mdot
.46253 .48527 Mdot
.46253 .5803 Mdot
.37215 .4559 Mdot
.22591 .40839 Mdot
.22591 .34965 Mdot
.22591 .65718 Mdot
.44709 .37902 Mdot
.44709 .62782 Mdot
.49705 .37902 Mdot
.49705 .62782 Mdot
.35671 .65718 Mdot
.40667 .40839 Mdot
.40667 .34965 Mdot
.40667 .65718 Mdot
.31629 .37902 Mdot
.31629 .62782 Mdot
.13553 .37902 Mdot
.21047 .30214 Mdot
.21047 .7047 Mdot
.26043 .30214 Mdot
.26043 .7047 Mdot
.21047 .30214 Mdot
.21047 .7047 Mdot
.17005 .27277 Mdot
.17005 .73407 Mdot
.07967 .30214 Mdot
.07967 .7047 Mdot
.17005 .3315 Mdot
.17005 .67533 Mdot
.82995 .50342 Mdot
.87991 .50342 Mdot
.46253 .3315 Mdot
.46253 .67533 Mdot
.37215 .30214 Mdot
.37215 .7047 Mdot
.22591 .25462 Mdot
.22591 .75222 Mdot
.35671 .25462 Mdot
.35671 .75222 Mdot
.40667 .25462 Mdot
.40667 .75222 Mdot
.31629 .22525 Mdot
.31629 .28399 Mdot
.31629 .78158 Mdot
.84539 .4559 Mdot
.84539 .55093 Mdot
.97619 .4559 Mdot
.97619 .55093 Mdot
.73957 .22525 Mdot
.73957 .78158 Mdot
.78953 .22525 Mdot
.78953 .78158 Mdot
.31629 .07149 Mdot
.31629 .93535 Mdot
.44709 .13022 Mdot
.44709 .87662 Mdot
.49705 .13022 Mdot
.49705 .87662 Mdot
.35671 .10086 Mdot
.35671 .90598 Mdot
.40667 .10086 Mdot
.40667 .90598 Mdot
.84539 .2071 Mdot
.84539 .79973 Mdot
.59333 .02397 Mdot
.59333 .98287 Mdot
.46253 .08271 Mdot
.46253 .92413 Mdot
.37215 .05334 Mdot
.37215 .9535 Mdot
.59333 .42654 Mdot
.59333 .5803 Mdot
.64329 .42654 Mdot
.64329 .5803 Mdot
.55291 .60967 Mdot
.60877 .53279 Mdot
.60877 .37902 Mdot
.60877 .62782 Mdot
.82995 .34965 Mdot
.82995 .65718 Mdot
.87991 .34965 Mdot
.87991 .65718 Mdot
.59333 .3315 Mdot
.64329 .3315 Mdot
.64329 .67533 Mdot
.55291 .30214 Mdot
.55291 .7047 Mdot
.46253 .27277 Mdot
.46253 .73407 Mdot
.44709 .22525 Mdot
.44709 .78158 Mdot
.49705 .22525 Mdot
.49705 .78158 Mdot
.84539 .30214 Mdot
.84539 .60967 Mdot
.84539 .7047 Mdot
.82995 .25462 Mdot
.82995 .75222 Mdot
.87991 .25462 Mdot
.87991 .75222 Mdot
.55291 .2071 Mdot
.55291 .79973 Mdot
.46253 .17774 Mdot
.46253 .8291 Mdot
.69915 .10086 Mdot
.69915 .90598 Mdot
.60877 .13022 Mdot
.60877 .87662 Mdot
.68371 .05334 Mdot
.68371 .9535 Mdot
.55291 .05334 Mdot
.55291 .9535 Mdot
.46253 .02397 Mdot
.46253 .98287 Mdot
.68371 .4559 Mdot
.69915 .50342 Mdot
.69915 .40839 Mdot
.69915 .59845 Mdot
.69915 .34965 Mdot
.69915 .65718 Mdot
.92033 .37902 Mdot
.68371 .30214 Mdot
.68371 .7047 Mdot
.64329 .73407 Mdot
.93577 .3315 Mdot
.93577 .42654 Mdot
.93577 .5803 Mdot
.93577 .67533 Mdot
.69915 .25462 Mdot
.69915 .75222 Mdot
.69915 .81095 Mdot
.60877 .22525 Mdot
.60877 .78158 Mdot
.59333 .17774 Mdot
.59333 .8291 Mdot
.64329 .17774 Mdot
.64329 .8291 Mdot
.55291 .14837 Mdot
.55291 .85847 Mdot
.73957 .37902 Mdot
.73957 .62782 Mdot
.78953 .47405 Mdot
.78953 .53279 Mdot
.78953 .37902 Mdot
.78953 .62782 Mdot
.75501 .5803 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[377]:=",
  ImageSize->{288, 289.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00018B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00O03oool500000080oooo0P00002K0?ooo`00OP3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2C0?ooo`00
OP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3000009<0
oooo001f0?ooo`@00000103oool010000000oooo0?ooo`3oool4000000@0oooo00<000000?ooo`3o
ool06P3oool2000007L0oooo001n0?ooo`030000003oool0oooo00H000000`3oool00`000000oooo
0?ooo`0H0?ooo`H00000M@3oool007d0oooo0P0000000`3oool000000000000600000080oooo00<0
00000?ooo`3oool05`3oool8000007@0oooo00200?ooo`P000000P3oool00`000000oooo0?ooo`0G
0?ooo`P00000M03oool007l0oooo2P0000000`3oool000000?ooo`0G0?ooo`X00000L`3oool007l0
oooo2P0000000`3oool000000?ooo`0G0?ooo`X00000L`3oool00800oooo200000020?ooo`030000
003oool0oooo01L0oooo2000001d0?ooo`00P03oool800000080oooo00<000000?ooo`3oool05`3o
ool8000007@0oooo00210?ooo`H000000`3oool00`000000oooo0?ooo`0H0?ooo`H00000M@3oool0
06T0oooo0P00000H0?ooo`8000001@3oool00`000000oooo0?ooo`0?0?ooo`8000002@3oool20000
01P0oooo0P00001M0?ooo`00I`3oool6000001d0oooo00<000000?ooo`3oool03@3oool6000001l0
oooo1P00001K0?ooo`00IP3oool8000001`0oooo00<000000?ooo`3oool0303oool8000001d0oooo
2000001J0?ooo`00IP3oool8000001`0oooo00<000000?ooo`3oool0303oool8000001d0oooo2000
001J0?ooo`00I@3oool:000001/0oooo0P00000<0?ooo`X000006`3oool:000005T0oooo001J0?oo
o`8000002@3oool:000001/0oooo00<000000?ooo`3oool02`3oool:000001/0oooo2P00001I0?oo
o`00F03oool6000000P0oooo2000000L0?ooo`030000003oool0oooo00`0oooo2000000M0?ooo`P0
0000FP3oool005L0oooo200000070?ooo`P00000703oool00`000000oooo0?ooo`0<0?ooo`P00000
7@3oool8000005X0oooo001G0?ooo`P00000203oool6000001H0oooo0P0000050?ooo`030000003o
ool0oooo00d0oooo1P00000O0?ooo`H00000F`3oool005H0oooo2P0000090?ooo`8000005P3oool6
000000<0oooo00<000000?ooo`3oool03`3oool2000002<0oooo0P00001M0?ooo`00EP3oool:0000
0200oooo200000020?ooo`030000003oool0oooo09<0oooo001G0?ooo`P000008@3oool800000080
oooo00<000000?ooo`3oool0T`3oool005L0oooo2000000P0?ooo`X0000000<0oooo0000003oool0
U03oool00400oooo0P00000F0?ooo`H000001`3oool2000000`0oooo0P00000:0?ooo`X0000000<0
oooo0000003oool0>@3oool2000005T0oooo000n0?ooo`H000005P3oool2000000L0oooo1P000008
0?ooo`H000002@3oool800000080oooo00<000000?ooo`3oool0=P3oool6000005L0oooo000m0?oo
o`P000007@3oool8000000H0oooo200000080?ooo`P000000P3oool00`000000oooo0?ooo`0e0?oo
o`P00000EP3oool003d0oooo2000000M0?ooo`P000001P3oool8000000T0oooo1P0000030?ooo`03
0000003oool0oooo03D0oooo2000001F0?ooo`00?03oool:000001/0oooo2P0000040?ooo`X00000
2P3oool2000000D0oooo00<000000?ooo`3oool0=03oool:000005D0oooo000l0?ooo`X000006`3o
ool:000000@0oooo2P00000A0?ooo`800000=@3oool:000005D0oooo000m0?ooo`P000007@3oool8
000000H0oooo2000000B0?ooo`030000003oool0oooo03D0oooo2000001F0?ooo`00?@3oool80000
01d0oooo200000060?ooo`P000004P3oool00`000000oooo0?ooo`0e0?ooo`P00000EP3oool003h0
oooo1P00000F0?ooo`8000001`3oool6000000P0oooo1P0000070?ooo`8000002P3oool010000000
oooo00000000000N0?ooo`8000005@3oool6000000L0oooo0P00000<0?ooo`800000@03oool00400
oooo0P00000F0?ooo`H000001`3oool2000000`0oooo0P0000070?ooo`H00000203oool6000001X0
oooo1P00000E0?ooo`8000001`3oool6000000P0oooo1P00000n0?ooo`00E`3oool8000001`0oooo
200000060?ooo`P00000603oool8000001`0oooo200000060?ooo`P00000?@3oool005L0oooo2000
000L0?ooo`P000001P3oool8000001P0oooo2000000L0?ooo`P000001P3oool8000003d0oooo001F
0?ooo`X000006P3oool:000000@0oooo2P00000F0?ooo`X000006P3oool:000000@0oooo2P00000l
0?ooo`00BP3oool2000000X0oooo2P00000J0?ooo`X00000103oool:000000X0oooo0P00000:0?oo
o`X000006P3oool:000000@0oooo2P00000l0?ooo`00B03oool6000000T0oooo2000000L0?ooo`P0
00001P3oool8000000T0oooo1P0000090?ooo`P00000703oool8000000H0oooo2000000m0?ooo`00
A`3oool8000000P0oooo2000000L0?ooo`P000001P3oool8000000P0oooo200000080?ooo`P00000
703oool8000000H0oooo2000000m0?ooo`00A`3oool8000000T0oooo1P00000N0?ooo`H00000203o
ool6000000T0oooo200000090?ooo`H000007P3oool6000000P0oooo1P00000n0?ooo`00AP3oool:
000000X0oooo0P00000R0?ooo`8000002P3oool010000000oooo00000000000:0?ooo`X000002P3o
ool200000280oooo0P00000<0?ooo`800000@03oool004H0oooo2P00000j0?ooo`030000003oool0
oooo00/0oooo2P00001n0?ooo`00A`3oool8000003/0oooo0P00000=0?ooo`P00000O`3oool004L0
oooo2000000k0?ooo`030000003oool0oooo00`0oooo2000001o0?ooo`00B03oool6000003`0oooo
00<000000?ooo`3oool03@3oool600000800oooo000S0?ooo`800000303oool2000001L0oooo0P00
00090?ooo`800000;03oool2000000D0oooo00<000000?ooo`3oool03`3oool2000000T0oooo0P00
000<0?ooo`8000007@3oool2000004X0oooo000Q0?ooo`H00000203oool6000001h0oooo1P00000X
0?ooo`H000000`3oool00`000000oooo0?ooo`0H0?ooo`H00000203oool6000001T0oooo1P000018
0?ooo`00803oool8000000H0oooo2000000L0?ooo`P000009P3oool800000080oooo00<000000?oo
o`3oool05`3oool8000000H0oooo2000000G0?ooo`P00000A`3oool00200oooo200000060?ooo`P0
0000703oool8000002H0oooo200000020?ooo`030000003oool0oooo01L0oooo200000060?ooo`P0
00005`3oool8000004L0oooo000O0?ooo`X00000103oool:000001X0oooo2P00000T0?ooo`X00000
00<0oooo0000003oool05`3oool:000000@0oooo2P00000E0?ooo`X00000AP3oool001l0oooo2P00
00040?ooo`X000006P3oool:000002@0oooo2P0000000`3oool000000?ooo`0G0?ooo`X00000103o
ool:000001D0oooo2P0000160?ooo`00803oool8000000H0oooo2000000L0?ooo`P000009P3oool8
00000080oooo00<000000?ooo`3oool05`3oool8000000H0oooo2000000G0?ooo`P00000A`3oool0
0200oooo200000060?ooo`P00000703oool8000002H0oooo200000020?ooo`030000003oool0oooo
01L0oooo200000060?ooo`P000005`3oool8000004L0oooo000Q0?ooo`H00000203oool6000001D0
oooo0P0000070?ooo`H00000:03oool6000000<0oooo00<000000?ooo`3oool03`3oool2000000L0
oooo1P0000080?ooo`H000006@3oool6000001H0oooo0P00000`0?ooo`008`3oool2000000`0oooo
0P00000E0?ooo`H000001`3oool2000002`0oooo0P0000050?ooo`030000003oool0oooo00d0oooo
1P0000070?ooo`800000303oool2000001d0oooo0P00000F0?ooo`H00000;P3oool004L0oooo2000
000k0?ooo`030000003oool0oooo00`0oooo2000001:0?ooo`P00000;@3oool004L0oooo2000000k
0?ooo`8000003@3oool8000004X0oooo2000000]0?ooo`00AP3oool:000003X0oooo00<000000?oo
o`3oool02`3oool:000004P0oooo2P00000/0?ooo`00AP3oool:000000X0oooo0P00000R0?ooo`80
00002P3oool010000000oooo00000000000:0?ooo`X000002P3oool200000280oooo0P00000<0?oo
o`8000002P3oool:000002`0oooo00170?ooo`P000002@3oool6000001h0oooo1P0000080?ooo`H0
00002@3oool8000000T0oooo1P00000N0?ooo`H00000203oool6000000T0oooo2000000]0?ooo`00
A`3oool8000000P0oooo2000000L0?ooo`P000001P3oool8000000P0oooo200000080?ooo`P00000
703oool8000000H0oooo200000080?ooo`P00000;@3oool004P0oooo1P0000090?ooo`P00000703o
ool8000000H0oooo200000090?ooo`H000002@3oool8000001`0oooo200000060?ooo`P000002@3o
ool6000002h0oooo001:0?ooo`8000002P3oool:000001X0oooo2P0000040?ooo`X000002P3oool2
000000X0oooo2P00000J0?ooo`X00000103oool:000000X0oooo0P00000`0?ooo`00EP3oool:0000
01X0oooo2P0000040?ooo`X000005P3oool:000001X0oooo2P0000040?ooo`X00000?03oool005L0
oooo2000000L0?ooo`P000001P3oool8000001P0oooo2000000L0?ooo`P000001P3oool8000003d0
oooo001G0?ooo`P00000703oool8000000H0oooo2000000H0?ooo`P00000703oool8000000H0oooo
2000000m0?ooo`004`3oool2000002/0oooo0P00000F0?ooo`H000001`3oool2000000`0oooo0P00
00070?ooo`H00000203oool6000001X0oooo1P00000E0?ooo`8000001`3oool6000000P0oooo1P00
00070?ooo`800000303oool2000002L0oooo000A0?ooo`H000009`3oool6000001H0oooo0P000007
0?ooo`H00000203oool6000000L0oooo0P00000:0?ooo`040000003oool00000000001h0oooo0P00
000E0?ooo`H000001`3oool2000000`0oooo0P0000070?ooo`H00000203oool6000002D0oooo000@
0?ooo`P000009@3oool8000001d0oooo200000060?ooo`P000002`3oool2000000D0oooo00<00000
0?ooo`3oool0=@3oool8000001`0oooo200000060?ooo`P00000903oool00100oooo2000000U0?oo
o`P000007@3oool8000000H0oooo2000000:0?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool0=@3oool8000001`0oooo200000060?ooo`P00000903oool000l0oooo2P00000S0?oo
o`X000006`3oool:000000@0oooo2P00000<0?ooo`030000003oool0oooo0080oooo0`00000d0?oo
o`X000006P3oool:000000@0oooo2P00000S0?ooo`003`3oool:000001P0oooo0P0000090?ooo`X0
00006`3oool:000000@0oooo2P0000030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3o
ool0=03oool:000001X0oooo2P0000040?ooo`X000008`3oool00100oooo2000000G0?ooo`H00000
203oool8000001d0oooo200000060?ooo`P000002@3oool6000000<0oooo00<000000?ooo`3oool0
=@3oool8000001`0oooo200000060?ooo`P00000903oool00100oooo2000000F0?ooo`P000001`3o
ool8000001d0oooo200000060?ooo`P00000203oool800000080oooo00<000000?ooo`3oool0=@3o
ool8000001`0oooo200000060?ooo`P00000903oool00140oooo1P00000G0?ooo`P00000203oool6
000001H0oooo0P0000070?ooo`H00000203oool6000000T0oooo200000020?ooo`030000003oool0
oooo03H0oooo1P00000N0?ooo`H00000203oool6000002D0oooo000C0?ooo`800000603oool:0000
00T0oooo0P00000F0?ooo`H000001`3oool2000000`0oooo0P00000:0?ooo`X0000000<0oooo0000
003oool0>@3oool200000280oooo0P00000<0?ooo`8000009`3oool002d0oooo2P00000P0?ooo`P0
0000803oool:000000030?ooo`000000oooo09@0oooo000^0?ooo`P000008@3oool800000240oooo
200000020?ooo`030000003oool0oooo09<0oooo000^0?ooo`P00000803oool:00000200oooo2000
00020?ooo`030000003oool0oooo09<0oooo000G0?ooo`8000005P3oool6000000L0oooo0P00000<
0?ooo`8000002P3oool:000000T0oooo0P00000F0?ooo`H000000`3oool00`000000oooo0?ooo`0?
0?ooo`8000008`3oool2000002/0oooo0P00000`0?ooo`005@3oool6000001H0oooo0P0000070?oo
o`H00000203oool6000000T0oooo200000080?ooo`H000005P3oool2000000D0oooo00<000000?oo
o`3oool03@3oool6000001l0oooo1P00000W0?ooo`H00000;P3oool001@0oooo2000000M0?ooo`P0
00001P3oool8000000P0oooo200000070?ooo`P00000703oool00`000000oooo0?ooo`0<0?ooo`P0
00007@3oool8000002D0oooo2000000]0?ooo`00503oool8000001d0oooo200000060?ooo`P00000
2@3oool6000000P0oooo2000000L0?ooo`030000003oool0oooo00`0oooo2000000M0?ooo`P00000
9@3oool8000002d0oooo000C0?ooo`X000006`3oool:000000@0oooo2P00000:0?ooo`8000002@3o
ool:000001/0oooo00<000000?ooo`3oool02`3oool:000001/0oooo2P00000S0?ooo`X00000;03o
ool001<0oooo2P00000K0?ooo`X00000103oool:000001D0oooo2P00000K0?ooo`800000303oool:
000001/0oooo2P00000S0?ooo`X00000;03oool001@0oooo2000000M0?ooo`P000001P3oool80000
01L0oooo2000000L0?ooo`030000003oool0oooo00`0oooo2000000M0?ooo`P000009@3oool80000
02d0oooo000D0?ooo`P000007@3oool8000000H0oooo2000000G0?ooo`P00000703oool00`000000
oooo0?ooo`0<0?ooo`P000007@3oool8000002D0oooo2000000]0?ooo`005@3oool6000001l0oooo
1P0000080?ooo`H000006@3oool6000001d0oooo00<000000?ooo`3oool03@3oool6000001l0oooo
1P00000W0?ooo`H00000;P3oool001L0oooo0P00000H0?ooo`8000002@3oool2000000`0oooo0P00
000M0?ooo`800000603oool2000000D0oooo00<000000?ooo`3oool03`3oool2000000T0oooo0P00
000<0?ooo`8000002P3oool2000002/0oooo0P00000G0?ooo`8000005`3oool002l0oooo1P00001<
0?ooo`H000000`3oool00`000000oooo0?ooo`0H0?ooo`H00000203oool6000004`0oooo1P00000E
0?ooo`00;P3oool8000004X0oooo200000020?ooo`030000003oool0oooo01L0oooo200000060?oo
o`P00000BP3oool8000001@0oooo000^0?ooo`P00000BP3oool800000080oooo00<000000?ooo`3o
ool05`3oool8000000H0oooo2000001:0?ooo`P00000503oool002d0oooo2P0000180?ooo`X00000
00<0oooo0000003oool05`3oool:000000@0oooo2P0000180?ooo`X000004`3oool002d0oooo2P00
00090?ooo`800000<@3oool2000000X0oooo2P0000000`3oool000000?ooo`0G0?ooo`X00000103o
ool:000000X0oooo0P00000R0?ooo`800000303oool2000000X0oooo2P00000C0?ooo`00;P3oool8
000000P0oooo1P00000]0?ooo`H000002@3oool800000080oooo00<000000?ooo`3oool05`3oool8
000000H0oooo200000090?ooo`H000007P3oool6000000P0oooo1P0000090?ooo`P00000503oool0
02h0oooo200000070?ooo`P00000:`3oool8000000P0oooo200000020?ooo`030000003oool0oooo
01L0oooo200000060?ooo`P00000203oool8000001`0oooo200000060?ooo`P00000203oool80000
01@0oooo000_0?ooo`H00000203oool8000002/0oooo200000090?ooo`H000000`3oool00`000000
oooo0?ooo`0H0?ooo`H00000203oool6000000T0oooo2000000L0?ooo`P000001P3oool8000000T0
oooo1P00000E0?ooo`00<@3oool2000000T0oooo2P00000Y0?ooo`X000002P3oool2000000D0oooo
00<000000?ooo`3oool06P3oool2000000`0oooo0P00000:0?ooo`X000006P3oool:000000@0oooo
2P00000:0?ooo`8000005`3oool003`0oooo2P00000Y0?ooo`X000004@3oool2000003D0oooo2P00
000J0?ooo`X00000103oool:000002<0oooo000m0?ooo`P00000:`3oool800000180oooo00<00000
0?ooo`3oool0=@3oool8000001`0oooo200000060?ooo`P00000903oool003d0oooo2000000[0?oo
o`P000004P3oool00`000000oooo0?ooo`0e0?ooo`P00000703oool8000000H0oooo2000000T0?oo
o`00203oool2000001d0oooo0P00000E0?ooo`H000005P3oool2000001D0oooo1P0000070?ooo`80
00002P3oool010000000oooo00000000000N0?ooo`8000005@3oool6000000L0oooo0P00000<0?oo
o`8000001`3oool6000000P0oooo1P0000080?ooo`8000006`3oool000H0oooo1P00000I0?ooo`H0
00005@3oool2000001H0oooo1P00000E0?ooo`8000001`3oool6000000P0oooo1P00000J0?ooo`H0
00005@3oool2000000L0oooo1P0000080?ooo`H000001`3oool2000000`0oooo0P0000080?ooo`H0
00006@3oool000D0oooo2000000G0?ooo`P00000:`3oool8000001`0oooo200000060?ooo`P00000
603oool8000001`0oooo200000060?ooo`P000007@3oool8000001P0oooo00050?ooo`P000005`3o
ool8000002/0oooo2000000L0?ooo`P000001P3oool8000001P0oooo2000000L0?ooo`P000001P3o
ool8000001d0oooo2000000H0?ooo`00103oool:000001D0oooo2P00000Y0?ooo`X000006P3oool:
000000@0oooo2P00000F0?ooo`X000006P3oool:000000@0oooo2P00000K0?ooo`X000005`3oool0
00@0oooo2P0000090?ooo`8000002P3oool:000002T0oooo2P00000J0?ooo`X00000103oool:0000
01H0oooo2P00000J0?ooo`X00000103oool:000001/0oooo2P00000G0?ooo`001@3oool8000000P0
oooo1P0000090?ooo`P00000:`3oool8000001`0oooo200000060?ooo`P00000603oool8000001`0
oooo200000060?ooo`P000007@3oool8000001P0oooo00050?ooo`P000001`3oool8000000P0oooo
2000000[0?ooo`P00000703oool8000000H0oooo2000000H0?ooo`P00000703oool8000000H0oooo
2000000M0?ooo`P00000603oool000H0oooo1P0000080?ooo`P000002@3oool6000001D0oooo0P00
000F0?ooo`H000005@3oool2000000L0oooo1P0000080?ooo`H000006P3oool6000001D0oooo0P00
00070?ooo`H00000203oool6000001l0oooo1P00000I0?ooo`00203oool2000000T0oooo2P00000:
0?ooo`8000005@3oool6000001H0oooo0P00000E0?ooo`H000001`3oool2000000X0oooo00@00000
0?ooo`00000000007P3oool2000001D0oooo1P0000070?ooo`800000303oool2000002<0oooo0P00
000K0?ooo`004`3oool:00000200oooo2000000[0?ooo`P000004P3oool00`000000oooo0?ooo`0e
0?ooo`P00000EP3oool001@0oooo2000000Q0?ooo`P00000:`3oool800000180oooo0P00000f0?oo
o`P00000EP3oool001@0oooo2000000P0?ooo`X00000:@3oool:00000140oooo00<000000?ooo`3o
ool0=03oool:000005D0oooo000E0?ooo`H00000203oool2000000`0oooo0P0000090?ooo`X00000
:@3oool:000000X0oooo0P0000050?ooo`030000003oool0oooo01X0oooo0P00000<0?ooo`800000
2P3oool:000003`0oooo0P00000G0?ooo`005`3oool2000000P0oooo1P0000080?ooo`H00000203o
ool8000002/0oooo200000090?ooo`H000000`3oool00`000000oooo0?ooo`0H0?ooo`H00000203o
ool6000000T0oooo2000000k0?ooo`H000005@3oool00200oooo200000060?ooo`P000001`3oool8
000002/0oooo200000080?ooo`P000000P3oool00`000000oooo0?ooo`0G0?ooo`P000001P3oool8
000000P0oooo2000000j0?ooo`P00000503oool00200oooo200000060?ooo`P00000203oool60000
02d0oooo1P0000090?ooo`P000000P3oool00`000000oooo0?ooo`0G0?ooo`P000001P3oool80000
00T0oooo1P00000k0?ooo`P00000503oool001l0oooo2P0000040?ooo`X000002@3oool200000340
oooo0P00000:0?ooo`X0000000<0oooo0000003oool05`3oool:000000@0oooo2P00000:0?ooo`80
0000?03oool:000001<0oooo000O0?ooo`X00000103oool:000004P0oooo2P0000000`3oool00000
0?ooo`0G0?ooo`X00000103oool:000004P0oooo2P00000C0?ooo`00803oool8000000H0oooo2000
001:0?ooo`P000000P3oool00`000000oooo0?ooo`0G0?ooo`P000001P3oool8000004X0oooo2000
000D0?ooo`00803oool8000000H0oooo2000001:0?ooo`P000000P3oool00`000000oooo0?ooo`0G
0?ooo`P000001P3oool8000004X0oooo2000000D0?ooo`005`3oool2000000P0oooo1P0000080?oo
o`H000001`3oool2000000`0oooo0P00000M0?ooo`8000005P3oool6000000<0oooo00<000000?oo
o`3oool03`3oool2000000L0oooo1P0000080?ooo`H00000203oool2000002/0oooo0P00000E0?oo
o`H000001`3oool2000000`0oooo000E0?ooo`H00000203oool2000000`0oooo0P0000070?ooo`H0
0000203oool6000001T0oooo1P00000F0?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`H0
00001`3oool2000000`0oooo0P0000080?ooo`H000009`3oool6000001D0oooo0P0000070?ooo`H0
00002P3oool001@0oooo2000000M0?ooo`P000001P3oool8000001L0oooo2000000L0?ooo`030000
003oool0oooo00`0oooo2000000M0?ooo`P000009@3oool8000001`0oooo200000090?ooo`00503o
ool8000001d0oooo200000060?ooo`P000005`3oool8000001`0oooo00<000000?ooo`3oool0303o
ool8000001d0oooo2000000U0?ooo`P00000703oool8000000T0oooo000C0?ooo`X000006`3oool:
000000@0oooo2P00000E0?ooo`X000006`3oool2000000`0oooo2P00000K0?ooo`X000008`3oool:
000001X0oooo2P0000080?ooo`004`3oool:000001/0oooo2P0000040?ooo`X000005@3oool:0000
01/0oooo00<000000?ooo`3oool02`3oool:000001/0oooo2P00000S0?ooo`X000006P3oool:0000
00P0oooo00080?ooo`8000002P3oool8000001d0oooo200000060?ooo`P000002`3oool2000000X0
oooo2000000L0?ooo`030000003oool0oooo00`0oooo2000000M0?ooo`P00000603oool2000000/0
oooo2000000L0?ooo`P000002@3oool000H0oooo1P0000080?ooo`P000007@3oool8000000D0oooo
2@0000090?ooo`H00000203oool8000001`0oooo00<000000?ooo`3oool0303oool8000001d0oooo
200000090?ooo`8000002`3oool6000000T0oooo2000000L0?ooo`P0000000<0oooo000000000000
1P3oool000D0oooo200000080?ooo`H000007`3oool6000000D0oooo00<000000?ooo`3oool01P00
00090?ooo`P00000203oool6000001d0oooo00<000000?ooo`3oool03@3oool6000001l0oooo1P00
00090?ooo`040000003oool0oooo000000T0oooo200000090?ooo`H000007P3oool6000000050?oo
o`000000oooo0?ooo`0000001@3oool000D0oooo2000000:0?ooo`8000008`3oool2000000X0oooo
00@000000?ooo`00000000002`3oool8000000X0oooo0P00000H0?ooo`8000001@3oool00`000000
oooo0?ooo`0?0?ooo`8000008`3oool2000000h0oooo00<000000?ooo`3oool01`3oool8000000/0
oooo0P00000R0?ooo`8000000`3oool010000000oooo0?ooo`0000050?ooo`00103oool:00000340
oooo100000030?ooo`8000003P3oool:00000240oooo1P0000030?ooo`030000003oool0oooo0480
oooo0P0000090?ooo`X00000;`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool00`3oool000@0oooo2P00000h0?ooo`030000003oool0oooo00d0oooo2P00000P0?ooo`P0
00000P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00P0oooo2P00000_0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`001@3oool8000003T0
oooo0`00000>0?ooo`P000008@3oool800000080oooo00<000000?ooo`3oool0@P3oool3000000T0
oooo2000000_0?ooo`800000103oool2000000H0oooo00050?ooo`P00000BP3oool800000200oooo
2P0000000`3oool000000?ooo`1?0?ooo`P00000?@3oool000H0oooo1P0000070?ooo`800000:`3o
ool2000001H0oooo1P0000070?ooo`800000303oool2000000X0oooo2P0000000`3oool000000?oo
o`0i0?ooo`8000005@3oool6000000L0oooo0P00000<0?ooo`8000009`3oool000P0oooo0P000007
0?ooo`H000009`3oool6000001H0oooo0P0000070?ooo`H00000203oool6000000T0oooo20000002
0?ooo`030000003oool0oooo03H0oooo1P00000E0?ooo`8000001`3oool6000000P0oooo1P00000U
0?ooo`00403oool8000002D0oooo2000000M0?ooo`P000001P3oool8000000P0oooo200000020?oo
o`030000003oool0oooo03D0oooo2000000L0?ooo`P000001P3oool8000002@0oooo000@0?ooo`P0
00009@3oool8000001d0oooo200000060?ooo`P000002@3oool6000000<0oooo00<000000?ooo`3o
ool0=@3oool8000001`0oooo200000060?ooo`P00000903oool00080ooooo`00000J000000D0oooo
000<0?ooo`030000003oool0oooo00X0000000<0oooo0000003oool0303oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00<0oooo2P00000<0?ooo`030000003oool0oooo00/0oooo2`00
00030?ooo`/000000`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo2P00
00050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool:000000@0oooo2P00
000;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00100oooo2000000U
0?ooo`P000007@3oool8000000H0oooo2000000B0?ooo`030000003oool0oooo03D0oooo20000006
0?ooo`030000003oool0oooo01<0oooo200000060?ooo`P000006P3oool00`000000oooo0?ooo`07
0?ooo`00403oool8000002D0oooo2000000M0?ooo`P000001P3oool800000180oooo00<000000?oo
o`3oool0=@3oool8000001`0oooo200000060?ooo`P00000903oool000P0oooo0P0000070?ooo`H0
00009`3oool6000001H0oooo0P0000070?ooo`H00000203oool6000000L0oooo0P00000:0?ooo`04
0000003oool00000000001h0oooo0P00000E0?ooo`H000005@3oool2000000L0oooo1P0000080?oo
o`H000009@3oool000H0oooo1P0000070?ooo`800000:`3oool2000001H0oooo1P0000070?ooo`80
0000303oool2000000L0oooo1P0000080?ooo`H000006P3oool6000001D0oooo0P00000E0?ooo`H0
00001`3oool2000000`0oooo0P00000W0?ooo`001@3oool8000004X0oooo2000000L0?ooo`P00000
1P3oool8000001P0oooo2000000Z0?ooo`P00000?@3oool000D0oooo2000001:0?ooo`P00000703o
ool8000000H0oooo2000000H0?ooo`P00000:P3oool8000003d0oooo00040?ooo`X00000B03oool:
000001X0oooo2P0000040?ooo`X000005P3oool:000002P0oooo2P00000l0?ooo`00103oool:0000
00T0oooo0P00000S0?ooo`800000303oool2000000X0oooo2P00000J0?ooo`X00000103oool:0000
00X0oooo0P00000:0?ooo`X00000:03oool:000000X0oooo0P00000R0?ooo`800000303oool000D0
oooo200000080?ooo`H000007`3oool6000000P0oooo1P0000090?ooo`P00000703oool8000000H0
oooo200000090?ooo`H000002@3oool8000002X0oooo200000090?ooo`H000007P3oool6000000X0
oooo00050?ooo`P000001`3oool8000001d0oooo200000060?ooo`P00000203oool8000001`0oooo
200000060?ooo`P00000203oool8000000P0oooo2000000Z0?ooo`P00000203oool8000001`0oooo
200000090?ooo`001P3oool6000000P0oooo2000000M0?ooo`P000001P3oool8000000T0oooo1P00
000N0?ooo`H00000203oool6000000T0oooo200000090?ooo`H00000;03oool6000000T0oooo2000
000L0?ooo`P000002@3oool000P0oooo0P0000090?ooo`X000006`3oool:000000@0oooo2P00000:
0?ooo`8000008P3oool2000000X0oooo00@000000?ooo`00000000002P3oool:000000X0oooo0P00
000`0?ooo`8000002P3oool:000001X0oooo2P0000080?ooo`004`3oool:000001/0oooo2P000004
0?ooo`X00000>P3oool2000000`0oooo2P0000180?ooo`X000006P3oool:000000P0oooo000D0?oo
o`P000007@3oool8000000H0oooo2000000k0?ooo`030000003oool0oooo00`0oooo2000001:0?oo
o`P00000703oool8000000T0oooo000D0?ooo`P000007@3oool8000000H0oooo2000000k0?ooo`03
0000003oool0oooo00`0oooo2000001:0?ooo`P00000703oool8000000T0oooo000E0?ooo`H00000
203oool2000000`0oooo0P0000070?ooo`H00000203oool6000000L0oooo0P00000/0?ooo`800000
1@3oool00`000000oooo0?ooo`0=0?ooo`H000001`3oool2000000`0oooo0P00000M0?ooo`800000
5P3oool6000001D0oooo0P0000070?ooo`H000002P3oool001L0oooo0P0000080?ooo`H00000203o
ool6000000L0oooo0P00000<0?ooo`8000001`3oool6000002P0oooo1P0000030?ooo`030000003o
ool0oooo00l0oooo0P0000070?ooo`H00000203oool6000001T0oooo1P00000F0?ooo`8000005@3o
ool6000000L0oooo0P00000<0?ooo`00803oool8000000H0oooo2000000L0?ooo`P000009P3oool8
00000080oooo00<000000?ooo`3oool05`3oool8000000H0oooo2000000G0?ooo`P00000:`3oool8
000001@0oooo000P0?ooo`P000001P3oool8000001`0oooo2000000V0?ooo`P000000P3oool00`00
0000oooo0?ooo`0G0?ooo`P000001P3oool8000001L0oooo2000000[0?ooo`P00000503oool001l0
oooo2P0000040?ooo`X000006P3oool:000002@0oooo2P0000000`3oool000000?ooo`0G0?ooo`X0
0000103oool:000001D0oooo2P00000Y0?ooo`X000004`3oool001l0oooo2P0000040?ooo`X00000
6P3oool:000002@0oooo2P0000000`3oool000000?ooo`0G0?ooo`X00000103oool:000000X0oooo
0P0000090?ooo`X00000:@3oool:000001<0oooo000P0?ooo`P000001P3oool8000001`0oooo2000
000V0?ooo`P000000P3oool00`000000oooo0?ooo`0G0?ooo`P000001P3oool8000000T0oooo1P00
00080?ooo`P00000:`3oool8000001@0oooo000P0?ooo`P000001P3oool8000001`0oooo2000000V
0?ooo`P000000P3oool00`000000oooo0?ooo`0G0?ooo`P000001P3oool8000000P0oooo20000007
0?ooo`P00000:`3oool8000001@0oooo000Q0?ooo`H00000203oool6000001h0oooo1P00000X0?oo
o`H000000`3oool00`000000oooo0?ooo`0H0?ooo`H00000203oool6000000T0oooo200000080?oo
o`H00000;@3oool6000001D0oooo000G0?ooo`8000002P3oool2000000`0oooo0P00000R0?ooo`80
0000;03oool2000000D0oooo00<000000?ooo`3oool03`3oool2000000T0oooo0P00000<0?ooo`80
00002P3oool:000000T0oooo0P00000H0?ooo`8000005`3oool2000001L0oooo000E0?ooo`H00000
K`3oool00`000000oooo0?ooo`0=0?ooo`H000008@3oool:00000240oooo1P00000^0?ooo`00503o
ool8000006h0oooo0P00000=0?ooo`P000008@3oool800000240oooo2000000]0?ooo`00503oool8
000006h0oooo00<000000?ooo`3oool0303oool800000240oooo2000000Q0?ooo`P00000;@3oool0
01<0oooo2P00001]0?ooo`030000003oool0oooo00/0oooo2P00000Q0?ooo`H000008@3oool:0000
02`0oooo00080?ooo`8000002@3oool:000003d0oooo0P00000R0?ooo`8000002P3oool010000000
oooo00000000000:0?ooo`X000002P3oool2000001L0oooo0P0000090?ooo`800000303oool20000
00X0oooo2P00000/0?ooo`001P3oool6000000P0oooo2000000l0?ooo`H000007P3oool6000000P0
oooo1P0000090?ooo`P000002@3oool6000001h0oooo1P0000080?ooo`H000002@3oool8000002d0
oooo00050?ooo`P000001`3oool8000003/0oooo2000000L0?ooo`P000001P3oool8000000P0oooo
200000080?ooo`P00000703oool8000000H0oooo200000080?ooo`P00000;@3oool000D0oooo2000
00080?ooo`H00000?03oool8000001`0oooo200000060?ooo`P000002@3oool6000000T0oooo2000
000L0?ooo`P000001P3oool8000000T0oooo1P00000^0?ooo`00103oool:000000T0oooo0P00000m
0?ooo`X000006P3oool:000000@0oooo2P00000:0?ooo`8000002P3oool:000001X0oooo2P000004
0?ooo`X000002P3oool200000300oooo00040?ooo`X00000B03oool:000001X0oooo2P0000040?oo
o`X000005P3oool:000001X0oooo2P0000040?ooo`X00000?03oool000D0oooo2000001:0?ooo`P0
0000703oool8000000H0oooo2000000H0?ooo`P00000703oool8000000H0oooo2000000m0?ooo`00
1@3oool8000004X0oooo2000000L0?ooo`P000001P3oool8000001P0oooo2000000L0?ooo`P00000
1P3oool8000003d0oooo00060?ooo`H000001`3oool2000002/0oooo0P00000F0?ooo`H000001`3o
ool2000000`0oooo0P0000070?ooo`H00000203oool6000001X0oooo1P00000E0?ooo`8000001`3o
ool6000000P0oooo1P0000070?ooo`800000303oool2000002L0oooo00080?ooo`8000001`3oool6
000002L0oooo1P00000F0?ooo`8000001`3oool6000000P0oooo1P0000070?ooo`8000002P3oool0
10000000oooo00000000000N0?ooo`8000005@3oool6000000L0oooo0P00000<0?ooo`8000001`3o
ool6000000P0oooo1P00000U0?ooo`00403oool8000002D0oooo2000000M0?ooo`P000001P3oool8
00000180oooo00<000000?ooo`3oool0=@3oool8000001`0oooo200000060?ooo`P00000903oool0
0100oooo2000000U0?ooo`P000007@3oool8000000H0oooo2000000B0?ooo`800000=P3oool80000
01`0oooo200000060?ooo`P00000903oool000l0oooo2P00000S0?ooo`X000006`3oool:000000@0
oooo2P00000A0?ooo`030000003oool0oooo03@0oooo2P00000J0?ooo`X00000103oool:000002<0
oooo000?0?ooo`X00000603oool2000000T0oooo2P00000K0?ooo`X00000103oool:000000X0oooo
0P0000050?ooo`030000003oool0oooo02P0oooo0P00000:0?ooo`X000006P3oool:000000@0oooo
2P00000:0?ooo`8000005`3oool00100oooo2000000G0?ooo`H00000203oool8000001d0oooo2000
00060?ooo`P000002@3oool6000000<0oooo00<000000?ooo`3oool09P3oool6000000T0oooo2000
000L0?ooo`P000001P3oool8000000T0oooo1P00000E0?ooo`00403oool8000001H0oooo20000007
0?ooo`P000007@3oool8000000H0oooo200000080?ooo`P000000P3oool00`000000oooo0?ooo`0U
0?ooo`P00000203oool8000001`0oooo200000060?ooo`P00000203oool8000001@0oooo000A0?oo
o`H000005`3oool8000000P0oooo1P00000O0?ooo`H00000203oool6000000T0oooo200000020?oo
o`030000003oool0oooo02D0oooo200000090?ooo`H000007P3oool6000000P0oooo1P0000090?oo
o`P00000503oool001<0oooo0P00000H0?ooo`X000002@3oool2000002<0oooo0P00000<0?ooo`80
00002P3oool:000000030?ooo`000000oooo02D0oooo2P00000:0?ooo`8000008P3oool2000000`0
oooo0P00000:0?ooo`X000004`3oool002d0oooo2P0000180?ooo`X0000000<0oooo0000003oool0
9@3oool:000004P0oooo2P00000C0?ooo`00;P3oool8000004X0oooo200000020?ooo`030000003o
ool0oooo02D0oooo2000001:0?ooo`P00000503oool002h0oooo2000001:0?ooo`P000000P3oool0
0`000000oooo0?ooo`0U0?ooo`P00000BP3oool8000001@0oooo000G0?ooo`8000005P3oool60000
00L0oooo0P00000<0?ooo`8000007@3oool2000001H0oooo1P0000030?ooo`030000003oool0oooo
00l0oooo0P00000E0?ooo`H00000203oool2000002/0oooo0P00000E0?ooo`H000005@3oool001D0
oooo1P00000F0?ooo`8000001`3oool6000000P0oooo1P00000I0?ooo`H000005P3oool2000000D0
oooo00<000000?ooo`3oool03@3oool6000001D0oooo0P0000080?ooo`H000009`3oool6000001D0
oooo0P00000G0?ooo`00503oool8000001d0oooo200000060?ooo`P000005`3oool8000001`0oooo
00<000000?ooo`3oool0303oool8000001d0oooo2000000U0?ooo`P00000;@3oool001@0oooo2000
000M0?ooo`P000001P3oool8000001L0oooo2000000L0?ooo`030000003oool0oooo00`0oooo2000
000M0?ooo`P000009@3oool8000002d0oooo000C0?ooo`X000006`3oool:000000@0oooo2P00000E
0?ooo`X000006`3oool2000000`0oooo2P00000K0?ooo`X000008`3oool:000002`0oooo000C0?oo
o`X000006`3oool:000000@0oooo2P00000E0?ooo`X000006`3oool00`000000oooo0?ooo`0;0?oo
o`X000006`3oool:000002<0oooo2P00000/0?ooo`00503oool8000001d0oooo200000060?ooo`P0
00005`3oool8000001`0oooo00<000000?ooo`3oool0303oool8000001d0oooo2000000U0?ooo`P0
0000;@3oool001@0oooo2000000M0?ooo`P000001P3oool8000001L0oooo2000000L0?ooo`030000
003oool0oooo00`0oooo2000000M0?ooo`P000009@3oool8000002d0oooo000E0?ooo`H000005P3o
ool2000000L0oooo1P0000080?ooo`H000006@3oool6000001H0oooo0P0000050?ooo`030000003o
ool0oooo00d0oooo1P00000E0?ooo`800000203oool6000002L0oooo1P00000^0?ooo`005`3oool2
000001H0oooo1P0000070?ooo`800000303oool2000001d0oooo0P00000F0?ooo`H000000`3oool0
0`000000oooo0?ooo`0?0?ooo`8000005@3oool6000000P0oooo0P00000[0?ooo`800000<03oool0
02h0oooo2000001:0?ooo`P000000P3oool00`000000oooo0?ooo`0U0?ooo`P00000IP3oool002h0
oooo2000001:0?ooo`P000000P3oool00`000000oooo0?ooo`0U0?ooo`P00000IP3oool002d0oooo
2P0000180?ooo`X0000000<0oooo0000003oool09@3oool:000006D0oooo000C0?ooo`800000603o
ool:000000T0oooo0P00000S0?ooo`800000303oool2000000X0oooo2P0000000`3oool000000?oo
o`0U0?ooo`X000002P3oool200000280oooo0P00000<0?ooo`8000009`3oool00140oooo1P00000G
0?ooo`P00000203oool6000001l0oooo1P0000080?ooo`H000002@3oool800000080oooo00<00000
0?ooo`3oool09@3oool8000000T0oooo1P00000N0?ooo`H00000203oool6000002D0oooo000@0?oo
o`P000005P3oool8000000L0oooo2000000M0?ooo`P000001P3oool8000000P0oooo200000020?oo
o`030000003oool0oooo02D0oooo200000080?ooo`P00000703oool8000000H0oooo2000000T0?oo
o`00403oool8000001L0oooo1P0000080?ooo`P000007@3oool8000000H0oooo200000090?ooo`H0
00000`3oool00`000000oooo0?ooo`0V0?ooo`H000002@3oool8000001`0oooo200000060?ooo`P0
0000903oool000l0oooo2P00000H0?ooo`8000002@3oool:000001/0oooo2P0000040?ooo`X00000
2@3oool4000000@0oooo00<000000?ooo`3oool0:03oool2000000X0oooo2P00000J0?ooo`X00000
103oool:000002<0oooo000?0?ooo`X000008`3oool:000001/0oooo2P0000040?ooo`X00000303o
ool00`000000oooo0?ooo`020?ooo`<00000=03oool:000001X0oooo2P0000040?ooo`X000008`3o
ool00100oooo2000000U0?ooo`P000007@3oool8000000H0oooo2000000;0?ooo`8000001@3oool0
0`000000oooo0?ooo`0e0?ooo`P00000703oool8000000H0oooo2000000T0?ooo`00403oool80000
02D0oooo2000000M0?ooo`P000001P3oool8000000/0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0e0?ooo`P00000703oool8000000H0oooo2000000T0?ooo`004@3oool6000002L0
oooo1P00000O0?ooo`H00000203oool6000000`0oooo0`0000040?ooo`030000003oool0oooo03H0
oooo1P00000N0?ooo`H00000203oool6000002D0oooo000C0?ooo`800000:`3oool2000001P0oooo
0P0000090?ooo`800000303oool2000000T0oooo0P00000:0?ooo`040000003oool00000000001h0
oooo0P00000G0?ooo`8000002@3oool2000000`0oooo0P0000090?ooo`800000303oool2000002L0
oooo001H0?ooo`H000007P3oool6000000P0oooo1P00000J0?ooo`H000007P3oool6000000P0oooo
1P00000n0?ooo`00E`3oool8000001`0oooo200000060?ooo`P00000603oool8000001`0oooo2000
00060?ooo`P00000?@3oool005L0oooo2000000L0?ooo`P000001P3oool8000001P0oooo2000000L
0?ooo`P000001P3oool8000003d0oooo001F0?ooo`X000006P3oool:000000@0oooo2P00000F0?oo
o`X000006P3oool:000000@0oooo2P00000l0?ooo`00EP3oool:000001X0oooo2P0000040?ooo`X0
00002P3oool2000000X0oooo2P00000J0?ooo`X00000103oool:000000X0oooo0P00000`0?ooo`00
E`3oool8000001`0oooo200000060?ooo`P000002@3oool6000000T0oooo2000000L0?ooo`P00000
1P3oool8000000T0oooo1P00000^0?ooo`00E`3oool8000001`0oooo200000060?ooo`P00000203o
ool8000000P0oooo2000000L0?ooo`P000001P3oool8000000P0oooo2000000]0?ooo`00F03oool6
000001h0oooo1P0000080?ooo`H000002@3oool8000000T0oooo1P00000E0?ooo`8000001`3oool6
000000P0oooo1P0000090?ooo`P00000;@3oool005X0oooo0P00000R0?ooo`8000002P3oool01000
0000oooo00000000000:0?ooo`X000002P3oool2000001D0oooo1P0000070?ooo`800000303oool2
000000X0oooo2P00000/0?ooo`00RP3oool2000000`0oooo2P00000P0?ooo`P00000803oool:0000
02`0oooo002:0?ooo`030000003oool0oooo00`0oooo2000000Q0?ooo`P000008@3oool8000002d0
oooo002:0?ooo`030000003oool0oooo00`0oooo2000000P0?ooo`X00000803oool8000002d0oooo
000S0?ooo`800000303oool200000280oooo0P00000/0?ooo`8000001@3oool00`000000oooo0?oo
o`0=0?ooo`H000001`3oool2000000`0oooo0P00000:0?ooo`X000002@3oool2000001H0oooo1P00
000^0?ooo`008@3oool6000000P0oooo1P00000N0?ooo`H00000:03oool6000000<0oooo00<00000
0?ooo`3oool03`3oool2000000L0oooo1P0000080?ooo`H000002@3oool8000000P0oooo1P00000F
0?ooo`800000<03oool00200oooo200000060?ooo`P00000703oool8000002H0oooo200000020?oo
o`030000003oool0oooo01L0oooo200000060?ooo`P00000203oool8000000L0oooo200000170?oo
o`00803oool8000000H0oooo2000000L0?ooo`P000009P3oool800000080oooo00<000000?ooo`3o
ool05`3oool8000000H0oooo200000090?ooo`H00000203oool8000004L0oooo000O0?ooo`X00000
103oool:000001X0oooo2P00000T0?ooo`X0000000<0oooo0000003oool05`3oool:000000@0oooo
2P00000:0?ooo`8000002@3oool:000004H0oooo000O0?ooo`X00000103oool:000001X0oooo2P00
000T0?ooo`X0000000<0oooo0000003oool05`3oool:000000@0oooo2P00000E0?ooo`X00000AP3o
ool00200oooo200000060?ooo`P00000703oool8000002H0oooo200000020?ooo`030000003oool0
oooo01L0oooo200000060?ooo`P000005`3oool8000004L0oooo000P0?ooo`P000001P3oool80000
01`0oooo2000000V0?ooo`P000000P3oool00`000000oooo0?ooo`0G0?ooo`P000001P3oool80000
01L0oooo200000170?ooo`008@3oool6000000P0oooo1P0000070?ooo`800000303oool2000000L0
oooo1P00000X0?ooo`H000000`3oool00`000000oooo0?ooo`0?0?ooo`8000001`3oool6000000P0
oooo1P00000I0?ooo`H00000B03oool002<0oooo0P00000<0?ooo`8000001`3oool6000000P0oooo
1P0000070?ooo`800000;03oool2000000D0oooo00<000000?ooo`3oool03@3oool6000000L0oooo
0P00000<0?ooo`8000007@3oool2000004X0oooo000i0?ooo`P000001P3oool8000003/0oooo00<0
00000?ooo`3oool0303oool8000007l0oooo000i0?ooo`P000001P3oool8000003/0oooo0P00000=
0?ooo`P00000O`3oool003P0oooo2P0000040?ooo`X00000>P3oool00`000000oooo0?ooo`0;0?oo
o`X00000OP3oool003P0oooo2P0000040?ooo`X000002P3oool200000280oooo0P00000:0?ooo`04
0000003oool00000000000X0oooo2P00000:0?ooo`800000<03oool200000400oooo000i0?ooo`P0
00001P3oool8000000T0oooo1P00000N0?ooo`H00000203oool6000000T0oooo200000090?ooo`H0
0000;03oool6000003h0oooo000i0?ooo`P000001P3oool8000000P0oooo2000000L0?ooo`P00000
1P3oool8000000P0oooo200000080?ooo`P00000:P3oool8000003d0oooo000j0?ooo`H00000203o
ool6000000T0oooo2000000L0?ooo`P000001P3oool8000000T0oooo1P0000090?ooo`P00000:P3o
ool8000003d0oooo000l0?ooo`800000303oool2000000X0oooo2P00000J0?ooo`X00000103oool:
000000X0oooo0P00000:0?ooo`X00000:03oool:000003`0oooo001F0?ooo`X000006P3oool:0000
00@0oooo2P00000F0?ooo`X00000:03oool:000003`0oooo001G0?ooo`P00000703oool8000000H0
oooo2000000H0?ooo`P00000:P3oool8000003d0oooo001G0?ooo`P00000703oool8000000H0oooo
2000000H0?ooo`P00000:P3oool8000003d0oooo001H0?ooo`H000007P3oool6000000P0oooo1P00
000J0?ooo`H00000;03oool6000003h0oooo00100?ooo`800000603oool2000000T0oooo0P00000<
0?ooo`8000002@3oool2000000X0oooo00@000000?ooo`00000000007P3oool2000001L0oooo0P00
000G0?ooo`800000@03oool003h0oooo1P00000O0?ooo`H00000203oool6000001<0oooo00<00000
0?ooo`3oool0=P3oool6000005L0oooo000m0?ooo`P000007@3oool8000000H0oooo2000000B0?oo
o`030000003oool0oooo03D0oooo2000001F0?ooo`00?@3oool8000001d0oooo200000060?ooo`P0
00004P3oool2000003H0oooo2000001F0?ooo`00?03oool:000001/0oooo2P0000040?ooo`X00000
4@3oool00`000000oooo0?ooo`0d0?ooo`X00000E@3oool003`0oooo2P00000K0?ooo`X00000103o
ool:000000X0oooo0P0000050?ooo`030000003oool0oooo03@0oooo2P00001E0?ooo`00?@3oool8
000001d0oooo200000060?ooo`P000002@3oool6000000<0oooo00<000000?ooo`3oool0=@3oool8
000005H0oooo000m0?ooo`P000007@3oool8000000H0oooo200000080?ooo`P000000P3oool00`00
0000oooo0?ooo`0e0?ooo`P00000EP3oool003h0oooo1P00000F0?ooo`8000001`3oool6000000P0
oooo1P0000090?ooo`P000000P3oool00`000000oooo0?ooo`0f0?ooo`H00000E`3oool00400oooo
0P00000F0?ooo`H000001`3oool2000000`0oooo0P00000:0?ooo`X0000000<0oooo0000003oool0
>@3oool2000005T0oooo001G0?ooo`P00000803oool:000000030?ooo`000000oooo09@0oooo001G
0?ooo`P000008@3oool800000080oooo00<000000?ooo`3oool0T`3oool005H0oooo2P00000P0?oo
o`P000000P3oool00`000000oooo0?ooo`2C0?ooo`00EP3oool:000000T0oooo0P00000F0?ooo`H0
00000`3oool00`000000oooo0?ooo`0?0?ooo`8000008`3oool2000005d0oooo001G0?ooo`P00000
203oool6000001H0oooo0P0000050?ooo`030000003oool0oooo00d0oooo1P00000O0?ooo`H00000
F`3oool005L0oooo200000070?ooo`P00000703oool00`000000oooo0?ooo`0<0?ooo`P000007@3o
ool8000005X0oooo001H0?ooo`H00000203oool8000001`0oooo00<000000?ooo`3oool0303oool8
000001d0oooo2000001J0?ooo`00FP3oool2000000T0oooo2P00000K0?ooo`800000303oool:0000
01/0oooo2P00001I0?ooo`00I@3oool:000001/0oooo00<000000?ooo`3oool02`3oool:000001/0
oooo2P00001I0?ooo`00IP3oool8000001`0oooo00<000000?ooo`3oool0303oool8000001d0oooo
2000001J0?ooo`00IP3oool8000001`0oooo00<000000?ooo`3oool0303oool8000001d0oooo2000
001J0?ooo`00I`3oool6000001H0oooo0P0000050?ooo`030000003oool0oooo00d0oooo1P000007
0?ooo`8000005P3oool6000005/0oooo001Y0?ooo`8000005P3oool6000000<0oooo00<000000?oo
o`3oool03`3oool2000000L0oooo1P00000F0?ooo`800000G@3oool00800oooo200000020?ooo`03
0000003oool0oooo01L0oooo2000001d0?ooo`00P03oool800000080oooo00<000000?ooo`3oool0
5`3oool8000007@0oooo001o0?ooo`X0000000<0oooo0000003oool05`3oool:000007<0oooo001o
0?ooo`X0000000<0oooo0000003oool05`3oool:000007<0oooo00200?ooo`P000000P3oool00`00
0000oooo0?ooo`0G0?ooo`P00000M03oool00800oooo200000020?ooo`030000003oool0oooo01L0
oooo2000001d0?ooo`00O03oool;000000<0oooo00<000000?ooo`3oool0603oool6000007D0oooo
001n0?ooo`040000003oool0oooo0?ooo`@00000103oool00`000000oooo0?ooo`0J0?ooo`800000
M`3oool007h0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo
0`00002C0?ooo`00OP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`2C0?ooo`00OP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0V03oool007d0oooo0P0000040?ooo`800000V`3oool00?l0oooo8@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {288.938, 0}} -> {-9.91696, -10.3217, \
0.0714452, 0.0714452}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[377]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generating the remainig regions", "Subsection"],

Cell[BoxData[{
    \(\(QL121 = 
        Table[QL021[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                QL021]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL131 = 
        Table[QL031[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                QL031]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL132 = 
        Table[QL032[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                QL032]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL141 = 
        Table[QL041[\([i]\)]\  + 
            e[4], {i, \(Dimensions[
                QL041]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL142 = 
        Table[QL042[\([i]\)]\  + 
            e[4], {i, \(Dimensions[
                QL042]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL143 = 
        Table[QL043[\([i]\)]\  + 
            e[4], {i, \(Dimensions[
                QL043]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL151 = 
        Table[QL051[\([i]\)]\  + 
            e[5], {i, \(Dimensions[
                QL051]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL152 = 
        Table[QL052[\([i]\)]\  + 
            e[5], {i, \(Dimensions[
                QL052]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL153 = 
        Table[QL053[\([i]\)]\  + 
            e[5], {i, \(Dimensions[
                QL053]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL154 = 
        Table[QL054[\([i]\)]\  + 
            e[5], {i, \(Dimensions[QL054]\)[\([1]\)]}];\)\)}], "Input",
  CellLabel->"In[378]:="],

Cell[BoxData[{
    \(\(QL221 = 
        Table[QL021[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                QL021]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL231 = 
        Table[QL031[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                QL031]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL232 = 
        Table[QL032[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                QL032]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL241 = 
        Table[QL041[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                QL041]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL242 = 
        Table[QL042[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                QL042]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL243 = 
        Table[QL043[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                QL043]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL251 = 
        Table[QL051[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                QL051]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL252 = 
        Table[QL052[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                QL052]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL253 = 
        Table[QL053[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                QL053]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL254 = 
        Table[QL054[\([i]\)]\  + 
            e[4], {i, \(Dimensions[QL054]\)[\([1]\)]}];\)\)}], "Input",
  CellLabel->"In[388]:="],

Cell[BoxData[{
    \(\(QL321 = 
        Table[QL021[\([i]\)]\  + e[2] + 
            e[1], {i, \(Dimensions[
                QL021]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL331 = 
        Table[QL031[\([i]\)]\  + e[3] + 
            e[1], {i, \(Dimensions[
                QL031]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL332 = 
        Table[QL032[\([i]\)]\  + e[3] + 
            e[2], {i, \(Dimensions[
                QL032]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL341 = 
        Table[QL041[\([i]\)]\  + e[4] + 
            e[1], {i, \(Dimensions[
                QL041]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL342 = 
        Table[QL042[\([i]\)]\  + e[4] + 
            e[2], {i, \(Dimensions[
                QL042]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL343 = 
        Table[QL043[\([i]\)]\  + e[4] + 
            e[3], {i, \(Dimensions[
                QL043]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL351 = 
        Table[QL051[\([i]\)]\  + e[5] + 
            e[1], {i, \(Dimensions[
                QL051]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL352 = 
        Table[QL052[\([i]\)]\  + e[5] + 
            e[2], {i, \(Dimensions[
                QL052]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL353 = 
        Table[QL053[\([i]\)]\  + e[5] + 
            e[3], {i, \(Dimensions[
                QL053]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(QL354 = 
        Table[QL054[\([i]\)]\  + e[5] + 
            e[4], {i, \(Dimensions[QL054]\)[\([1]\)]}];\)\)}], "Input",
  CellLabel->"In[398]:="],

Cell[BoxData[
    \(\(QL = 
        Union[QL021, QL031, QL032, QL041, QL042, QL043, \ QL051, QL052, 
          QL053, QL054, QL121, QL131, QL132, QL141, QL142, QL143, \ QL151, 
          QL152, QL153, QL154, QL221, QL231, QL232, QL241, QL242, QL243, \ 
          QL251, QL252, QL253, QL254, QL321, QL331, QL332, QL341, QL342, 
          QL343, QL351, QL352, QL353, QL354];\)\)], "Input",
  CellLabel->"In[408]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[SphericalCut[QL, 10], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.02], 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[409]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9811 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0486845 0.490552 0.0486845 [
[.01316 .47805 -9 -9 ]
[.01316 .47805 9 0 ]
[.25658 .47805 -6 -9 ]
[.25658 .47805 6 0 ]
[.74342 .47805 -3 -9 ]
[.74342 .47805 3 0 ]
[.98684 .47805 -6 -9 ]
[.98684 .47805 6 0 ]
[.4875 .00371 -18 -4.5 ]
[.4875 .00371 0 4.5 ]
[.4875 .24713 -12 -4.5 ]
[.4875 .24713 0 4.5 ]
[.4875 .73397 -6 -4.5 ]
[.4875 .73397 0 4.5 ]
[.4875 .9774 -12 -4.5 ]
[.4875 .9774 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .9811 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01316 .49055 m
.01316 .4968 L
s
[(-10)] .01316 .47805 0 1 Mshowa
.25658 .49055 m
.25658 .4968 L
s
[(-5)] .25658 .47805 0 1 Mshowa
.74342 .49055 m
.74342 .4968 L
s
[(5)] .74342 .47805 0 1 Mshowa
.98684 .49055 m
.98684 .4968 L
s
[(10)] .98684 .47805 0 1 Mshowa
.125 Mabswid
.06184 .49055 m
.06184 .4943 L
s
.11052 .49055 m
.11052 .4943 L
s
.15921 .49055 m
.15921 .4943 L
s
.20789 .49055 m
.20789 .4943 L
s
.30526 .49055 m
.30526 .4943 L
s
.35395 .49055 m
.35395 .4943 L
s
.40263 .49055 m
.40263 .4943 L
s
.45132 .49055 m
.45132 .4943 L
s
.54868 .49055 m
.54868 .4943 L
s
.59737 .49055 m
.59737 .4943 L
s
.64605 .49055 m
.64605 .4943 L
s
.69474 .49055 m
.69474 .4943 L
s
.79211 .49055 m
.79211 .4943 L
s
.84079 .49055 m
.84079 .4943 L
s
.88948 .49055 m
.88948 .4943 L
s
.93816 .49055 m
.93816 .4943 L
s
.25 Mabswid
0 .49055 m
1 .49055 L
s
.5 .00371 m
.50625 .00371 L
s
[(-10)] .4875 .00371 1 0 Mshowa
.5 .24713 m
.50625 .24713 L
s
[(-5)] .4875 .24713 1 0 Mshowa
.5 .73397 m
.50625 .73397 L
s
[(5)] .4875 .73397 1 0 Mshowa
.5 .9774 m
.50625 .9774 L
s
[(10)] .4875 .9774 1 0 Mshowa
.125 Mabswid
.5 .05239 m
.50375 .05239 L
s
.5 .10108 m
.50375 .10108 L
s
.5 .14976 m
.50375 .14976 L
s
.5 .19844 m
.50375 .19844 L
s
.5 .29581 m
.50375 .29581 L
s
.5 .3445 m
.50375 .3445 L
s
.5 .39318 m
.50375 .39318 L
s
.5 .44187 m
.50375 .44187 L
s
.5 .53924 m
.50375 .53924 L
s
.5 .58792 m
.50375 .58792 L
s
.5 .63661 m
.50375 .63661 L
s
.5 .68529 m
.50375 .68529 L
s
.5 .78266 m
.50375 .78266 L
s
.5 .83134 m
.50375 .83134 L
s
.5 .88003 m
.50375 .88003 L
s
.5 .92871 m
.50375 .92871 L
s
.25 Mabswid
.5 0 m
.5 .9811 L
s
0 0 m
1 0 L
1 .9811 L
0 .9811 L
closepath
clip
newpath
.02 w
.24508 .09828 Mdot
.24508 .88283 Mdot
.24508 .09828 Mdot
.24508 .88283 Mdot
.29377 .09828 Mdot
.29377 .09828 Mdot
.29377 .88283 Mdot
.24508 .49055 Mdot
.29377 .49055 Mdot
.46061 .51917 Mdot
.42123 .49055 Mdot
.38184 .51917 Mdot
.38184 .12689 Mdot
.38184 .85421 Mdot
.91246 .49055 Mdot
.91246 .64039 Mdot
.95185 .46194 Mdot
.95185 .51917 Mdot
.5093 .51917 Mdot
.2057 .46194 Mdot
.2057 .51917 Mdot
.2057 .12689 Mdot
.2057 .85421 Mdot
.2057 .12689 Mdot
.25438 .12689 Mdot
.37254 .49055 Mdot
.16631 .49055 Mdot
.33316 .46194 Mdot
.33316 .51917 Mdot
.33316 .12689 Mdot
.33316 .85421 Mdot
.02381 .44425 Mdot
.02381 .53685 Mdot
.23004 .44425 Mdot
.23004 .53685 Mdot
.23004 .83652 Mdot
.27872 .44425 Mdot
.27872 .53685 Mdot
.27872 .20181 Mdot
.27872 .14458 Mdot
.27872 .83652 Mdot
.23004 .44425 Mdot
.23004 .53685 Mdot
.27872 .53685 Mdot
.27872 .20181 Mdot
.27872 .14458 Mdot
.27872 .83652 Mdot
.76066 .1732 Mdot
.76066 .80791 Mdot
.80935 .1732 Mdot
.80935 .2658 Mdot
.80935 .7153 Mdot
.80935 .80791 Mdot
.14197 .1732 Mdot
.14197 .80791 Mdot
.19065 .1732 Mdot
.19065 .41563 Mdot
.19065 .56547 Mdot
.19065 .80791 Mdot
.23934 .1732 Mdot
.23934 .1732 Mdot
.23934 .56547 Mdot
.23934 .80791 Mdot
.80935 .1732 Mdot
.80935 .80791 Mdot
.85803 .1732 Mdot
.85803 .80791 Mdot
.10258 .38702 Mdot
.10258 .59409 Mdot
.15127 .20181 Mdot
.15127 .59409 Mdot
.15127 .77929 Mdot
.31811 .1732 Mdot
.31811 .56547 Mdot
.31811 .80791 Mdot
.0632 .41563 Mdot
.0632 .56547 Mdot
.14197 .41563 Mdot
.14197 .56547 Mdot
.19065 .41563 Mdot
.19065 .56547 Mdot
.23934 .1732 Mdot
.23934 .56547 Mdot
.10258 .44425 Mdot
.10258 .53685 Mdot
.10258 .38702 Mdot
.10258 .59409 Mdot
.15127 .44425 Mdot
.15127 .53685 Mdot
.15127 .59409 Mdot
.0632 .41563 Mdot
.0632 .56547 Mdot
.74562 .12689 Mdot
.7943 .12689 Mdot
.7943 .85421 Mdot
.7943 .12689 Mdot
.7943 .85421 Mdot
.08754 .64039 Mdot
.08754 .24811 Mdot
.08754 .73299 Mdot
.75492 .88283 Mdot
.04815 .46194 Mdot
.04815 .51917 Mdot
.04815 .36933 Mdot
.04815 .61177 Mdot
.08754 .49055 Mdot
.04815 .46194 Mdot
.04815 .51917 Mdot
.56373 .44425 Mdot
.56373 .53685 Mdot
.61241 .44425 Mdot
.30881 .44425 Mdot
.47566 .41563 Mdot
.47566 .47287 Mdot
.47566 .56547 Mdot
.52434 .41563 Mdot
.52434 .47287 Mdot
.52434 .56547 Mdot
.38759 .44425 Mdot
.43627 .44425 Mdot
.43627 .53685 Mdot
.43627 .59409 Mdot
.48496 .44425 Mdot
.3482 .1732 Mdot
.3482 .41563 Mdot
.3482 .56547 Mdot
.3482 .80791 Mdot
.39688 .1732 Mdot
.39688 .41563 Mdot
.39688 .56547 Mdot
.39688 .80791 Mdot
.24508 .49055 Mdot
.24508 .39795 Mdot
.24508 .88283 Mdot
.29377 .49055 Mdot
.29377 .39795 Mdot
.29377 .58316 Mdot
.29377 .09828 Mdot
.29377 .34072 Mdot
.29377 .64039 Mdot
.29377 .88283 Mdot
.29377 .24811 Mdot
.29377 .79022 Mdot
.24508 .39795 Mdot
.24508 .34072 Mdot
.24508 .64039 Mdot
.29377 .49055 Mdot
.29377 .39795 Mdot
.29377 .58316 Mdot
.29377 .09828 Mdot
.29377 .34072 Mdot
.29377 .64039 Mdot
.29377 .88283 Mdot
.29377 .24811 Mdot
.29377 .79022 Mdot
.46061 .36933 Mdot
.46061 .61177 Mdot
.5093 .36933 Mdot
.5093 .61177 Mdot
.2057 .46194 Mdot
.2057 .51917 Mdot
.2057 .12689 Mdot
.2057 .36933 Mdot
.2057 .61177 Mdot
.2057 .85421 Mdot
.2057 .2195 Mdot
.2057 .76161 Mdot
.25438 .12689 Mdot
.25438 .36933 Mdot
.25438 .61177 Mdot
.25438 .2195 Mdot
.25438 .2195 Mdot
.25438 .76161 Mdot
.37254 .64039 Mdot
.42123 .39795 Mdot
.42123 .34072 Mdot
.42123 .64039 Mdot
.11763 .34072 Mdot
.11763 .64039 Mdot
.11763 .24811 Mdot
.11763 .73299 Mdot
.16631 .64039 Mdot
.16631 .24811 Mdot
.16631 .73299 Mdot
.33316 .51917 Mdot
.33316 .12689 Mdot
.33316 .36933 Mdot
.33316 .61177 Mdot
.33316 .85421 Mdot
.33316 .2195 Mdot
.33316 .76161 Mdot
.38184 .36933 Mdot
.38184 .61177 Mdot
.07824 .36933 Mdot
.15701 .36933 Mdot
.2057 .46194 Mdot
.2057 .51917 Mdot
.2057 .36933 Mdot
.2057 .61177 Mdot
.25438 .36933 Mdot
.25438 .61177 Mdot
.11763 .49055 Mdot
.11763 .34072 Mdot
.16631 .49055 Mdot
.16631 .34072 Mdot
.16631 .64039 Mdot
.02381 .44425 Mdot
.02381 .53685 Mdot
.23004 .29441 Mdot
.23004 .68669 Mdot
.27872 .29441 Mdot
.27872 .68669 Mdot
.23004 .29441 Mdot
.23004 .68669 Mdot
.76066 .1732 Mdot
.80935 .1732 Mdot
.80935 .80791 Mdot
.19065 .2658 Mdot
.19065 .32303 Mdot
.19065 .2658 Mdot
.19065 .65807 Mdot
.19065 .7153 Mdot
.19065 .7153 Mdot
.80935 .1732 Mdot
.80935 .80791 Mdot
.10258 .29441 Mdot
.10258 .59409 Mdot
.10258 .68669 Mdot
.10258 .29441 Mdot
.10258 .68669 Mdot
.15127 .29441 Mdot
.15127 .29441 Mdot
.15127 .68669 Mdot
.15127 .68669 Mdot
.0632 .32303 Mdot
.0632 .41563 Mdot
.0632 .56547 Mdot
.0632 .65807 Mdot
.19065 .32303 Mdot
.19065 .65807 Mdot
.10258 .44425 Mdot
.10258 .53685 Mdot
.15127 .29441 Mdot
.15127 .68669 Mdot
.0632 .41563 Mdot
.0632 .56547 Mdot
.57877 .49055 Mdot
.57877 .39795 Mdot
.62746 .49055 Mdot
.83369 .49055 Mdot
.88237 .49055 Mdot
.88237 .34072 Mdot
.53939 .51917 Mdot
.53939 .36933 Mdot
.7943 .46194 Mdot
.7943 .51917 Mdot
.75492 .49055 Mdot
.30881 .44425 Mdot
.30881 .44425 Mdot
.30881 .29441 Mdot
.30881 .68669 Mdot
.47566 .32303 Mdot
.47566 .41563 Mdot
.47566 .56547 Mdot
.47566 .65807 Mdot
.52434 .32303 Mdot
.52434 .41563 Mdot
.52434 .56547 Mdot
.52434 .65807 Mdot
.38759 .29441 Mdot
.38759 .68669 Mdot
.43627 .44425 Mdot
.43627 .29441 Mdot
.43627 .59409 Mdot
.43627 .68669 Mdot
.48496 .29441 Mdot
.48496 .68669 Mdot
.3482 .1732 Mdot
.3482 .32303 Mdot
.3482 .41563 Mdot
.3482 .56547 Mdot
.3482 .65807 Mdot
.3482 .7153 Mdot
.3482 .80791 Mdot
.39688 .32303 Mdot
.39688 .41563 Mdot
.39688 .56547 Mdot
.24508 .34072 Mdot
.24508 .64039 Mdot
.24508 .24811 Mdot
.24508 .73299 Mdot
.29377 .34072 Mdot
.29377 .64039 Mdot
.29377 .24811 Mdot
.29377 .73299 Mdot
.24508 .24811 Mdot
.24508 .73299 Mdot
.29377 .24811 Mdot
.29377 .73299 Mdot
.29377 .79022 Mdot
.2057 .36933 Mdot
.2057 .61177 Mdot
.2057 .2195 Mdot
.2057 .2195 Mdot
.2057 .76161 Mdot
.2057 .76161 Mdot
.25438 .2195 Mdot
.25438 .76161 Mdot
.37254 .24811 Mdot
.37254 .73299 Mdot
.42123 .24811 Mdot
.42123 .73299 Mdot
.11763 .34072 Mdot
.11763 .64039 Mdot
.11763 .24811 Mdot
.11763 .73299 Mdot
.16631 .34072 Mdot
.16631 .64039 Mdot
.16631 .24811 Mdot
.16631 .73299 Mdot
.33316 .2195 Mdot
.33316 .27673 Mdot
.33316 .76161 Mdot
.38184 .2195 Mdot
.38184 .76161 Mdot
.07824 .36933 Mdot
.2057 .36933 Mdot
.2057 .61177 Mdot
.25438 .76161 Mdot
.11763 .49055 Mdot
.16631 .34072 Mdot
.16631 .64039 Mdot
.84873 .44425 Mdot
.84873 .53685 Mdot
.89742 .44425 Mdot
.89742 .53685 Mdot
.89742 .29441 Mdot
.89742 .38702 Mdot
.89742 .59409 Mdot
.89742 .68669 Mdot
.97619 .44425 Mdot
.97619 .53685 Mdot
.9368 .41563 Mdot
.9368 .56547 Mdot
.80935 .41563 Mdot
.80935 .56547 Mdot
.85803 .41563 Mdot
.85803 .56547 Mdot
.74562 .2195 Mdot
.74562 .76161 Mdot
.7943 .2195 Mdot
.7943 .76161 Mdot
.53939 .36933 Mdot
.53939 .61177 Mdot
.30881 .29441 Mdot
.30881 .68669 Mdot
.30881 .29441 Mdot
.30881 .68669 Mdot
.38759 .29441 Mdot
.38759 .68669 Mdot
.43627 .20181 Mdot
.43627 .29441 Mdot
.43627 .68669 Mdot
.43627 .77929 Mdot
.3482 .1732 Mdot
.3482 .32303 Mdot
.3482 .7153 Mdot
.3482 .80791 Mdot
.39688 .1732 Mdot
.39688 .80791 Mdot
.30881 .05198 Mdot
.30881 .92913 Mdot
.33316 .06966 Mdot
.33316 .91144 Mdot
.33316 .06966 Mdot
.33316 .12689 Mdot
.33316 .85421 Mdot
.33316 .91144 Mdot
.38184 .12689 Mdot
.38184 .85421 Mdot
.91246 .64039 Mdot
.29377 .09828 Mdot
.29377 .88283 Mdot
.91246 .24811 Mdot
.91246 .73299 Mdot
.46061 .12689 Mdot
.46061 .85421 Mdot
.5093 .12689 Mdot
.5093 .85421 Mdot
.37254 .09828 Mdot
.37254 .88283 Mdot
.42123 .09828 Mdot
.42123 .88283 Mdot
.29377 .09828 Mdot
.29377 .88283 Mdot
.68189 .1732 Mdot
.84873 .20181 Mdot
.84873 .29441 Mdot
.84873 .68669 Mdot
.84873 .77929 Mdot
.89742 .29441 Mdot
.89742 .68669 Mdot
.85803 .1732 Mdot
.85803 .80791 Mdot
.66684 .06966 Mdot
.66684 .91144 Mdot
.57877 .24811 Mdot
.57877 .73299 Mdot
.62746 .09828 Mdot
.62746 .88283 Mdot
.53939 .2195 Mdot
.53939 .76161 Mdot
.39688 .02336 Mdot
.39688 .95774 Mdot
.60312 .02336 Mdot
.60312 .95774 Mdot
.56373 .05198 Mdot
.56373 .92913 Mdot
.61241 .05198 Mdot
.61241 .92913 Mdot
.47566 .08059 Mdot
.47566 .90051 Mdot
.52434 .08059 Mdot
.52434 .90051 Mdot
.38759 .05198 Mdot
.38759 .92913 Mdot
.43627 .05198 Mdot
.43627 .92913 Mdot
.48496 .05198 Mdot
.48496 .92913 Mdot
.60312 .41563 Mdot
.60312 .56547 Mdot
.6518 .41563 Mdot
.6518 .56547 Mdot
.39688 .1732 Mdot
.39688 .80791 Mdot
.39688 .02336 Mdot
.39688 .95774 Mdot
.56373 .44425 Mdot
.56373 .53685 Mdot
.56373 .59409 Mdot
.61241 .44425 Mdot
.30881 .05198 Mdot
.30881 .92913 Mdot
.30881 .05198 Mdot
.30881 .92913 Mdot
.47566 .08059 Mdot
.47566 .1732 Mdot
.47566 .80791 Mdot
.47566 .90051 Mdot
.52434 .08059 Mdot
.52434 .1732 Mdot
.52434 .56547 Mdot
.52434 .80791 Mdot
.52434 .90051 Mdot
.38759 .05198 Mdot
.38759 .92913 Mdot
.43627 .05198 Mdot
.43627 .14458 Mdot
.43627 .83652 Mdot
.43627 .92913 Mdot
.43627 .05198 Mdot
.43627 .92913 Mdot
.91246 .24811 Mdot
.91246 .73299 Mdot
.61816 .51917 Mdot
.61816 .36933 Mdot
.61816 .61177 Mdot
.66684 .46194 Mdot
.66684 .51917 Mdot
.66684 .36933 Mdot
.66684 .61177 Mdot
.83369 .34072 Mdot
.83369 .64039 Mdot
.88237 .34072 Mdot
.88237 .64039 Mdot
.57877 .49055 Mdot
.57877 .39795 Mdot
.57877 .34072 Mdot
.57877 .64039 Mdot
.62746 .49055 Mdot
.62746 .64039 Mdot
.53939 .12689 Mdot
.53939 .36933 Mdot
.53939 .61177 Mdot
.53939 .85421 Mdot
.60312 .32303 Mdot
.6518 .32303 Mdot
.6518 .65807 Mdot
.56373 .29441 Mdot
.56373 .68669 Mdot
.61241 .29441 Mdot
.61241 .68669 Mdot
.47566 .2658 Mdot
.47566 .7153 Mdot
.52434 .2658 Mdot
.52434 .32303 Mdot
.52434 .65807 Mdot
.52434 .7153 Mdot
.43627 .29441 Mdot
.43627 .68669 Mdot
.48496 .29441 Mdot
.48496 .68669 Mdot
.46061 .2195 Mdot
.46061 .76161 Mdot
.5093 .2195 Mdot
.5093 .76161 Mdot
.42123 .24811 Mdot
.42123 .73299 Mdot
.68189 .56547 Mdot
.84873 .29441 Mdot
.84873 .59409 Mdot
.84873 .68669 Mdot
.89742 .29441 Mdot
.89742 .38702 Mdot
.89742 .59409 Mdot
.89742 .68669 Mdot
.89742 .29441 Mdot
.89742 .68669 Mdot
.61816 .36933 Mdot
.66684 .36933 Mdot
.66684 .61177 Mdot
.66684 .27673 Mdot
.66684 .76161 Mdot
.83369 .24811 Mdot
.83369 .73299 Mdot
.88237 .24811 Mdot
.88237 .73299 Mdot
.57877 .34072 Mdot
.57877 .64039 Mdot
.57877 .24811 Mdot
.57877 .73299 Mdot
.62746 .64039 Mdot
.62746 .24811 Mdot
.62746 .73299 Mdot
.53939 .36933 Mdot
.53939 .61177 Mdot
.53939 .2195 Mdot
.53939 .76161 Mdot
.39688 .1732 Mdot
.39688 .80791 Mdot
.56373 .20181 Mdot
.56373 .77929 Mdot
.47566 .1732 Mdot
.47566 .80791 Mdot
.47566 .1732 Mdot
.47566 .2658 Mdot
.47566 .7153 Mdot
.47566 .80791 Mdot
.52434 .1732 Mdot
.52434 .80791 Mdot
.52434 .1732 Mdot
.52434 .2658 Mdot
.52434 .7153 Mdot
.52434 .80791 Mdot
.43627 .20181 Mdot
.43627 .14458 Mdot
.43627 .77929 Mdot
.43627 .83652 Mdot
.43627 .20181 Mdot
.43627 .29441 Mdot
.43627 .68669 Mdot
.43627 .77929 Mdot
.91246 .24811 Mdot
.91246 .73299 Mdot
.95185 .46194 Mdot
.95185 .51917 Mdot
.95185 .36933 Mdot
.95185 .61177 Mdot
.95185 .61177 Mdot
.72128 .29441 Mdot
.72128 .68669 Mdot
.72128 .20181 Mdot
.72128 .14458 Mdot
.72128 .29441 Mdot
.72128 .68669 Mdot
.72128 .83652 Mdot
.76996 .29441 Mdot
.76996 .68669 Mdot
.76996 .83652 Mdot
.68189 .1732 Mdot
.68189 .80791 Mdot
.70623 .09828 Mdot
.70623 .88283 Mdot
.75492 .09828 Mdot
.75492 .88283 Mdot
.61816 .12689 Mdot
.61816 .85421 Mdot
.61816 .2195 Mdot
.61816 .12689 Mdot
.61816 .76161 Mdot
.61816 .85421 Mdot
.66684 .12689 Mdot
.66684 .85421 Mdot
.66684 .2195 Mdot
.66684 .12689 Mdot
.66684 .06966 Mdot
.66684 .12689 Mdot
.66684 .76161 Mdot
.66684 .85421 Mdot
.66684 .85421 Mdot
.66684 .91144 Mdot
.57877 .09828 Mdot
.57877 .88283 Mdot
.57877 .24811 Mdot
.57877 .09828 Mdot
.57877 .73299 Mdot
.57877 .88283 Mdot
.62746 .09828 Mdot
.62746 .88283 Mdot
.53939 .12689 Mdot
.53939 .85421 Mdot
.53939 .12689 Mdot
.53939 .85421 Mdot
.43627 .05198 Mdot
.43627 .92913 Mdot
.48496 .05198 Mdot
.48496 .92913 Mdot
.69119 .05198 Mdot
.69119 .92913 Mdot
.56373 .05198 Mdot
.56373 .92913 Mdot
.61241 .05198 Mdot
.61241 .92913 Mdot
.47566 .02336 Mdot
.47566 .95774 Mdot
.52434 .02336 Mdot
.52434 .02336 Mdot
.52434 .08059 Mdot
.52434 .95774 Mdot
.52434 .90051 Mdot
.52434 .95774 Mdot
.69119 .44425 Mdot
.43627 .05198 Mdot
.43627 .92913 Mdot
.6518 .41563 Mdot
.47566 .02336 Mdot
.47566 .95774 Mdot
.52434 .02336 Mdot
.52434 .95774 Mdot
.72128 .14458 Mdot
.72128 .83652 Mdot
.76996 .83652 Mdot
.68189 .1732 Mdot
.68189 .80791 Mdot
.70623 .49055 Mdot
.70623 .39795 Mdot
.70623 .58316 Mdot
.70623 .34072 Mdot
.70623 .64039 Mdot
.75492 .49055 Mdot
.75492 .39795 Mdot
.75492 .34072 Mdot
.75492 .64039 Mdot
.92176 .36933 Mdot
.66684 .46194 Mdot
.66684 .51917 Mdot
.66684 .36933 Mdot
.66684 .61177 Mdot
.62746 .49055 Mdot
.69119 .29441 Mdot
.69119 .68669 Mdot
.6518 .32303 Mdot
.6518 .65807 Mdot
.6518 .7153 Mdot
.61241 .68669 Mdot
.72128 .44425 Mdot
.72128 .53685 Mdot
.72128 .29441 Mdot
.72128 .68669 Mdot
.76996 .44425 Mdot
.76996 .53685 Mdot
.76996 .29441 Mdot
.76996 .68669 Mdot
.9368 .32303 Mdot
.9368 .41563 Mdot
.9368 .56547 Mdot
.9368 .65807 Mdot
.68189 .56547 Mdot
.9368 .32303 Mdot
.9368 .65807 Mdot
.89742 .29441 Mdot
.89742 .68669 Mdot
.70623 .34072 Mdot
.70623 .64039 Mdot
.70623 .24811 Mdot
.70623 .73299 Mdot
.70623 .79022 Mdot
.75492 .24811 Mdot
.75492 .73299 Mdot
.61816 .2195 Mdot
.61816 .76161 Mdot
.66684 .36933 Mdot
.66684 .61177 Mdot
.66684 .2195 Mdot
.66684 .27673 Mdot
.66684 .76161 Mdot
.66684 .76161 Mdot
.57877 .24811 Mdot
.57877 .73299 Mdot
.62746 .24811 Mdot
.62746 .73299 Mdot
.60312 .1732 Mdot
.60312 .80791 Mdot
.6518 .1732 Mdot
.6518 .80791 Mdot
.56373 .20181 Mdot
.56373 .14458 Mdot
.56373 .77929 Mdot
.56373 .83652 Mdot
.52434 .1732 Mdot
.52434 .1732 Mdot
.52434 .80791 Mdot
.52434 .80791 Mdot
.68189 .1732 Mdot
.68189 .80791 Mdot
.80935 .1732 Mdot
.80935 .2658 Mdot
.80935 .7153 Mdot
.80935 .80791 Mdot
.85803 .1732 Mdot
.85803 .80791 Mdot
.74562 .36933 Mdot
.74562 .61177 Mdot
.7943 .46194 Mdot
.7943 .51917 Mdot
.7943 .36933 Mdot
.7943 .61177 Mdot
.84299 .36933 Mdot
.70623 .39795 Mdot
.70623 .58316 Mdot
.70623 .34072 Mdot
.70623 .64039 Mdot
.75492 .49055 Mdot
.75492 .39795 Mdot
.75492 .34072 Mdot
.75492 .64039 Mdot
.66684 .36933 Mdot
.66684 .61177 Mdot
.76066 .56547 Mdot
.80935 .2658 Mdot
.80935 .32303 Mdot
.80935 .41563 Mdot
.80935 .56547 Mdot
.80935 .65807 Mdot
.80935 .7153 Mdot
.85803 .41563 Mdot
.85803 .56547 Mdot
.72128 .53685 Mdot
.76996 .44425 Mdot
.76996 .53685 Mdot
.76996 .29441 Mdot
.76996 .68669 Mdot
.7943 .2195 Mdot
.7943 .76161 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[409]:=",
  ImageSize->{288, 282.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00016R000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00PP3oool500000080oooo0P00002E0?ooo`00Q03o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`2<0?ooo`00Q03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0`3oool2000008d0oooo001l0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00Q03oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00LP3o
ool3000000h0oooo0P0000030?ooo`<000001P3oool00`000000oooo0?ooo`020?ooo`<000004`3o
ool300000740oooo001a0?ooo`D000004@3oool5000000D0oooo00@000000?ooo`3oool0oooo1@00
000A0?ooo`D00000L03oool00740oooo1@00000A0?ooo`D000001@3oool010000000oooo0?ooo`3o
ool500000140oooo1@00001`0?ooo`00L@3oool500000140oooo1@0000050?ooo`040000003oool0
oooo0?ooo`D000004@3oool500000700oooo001b0?ooo`<000004`3oool3000000H0oooo00<00000
0?ooo`3oool00P3oool3000001<0oooo0`00001a0?ooo`00T@3oool00`000000oooo0?ooo`2<0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00FP3o
ool3000001<0oooo0`00000:0?ooo`<000002`3oool3000000<0oooo00<000000?ooo`3oool03@3o
ool3000000/0oooo0`00000C0?ooo`<00000F03oool005T0oooo1@00000A0?ooo`D00000203oool5
000000T0oooo1@0000020?ooo`030000003oool0oooo00`0oooo1@0000090?ooo`D000004@3oool5
000005L0oooo001I0?ooo`D000004@3oool5000000P0oooo1@0000090?ooo`D000000P3oool20000
00d0oooo1@0000090?ooo`D000004@3oool5000005L0oooo001I0?ooo`D000004@3oool5000000P0
oooo1@0000090?ooo`D000000P3oool00`000000oooo0?ooo`0<0?ooo`D000002@3oool500000140
oooo1@00001G0?ooo`00FP3oool3000001<0oooo0`00000:0?ooo`<000002`3oool3000000<0oooo
00<000000?ooo`3oool03@3oool3000000/0oooo0`00000C0?ooo`<00000F03oool00640oooo0`00
000]0?ooo`030000003oool0oooo02X0oooo0`00001O0?ooo`00H03oool5000002`0oooo00<00000
0?ooo`3oool0:@3oool5000005h0oooo001P0?ooo`D00000;03oool00`000000oooo0?ooo`0Y0?oo
o`D00000GP3oool00600oooo1@00000S0?ooo`<000001P3oool00`000000oooo0?ooo`020?ooo`<0
0000903oool5000005h0oooo001Q0?ooo`<000008`3oool5000000D0oooo00@000000?ooo`3oool0
oooo1@00000T0?ooo`<00000G`3oool008L0oooo1@0000050?ooo`040000003oool0oooo0?ooo`D0
0000QP3oool008L0oooo1@0000050?ooo`040000003oool0oooo0?ooo`D00000QP3oool008P0oooo
0`0000060?ooo`030000003oool0oooo0080oooo0`0000270?ooo`00B03oool3000000/0oooo0`00
000C0?ooo`<000002P3oool3000001D0oooo00<000000?ooo`3oool04@3oool3000000/0oooo0`00
000C0?ooo`<000002P3oool3000004L0oooo00170?ooo`D000002@3oool500000140oooo1@000008
0?ooo`D00000503oool00`000000oooo0?ooo`0@0?ooo`D000002@3oool500000140oooo1@000008
0?ooo`D00000AP3oool004L0oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@00000D0?oo
o`030000003oool0oooo0100oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@0000160?oo
o`00A`3oool5000000T0oooo1@00000A0?ooo`D00000203oool5000001@0oooo0P00000A0?ooo`D0
00002@3oool500000140oooo1@0000080?ooo`D00000AP3oool004P0oooo0`00000;0?ooo`<00000
4`3oool3000000X0oooo0`00000E0?ooo`030000003oool0oooo0140oooo0`00000;0?ooo`<00000
4`3oool3000000X0oooo0`0000170?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool0
0`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00?@3oool3000000/0
oooo0`00000C0?ooo`<000002P3oool3000001<0oooo0`00000:0?ooo`@000001@3oool3000001<0
oooo0`00000;0?ooo`<000004`3oool3000000X0oooo0`00000l0?ooo`00?03oool5000000T0oooo
1@00000A0?ooo`D00000203oool500000140oooo1@0000090?ooo`D000000`3oool500000140oooo
1@0000090?ooo`D000004@3oool5000000P0oooo1@00000k0?ooo`00?03oool5000000T0oooo1@00
000A0?ooo`D00000203oool500000140oooo1@0000090?ooo`D000000`3oool500000140oooo1@00
00090?ooo`D000004@3oool5000000P0oooo1@00000k0?ooo`00?03oool5000000T0oooo1@00000A
0?ooo`D00000203oool500000140oooo1@0000090?ooo`D000000`3oool500000140oooo1@000009
0?ooo`D000004@3oool5000000P0oooo1@00000k0?ooo`00?@3oool3000000/0oooo0`00000C0?oo
o`<000002P3oool3000001<0oooo0`00000:0?ooo`@000001@3oool3000001<0oooo0`00000;0?oo
o`<000004`3oool3000000X0oooo0`00000l0?ooo`00D@3oool3000002T0oooo0`00000A0?ooo`03
0000003oool0oooo00d0oooo0`00000Y0?ooo`<00000D03oool00500oooo1@00000W0?ooo`D00000
403oool00`000000oooo0?ooo`0<0?ooo`D000009`3oool5000004l0oooo001@0?ooo`D000009`3o
ool500000100oooo00<000000?ooo`3oool0303oool5000002L0oooo1@00001?0?ooo`00D03oool5
000002L0oooo1@00000@0?ooo`030000003oool0oooo00`0oooo1@00000W0?ooo`D00000C`3oool0
0540oooo0`00000Y0?ooo`<000004@3oool2000000h0oooo0`00000Y0?ooo`<00000D03oool00940
oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool002/0oooo0`00000;0?ooo`<000002P3oool3000001<0oooo0`000006
0?ooo`<000002P3oool3000001<0oooo0`0000060?ooo`030000003oool0oooo0080oooo0`00000C
0?ooo`<000002`3oool3000000D0oooo0`00000C0?ooo`<000002`3oool3000000X0oooo0`00000Z
0?ooo`00:P3oool5000000T0oooo1@0000080?ooo`D000004@3oool5000000@0oooo1@0000080?oo
o`D000004@3oool5000000D0oooo00@000000?ooo`3oool0oooo1@00000A0?ooo`D000002@3oool5
000000<0oooo1@00000A0?ooo`D000002@3oool5000000P0oooo1@00000Y0?ooo`00:P3oool50000
00T0oooo1@0000080?ooo`D000004@3oool5000000@0oooo1@0000080?ooo`D000004@3oool50000
00D0oooo00@000000?ooo`3oool0oooo1@00000A0?ooo`D000002@3oool5000000<0oooo1@00000A
0?ooo`D000002@3oool5000000P0oooo1@00000Y0?ooo`00:P3oool5000000T0oooo1@0000080?oo
o`D000004@3oool5000000@0oooo1@0000080?ooo`D000004@3oool5000000D0oooo00@000000?oo
o`3oool0oooo1@00000A0?ooo`D000002@3oool5000000<0oooo1@00000A0?ooo`D000002@3oool5
000000P0oooo1@00000Y0?ooo`00:`3oool3000000/0oooo0`00000:0?ooo`<000004`3oool30000
00H0oooo0`00000:0?ooo`<000004`3oool3000000H0oooo00<000000?ooo`3oool00P3oool30000
01<0oooo0`00000;0?ooo`<000001@3oool3000001<0oooo0`00000;0?ooo`<000002P3oool30000
02X0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo000^0?ooo`<00000803oool3000002T0oooo0`00000A
0?ooo`030000003oool0oooo00d0oooo0`00000Y0?ooo`<000008@3oool3000002`0oooo000]0?oo
o`D000007P3oool5000002L0oooo1@00000@0?ooo`8000003@3oool5000002L0oooo1@00000O0?oo
o`D00000:`3oool002d0oooo1@00000N0?ooo`D000009`3oool500000100oooo00<000000?ooo`3o
ool0303oool5000002L0oooo1@00000O0?ooo`D00000:`3oool002d0oooo1@00000N0?ooo`D00000
9`3oool500000100oooo00<000000?ooo`3oool0303oool5000002L0oooo1@00000O0?ooo`D00000
:`3oool002h0oooo0`00000P0?ooo`<00000:@3oool300000140oooo00<000000?ooo`3oool03@3o
ool3000002T0oooo0`00000Q0?ooo`<00000;03oool003d0oooo0`00000;0?ooo`<000004`3oool3
000000X0oooo0`00000C0?ooo`<000002P3oool4000000D0oooo0`00000C0?ooo`<000002`3oool3
000001<0oooo0`00000:0?ooo`<00000?03oool003`0oooo1@0000090?ooo`D000004@3oool50000
00P0oooo1@00000A0?ooo`D000002@3oool5000000<0oooo1@00000A0?ooo`D000002@3oool50000
0140oooo1@0000080?ooo`D00000>`3oool003`0oooo1@0000090?ooo`D000004@3oool5000000P0
oooo1@00000A0?ooo`D000002@3oool5000000<0oooo1@00000A0?ooo`D000002@3oool500000140
oooo1@0000080?ooo`D00000>`3oool003`0oooo1@0000090?ooo`D000004@3oool5000000P0oooo
1@00000A0?ooo`D000002@3oool5000000<0oooo1@00000A0?ooo`D000002@3oool500000140oooo
1@0000080?ooo`D00000>`3oool003d0oooo0`00000;0?ooo`<000004`3oool3000000X0oooo0`00
000C0?ooo`<000002P3oool4000000D0oooo0`00000C0?ooo`<000002`3oool3000001<0oooo0`00
000:0?ooo`<00000?03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool001`0oooo0`0000050?ooo`<00000
2`3oool3000001<0oooo0`00000;0?ooo`<000004`3oool3000000X0oooo0`00000=0?ooo`800000
1P3oool00`000000oooo0?ooo`0A0?ooo`<000002`3oool3000001<0oooo0`00000:0?ooo`<00000
4`3oool3000000/0oooo0`0000050?ooo`<000006`3oool001/0oooo1@0000030?ooo`D000002@3o
ool500000140oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@00000;0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0403oool5000000T0oooo1@00000A0?ooo`D00000
203oool500000140oooo1@0000090?ooo`D000000`3oool5000001X0oooo000K0?ooo`D000000`3o
ool5000000T0oooo1@00000A0?ooo`D000002@3oool500000140oooo1@0000080?ooo`D000003P3o
ool00`000000oooo0?ooo`030?ooo`8000004@3oool5000000T0oooo1@00000A0?ooo`D00000203o
ool500000140oooo1@0000090?ooo`D000000`3oool5000001X0oooo000K0?ooo`D000000`3oool5
000000T0oooo1@00000A0?ooo`D000002@3oool500000140oooo1@0000080?ooo`D000001@3oool4
000000<0oooo0P0000060?ooo`030000003oool0oooo0100oooo1@0000090?ooo`D000004@3oool5
000000P0oooo1@00000A0?ooo`D000002@3oool5000000<0oooo1@00000J0?ooo`00703oool30000
00D0oooo0`00000;0?ooo`<000004`3oool3000000/0oooo0`00000C0?ooo`<000002P3oool30000
00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`<000002`3oool30000
01<0oooo0`00000:0?ooo`<000004`3oool3000000/0oooo0`0000050?ooo`<000006`3oool003T0
oooo0`00001<0?ooo`@000001@3oool00`000000oooo0?ooo`020?ooo`<00000C@3oool3000003L0
oooo000h0?ooo`D00000BP3oool5000000D0oooo00@000000?ooo`3oool0oooo1@00001;0?ooo`D0
0000=P3oool003P0oooo1@00001:0?ooo`D000001@3oool010000000oooo0?ooo`3oool5000004/0
oooo1@00000f0?ooo`00>03oool5000002@0oooo0`00000S0?ooo`D000001@3oool010000000oooo
0?ooo`3oool5000002@0oooo0`00000T0?ooo`D00000=P3oool003T0oooo0`00000T0?ooo`D00000
8`3oool3000000H0oooo00<000000?ooo`3oool00P3oool3000002@0oooo1@00000T0?ooo`<00000
=`3oool00600oooo1@00000/0?ooo`030000003oool0oooo02T0oooo1@00001N0?ooo`00H03oool5
000002`0oooo00<000000?ooo`3oool0:@3oool5000005h0oooo001Q0?ooo`<00000;@3oool00`00
0000oooo0?ooo`0Z0?ooo`<00000G`3oool00200oooo0`00000;0?ooo`<000004`3oool3000000X0
oooo0`0000060?ooo`<000004`3oool3000000X0oooo0`00000;0?ooo`<000000`3oool00`000000
oooo0?ooo`0=0?ooo`<000002`3oool3000001<0oooo0`0000050?ooo`<000002`3oool3000001<0
oooo0`00000:0?ooo`<000007`3oool001l0oooo1@0000090?ooo`D000004@3oool5000000P0oooo
1@0000040?ooo`D000004@3oool5000000P0oooo1@0000090?ooo`D000000P3oool00`000000oooo
0?ooo`0<0?ooo`D000002@3oool500000140oooo1@0000030?ooo`D000002@3oool500000140oooo
1@0000080?ooo`D000007P3oool001l0oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@00
00040?ooo`D000004@3oool5000000P0oooo1@0000090?ooo`D000000P3oool2000000d0oooo1@00
00090?ooo`D000004@3oool5000000<0oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@00
000N0?ooo`007`3oool5000000T0oooo1@00000A0?ooo`D00000203oool5000000@0oooo1@00000A
0?ooo`D00000203oool5000000T0oooo1@0000020?ooo`030000003oool0oooo00`0oooo1@000009
0?ooo`D000004@3oool5000000<0oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@00000N
0?ooo`00803oool3000000/0oooo0`00000C0?ooo`<000002P3oool3000000H0oooo0`00000C0?oo
o`<000002P3oool3000000/0oooo0`0000030?ooo`030000003oool0oooo00d0oooo0`00000;0?oo
o`<000004`3oool3000000D0oooo0`00000;0?ooo`<000004`3oool3000000X0oooo0`00000O0?oo
o`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3o
ool00`000000oooo0?ooo`2<0?ooo`005@3oool300000240oooo0`00000Y0?ooo`<000002P3oool3
000001<0oooo0`0000060?ooo`030000003oool0oooo0080oooo0`00000C0?ooo`<000002`3oool3
000002T0oooo0`00000P0?ooo`<00000503oool001@0oooo1@00000O0?ooo`D000009`3oool50000
00P0oooo1@00000A0?ooo`D000001@3oool010000000oooo0?ooo`3oool500000140oooo1@000009
0?ooo`D000009`3oool5000001h0oooo1@00000C0?ooo`00503oool5000001l0oooo1@00000W0?oo
o`D00000203oool500000140oooo1@0000050?ooo`040000003oool0oooo0?ooo`D000004@3oool5
000000T0oooo1@00000W0?ooo`D000007P3oool5000001<0oooo000D0?ooo`D000007`3oool50000
02L0oooo1@0000080?ooo`D000004@3oool5000000D0oooo00@000000?ooo`3oool0oooo1@00000A
0?ooo`D000002@3oool5000002L0oooo1@00000N0?ooo`D000004`3oool001D0oooo0`00000Q0?oo
o`<00000:@3oool3000000X0oooo0`00000C0?ooo`<000001P3oool00`000000oooo0?ooo`020?oo
o`<000004`3oool3000000/0oooo0`00000Y0?ooo`<00000803oool3000001@0oooo000T0?ooo`<0
00002`3oool3000001<0oooo0`00000;0?ooo`<00000803oool3000001D0oooo00<000000?ooo`3o
ool04@3oool300000240oooo0`00000:0?ooo`<000004`3oool3000000/0oooo0`00000S0?ooo`00
8`3oool5000000T0oooo1@00000A0?ooo`D000002@3oool5000001h0oooo1@00000D0?ooo`030000
003oool0oooo0100oooo1@00000O0?ooo`D00000203oool500000140oooo1@0000090?ooo`D00000
8P3oool002<0oooo1@0000090?ooo`D000004@3oool5000000T0oooo1@00000N0?ooo`D00000503o
ool00`000000oooo0?ooo`0@0?ooo`D000007`3oool5000000P0oooo1@00000A0?ooo`D000002@3o
ool500000280oooo000S0?ooo`D000002@3oool500000140oooo1@0000090?ooo`D000007P3oool5
000001@0oooo0P00000A0?ooo`D000007`3oool5000000P0oooo1@00000A0?ooo`D000002@3oool5
00000280oooo000T0?ooo`<000002`3oool3000001<0oooo0`00000;0?ooo`<00000803oool30000
01D0oooo00<000000?ooo`3oool04@3oool300000240oooo0`00000:0?ooo`<000004`3oool30000
00/0oooo0`00000S0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo
0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`004@3oool3000000D0oooo0`00000C
0?ooo`<000002`3oool3000000/0oooo0`00000C0?ooo`<000002P3oool3000001<0oooo0`00000:
0?ooo`@000001@3oool3000001<0oooo0`00000;0?ooo`<000004`3oool3000000X0oooo0`00000;
0?ooo`<000004`3oool3000000D0oooo0`00000@0?ooo`00403oool5000000<0oooo1@00000A0?oo
o`D000002@3oool5000000T0oooo1@00000A0?ooo`D00000203oool500000140oooo1@0000090?oo
o`D000000`3oool500000140oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@0000090?oo
o`D000004@3oool5000000<0oooo1@00000?0?ooo`00403oool5000000<0oooo1@00000A0?ooo`D0
00002@3oool5000000T0oooo1@00000A0?ooo`D00000203oool500000140oooo1@0000090?ooo`D0
00000`3oool500000140oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@0000090?ooo`D0
00004@3oool5000000<0oooo1@00000?0?ooo`00403oool5000000<0oooo1@00000A0?ooo`D00000
2@3oool5000000T0oooo1@00000A0?ooo`D00000203oool500000140oooo1@0000090?ooo`D00000
0`3oool500000140oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@0000090?ooo`D00000
4@3oool5000000<0oooo1@00000?0?ooo`004@3oool3000000D0oooo0`00000C0?ooo`<000002`3o
ool3000000/0oooo0`00000C0?ooo`<000002P3oool3000001<0oooo0`00000:0?ooo`@000001@3o
ool3000001<0oooo0`00000;0?ooo`<000004`3oool3000000X0oooo0`00000;0?ooo`<000004`3o
ool3000000D0oooo0`00000@0?ooo`00803oool3000006h0oooo00<000000?ooo`3oool0JP3oool3
000001l0oooo000O0?ooo`D00000K@3oool00`000000oooo0?ooo`1Y0?ooo`D000007P3oool001l0
oooo1@00001]0?ooo`030000003oool0oooo06T0oooo1@00000N0?ooo`007`3oool5000002@0oooo
0`00000;0?ooo`<00000803oool3000001D0oooo00<000000?ooo`3oool04@3oool300000240oooo
0`00000:0?ooo`<00000903oool5000001h0oooo000P0?ooo`<00000903oool5000000T0oooo1@00
000N0?ooo`D00000503oool200000140oooo1@00000O0?ooo`D00000203oool5000002@0oooo0`00
000O0?ooo`00A`3oool5000000T0oooo1@00000N0?ooo`D00000503oool00`000000oooo0?ooo`0@
0?ooo`D000007`3oool5000000P0oooo1@0000160?ooo`00A`3oool5000000T0oooo1@00000N0?oo
o`D00000503oool00`000000oooo0?ooo`0@0?ooo`D000007`3oool5000000P0oooo1@0000160?oo
o`00B03oool3000000/0oooo0`00000P0?ooo`<000005@3oool00`000000oooo0?ooo`0A0?ooo`<0
00008@3oool3000000X0oooo0`0000170?ooo`005@3oool3000001<0oooo0`00000;0?ooo`<00000
:@3oool3000000X0oooo0`00000C0?ooo`<000001P3oool00`000000oooo0?ooo`020?ooo`<00000
4`3oool3000000/0oooo0`00000Y0?ooo`<000002P3oool3000001<0oooo0`00000D0?ooo`00503o
ool500000140oooo1@0000090?ooo`D000009`3oool5000000P0oooo1@00000A0?ooo`D000001@3o
ool010000000oooo0?ooo`3oool500000140oooo1@0000090?ooo`D000009`3oool5000000P0oooo
1@00000A0?ooo`D000004`3oool001@0oooo1@00000A0?ooo`D000002@3oool5000002L0oooo1@00
00080?ooo`D000004@3oool5000000D0oooo00@000000?ooo`3oool0oooo1@00000A0?ooo`D00000
2@3oool5000002L0oooo1@0000080?ooo`D000004@3oool5000001<0oooo000D0?ooo`D000004@3o
ool5000000T0oooo1@00000W0?ooo`D00000203oool500000140oooo1@0000050?ooo`040000003o
ool0oooo0?ooo`D000004@3oool5000000T0oooo1@00000W0?ooo`D00000203oool500000140oooo
1@00000C0?ooo`005@3oool3000001<0oooo0`00000;0?ooo`<00000:@3oool3000000X0oooo0`00
000C0?ooo`<000001P3oool00`000000oooo0?ooo`020?ooo`<000004`3oool3000000/0oooo0`00
000Y0?ooo`<000002P3oool3000001<0oooo0`00000D0?ooo`00T@3oool00`000000oooo0?ooo`2<
0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00T@3oool00`000000oooo0?ooo`2<0?ooo`00
2P3oool3000001<0oooo0`00000;0?ooo`<000004`3oool3000000X0oooo0`0000060?ooo`<00000
4`3oool3000000X0oooo0`00000;0?ooo`<000000`3oool00`000000oooo0?ooo`0=0?ooo`<00000
2`3oool3000001<0oooo0`0000050?ooo`<000002`3oool3000001<0oooo0`00000:0?ooo`<00000
4`3oool3000000T0oooo00090?ooo`D000004@3oool5000000T0oooo1@00000A0?ooo`D00000203o
ool5000000@0oooo1@00000A0?ooo`D00000203oool5000000T0oooo1@0000020?ooo`8000003@3o
ool5000000T0oooo1@00000A0?ooo`D000000`3oool5000000T0oooo1@00000A0?ooo`D00000203o
ool500000140oooo1@0000080?ooo`002@3oool500000140oooo1@0000090?ooo`D000004@3oool5
000000P0oooo1@0000040?ooo`D000004@3oool5000000P0oooo1@0000090?ooo`D000000P3oool0
0`000000oooo0?ooo`0<0?ooo`D000002@3oool500000140oooo1@0000030?ooo`D000002@3oool5
00000140oooo1@0000080?ooo`D000004@3oool5000000P0oooo00070?ooo`T000003`3oool50000
00T0oooo1@00000A0?ooo`D000001`3oool6000000@0oooo1@00000A0?ooo`D00000203oool50000
00T0oooo1@0000020?ooo`030000003oool0oooo00`0oooo1@0000090?ooo`D000004@3oool50000
00<0oooo1@0000030?ooo`800000103oool500000140oooo1@0000080?ooo`D000004@3oool60000
0080oooo0P0000030?ooo`002@3oool500000080oooo00<000000?ooo`3oool03@3oool3000000/0
oooo0`00000C0?ooo`<000001`3oool00`000000oooo0?ooo`03000000H0oooo0`00000C0?ooo`<0
00002P3oool3000000/0oooo0`0000030?ooo`030000003oool0oooo00d0oooo0`00000;0?ooo`<0
00004`3oool3000000D0oooo0`0000030?ooo`040000003oool0oooo000000@0oooo0`00000C0?oo
o`<000002P3oool3000001<0oooo0`0000030?ooo`040000003oool0oooo00000080oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool4000002T0oooo0`00000A0?ooo`030000003oool0
oooo00d0oooo0`00000]0?ooo`030000003oool0oooo02X0oooo0`00000E0?ooo`030000003oool0
oooo00P0oooo0`00000Y0?ooo`<000001P3oool01@000000oooo0?ooo`3oool000000080oooo0@00
00010?ooo`40oooo00000`3oool0000000000002000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`D000009`3oool5000000L0oooo100000030?ooo`8000003`3oool5000002`0oooo00<0
00000?ooo`3oool0:@3oool500000180oooo0P00000:0?ooo`D000009`3oool5000000D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`4000000@3oool10?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo1@00000W0?ooo`D000003P3oool00`000000oooo0?ooo`0>0?ooo`D00000
;03oool00`000000oooo0?ooo`0Y0?ooo`D000004P3oool00`000000oooo0?ooo`090?ooo`D00000
9`3oool5000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`4000000@3oool10?ooo`00
203oool2000000@0oooo1`00000W0?ooo`D000003P3oool3000000h0oooo1@00000S0?ooo`<00000
1P3oool00`000000oooo0?ooo`020?ooo`<00000903oool500000180oooo0`0000090?ooo`D00000
9`3oool5000000@0oooo0P0000040?ooo`8000000`3oool00140oooo0`00000Y0?ooo`<000008@3o
ool3000002<0oooo1@0000050?ooo`040000003oool0oooo0?ooo`D00000903oool300000200oooo
0`00000Y0?ooo`<00000403oool008L0oooo1@0000050?ooo`040000003oool0oooo0?ooo`D00000
QP3oool008L0oooo1@0000050?ooo`040000003oool0oooo0?ooo`D00000QP3oool008P0oooo0`00
00060?ooo`030000003oool0oooo0080oooo0`0000270?ooo`00703oool3000000D0oooo0`00000;
0?ooo`<000004`3oool3000000/0oooo0`00000C0?ooo`<000002P3oool3000001D0oooo00<00000
0?ooo`3oool04@3oool3000000/0oooo0`00000C0?ooo`<000002P3oool3000001<0oooo0`00000;
0?ooo`<000001@3oool3000001/0oooo000K0?ooo`D000000`3oool5000000T0oooo1@00000A0?oo
o`D000002@3oool500000140oooo1@0000080?ooo`D00000503oool00`000000oooo0?ooo`0@0?oo
o`D000002@3oool500000140oooo1@0000080?ooo`D000004@3oool5000000T0oooo1@0000030?oo
o`D000006P3oool000D0ooooo`00000I000000<0oooo00090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool5000000<0oooo1@0000090?ooo`D000002@3oool00`000000oooo
0?ooo`050?ooo`D0000000<0oooo0000003oool01P3oool6000000d0oooo00<000000?ooo`3oool0
1@0000050?ooo`030000003oool0oooo00D000001P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool5000000<0oooo00<000000?ooo`3oool0
0`3oool500000080oooo00<000000?ooo`3oool02`3oool6000000P0oooo1@0000080?ooo`030000
003oool0oooo00H0oooo1P0000080?ooo`D000000`3oool5000000D0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`040?ooo`00703oool3000000D0oooo0`00000;0?ooo`<000004`3o
ool3000000/0oooo0`00000C0?ooo`<000002P3oool3000001D0oooo00<000000?ooo`3oool04@3o
ool3000000/0oooo0`00000C0?ooo`<000002P3oool3000001<0oooo0`00000;0?ooo`<000001@3o
ool3000001/0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo000A0?ooo`<00000:@3oool300000240oooo
0`00000:0?ooo`<000004`3oool3000000X0oooo100000050?ooo`<000004`3oool3000000/0oooo
0`00000P0?ooo`<00000:@3oool300000100oooo000@0?ooo`D000009`3oool5000001l0oooo1@00
00080?ooo`D000004@3oool5000000T0oooo1@0000030?ooo`D000004@3oool5000000T0oooo1@00
000N0?ooo`D000009`3oool5000000l0oooo000@0?ooo`D000009`3oool5000001l0oooo1@000008
0?ooo`D000004@3oool5000000T0oooo1@0000030?ooo`D000004@3oool5000000T0oooo1@00000N
0?ooo`D000009`3oool5000000l0oooo000@0?ooo`D000009`3oool5000001l0oooo1@0000080?oo
o`D000004@3oool5000000T0oooo1@0000030?ooo`D000004@3oool5000000T0oooo1@00000N0?oo
o`D000009`3oool5000000l0oooo000A0?ooo`<00000:@3oool300000240oooo0`00000:0?ooo`<0
00004`3oool3000000X0oooo100000050?ooo`<000004`3oool3000000/0oooo0`00000P0?ooo`<0
0000:@3oool300000100oooo000:0?ooo`<000004`3oool3000000/0oooo0`00000C0?ooo`<00000
2P3oool3000002T0oooo0`00000A0?ooo`030000003oool0oooo00d0oooo0`00000Y0?ooo`<00000
2`3oool3000001<0oooo0`00000:0?ooo`<000004`3oool3000000T0oooo00090?ooo`D000004@3o
ool5000000T0oooo1@00000A0?ooo`D00000203oool5000002L0oooo1@00000@0?ooo`030000003o
ool0oooo00`0oooo1@00000W0?ooo`D000002@3oool500000140oooo1@0000080?ooo`D000004@3o
ool5000000P0oooo00090?ooo`D000004@3oool5000000T0oooo1@00000A0?ooo`D00000203oool5
000002L0oooo1@00000@0?ooo`8000003@3oool5000002L0oooo1@0000090?ooo`D000004@3oool5
000000P0oooo1@00000A0?ooo`D00000203oool000T0oooo1@00000A0?ooo`D000002@3oool50000
0140oooo1@0000080?ooo`D000009`3oool500000100oooo00<000000?ooo`3oool0303oool50000
02L0oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@00000A0?ooo`D00000203oool000X0
oooo0`00000C0?ooo`<000002`3oool3000001<0oooo0`00000:0?ooo`<00000:@3oool300000140
oooo00<000000?ooo`3oool03@3oool3000002T0oooo0`00000;0?ooo`<000004`3oool3000000X0
oooo0`00000C0?ooo`<000002@3oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool001D0oooo0`00000C0?oo
o`<000002`3oool3000000X0oooo0`00000C0?ooo`<000001P3oool3000000X0oooo0`00000C0?oo
o`<000001P3oool00`000000oooo0?ooo`020?ooo`<000004`3oool3000000/0oooo0`0000050?oo
o`<000004`3oool3000000/0oooo0`00000:0?ooo`<000004`3oool3000001@0oooo000D0?ooo`D0
00004@3oool5000000T0oooo1@0000080?ooo`D000004@3oool5000000@0oooo1@0000080?ooo`D0
00004@3oool5000000D0oooo00@000000?ooo`3oool0oooo1@00000A0?ooo`D000002@3oool50000
00<0oooo1@00000A0?ooo`D000002@3oool5000000P0oooo1@00000A0?ooo`D000004`3oool001@0
oooo1@00000A0?ooo`D000002@3oool5000000P0oooo1@00000A0?ooo`D00000103oool5000000P0
oooo1@00000A0?ooo`D000001@3oool010000000oooo0?ooo`3oool500000140oooo1@0000090?oo
o`D000000`3oool500000140oooo1@0000090?ooo`D00000203oool500000140oooo1@00000C0?oo
o`00503oool500000140oooo1@0000090?ooo`D00000203oool500000140oooo1@0000040?ooo`D0
0000203oool500000140oooo1@0000050?ooo`040000003oool0oooo0?ooo`D000004@3oool50000
00T0oooo1@0000030?ooo`D000004@3oool5000000T0oooo1@0000080?ooo`D000004@3oool50000
01<0oooo000E0?ooo`<000004`3oool3000000/0oooo0`00000:0?ooo`<000004`3oool3000000H0
oooo0`00000:0?ooo`<000004`3oool3000000H0oooo00<000000?ooo`3oool00P3oool3000001<0
oooo0`00000;0?ooo`<000001@3oool3000001<0oooo0`00000;0?ooo`<000002P3oool3000001<0
oooo0`00000D0?ooo`00EP3oool3000003P0oooo00<000000?ooo`3oool0=@3oool3000005@0oooo
001E0?ooo`D00000=`3oool00`000000oooo0?ooo`0d0?ooo`D00000D`3oool005D0oooo1@00000g
0?ooo`030000003oool0oooo03@0oooo1@00001C0?ooo`00803oool3000000/0oooo0`00000T0?oo
o`D000008`3oool300000140oooo0P00000>0?ooo`<00000903oool5000002@0oooo0`00000:0?oo
o`<000007`3oool001l0oooo1@0000090?ooo`D00000903oool3000002<0oooo1@00000@0?ooo`03
0000003oool0oooo00`0oooo1@00000T0?ooo`<00000903oool5000000P0oooo1@00000N0?ooo`00
7`3oool5000000T0oooo1@00001:0?ooo`D00000403oool00`000000oooo0?ooo`0<0?ooo`D00000
B`3oool5000000P0oooo1@00000N0?ooo`007`3oool5000000T0oooo1@00001:0?ooo`D00000403o
ool00`000000oooo0?ooo`0<0?ooo`D00000B`3oool5000000P0oooo1@00000N0?ooo`00803oool3
000000/0oooo0`00001<0?ooo`<000004@3oool00`000000oooo0?ooo`0=0?ooo`<00000C@3oool3
000000X0oooo0`00000O0?ooo`004@3oool3000002T0oooo0`00000;0?ooo`<000004`3oool30000
00X0oooo0`00000C0?ooo`<000002P3oool4000000D0oooo0`00000C0?ooo`<000002`3oool30000
01<0oooo0`00000:0?ooo`<00000:@3oool300000100oooo000@0?ooo`D000009`3oool5000000T0
oooo1@00000A0?ooo`D00000203oool500000140oooo1@0000090?ooo`D000000`3oool500000140
oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@00000W0?ooo`D000003`3oool00100oooo
1@00000W0?ooo`D000002@3oool500000140oooo1@0000080?ooo`D000004@3oool5000000T0oooo
1@0000030?ooo`D000004@3oool5000000T0oooo1@00000A0?ooo`D00000203oool5000002L0oooo
1@00000?0?ooo`00403oool5000002L0oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@00
000A0?ooo`D000002@3oool5000000<0oooo1@00000A0?ooo`D000002@3oool500000140oooo1@00
00080?ooo`D000009`3oool5000000l0oooo000A0?ooo`<00000:@3oool3000000/0oooo0`00000C
0?ooo`<000002P3oool3000001<0oooo0`00000:0?ooo`@000001@3oool3000001<0oooo0`00000;
0?ooo`<000004`3oool3000000X0oooo0`00000Y0?ooo`<00000403oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool001`0oooo0`0000050?ooo`<000002`3oool3000001<0oooo0`00000;0?ooo`<000004`3o
ool3000000X0oooo0`00000E0?ooo`030000003oool0oooo0140oooo0`00000;0?ooo`<000004`3o
ool3000000X0oooo0`00000C0?ooo`<000002`3oool3000000D0oooo0`00000K0?ooo`006`3oool5
000000<0oooo1@0000090?ooo`D000004@3oool5000000T0oooo1@00000A0?ooo`D00000203oool5
000001@0oooo0P00000A0?ooo`D000002@3oool500000140oooo1@0000080?ooo`D000004@3oool5
000000T0oooo1@0000030?ooo`D000006P3oool001/0oooo1@0000030?ooo`D000002@3oool50000
0140oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@00000D0?ooo`030000003oool0oooo
0100oooo1@0000090?ooo`D000004@3oool5000000P0oooo1@00000A0?ooo`D000002@3oool50000
00<0oooo1@00000J0?ooo`006`3oool5000000<0oooo1@0000090?ooo`D000004@3oool5000000T0
oooo1@00000A0?ooo`D00000203oool5000001@0oooo00<000000?ooo`3oool0403oool5000000T0
oooo1@00000A0?ooo`D00000203oool500000140oooo1@0000090?ooo`D000000`3oool5000001X0
oooo000L0?ooo`<000001@3oool3000000/0oooo0`00000C0?ooo`<000002`3oool3000001<0oooo
0`00000:0?ooo`<000005@3oool00`000000oooo0?ooo`0A0?ooo`<000002`3oool3000001<0oooo
0`00000:0?ooo`<000004`3oool3000000/0oooo0`0000050?ooo`<000006`3oool001D0oooo0`00
000Q0?ooo`<00000:@3oool300000200oooo0`0000060?ooo`030000003oool0oooo0080oooo0`00
000Q0?ooo`<00000:@3oool300000200oooo0`00000D0?ooo`00503oool5000001l0oooo1@00000W
0?ooo`D000007P3oool5000000D0oooo00@000000?ooo`3oool0oooo1@00000O0?ooo`D000009`3o
ool5000001h0oooo1@00000C0?ooo`00503oool5000001l0oooo1@00000W0?ooo`D000007P3oool5
000000D0oooo00@000000?ooo`3oool0oooo1@00000O0?ooo`D000009`3oool5000001h0oooo1@00
000C0?ooo`00503oool5000001l0oooo1@00000W0?ooo`D000007P3oool5000000D0oooo00@00000
0?ooo`3oool0oooo1@00000O0?ooo`D000009`3oool5000001h0oooo1@00000C0?ooo`005@3oool3
00000240oooo0`00000Y0?ooo`<00000803oool3000000H0oooo00<000000?ooo`3oool00P3oool3
00000240oooo0`00000Y0?ooo`<00000803oool3000001@0oooo002A0?ooo`030000003oool0oooo
08`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
000P0?ooo`<000002`3oool3000001<0oooo0`00000:0?ooo`<000001P3oool3000001<0oooo0`00
000:0?ooo`<000002`3oool3000000<0oooo00<000000?ooo`3oool03@3oool3000000/0oooo0`00
000C0?ooo`<000001@3oool3000000/0oooo0`00000C0?ooo`<000002P3oool3000001l0oooo000O
0?ooo`D000002@3oool500000140oooo1@0000080?ooo`D00000103oool500000140oooo1@000008
0?ooo`D000002@3oool500000080oooo0P00000=0?ooo`D000002@3oool500000140oooo1@000003
0?ooo`D000002@3oool500000140oooo1@0000080?ooo`D000007P3oool001l0oooo1@0000090?oo
o`D000004@3oool5000000P0oooo1@0000040?ooo`D000004@3oool5000000P0oooo1@0000090?oo
o`D000000P3oool00`000000oooo0?ooo`0<0?ooo`D000002@3oool500000140oooo1@0000030?oo
o`D000002@3oool500000140oooo1@0000080?ooo`D000007P3oool001l0oooo1@0000090?ooo`D0
00004@3oool5000000P0oooo1@0000040?ooo`D000004@3oool5000000P0oooo1@0000090?ooo`D0
00000P3oool00`000000oooo0?ooo`0<0?ooo`D000002@3oool500000140oooo1@0000030?ooo`D0
00002@3oool500000140oooo1@0000080?ooo`D000007P3oool00200oooo0`00000;0?ooo`<00000
4`3oool3000000X0oooo0`0000060?ooo`<000004`3oool3000000X0oooo0`00000;0?ooo`<00000
0`3oool00`000000oooo0?ooo`0=0?ooo`<000002`3oool3000001<0oooo0`0000050?ooo`<00000
2`3oool3000001<0oooo0`00000:0?ooo`<000007`3oool00940oooo00<000000?ooo`3oool0S03o
ool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool003T0
oooo0`00000Y0?ooo`<00000803oool3000000H0oooo00<000000?ooo`3oool00P3oool300000240
oooo0`00000Y0?ooo`<00000=`3oool003P0oooo1@00000W0?ooo`D000007P3oool5000000D0oooo
00@000000?ooo`3oool0oooo1@00000O0?ooo`D000009`3oool5000003H0oooo000h0?ooo`D00000
9`3oool5000001h0oooo1@0000050?ooo`040000003oool0oooo0?ooo`D000007`3oool5000002L0
oooo1@00000f0?ooo`00>03oool5000002L0oooo1@00000N0?ooo`D000001@3oool010000000oooo
0?ooo`3oool5000001l0oooo1@00000W0?ooo`D00000=P3oool003T0oooo0`00000Y0?ooo`<00000
803oool3000000H0oooo00<000000?ooo`3oool00P3oool300000240oooo0`00000Y0?ooo`<00000
=`3oool001`0oooo0`0000050?ooo`<000002`3oool3000001<0oooo0`00000;0?ooo`<000004`3o
ool3000000X0oooo0`00000=0?ooo`8000001P3oool00`000000oooo0?ooo`0A0?ooo`<000002`3o
ool3000001<0oooo0`00000:0?ooo`<000004`3oool3000000/0oooo0`0000050?ooo`<000006`3o
ool001/0oooo1@0000030?ooo`D000002@3oool500000140oooo1@0000090?ooo`D000004@3oool5
000000P0oooo1@00000;0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0403o
ool5000000T0oooo1@00000A0?ooo`D00000203oool500000140oooo1@0000090?ooo`D000000`3o
ool5000001X0oooo000K0?ooo`D000000`3oool5000000T0oooo1@00000A0?ooo`D000002@3oool5
00000140oooo1@0000080?ooo`D000003P3oool00`000000oooo0?ooo`030?ooo`8000004@3oool5
000000T0oooo1@00000A0?ooo`D00000203oool500000140oooo1@0000090?ooo`D000000`3oool5
000001X0oooo000K0?ooo`D000000`3oool5000000T0oooo1@00000A0?ooo`D000002@3oool50000
0140oooo1@0000080?ooo`D00000303oool2000000H0oooo00<000000?ooo`3oool0403oool50000
00T0oooo1@00000A0?ooo`D00000203oool500000140oooo1@0000090?ooo`D000000`3oool50000
01X0oooo000L0?ooo`<000001@3oool3000000/0oooo0`00000C0?ooo`<000002`3oool3000001<0
oooo0`00000:0?ooo`<000003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0140
oooo0`00000;0?ooo`<000004`3oool3000000X0oooo0`00000C0?ooo`<000002`3oool3000000D0
oooo0`00000K0?ooo`00R@3oool3000000D0oooo00<000000?ooo`3oool0S03oool00940oooo00<0
00000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool003d0oooo0`00000;0?oo
o`<000004`3oool3000000X0oooo0`00000C0?ooo`<000002P3oool4000000D0oooo0`00000C0?oo
o`<000002`3oool3000001<0oooo0`00000:0?ooo`<00000?03oool003`0oooo1@0000090?ooo`D0
00004@3oool5000000P0oooo1@00000A0?ooo`D000002@3oool5000000<0oooo1@00000A0?ooo`D0
00002@3oool500000140oooo1@0000080?ooo`D00000>`3oool003`0oooo1@0000090?ooo`D00000
4@3oool5000000P0oooo1@00000A0?ooo`D000002@3oool5000000<0oooo1@00000A0?ooo`D00000
2@3oool500000140oooo1@0000080?ooo`D00000>`3oool003`0oooo1@0000090?ooo`D000004@3o
ool5000000P0oooo1@00000A0?ooo`D000002@3oool5000000<0oooo1@00000A0?ooo`D000002@3o
ool500000140oooo1@0000080?ooo`D00000>`3oool003d0oooo0`00000;0?ooo`<000004`3oool3
000000X0oooo0`00000C0?ooo`<000002P3oool4000000D0oooo0`00000C0?ooo`<000002`3oool3
000001<0oooo0`00000:0?ooo`<00000?03oool002h0oooo0`00001<0?ooo`<000004@3oool00`00
0000oooo0?ooo`0=0?ooo`<00000C@3oool3000002`0oooo000]0?ooo`D00000BP3oool500000100
oooo00<000000?ooo`3oool0303oool5000004/0oooo1@00000[0?ooo`00;@3oool5000004X0oooo
1@00000@0?ooo`8000003@3oool5000004/0oooo1@00000[0?ooo`00;@3oool5000002@0oooo0`00
000S0?ooo`D00000403oool00`000000oooo0?ooo`0<0?ooo`D00000903oool3000002@0oooo1@00
000[0?ooo`00;P3oool3000002@0oooo1@00000S0?ooo`<000004@3oool00`000000oooo0?ooo`0=
0?ooo`<00000903oool5000002@0oooo0`00000/0?ooo`00E@3oool5000003L0oooo00<000000?oo
o`3oool0=03oool5000005<0oooo001E0?ooo`D00000=`3oool00`000000oooo0?ooo`0d0?ooo`D0
0000D`3oool005H0oooo0`00000h0?ooo`030000003oool0oooo03D0oooo0`00001D0?ooo`00:`3o
ool3000000/0oooo0`00000:0?ooo`<000004`3oool3000000H0oooo0`00000:0?ooo`<000004`3o
ool3000000H0oooo00<000000?ooo`3oool00P3oool3000001<0oooo0`00000;0?ooo`<000001@3o
ool3000001<0oooo0`00000;0?ooo`<000002P3oool3000002X0oooo000Z0?ooo`D000002@3oool5
000000P0oooo1@00000A0?ooo`D00000103oool5000000P0oooo1@00000A0?ooo`D000001@3oool0
10000000oooo0?ooo`3oool500000140oooo1@0000090?ooo`D000000`3oool500000140oooo1@00
00090?ooo`D00000203oool5000002T0oooo000Z0?ooo`D000002@3oool5000000P0oooo1@00000A
0?ooo`D00000103oool5000000P0oooo1@00000A0?ooo`D000001@3oool010000000oooo0?ooo`3o
ool500000140oooo1@0000090?ooo`D000000`3oool500000140oooo1@0000090?ooo`D00000203o
ool5000002T0oooo000Z0?ooo`D000002@3oool5000000P0oooo1@00000A0?ooo`D00000103oool5
000000P0oooo1@00000A0?ooo`D000001@3oool010000000oooo0?ooo`3oool500000140oooo1@00
00090?ooo`D000000`3oool500000140oooo1@0000090?ooo`D00000203oool5000002T0oooo000[
0?ooo`<000002`3oool3000000X0oooo0`00000C0?ooo`<000001P3oool3000000X0oooo0`00000C
0?ooo`<000001P3oool00`000000oooo0?ooo`020?ooo`<000004`3oool3000000/0oooo0`000005
0?ooo`<000004`3oool3000000/0oooo0`00000:0?ooo`<00000:P3oool00940oooo00<000000?oo
o`3oool0S03oool00940oooo00<000000?ooo`3oool0S03oool00940oooo00<000000?ooo`3oool0
S03oool004@0oooo0`00000:0?ooo`<00000:@3oool300000140oooo0P00000>0?ooo`<00000:@3o
ool3000000/0oooo0`0000120?ooo`00@`3oool5000000P0oooo1@00000W0?ooo`D00000403oool0
0`000000oooo0?ooo`0<0?ooo`D000009`3oool5000000T0oooo1@0000110?ooo`00@`3oool50000
00P0oooo1@00000W0?ooo`D00000403oool00`000000oooo0?ooo`0<0?ooo`D000009`3oool50000
00T0oooo1@0000110?ooo`00@`3oool5000000P0oooo1@00000W0?ooo`D00000403oool00`000000
oooo0?ooo`0<0?ooo`D000009`3oool5000000T0oooo1@0000110?ooo`00A03oool3000000X0oooo
0`00000Y0?ooo`<000004@3oool00`000000oooo0?ooo`0=0?ooo`<00000:@3oool3000000/0oooo
0`0000120?ooo`00?@3oool300000240oooo0`00000:0?ooo`<000004`3oool3000000X0oooo1000
00050?ooo`<000004`3oool3000000/0oooo0`00000P0?ooo`<00000?03oool003`0oooo1@00000O
0?ooo`D00000203oool500000140oooo1@0000090?ooo`D000000`3oool500000140oooo1@000009
0?ooo`D000007P3oool5000003/0oooo000l0?ooo`D000007`3oool5000000P0oooo1@00000A0?oo
o`D000002@3oool5000000<0oooo1@00000A0?ooo`D000002@3oool5000001h0oooo1@00000k0?oo
o`00?03oool5000001l0oooo1@0000080?ooo`D000004@3oool5000000T0oooo1@0000030?ooo`D0
00004@3oool5000000T0oooo1@00000N0?ooo`D00000>`3oool003d0oooo0`00000Q0?ooo`<00000
2P3oool3000001<0oooo0`00000:0?ooo`@000001@3oool3000001<0oooo0`00000;0?ooo`<00000
803oool3000003`0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0
oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo00180?ooo`<000002`3oool3000001<0
oooo0`00000:0?ooo`<000005@3oool00`000000oooo0?ooo`0A0?ooo`<000002`3oool3000001<0
oooo0`00000:0?ooo`<00000A`3oool004L0oooo1@0000090?ooo`D000004@3oool5000000P0oooo
1@00000D0?ooo`8000004@3oool5000000T0oooo1@00000A0?ooo`D00000203oool5000004H0oooo
00170?ooo`D000002@3oool500000140oooo1@0000080?ooo`D00000503oool00`000000oooo0?oo
o`0@0?ooo`D000002@3oool500000140oooo1@0000080?ooo`D00000AP3oool004L0oooo1@000009
0?ooo`D000004@3oool5000000P0oooo1@00000D0?ooo`030000003oool0oooo0100oooo1@000009
0?ooo`D000004@3oool5000000P0oooo1@0000160?ooo`00B03oool3000000/0oooo0`00000C0?oo
o`<000002P3oool3000001D0oooo00<000000?ooo`3oool04@3oool3000000/0oooo0`00000C0?oo
o`<000002P3oool3000004L0oooo00280?ooo`<000001P3oool00`000000oooo0?ooo`020?ooo`<0
0000Q`3oool008L0oooo1@0000050?ooo`040000003oool0oooo0?ooo`D00000QP3oool008L0oooo
1@0000050?ooo`040000003oool0oooo0?ooo`D00000QP3oool00640oooo0`00000S0?ooo`D00000
1@3oool010000000oooo0?ooo`3oool5000002@0oooo0`00001O0?ooo`00H03oool5000002<0oooo
0`0000060?ooo`030000003oool0oooo0080oooo0`00000T0?ooo`D00000GP3oool00600oooo1@00
000/0?ooo`030000003oool0oooo02T0oooo1@00001N0?ooo`00H03oool5000002`0oooo00<00000
0?ooo`3oool0:@3oool5000005h0oooo001Q0?ooo`<00000;@3oool00`000000oooo0?ooo`0Z0?oo
o`<00000G`3oool005X0oooo0`00000C0?ooo`<000002P3oool3000000/0oooo0`0000030?ooo`03
0000003oool0oooo00d0oooo0`00000;0?ooo`<000004`3oool3000005P0oooo001I0?ooo`D00000
4@3oool5000000P0oooo1@0000090?ooo`D000000P3oool2000000d0oooo1@0000090?ooo`D00000
4@3oool5000005L0oooo001I0?ooo`D000004@3oool5000000P0oooo1@0000090?ooo`D000000P3o
ool00`000000oooo0?ooo`0<0?ooo`D000002@3oool500000140oooo1@00001G0?ooo`00F@3oool5
00000140oooo1@0000080?ooo`D000002@3oool500000080oooo00<000000?ooo`3oool0303oool5
000000T0oooo1@00000A0?ooo`D00000E`3oool005X0oooo0`00000C0?ooo`<000002P3oool30000
00/0oooo0`0000030?ooo`030000003oool0oooo00d0oooo0`00000;0?ooo`<000004`3oool30000
05P0oooo002A0?ooo`030000003oool0oooo08`0oooo002A0?ooo`030000003oool0oooo08`0oooo
002A0?ooo`030000003oool0oooo08`0oooo001b0?ooo`<000004`3oool3000000H0oooo00<00000
0?ooo`3oool00P3oool3000001<0oooo0`00001a0?ooo`00L@3oool500000140oooo1@0000050?oo
o`040000003oool0oooo0?ooo`D000004@3oool500000700oooo001a0?ooo`D000004@3oool50000
00D0oooo00@000000?ooo`3oool0oooo1@00000A0?ooo`D00000L03oool00740oooo1@00000A0?oo
o`D000001@3oool010000000oooo0?ooo`3oool500000140oooo1@00001`0?ooo`00LP3oool30000
01<0oooo0`0000060?ooo`030000003oool0oooo0080oooo0`00000C0?ooo`<00000L@3oool00880
oooo1@0000020?ooo`8000001P3oool00`000000oooo0?ooo`2<0?ooo`00Q03oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2<0?ooo`00
Q03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool2000008d0
oooo00240?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo08`0oooo00240?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`2B0?ooo`00P`3oool2000000@0oooo0P00002E0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {281.5, 0}} -> {-10.6618, -10.3492, 0.0735294, \
0.0735294}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[409]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(tiling2D[SphericalCut[N[QL], 15], \ 1.0]\)], "Input",
  CellLabel->"In[410]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .98313 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0321181 0.491565 0.0321181 [
[ 0 0 0 0 ]
[ 1 .98313 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .98313 L
0 .98313 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.33183 .23277 m
.36395 .23277 L
s
.33183 .23277 m
.36395 .23277 L
s
.33183 .23277 m
.30584 .25165 L
s
.33183 .23277 m
.30584 .25165 L
s
.33183 .23277 m
.36395 .23277 L
s
.33183 .23277 m
.36395 .23277 L
s
.33183 .23277 m
.30584 .25165 L
s
.33183 .23277 m
.3219 .20223 L
s
.33183 .23277 m
.36395 .23277 L
s
.33183 .23277 m
.36395 .23277 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .75036 m
.30584 .73148 L
s
.33183 .75036 m
.30584 .76923 L
s
.33183 .75036 m
.30584 .76923 L
s
.33183 .75036 m
.30584 .76923 L
s
.33183 .75036 m
.3219 .71981 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .75036 m
.30584 .73148 L
s
.33183 .75036 m
.3219 .7809 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .17168 m
.36395 .17168 L
s
.33183 .17168 m
.30584 .1528 L
s
.33183 .17168 m
.30584 .1528 L
s
.33183 .17168 m
.3219 .20223 L
s
.33183 .17168 m
.36395 .17168 L
s
.33183 .17168 m
.30584 .1528 L
s
.33183 .23277 m
.36395 .23277 L
s
.33183 .23277 m
.36395 .23277 L
s
.33183 .23277 m
.30584 .25165 L
s
.33183 .23277 m
.30584 .25165 L
s
.33183 .23277 m
.36395 .23277 L
s
.33183 .23277 m
.36395 .23277 L
s
.33183 .23277 m
.30584 .25165 L
s
.33183 .23277 m
.3219 .20223 L
s
.33183 .23277 m
.36395 .23277 L
s
.33183 .23277 m
.36395 .23277 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .75036 m
.30584 .73148 L
s
.33183 .75036 m
.30584 .76923 L
s
.33183 .75036 m
.30584 .76923 L
s
.33183 .75036 m
.30584 .76923 L
s
.33183 .75036 m
.3219 .71981 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .75036 m
.30584 .73148 L
s
.33183 .75036 m
.3219 .7809 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .81145 m
.36395 .81145 L
s
.33183 .81145 m
.30584 .83033 L
s
.33183 .81145 m
.30584 .83033 L
s
.33183 .81145 m
.3219 .7809 L
s
.33183 .81145 m
.36395 .81145 L
s
.33183 .81145 m
.30584 .83033 L
s
.36395 .23277 m
.33796 .25165 L
s
.36395 .23277 m
.38993 .25165 L
s
.36395 .23277 m
.35402 .26332 L
s
.36395 .23277 m
.35402 .26332 L
s
.36395 .23277 m
.33796 .25165 L
s
.36395 .23277 m
.38993 .25165 L
s
.36395 .23277 m
.35402 .20223 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .23277 m
.38993 .2139 L
s
.36395 .23277 m
.38993 .2139 L
s
.36395 .23277 m
.38993 .25165 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .17168 m
.33796 .1528 L
s
.36395 .17168 m
.35402 .20223 L
s
.36395 .17168 m
.37387 .20223 L
s
.36395 .17168 m
.38993 .1528 L
s
.36395 .17168 m
.33796 .1528 L
s
.36395 .17168 m
.33796 .1528 L
s
.36395 .17168 m
.37387 .20223 L
s
.36395 .17168 m
.37387 .20223 L
s
.36395 .23277 m
.33796 .25165 L
s
.36395 .23277 m
.38993 .25165 L
s
.36395 .23277 m
.35402 .26332 L
s
.36395 .23277 m
.35402 .26332 L
s
.36395 .23277 m
.33796 .25165 L
s
.36395 .23277 m
.38993 .25165 L
s
.36395 .23277 m
.35402 .20223 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .23277 m
.38993 .2139 L
s
.36395 .23277 m
.38993 .2139 L
s
.36395 .23277 m
.38993 .25165 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .75036 m
.38993 .73148 L
s
.36395 .75036 m
.35402 .71981 L
s
.36395 .75036 m
.35402 .71981 L
s
.36395 .75036 m
.33183 .75036 L
s
.36395 .75036 m
.38993 .73148 L
s
.36395 .75036 m
.35402 .7809 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .75036 m
.38993 .76923 L
s
.36395 .75036 m
.38993 .73148 L
s
.36395 .75036 m
.38993 .76923 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .81145 m
.33796 .83033 L
s
.36395 .81145 m
.35402 .7809 L
s
.36395 .81145 m
.37387 .7809 L
s
.36395 .81145 m
.38993 .83033 L
s
.36395 .81145 m
.33796 .83033 L
s
.36395 .81145 m
.33796 .83033 L
s
.36395 .81145 m
.37387 .7809 L
s
.36395 .81145 m
.37387 .7809 L
s
.33183 .49156 m
.36395 .49156 L
s
.33183 .49156 m
.30584 .47269 L
s
.33183 .49156 m
.30584 .51044 L
s
.33183 .49156 m
.3219 .46102 L
s
.33183 .49156 m
.3219 .52211 L
s
.33183 .49156 m
.3219 .46102 L
s
.33183 .49156 m
.3219 .52211 L
s
.33183 .49156 m
.36395 .49156 L
s
.33183 .49156 m
.36395 .49156 L
s
.33183 .49156 m
.30584 .47269 L
s
.33183 .49156 m
.30584 .51044 L
s
.33183 .49156 m
.30584 .47269 L
s
.33183 .49156 m
.30584 .51044 L
s
.36395 .49156 m
.38993 .47269 L
s
.36395 .49156 m
.38993 .51044 L
s
.36395 .49156 m
.35402 .46102 L
s
.36395 .49156 m
.35402 .52211 L
s
.36395 .49156 m
.35402 .52211 L
s
.36395 .49156 m
.37387 .46102 L
s
.36395 .49156 m
.33183 .49156 L
s
.36395 .49156 m
.38993 .51044 L
s
.36395 .49156 m
.37387 .46102 L
s
.36395 .49156 m
.37387 .46102 L
s
.47402 .51044 m
.44803 .49156 L
s
.47402 .51044 m
.50613 .51044 L
s
.47402 .51044 m
.48394 .4799 L
s
.47402 .51044 m
.48394 .54099 L
s
.47402 .51044 m
.48394 .54099 L
s
.44803 .49156 m
.42205 .51044 L
s
.44803 .49156 m
.41591 .49156 L
s
.44803 .49156 m
.45796 .46102 L
s
.44803 .49156 m
.45796 .52211 L
s
.44803 .49156 m
.45796 .46102 L
s
.42205 .51044 m
.38993 .51044 L
s
.42205 .51044 m
.43197 .54099 L
s
.42205 .51044 m
.38993 .51044 L
s
.42205 .51044 m
.43197 .54099 L
s
.42205 .25165 m
.38993 .25165 L
s
.42205 .25165 m
.43197 .2822 L
s
.42205 .25165 m
.38993 .25165 L
s
.42205 .25165 m
.43197 .2822 L
s
.42205 .25165 m
.38993 .25165 L
s
.42205 .25165 m
.44803 .23277 L
s
.42205 .25165 m
.43197 .2822 L
s
.42205 .25165 m
.43197 .2822 L
s
.42205 .73148 m
.38993 .73148 L
s
.42205 .73148 m
.43197 .70093 L
s
.42205 .73148 m
.38993 .73148 L
s
.42205 .73148 m
.43197 .70093 L
s
.42205 .73148 m
.38993 .73148 L
s
.42205 .73148 m
.44803 .75036 L
s
.42205 .73148 m
.43197 .70093 L
s
.42205 .73148 m
.43197 .70093 L
s
.77211 .49156 m
.79809 .47269 L
s
.77211 .49156 m
.79809 .51044 L
s
.77211 .49156 m
.76218 .46102 L
s
.77211 .49156 m
.76218 .52211 L
s
.77211 .49156 m
.79809 .47269 L
s
.77211 .49156 m
.79809 .51044 L
s
.77211 .59041 m
.76218 .55987 L
s
.77211 .59041 m
.76218 .62096 L
s
.77211 .59041 m
.76218 .62096 L
s
.77211 .59041 m
.76218 .55987 L
s
.77211 .59041 m
.76218 .62096 L
s
.77211 .59041 m
.76218 .62096 L
s
.77211 .59041 m
.79809 .57154 L
s
.77211 .59041 m
.79809 .57154 L
s
.77211 .59041 m
.76218 .62096 L
s
.90816 .49156 m
.94028 .49156 L
s
.90816 .49156 m
.88218 .47269 L
s
.90816 .49156 m
.88218 .51044 L
s
.90816 .49156 m
.88218 .47269 L
s
.90816 .49156 m
.88218 .51044 L
s
.94028 .49156 m
.9724 .49156 L
s
.94028 .49156 m
.9724 .49156 L
s
.94028 .49156 m
.9143 .47269 L
s
.94028 .49156 m
.9143 .51044 L
s
.94028 .49156 m
.9143 .47269 L
s
.94028 .49156 m
.9143 .51044 L
s
.94028 .49156 m
.95021 .46102 L
s
.94028 .49156 m
.95021 .52211 L
s
.94028 .43047 m
.9143 .41159 L
s
.94028 .43047 m
.96627 .41159 L
s
.94028 .43047 m
.9143 .41159 L
s
.94028 .43047 m
.9143 .41159 L
s
.94028 .43047 m
.9143 .41159 L
s
.94028 .43047 m
.95021 .46102 L
s
.94028 .55266 m
.9143 .57154 L
s
.94028 .55266 m
.96627 .57154 L
s
.94028 .55266 m
.9143 .57154 L
s
.94028 .55266 m
.9143 .57154 L
s
.94028 .55266 m
.9143 .57154 L
s
.94028 .55266 m
.95021 .52211 L
s
.94028 .39272 m
.9143 .41159 L
s
.94028 .39272 m
.96627 .41159 L
s
.94028 .39272 m
.9143 .41159 L
s
.94028 .39272 m
.9143 .41159 L
s
.94028 .39272 m
.9143 .41159 L
s
.94028 .39272 m
.95021 .36217 L
s
.94028 .39272 m
.95021 .36217 L
s
.94028 .39272 m
.95021 .36217 L
s
.94028 .59041 m
.9143 .57154 L
s
.94028 .59041 m
.96627 .57154 L
s
.94028 .59041 m
.9143 .57154 L
s
.94028 .59041 m
.9143 .57154 L
s
.94028 .59041 m
.9143 .57154 L
s
.94028 .59041 m
.95021 .62096 L
s
.94028 .59041 m
.95021 .62096 L
s
.94028 .59041 m
.95021 .62096 L
s
.90816 .33162 m
.94028 .33162 L
s
.90816 .33162 m
.88218 .31274 L
s
.90816 .33162 m
.88218 .3505 L
s
.90816 .33162 m
.88218 .3505 L
s
.90816 .33162 m
.88218 .31274 L
s
.90816 .33162 m
.88218 .31274 L
s
.90816 .65151 m
.94028 .65151 L
s
.90816 .65151 m
.88218 .63263 L
s
.90816 .65151 m
.88218 .67039 L
s
.90816 .65151 m
.88218 .63263 L
s
.90816 .65151 m
.91809 .62096 L
s
.90816 .65151 m
.88218 .67039 L
s
.90816 .65151 m
.88218 .67039 L
s
.94028 .39272 m
.9143 .41159 L
s
.94028 .39272 m
.96627 .41159 L
s
.94028 .39272 m
.9143 .41159 L
s
.94028 .39272 m
.9143 .41159 L
s
.94028 .39272 m
.9143 .41159 L
s
.94028 .39272 m
.95021 .36217 L
s
.94028 .39272 m
.95021 .36217 L
s
.94028 .39272 m
.95021 .36217 L
s
.94028 .59041 m
.9143 .57154 L
s
.94028 .59041 m
.96627 .57154 L
s
.94028 .59041 m
.9143 .57154 L
s
.94028 .59041 m
.9143 .57154 L
s
.94028 .59041 m
.9143 .57154 L
s
.94028 .59041 m
.95021 .62096 L
s
.94028 .59041 m
.95021 .62096 L
s
.94028 .59041 m
.95021 .62096 L
s
.94028 .33162 m
.9143 .31274 L
s
.94028 .33162 m
.9143 .3505 L
s
.94028 .33162 m
.9143 .3505 L
s
.94028 .33162 m
.95021 .36217 L
s
.94028 .33162 m
.95021 .36217 L
s
.94028 .33162 m
.95021 .36217 L
s
.94028 .33162 m
.9143 .31274 L
s
.94028 .65151 m
.9143 .67039 L
s
.94028 .65151 m
.95021 .62096 L
s
.94028 .65151 m
.95021 .62096 L
s
.94028 .65151 m
.95021 .62096 L
s
.94028 .65151 m
.9143 .67039 L
s
.88218 .31274 m
.9143 .31274 L
s
.88218 .31274 m
.8562 .33162 L
s
.88218 .31274 m
.8562 .33162 L
s
.88218 .31274 m
.9143 .31274 L
s
.88218 .31274 m
.87225 .2822 L
s
.88218 .31274 m
.8921 .2822 L
s
.88218 .31274 m
.8562 .33162 L
s
.88218 .31274 m
.8562 .33162 L
s
.88218 .31274 m
.8921 .2822 L
s
.88218 .31274 m
.8921 .2822 L
s
.88218 .3505 m
.9143 .3505 L
s
.88218 .3505 m
.8562 .33162 L
s
.88218 .3505 m
.9143 .3505 L
s
.88218 .3505 m
.8921 .38105 L
s
.88218 .3505 m
.8921 .38105 L
s
.88218 .3505 m
.87225 .38105 L
s
.88218 .3505 m
.8921 .38105 L
s
.88218 .3505 m
.8562 .33162 L
s
.88218 .3505 m
.8562 .33162 L
s
.88218 .3505 m
.8562 .33162 L
s
.88218 .63263 m
.8562 .65151 L
s
.88218 .63263 m
.8921 .60208 L
s
.88218 .63263 m
.8921 .60208 L
s
.88218 .63263 m
.8921 .60208 L
s
.88218 .63263 m
.8562 .65151 L
s
.88218 .63263 m
.8562 .65151 L
s
.88218 .63263 m
.8562 .65151 L
s
.88218 .67039 m
.9143 .67039 L
s
.88218 .67039 m
.8562 .65151 L
s
.88218 .67039 m
.8562 .65151 L
s
.88218 .67039 m
.9143 .67039 L
s
.88218 .67039 m
.87225 .70093 L
s
.88218 .67039 m
.8921 .70093 L
s
.88218 .67039 m
.8562 .65151 L
s
.88218 .67039 m
.8562 .65151 L
s
.88218 .67039 m
.8921 .70093 L
s
.88218 .67039 m
.8921 .70093 L
s
.9143 .41159 m
.88218 .41159 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .44214 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .44214 L
s
.9143 .57154 m
.88218 .57154 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .54099 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .54099 L
s
.9143 .31274 m
.92422 .2822 L
s
.9143 .31274 m
.88218 .31274 L
s
.9143 .31274 m
.92422 .2822 L
s
.9143 .31274 m
.88218 .31274 L
s
.9143 .31274 m
.92422 .2822 L
s
.9143 .3505 m
.88218 .3505 L
s
.9143 .3505 m
.92422 .38105 L
s
.9143 .3505 m
.92422 .38105 L
s
.9143 .3505 m
.92422 .38105 L
s
.9143 .3505 m
.92422 .38105 L
s
.9143 .67039 m
.92422 .70093 L
s
.9143 .67039 m
.88218 .67039 L
s
.9143 .67039 m
.92422 .70093 L
s
.9143 .67039 m
.88218 .67039 L
s
.9143 .67039 m
.92422 .70093 L
s
.82408 .49156 m
.8562 .49156 L
s
.82408 .49156 m
.79809 .47269 L
s
.82408 .49156 m
.79809 .51044 L
s
.82408 .49156 m
.8562 .49156 L
s
.82408 .49156 m
.81415 .46102 L
s
.82408 .49156 m
.81415 .52211 L
s
.82408 .49156 m
.8562 .49156 L
s
.82408 .49156 m
.79809 .47269 L
s
.82408 .49156 m
.79809 .51044 L
s
.8562 .49156 m
.88218 .47269 L
s
.8562 .49156 m
.88218 .51044 L
s
.8562 .49156 m
.88218 .47269 L
s
.8562 .49156 m
.88218 .51044 L
s
.8562 .49156 m
.84627 .46102 L
s
.8562 .49156 m
.84627 .52211 L
s
.8562 .49156 m
.84627 .46102 L
s
.8562 .49156 m
.84627 .52211 L
s
.8562 .43047 m
.83021 .41159 L
s
.8562 .43047 m
.88218 .41159 L
s
.8562 .43047 m
.84627 .46102 L
s
.8562 .43047 m
.83021 .41159 L
s
.8562 .43047 m
.83021 .41159 L
s
.8562 .43047 m
.83021 .41159 L
s
.8562 .43047 m
.84627 .46102 L
s
.8562 .55266 m
.83021 .57154 L
s
.8562 .55266 m
.88218 .57154 L
s
.8562 .55266 m
.84627 .52211 L
s
.8562 .55266 m
.83021 .57154 L
s
.8562 .55266 m
.83021 .57154 L
s
.8562 .55266 m
.83021 .57154 L
s
.8562 .55266 m
.84627 .52211 L
s
.8562 .33162 m
.88218 .3505 L
s
.8562 .33162 m
.83021 .31274 L
s
.8562 .33162 m
.82408 .33162 L
s
.8562 .33162 m
.88218 .31274 L
s
.8562 .33162 m
.83021 .31274 L
s
.8562 .33162 m
.84627 .30108 L
s
.8562 .33162 m
.84627 .30108 L
s
.8562 .33162 m
.88218 .31274 L
s
.8562 .33162 m
.83021 .31274 L
s
.8562 .33162 m
.84627 .36217 L
s
.8562 .65151 m
.88218 .63263 L
s
.8562 .65151 m
.83021 .67039 L
s
.8562 .65151 m
.82408 .65151 L
s
.8562 .65151 m
.88218 .67039 L
s
.8562 .65151 m
.83021 .67039 L
s
.8562 .65151 m
.84627 .68205 L
s
.8562 .65151 m
.84627 .68205 L
s
.8562 .65151 m
.86612 .62096 L
s
.8562 .65151 m
.86612 .62096 L
s
.8562 .65151 m
.88218 .67039 L
s
.8562 .65151 m
.83021 .67039 L
s
.8562 .65151 m
.84627 .62096 L
s
.8562 .65151 m
.86612 .62096 L
s
.79809 .47269 m
.78817 .44214 L
s
.79809 .47269 m
.78817 .44214 L
s
.79809 .51044 m
.78817 .54099 L
s
.79809 .51044 m
.78817 .54099 L
s
.79809 .1528 m
.83021 .1528 L
s
.79809 .1528 m
.78817 .12226 L
s
.79809 .1528 m
.78817 .12226 L
s
.79809 .1528 m
.78817 .18335 L
s
.79809 .1528 m
.78817 .18335 L
s
.79809 .1528 m
.83021 .1528 L
s
.79809 .1528 m
.78817 .18335 L
s
.79809 .1528 m
.83021 .1528 L
s
.79809 .83033 m
.83021 .83033 L
s
.79809 .83033 m
.78817 .86087 L
s
.79809 .83033 m
.78817 .79978 L
s
.79809 .83033 m
.78817 .86087 L
s
.79809 .83033 m
.78817 .79978 L
s
.79809 .83033 m
.83021 .83033 L
s
.79809 .83033 m
.78817 .79978 L
s
.79809 .83033 m
.83021 .83033 L
s
.83021 .41159 m
.82029 .44214 L
s
.83021 .41159 m
.8562 .43047 L
s
.83021 .41159 m
.8562 .39272 L
s
.83021 .41159 m
.79809 .41159 L
s
.83021 .41159 m
.82029 .38105 L
s
.83021 .41159 m
.82029 .44214 L
s
.83021 .41159 m
.82029 .38105 L
s
.83021 .57154 m
.82029 .54099 L
s
.83021 .57154 m
.8562 .55266 L
s
.83021 .57154 m
.8562 .59041 L
s
.83021 .57154 m
.79809 .57154 L
s
.83021 .57154 m
.79809 .57154 L
s
.83021 .57154 m
.82029 .54099 L
s
.83021 .1528 m
.82029 .18335 L
s
.83021 .1528 m
.79809 .1528 L
s
.83021 .1528 m
.82029 .18335 L
s
.83021 .1528 m
.8562 .17168 L
s
.83021 .83033 m
.82029 .79978 L
s
.83021 .83033 m
.79809 .83033 L
s
.83021 .83033 m
.82029 .79978 L
s
.83021 .83033 m
.8562 .81145 L
s
.96627 .41159 m
.97619 .44214 L
s
.96627 .57154 m
.97619 .54099 L
s
.47402 .05395 m
.50613 .05395 L
s
.47402 .05395 m
.48394 .02341 L
s
.47402 .05395 m
.48394 .0845 L
s
.47402 .05395 m
.48394 .0845 L
s
.47402 .05395 m
.44803 .07283 L
s
.47402 .92918 m
.50613 .92918 L
s
.47402 .92918 m
.48394 .89863 L
s
.47402 .92918 m
.48394 .95972 L
s
.47402 .92918 m
.48394 .89863 L
s
.47402 .92918 m
.44803 .9103 L
s
.50613 .05395 m
.51606 .02341 L
s
.50613 .05395 m
.51606 .0845 L
s
.50613 .05395 m
.51606 .02341 L
s
.50613 .05395 m
.51606 .02341 L
s
.50613 .05395 m
.51606 .0845 L
s
.50613 .05395 m
.51606 .0845 L
s
.50613 .92918 m
.51606 .89863 L
s
.50613 .92918 m
.51606 .95972 L
s
.50613 .92918 m
.51606 .95972 L
s
.50613 .92918 m
.51606 .95972 L
s
.50613 .92918 m
.51606 .89863 L
s
.50613 .92918 m
.51606 .89863 L
s
.88218 .47269 m
.9143 .47269 L
s
.88218 .47269 m
.9143 .47269 L
s
.88218 .47269 m
.8562 .49156 L
s
.88218 .47269 m
.8921 .44214 L
s
.88218 .47269 m
.87225 .44214 L
s
.88218 .47269 m
.8921 .44214 L
s
.88218 .47269 m
.8562 .49156 L
s
.88218 .51044 m
.9143 .51044 L
s
.88218 .51044 m
.9143 .51044 L
s
.88218 .51044 m
.8562 .49156 L
s
.88218 .51044 m
.8921 .54099 L
s
.88218 .51044 m
.87225 .54099 L
s
.88218 .51044 m
.8921 .54099 L
s
.88218 .51044 m
.8562 .49156 L
s
.88218 .41159 m
.9143 .41159 L
s
.88218 .41159 m
.9143 .41159 L
s
.88218 .41159 m
.9143 .41159 L
s
.88218 .41159 m
.8921 .38105 L
s
.88218 .41159 m
.8921 .44214 L
s
.88218 .41159 m
.8921 .38105 L
s
.88218 .41159 m
.87225 .38105 L
s
.88218 .41159 m
.87225 .44214 L
s
.88218 .41159 m
.8921 .38105 L
s
.88218 .41159 m
.8921 .44214 L
s
.88218 .41159 m
.8562 .43047 L
s
.88218 .41159 m
.8562 .39272 L
s
.88218 .57154 m
.9143 .57154 L
s
.88218 .57154 m
.9143 .57154 L
s
.88218 .57154 m
.9143 .57154 L
s
.88218 .57154 m
.8921 .60208 L
s
.88218 .57154 m
.8921 .54099 L
s
.88218 .57154 m
.8921 .60208 L
s
.88218 .57154 m
.8921 .60208 L
s
.88218 .57154 m
.87225 .54099 L
s
.88218 .57154 m
.8921 .54099 L
s
.88218 .57154 m
.8562 .55266 L
s
.88218 .57154 m
.8562 .59041 L
s
.88218 .3505 m
.9143 .3505 L
s
.88218 .3505 m
.8921 .38105 L
s
.88218 .3505 m
.8921 .38105 L
s
.88218 .3505 m
.87225 .38105 L
s
.88218 .3505 m
.8921 .38105 L
s
.88218 .3505 m
.8562 .33162 L
s
.88218 .3505 m
.8562 .33162 L
s
.88218 .3505 m
.8562 .33162 L
s
.88218 .63263 m
.8921 .60208 L
s
.88218 .63263 m
.8921 .60208 L
s
.88218 .63263 m
.8921 .60208 L
s
.88218 .63263 m
.8562 .65151 L
s
.88218 .63263 m
.8562 .65151 L
s
.88218 .63263 m
.8562 .65151 L
s
.9143 .47269 m
.88218 .47269 L
s
.9143 .47269 m
.92422 .44214 L
s
.9143 .47269 m
.92422 .44214 L
s
.9143 .51044 m
.88218 .51044 L
s
.9143 .51044 m
.92422 .54099 L
s
.9143 .51044 m
.92422 .54099 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .44214 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .44214 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .44214 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .44214 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .54099 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .54099 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .54099 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .54099 L
s
.9143 .3505 m
.92422 .38105 L
s
.9143 .3505 m
.92422 .38105 L
s
.9143 .3505 m
.92422 .38105 L
s
.9143 .3505 m
.92422 .38105 L
s
.50613 .51044 m
.51606 .4799 L
s
.50613 .51044 m
.51606 .54099 L
s
.50613 .51044 m
.51606 .54099 L
s
.50613 .51044 m
.51606 .54099 L
s
.30584 .47269 m
.27986 .49156 L
s
.30584 .47269 m
.29592 .44214 L
s
.30584 .47269 m
.29592 .44214 L
s
.30584 .47269 m
.33183 .49156 L
s
.30584 .47269 m
.27986 .49156 L
s
.30584 .51044 m
.27986 .49156 L
s
.30584 .51044 m
.29592 .54099 L
s
.30584 .51044 m
.29592 .54099 L
s
.30584 .51044 m
.33183 .49156 L
s
.30584 .51044 m
.27986 .49156 L
s
.30584 .25165 m
.33796 .25165 L
s
.30584 .25165 m
.27986 .23277 L
s
.30584 .25165 m
.27986 .23277 L
s
.30584 .25165 m
.29592 .2822 L
s
.30584 .25165 m
.33796 .25165 L
s
.30584 .25165 m
.27986 .23277 L
s
.30584 .25165 m
.27986 .23277 L
s
.30584 .25165 m
.29592 .22111 L
s
.30584 .73148 m
.27986 .75036 L
s
.30584 .73148 m
.27986 .75036 L
s
.30584 .73148 m
.29592 .70093 L
s
.30584 .73148 m
.33183 .75036 L
s
.30584 .73148 m
.27986 .75036 L
s
.30584 .73148 m
.27986 .75036 L
s
.30584 .76923 m
.27986 .75036 L
s
.30584 .76923 m
.27986 .75036 L
s
.30584 .76923 m
.33183 .75036 L
s
.30584 .76923 m
.27986 .75036 L
s
.30584 .76923 m
.27986 .75036 L
s
.30584 .76923 m
.29592 .79978 L
s
.30584 .76923 m
.29592 .79978 L
s
.30584 .1528 m
.33796 .1528 L
s
.30584 .1528 m
.27373 .1528 L
s
.30584 .1528 m
.27986 .17168 L
s
.30584 .1528 m
.29592 .12226 L
s
.30584 .1528 m
.29592 .18335 L
s
.30584 .1528 m
.29592 .18335 L
s
.30584 .1528 m
.33796 .1528 L
s
.30584 .1528 m
.33183 .13392 L
s
.30584 .1528 m
.33796 .1528 L
s
.30584 .1528 m
.29592 .12226 L
s
.30584 .25165 m
.33796 .25165 L
s
.30584 .25165 m
.27986 .23277 L
s
.30584 .25165 m
.27986 .23277 L
s
.30584 .25165 m
.29592 .2822 L
s
.30584 .25165 m
.33796 .25165 L
s
.30584 .25165 m
.27986 .23277 L
s
.30584 .25165 m
.27986 .23277 L
s
.30584 .25165 m
.29592 .22111 L
s
.30584 .76923 m
.27986 .75036 L
s
.30584 .76923 m
.27986 .75036 L
s
.30584 .76923 m
.33183 .75036 L
s
.30584 .76923 m
.27986 .75036 L
s
.30584 .76923 m
.27986 .75036 L
s
.30584 .76923 m
.29592 .79978 L
s
.30584 .76923 m
.29592 .79978 L
s
.30584 .83033 m
.33796 .83033 L
s
.30584 .83033 m
.27373 .83033 L
s
.30584 .83033 m
.27986 .84921 L
s
.30584 .83033 m
.29592 .86087 L
s
.30584 .83033 m
.29592 .79978 L
s
.30584 .83033 m
.29592 .79978 L
s
.30584 .83033 m
.33796 .83033 L
s
.30584 .83033 m
.33183 .84921 L
s
.30584 .83033 m
.33796 .83033 L
s
.30584 .83033 m
.29592 .86087 L
s
.33796 .25165 m
.32804 .2822 L
s
.33796 .25165 m
.32804 .2822 L
s
.33796 .25165 m
.32804 .2822 L
s
.33796 .25165 m
.36395 .23277 L
s
.33796 .25165 m
.36395 .23277 L
s
.33796 .25165 m
.30584 .25165 L
s
.33796 .25165 m
.36395 .23277 L
s
.33796 .25165 m
.36395 .23277 L
s
.33796 .1528 m
.30584 .1528 L
s
.33796 .1528 m
.36395 .17168 L
s
.33796 .1528 m
.36395 .13392 L
s
.33796 .1528 m
.36395 .13392 L
s
.33796 .1528 m
.30584 .1528 L
s
.33796 .83033 m
.30584 .83033 L
s
.33796 .83033 m
.36395 .81145 L
s
.33796 .83033 m
.36395 .84921 L
s
.33796 .83033 m
.36395 .84921 L
s
.33796 .83033 m
.30584 .83033 L
s
.88218 .47269 m
.9143 .47269 L
s
.88218 .47269 m
.8562 .49156 L
s
.88218 .47269 m
.8921 .44214 L
s
.88218 .47269 m
.87225 .44214 L
s
.88218 .47269 m
.8921 .44214 L
s
.88218 .47269 m
.8562 .49156 L
s
.88218 .51044 m
.9143 .51044 L
s
.88218 .51044 m
.8562 .49156 L
s
.88218 .51044 m
.8921 .54099 L
s
.88218 .51044 m
.87225 .54099 L
s
.88218 .51044 m
.8921 .54099 L
s
.88218 .51044 m
.8562 .49156 L
s
.9143 .47269 m
.92422 .44214 L
s
.9143 .47269 m
.92422 .44214 L
s
.9143 .51044 m
.92422 .54099 L
s
.9143 .51044 m
.92422 .54099 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .44214 L
s
.9143 .41159 m
.92422 .38105 L
s
.9143 .41159 m
.92422 .44214 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .54099 L
s
.9143 .57154 m
.92422 .60208 L
s
.9143 .57154 m
.92422 .54099 L
s
.41591 .49156 m
.38993 .47269 L
s
.41591 .49156 m
.38993 .51044 L
s
.41591 .49156 m
.42584 .46102 L
s
.41591 .49156 m
.38993 .51044 L
s
.27986 .49156 m
.26993 .46102 L
s
.27986 .49156 m
.26993 .52211 L
s
.27986 .49156 m
.30584 .47269 L
s
.27986 .49156 m
.30584 .51044 L
s
.27986 .49156 m
.30584 .47269 L
s
.27986 .49156 m
.30584 .51044 L
s
.27986 .49156 m
.24774 .49156 L
s
.27986 .49156 m
.24774 .49156 L
s
.27986 .75036 m
.30584 .76923 L
s
.27986 .75036 m
.24774 .75036 L
s
.27986 .75036 m
.26993 .71981 L
s
.27986 .75036 m
.26993 .71981 L
s
.27986 .75036 m
.30584 .73148 L
s
.27986 .75036 m
.24774 .75036 L
s
.27986 .75036 m
.26993 .7809 L
s
.27986 .23277 m
.24774 .23277 L
s
.27986 .23277 m
.26993 .26332 L
s
.27986 .23277 m
.26993 .26332 L
s
.27986 .23277 m
.30584 .25165 L
s
.27986 .23277 m
.24774 .23277 L
s
.27986 .23277 m
.26993 .20223 L
s
.27986 .23277 m
.26993 .20223 L
s
.8562 .49156 m
.84627 .46102 L
s
.8562 .49156 m
.84627 .52211 L
s
.8562 .49156 m
.84627 .46102 L
s
.8562 .49156 m
.84627 .52211 L
s
.38993 .47269 m
.39985 .44214 L
s
.38993 .47269 m
.36395 .49156 L
s
.38993 .47269 m
.36395 .49156 L
s
.38993 .47269 m
.39985 .44214 L
s
.38993 .51044 m
.38 .54099 L
s
.38993 .51044 m
.39985 .54099 L
s
.38993 .51044 m
.36395 .49156 L
s
.38993 .51044 m
.36395 .49156 L
s
.38993 .51044 m
.39985 .54099 L
s
.38993 .25165 m
.38 .2822 L
s
.38993 .25165 m
.39985 .2822 L
s
.38993 .25165 m
.36395 .23277 L
s
.38993 .25165 m
.36395 .23277 L
s
.38993 .25165 m
.39985 .2822 L
s
.38993 .25165 m
.39985 .2822 L
s
.38993 .25165 m
.42205 .25165 L
s
.38993 .25165 m
.36395 .23277 L
s
.38993 .25165 m
.41591 .23277 L
s
.38993 .25165 m
.36395 .23277 L
s
.38993 .73148 m
.38 .70093 L
s
.38993 .73148 m
.39985 .70093 L
s
.38993 .73148 m
.36395 .75036 L
s
.38993 .73148 m
.36395 .75036 L
s
.38993 .73148 m
.39985 .70093 L
s
.38993 .73148 m
.39985 .70093 L
s
.38993 .73148 m
.42205 .73148 L
s
.38993 .73148 m
.36395 .75036 L
s
.38993 .73148 m
.41591 .75036 L
s
.38993 .73148 m
.36395 .75036 L
s
.27373 .1528 m
.30584 .1528 L
s
.27373 .1528 m
.24774 .17168 L
s
.27373 .1528 m
.2638 .12226 L
s
.27373 .1528 m
.30584 .1528 L
s
.27373 .83033 m
.30584 .83033 L
s
.27373 .83033 m
.24774 .84921 L
s
.27373 .83033 m
.2638 .79978 L
s
.27373 .83033 m
.30584 .83033 L
s
.30584 .1528 m
.27986 .17168 L
s
.30584 .1528 m
.29592 .12226 L
s
.30584 .1528 m
.29592 .18335 L
s
.30584 .1528 m
.29592 .18335 L
s
.30584 .1528 m
.33796 .1528 L
s
.30584 .1528 m
.33183 .13392 L
s
.30584 .1528 m
.33796 .1528 L
s
.30584 .1528 m
.29592 .12226 L
s
.30584 .09171 m
.27986 .07283 L
s
.30584 .09171 m
.29592 .12226 L
s
.30584 .09171 m
.33183 .07283 L
s
.30584 .09171 m
.33183 .07283 L
s
.30584 .09171 m
.27986 .07283 L
s
.30584 .09171 m
.29592 .12226 L
s
.30584 .76923 m
.27986 .75036 L
s
.30584 .76923 m
.33183 .75036 L
s
.30584 .76923 m
.27986 .75036 L
s
.30584 .76923 m
.27986 .75036 L
s
.30584 .76923 m
.29592 .79978 L
s
.30584 .76923 m
.29592 .79978 L
s
.30584 .83033 m
.27986 .84921 L
s
.30584 .83033 m
.29592 .86087 L
s
.30584 .83033 m
.29592 .79978 L
s
.30584 .83033 m
.29592 .79978 L
s
.30584 .83033 m
.33796 .83033 L
s
.30584 .83033 m
.33183 .84921 L
s
.30584 .83033 m
.33796 .83033 L
s
.30584 .83033 m
.29592 .86087 L
s
.24774 .17168 m
.27986 .17168 L
s
.24774 .17168 m
.22176 .1528 L
s
.24774 .17168 m
.23782 .14114 L
s
.24774 .17168 m
.22176 .1528 L
s
.24774 .17168 m
.23782 .20223 L
s
.24774 .23277 m
.27986 .23277 L
s
.24774 .23277 m
.23782 .26332 L
s
.24774 .23277 m
.23782 .26332 L
s
.24774 .23277 m
.27986 .23277 L
s
.24774 .23277 m
.27986 .23277 L
s
.24774 .23277 m
.23782 .20223 L
s
.24774 .23277 m
.23782 .26332 L
s
.24774 .75036 m
.27986 .75036 L
s
.24774 .75036 m
.23782 .71981 L
s
.24774 .75036 m
.23782 .71981 L
s
.24774 .75036 m
.27986 .75036 L
s
.24774 .75036 m
.27986 .75036 L
s
.24774 .75036 m
.23782 .71981 L
s
.24774 .75036 m
.23782 .7809 L
s
.24774 .84921 m
.27986 .84921 L
s
.24774 .84921 m
.22176 .83033 L
s
.24774 .84921 m
.23782 .87975 L
s
.24774 .84921 m
.22176 .83033 L
s
.24774 .84921 m
.23782 .81866 L
s
.27986 .17168 m
.26993 .20223 L
s
.27986 .17168 m
.26993 .20223 L
s
.27986 .17168 m
.30584 .1528 L
s
.27986 .07283 m
.26993 .10338 L
s
.27986 .07283 m
.30584 .05395 L
s
.27986 .07283 m
.30584 .09171 L
s
.27986 .07283 m
.30584 .09171 L
s
.27986 .23277 m
.26993 .26332 L
s
.27986 .23277 m
.26993 .26332 L
s
.27986 .23277 m
.30584 .25165 L
s
.27986 .23277 m
.24774 .23277 L
s
.27986 .23277 m
.26993 .20223 L
s
.27986 .23277 m
.26993 .20223 L
s
.27986 .75036 m
.26993 .71981 L
s
.27986 .75036 m
.26993 .71981 L
s
.27986 .75036 m
.30584 .73148 L
s
.27986 .75036 m
.24774 .75036 L
s
.27986 .75036 m
.26993 .7809 L
s
.27986 .9103 m
.26993 .87975 L
s
.27986 .9103 m
.30584 .92918 L
s
.27986 .9103 m
.30584 .92918 L
s
.27986 .9103 m
.26993 .87975 L
s
.27986 .84921 m
.26993 .87975 L
s
.27986 .84921 m
.30584 .83033 L
s
.27986 .84921 m
.26993 .87975 L
s
.22176 .1528 m
.21183 .12226 L
s
.22176 .1528 m
.21183 .12226 L
s
.22176 .1528 m
.21183 .12226 L
s
.22176 .1528 m
.21183 .18335 L
s
.22176 .1528 m
.21183 .18335 L
s
.22176 .1528 m
.21183 .18335 L
s
.22176 .83033 m
.21183 .86087 L
s
.22176 .83033 m
.21183 .79978 L
s
.22176 .83033 m
.21183 .86087 L
s
.22176 .83033 m
.21183 .79978 L
s
.22176 .83033 m
.21183 .79978 L
s
.15373 .46102 m
.18585 .46102 L
s
.15373 .46102 m
.17971 .44214 L
s
.15373 .46102 m
.1438 .49156 L
s
.15373 .46102 m
.1438 .43047 L
s
.15373 .46102 m
.18585 .46102 L
s
.15373 .46102 m
.12775 .44214 L
s
.15373 .46102 m
.17971 .44214 L
s
.15373 .46102 m
.12775 .44214 L
s
.15373 .52211 m
.18585 .52211 L
s
.15373 .52211 m
.17971 .54099 L
s
.15373 .52211 m
.1438 .49156 L
s
.15373 .52211 m
.1438 .55266 L
s
.15373 .52211 m
.18585 .52211 L
s
.15373 .52211 m
.12775 .54099 L
s
.15373 .52211 m
.17971 .54099 L
s
.15373 .52211 m
.12775 .54099 L
s
.18585 .46102 m
.21183 .44214 L
s
.18585 .46102 m
.21183 .44214 L
s
.18585 .46102 m
.17592 .49156 L
s
.18585 .46102 m
.17592 .49156 L
s
.18585 .46102 m
.15373 .46102 L
s
.18585 .46102 m
.21183 .44214 L
s
.18585 .46102 m
.21183 .44214 L
s
.18585 .52211 m
.21183 .54099 L
s
.18585 .52211 m
.21183 .54099 L
s
.18585 .52211 m
.17592 .49156 L
s
.18585 .52211 m
.17592 .49156 L
s
.18585 .52211 m
.15373 .52211 L
s
.18585 .52211 m
.21183 .54099 L
s
.18585 .52211 m
.21183 .54099 L
s
.3219 .46102 m
.35402 .46102 L
s
.3219 .46102 m
.29592 .44214 L
s
.3219 .46102 m
.29592 .44214 L
s
.3219 .46102 m
.33183 .49156 L
s
.3219 .46102 m
.33183 .43047 L
s
.3219 .46102 m
.33183 .43047 L
s
.3219 .52211 m
.35402 .52211 L
s
.3219 .52211 m
.35402 .52211 L
s
.3219 .52211 m
.29592 .54099 L
s
.3219 .52211 m
.29592 .54099 L
s
.3219 .52211 m
.33183 .49156 L
s
.3219 .71981 m
.35402 .71981 L
s
.3219 .71981 m
.35402 .71981 L
s
.3219 .71981 m
.29592 .70093 L
s
.3219 .71981 m
.33183 .75036 L
s
.35402 .46102 m
.3219 .46102 L
s
.35402 .46102 m
.36395 .49156 L
s
.35402 .46102 m
.36395 .43047 L
s
.35402 .46102 m
.36395 .49156 L
s
.35402 .46102 m
.36395 .43047 L
s
.35402 .52211 m
.3219 .52211 L
s
.35402 .52211 m
.32804 .54099 L
s
.35402 .52211 m
.38 .54099 L
s
.35402 .52211 m
.32804 .54099 L
s
.35402 .52211 m
.36395 .49156 L
s
.35402 .52211 m
.36395 .55266 L
s
.35402 .52211 m
.36395 .49156 L
s
.35402 .52211 m
.36395 .55266 L
s
.35402 .30108 m
.32804 .2822 L
s
.35402 .30108 m
.32804 .2822 L
s
.35402 .30108 m
.38 .2822 L
s
.35402 .30108 m
.32804 .2822 L
s
.35402 .30108 m
.36395 .33162 L
s
.35402 .30108 m
.36395 .33162 L
s
.35402 .30108 m
.36395 .33162 L
s
.35402 .30108 m
.36395 .33162 L
s
.35402 .26332 m
.32804 .2822 L
s
.35402 .26332 m
.32804 .2822 L
s
.35402 .26332 m
.38 .2822 L
s
.35402 .26332 m
.32804 .2822 L
s
.35402 .26332 m
.36395 .23277 L
s
.35402 .26332 m
.36395 .23277 L
s
.35402 .26332 m
.36395 .23277 L
s
.35402 .26332 m
.36395 .23277 L
s
.35402 .71981 m
.32804 .70093 L
s
.35402 .71981 m
.38 .70093 L
s
.35402 .71981 m
.36395 .75036 L
s
.35402 .71981 m
.36395 .68926 L
s
.35402 .71981 m
.36395 .75036 L
s
.35402 .71981 m
.36395 .68926 L
s
.35402 .71981 m
.36395 .68926 L
s
.35402 .71981 m
.36395 .75036 L
s
.35402 .71981 m
.36395 .75036 L
s
.3219 .46102 m
.29592 .44214 L
s
.3219 .46102 m
.29592 .44214 L
s
.3219 .46102 m
.33183 .49156 L
s
.3219 .46102 m
.33183 .43047 L
s
.3219 .46102 m
.33183 .43047 L
s
.3219 .52211 m
.35402 .52211 L
s
.3219 .52211 m
.29592 .54099 L
s
.3219 .52211 m
.29592 .54099 L
s
.3219 .52211 m
.33183 .49156 L
s
.35402 .52211 m
.32804 .54099 L
s
.35402 .52211 m
.38 .54099 L
s
.35402 .52211 m
.32804 .54099 L
s
.35402 .52211 m
.36395 .49156 L
s
.35402 .52211 m
.36395 .55266 L
s
.35402 .52211 m
.36395 .49156 L
s
.35402 .52211 m
.36395 .55266 L
s
.35402 .30108 m
.32804 .2822 L
s
.35402 .30108 m
.32804 .2822 L
s
.35402 .30108 m
.38 .2822 L
s
.35402 .30108 m
.32804 .2822 L
s
.35402 .30108 m
.36395 .33162 L
s
.35402 .30108 m
.36395 .33162 L
s
.35402 .30108 m
.36395 .33162 L
s
.35402 .30108 m
.36395 .33162 L
s
.35402 .26332 m
.32804 .2822 L
s
.35402 .26332 m
.32804 .2822 L
s
.35402 .26332 m
.38 .2822 L
s
.35402 .26332 m
.32804 .2822 L
s
.35402 .26332 m
.36395 .23277 L
s
.35402 .26332 m
.36395 .23277 L
s
.35402 .26332 m
.36395 .23277 L
s
.35402 .26332 m
.36395 .23277 L
s
.35402 .71981 m
.32804 .70093 L
s
.35402 .71981 m
.38 .70093 L
s
.35402 .71981 m
.36395 .75036 L
s
.35402 .71981 m
.36395 .68926 L
s
.35402 .71981 m
.36395 .75036 L
s
.35402 .71981 m
.36395 .68926 L
s
.35402 .71981 m
.36395 .68926 L
s
.35402 .71981 m
.36395 .75036 L
s
.35402 .71981 m
.36395 .75036 L
s
.73007 .26332 m
.76218 .26332 L
s
.73007 .26332 m
.70408 .2822 L
s
.73007 .26332 m
.70408 .2822 L
s
.73007 .26332 m
.72014 .23277 L
s
.73007 .26332 m
.76218 .26332 L
s
.73007 .26332 m
.70408 .2822 L
s
.73007 .26332 m
.70408 .2822 L
s
.73007 .26332 m
.76218 .26332 L
s
.73007 .26332 m
.70408 .2822 L
s
.73007 .71981 m
.76218 .71981 L
s
.73007 .71981 m
.70408 .70093 L
s
.73007 .71981 m
.70408 .70093 L
s
.73007 .71981 m
.72014 .75036 L
s
.73007 .71981 m
.76218 .71981 L
s
.73007 .71981 m
.70408 .70093 L
s
.73007 .71981 m
.70408 .70093 L
s
.73007 .71981 m
.76218 .71981 L
s
.73007 .71981 m
.70408 .70093 L
s
.76218 .26332 m
.7362 .2822 L
s
.76218 .26332 m
.75226 .23277 L
s
.76218 .26332 m
.73007 .26332 L
s
.76218 .26332 m
.77211 .23277 L
s
.76218 .26332 m
.78817 .2822 L
s
.76218 .26332 m
.7362 .2822 L
s
.76218 .26332 m
.77211 .23277 L
s
.76218 .26332 m
.77211 .23277 L
s
.76218 .26332 m
.7362 .2822 L
s
.76218 .71981 m
.7362 .70093 L
s
.76218 .71981 m
.75226 .75036 L
s
.76218 .71981 m
.73007 .71981 L
s
.76218 .71981 m
.77211 .75036 L
s
.76218 .71981 m
.78817 .70093 L
s
.76218 .71981 m
.7362 .70093 L
s
.76218 .71981 m
.77211 .75036 L
s
.76218 .71981 m
.77211 .75036 L
s
.76218 .71981 m
.7362 .70093 L
s
.67196 .2822 m
.70408 .2822 L
s
.67196 .2822 m
.70408 .2822 L
s
.67196 .2822 m
.66204 .25165 L
s
.67196 .2822 m
.70408 .2822 L
s
.67196 .2822 m
.70408 .2822 L
s
.67196 .2822 m
.66204 .31274 L
s
.67196 .2822 m
.64598 .30108 L
s
.67196 .2822 m
.64598 .26332 L
s
.67196 .2822 m
.64598 .26332 L
s
.67196 .2822 m
.70408 .2822 L
s
.67196 .70093 m
.70408 .70093 L
s
.67196 .70093 m
.70408 .70093 L
s
.67196 .70093 m
.70408 .70093 L
s
.67196 .70093 m
.70408 .70093 L
s
.67196 .70093 m
.66204 .67039 L
s
.67196 .70093 m
.64598 .71981 L
s
.67196 .70093 m
.64598 .71981 L
s
.67196 .70093 m
.70408 .70093 L
s
.70408 .2822 m
.7362 .2822 L
s
.70408 .2822 m
.69416 .25165 L
s
.70408 .2822 m
.69416 .25165 L
s
.70408 .2822 m
.73007 .26332 L
s
.70408 .2822 m
.67196 .2822 L
s
.70408 .2822 m
.69416 .31274 L
s
.70408 .2822 m
.73007 .30108 L
s
.70408 .2822 m
.7362 .2822 L
s
.70408 .2822 m
.7362 .2822 L
s
.70408 .2822 m
.69416 .31274 L
s
.70408 .34329 m
.69416 .31274 L
s
.70408 .34329 m
.73007 .36217 L
s
.70408 .34329 m
.73007 .36217 L
s
.70408 .34329 m
.6781 .36217 L
s
.70408 .34329 m
.6781 .36217 L
s
.70408 .34329 m
.6781 .36217 L
s
.70408 .34329 m
.69416 .31274 L
s
.70408 .63984 m
.69416 .67039 L
s
.70408 .63984 m
.73007 .62096 L
s
.70408 .63984 m
.73007 .62096 L
s
.70408 .63984 m
.6781 .62096 L
s
.70408 .63984 m
.6781 .62096 L
s
.70408 .63984 m
.6781 .62096 L
s
.70408 .63984 m
.69416 .67039 L
s
.70408 .70093 m
.7362 .70093 L
s
.70408 .70093 m
.69416 .73148 L
s
.70408 .70093 m
.69416 .73148 L
s
.70408 .70093 m
.73007 .71981 L
s
.70408 .70093 m
.69416 .67039 L
s
.70408 .70093 m
.73007 .68205 L
s
.70408 .70093 m
.7362 .70093 L
s
.70408 .70093 m
.6781 .71981 L
s
.70408 .70093 m
.6781 .71981 L
s
.70408 .70093 m
.7362 .70093 L
s
.70408 .70093 m
.69416 .67039 L
s
.2638 .2822 m
.29592 .2822 L
s
.2638 .2822 m
.23782 .26332 L
s
.2638 .2822 m
.23782 .30108 L
s
.2638 .2822 m
.23782 .26332 L
s
.2638 .2822 m
.23782 .30108 L
s
.2638 .2822 m
.23782 .26332 L
s
.2638 .70093 m
.29592 .70093 L
s
.2638 .70093 m
.23782 .71981 L
s
.2638 .70093 m
.23782 .68205 L
s
.2638 .70093 m
.23782 .71981 L
s
.2638 .70093 m
.23782 .68205 L
s
.2638 .70093 m
.23782 .71981 L
s
.29592 .2822 m
.32804 .2822 L
s
.29592 .2822 m
.32804 .2822 L
s
.29592 .2822 m
.26993 .26332 L
s
.29592 .2822 m
.26993 .30108 L
s
.29592 .2822 m
.32804 .2822 L
s
.29592 .2822 m
.26993 .26332 L
s
.29592 .2822 m
.30584 .25165 L
s
.29592 .2822 m
.30584 .31274 L
s
.29592 .2822 m
.30584 .31274 L
s
.29592 .2822 m
.30584 .31274 L
s
.29592 .44214 m
.2638 .44214 L
s
.29592 .44214 m
.26993 .46102 L
s
.29592 .44214 m
.30584 .47269 L
s
.29592 .44214 m
.30584 .41159 L
s
.29592 .44214 m
.30584 .47269 L
s
.29592 .44214 m
.30584 .41159 L
s
.29592 .44214 m
.30584 .41159 L
s
.29592 .44214 m
.30584 .41159 L
s
.29592 .54099 m
.32804 .54099 L
s
.29592 .54099 m
.26993 .55987 L
s
.29592 .54099 m
.2638 .54099 L
s
.29592 .54099 m
.32804 .54099 L
s
.29592 .54099 m
.26993 .52211 L
s
.29592 .54099 m
.26993 .55987 L
s
.29592 .54099 m
.30584 .51044 L
s
.29592 .54099 m
.30584 .57154 L
s
.29592 .54099 m
.30584 .51044 L
s
.29592 .54099 m
.30584 .57154 L
s
.29592 .54099 m
.30584 .57154 L
s
.29592 .54099 m
.30584 .57154 L
s
.29592 .70093 m
.32804 .70093 L
s
.29592 .70093 m
.26993 .71981 L
s
.29592 .70093 m
.26993 .68205 L
s
.29592 .70093 m
.26993 .71981 L
s
.29592 .70093 m
.30584 .73148 L
s
.29592 .70093 m
.30584 .67039 L
s
.29592 .70093 m
.30584 .67039 L
s
.29592 .70093 m
.30584 .67039 L
s
.32804 .2822 m
.33796 .25165 L
s
.32804 .2822 m
.33796 .31274 L
s
.32804 .2822 m
.33796 .31274 L
s
.32804 .2822 m
.33796 .31274 L
s
.32804 .2822 m
.33796 .25165 L
s
.32804 .2822 m
.33796 .31274 L
s
.32804 .2822 m
.33796 .31274 L
s
.32804 .2822 m
.33796 .31274 L
s
.32804 .54099 m
.29592 .54099 L
s
.32804 .54099 m
.33796 .57154 L
s
.32804 .54099 m
.33796 .57154 L
s
.32804 .70093 m
.33796 .67039 L
s
.32804 .70093 m
.33796 .67039 L
s
.32804 .70093 m
.33796 .67039 L
s
.70408 .2822 m
.7362 .2822 L
s
.70408 .2822 m
.69416 .25165 L
s
.70408 .2822 m
.69416 .25165 L
s
.70408 .2822 m
.73007 .26332 L
s
.70408 .2822 m
.67196 .2822 L
s
.70408 .2822 m
.69416 .31274 L
s
.70408 .2822 m
.73007 .30108 L
s
.70408 .2822 m
.7362 .2822 L
s
.70408 .2822 m
.7362 .2822 L
s
.70408 .2822 m
.69416 .31274 L
s
.70408 .70093 m
.7362 .70093 L
s
.70408 .70093 m
.69416 .73148 L
s
.70408 .70093 m
.69416 .73148 L
s
.70408 .70093 m
.73007 .71981 L
s
.70408 .70093 m
.69416 .67039 L
s
.70408 .70093 m
.73007 .68205 L
s
.70408 .70093 m
.7362 .70093 L
s
.70408 .70093 m
.6781 .71981 L
s
.70408 .70093 m
.6781 .71981 L
s
.70408 .70093 m
.7362 .70093 L
s
.70408 .70093 m
.69416 .67039 L
s
.7362 .2822 m
.76218 .26332 L
s
.7362 .2822 m
.70408 .2822 L
s
.7362 .2822 m
.70408 .2822 L
s
.7362 .2822 m
.76218 .30108 L
s
.7362 .2822 m
.76218 .26332 L
s
.7362 .2822 m
.76218 .30108 L
s
.7362 .2822 m
.70408 .2822 L
s
.7362 .70093 m
.76218 .71981 L
s
.7362 .70093 m
.70408 .70093 L
s
.7362 .70093 m
.70408 .70093 L
s
.7362 .70093 m
.76218 .68205 L
s
.7362 .70093 m
.76218 .71981 L
s
.7362 .70093 m
.76218 .68205 L
s
.7362 .70093 m
.70408 .70093 L
s
.23782 .26332 m
.26993 .26332 L
s
.23782 .26332 m
.21183 .2822 L
s
.23782 .26332 m
.26993 .26332 L
s
.23782 .26332 m
.24774 .23277 L
s
.23782 .26332 m
.21183 .2822 L
s
.23782 .26332 m
.21183 .2822 L
s
.23782 .26332 m
.22789 .23277 L
s
.23782 .26332 m
.21183 .2822 L
s
.23782 .26332 m
.21183 .2822 L
s
.23782 .30108 m
.26993 .30108 L
s
.23782 .30108 m
.21183 .2822 L
s
.23782 .30108 m
.22789 .33162 L
s
.23782 .30108 m
.24774 .33162 L
s
.23782 .30108 m
.21183 .2822 L
s
.23782 .30108 m
.21183 .2822 L
s
.23782 .30108 m
.24774 .33162 L
s
.23782 .30108 m
.21183 .2822 L
s
.23782 .30108 m
.21183 .2822 L
s
.23782 .42326 m
.21183 .44214 L
s
.23782 .42326 m
.2638 .44214 L
s
.23782 .42326 m
.21183 .44214 L
s
.23782 .42326 m
.24774 .39272 L
s
.23782 .42326 m
.24774 .39272 L
s
.23782 .42326 m
.21183 .44214 L
s
.23782 .42326 m
.21183 .44214 L
s
.23782 .42326 m
.24774 .39272 L
s
.23782 .55987 m
.26993 .55987 L
s
.23782 .55987 m
.21183 .54099 L
s
.23782 .55987 m
.2638 .54099 L
s
.23782 .55987 m
.26993 .55987 L
s
.23782 .55987 m
.21183 .54099 L
s
.23782 .55987 m
.22789 .59041 L
s
.23782 .55987 m
.24774 .59041 L
s
.23782 .55987 m
.21183 .54099 L
s
.23782 .55987 m
.21183 .54099 L
s
.23782 .55987 m
.24774 .59041 L
s
.23782 .71981 m
.26993 .71981 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .71981 m
.26993 .71981 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .71981 m
.24774 .75036 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .71981 m
.22789 .75036 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .68205 m
.26993 .68205 L
s
.23782 .68205 m
.21183 .70093 L
s
.23782 .68205 m
.21183 .70093 L
s
.23782 .68205 m
.22789 .65151 L
s
.23782 .68205 m
.24774 .65151 L
s
.23782 .68205 m
.21183 .70093 L
s
.23782 .68205 m
.21183 .70093 L
s
.23782 .68205 m
.24774 .65151 L
s
.23782 .68205 m
.21183 .70093 L
s
.23782 .68205 m
.21183 .70093 L
s
.26993 .26332 m
.23782 .26332 L
s
.26993 .26332 m
.27986 .23277 L
s
.26993 .26332 m
.27986 .23277 L
s
.26993 .26332 m
.23782 .26332 L
s
.26993 .30108 m
.27986 .33162 L
s
.26993 .30108 m
.23782 .30108 L
s
.26993 .30108 m
.27986 .33162 L
s
.26993 .55987 m
.29592 .54099 L
s
.26993 .55987 m
.23782 .55987 L
s
.26993 .55987 m
.27986 .59041 L
s
.26993 .55987 m
.27986 .59041 L
s
.26993 .55987 m
.23782 .55987 L
s
.26993 .55987 m
.27986 .59041 L
s
.26993 .55987 m
.27986 .59041 L
s
.26993 .71981 m
.23782 .71981 L
s
.26993 .71981 m
.27986 .75036 L
s
.26993 .71981 m
.27986 .75036 L
s
.26993 .71981 m
.23782 .71981 L
s
.26993 .68205 m
.27986 .65151 L
s
.26993 .68205 m
.23782 .68205 L
s
.26993 .68205 m
.27986 .65151 L
s
.38 .2822 m
.38993 .25165 L
s
.38 .2822 m
.38993 .31274 L
s
.38 .2822 m
.38993 .31274 L
s
.38 .2822 m
.38993 .25165 L
s
.38 .54099 m
.38993 .51044 L
s
.38 .54099 m
.38993 .57154 L
s
.38 .70093 m
.38993 .73148 L
s
.38 .70093 m
.38993 .67039 L
s
.38 .70093 m
.38993 .67039 L
s
.38 .70093 m
.38993 .73148 L
s
.17971 .44214 m
.21183 .44214 L
s
.17971 .44214 m
.21183 .44214 L
s
.17971 .44214 m
.16979 .41159 L
s
.17971 .44214 m
.15373 .46102 L
s
.17971 .44214 m
.21183 .44214 L
s
.17971 .44214 m
.21183 .44214 L
s
.17971 .54099 m
.21183 .54099 L
s
.17971 .54099 m
.21183 .54099 L
s
.17971 .54099 m
.16979 .57154 L
s
.17971 .54099 m
.15373 .52211 L
s
.17971 .54099 m
.21183 .54099 L
s
.17971 .54099 m
.21183 .54099 L
s
.21183 .2822 m
.23782 .26332 L
s
.21183 .2822 m
.17971 .2822 L
s
.21183 .2822 m
.20191 .31274 L
s
.21183 .2822 m
.20191 .31274 L
s
.21183 .2822 m
.23782 .30108 L
s
.21183 .2822 m
.17971 .2822 L
s
.21183 .2822 m
.20191 .25165 L
s
.21183 .2822 m
.20191 .25165 L
s
.21183 .2822 m
.23782 .26332 L
s
.21183 .2822 m
.17971 .2822 L
s
.21183 .44214 m
.23782 .46102 L
s
.21183 .44214 m
.23782 .42326 L
s
.21183 .44214 m
.20191 .47269 L
s
.21183 .44214 m
.20191 .41159 L
s
.21183 .44214 m
.20191 .47269 L
s
.21183 .44214 m
.22176 .41159 L
s
.21183 .44214 m
.18585 .46102 L
s
.21183 .44214 m
.17971 .44214 L
s
.21183 .44214 m
.23782 .46102 L
s
.21183 .44214 m
.22176 .41159 L
s
.21183 .54099 m
.23782 .52211 L
s
.21183 .54099 m
.23782 .55987 L
s
.21183 .54099 m
.20191 .51044 L
s
.21183 .54099 m
.20191 .57154 L
s
.21183 .54099 m
.20191 .51044 L
s
.21183 .54099 m
.18585 .52211 L
s
.21183 .54099 m
.23782 .55987 L
s
.21183 .54099 m
.17971 .54099 L
s
.21183 .54099 m
.23782 .52211 L
s
.21183 .70093 m
.23782 .71981 L
s
.21183 .70093 m
.17971 .70093 L
s
.21183 .70093 m
.18585 .71981 L
s
.21183 .70093 m
.20191 .67039 L
s
.21183 .70093 m
.20191 .67039 L
s
.21183 .70093 m
.23782 .68205 L
s
.21183 .70093 m
.17971 .70093 L
s
.21183 .70093 m
.20191 .73148 L
s
.21183 .70093 m
.20191 .73148 L
s
.21183 .70093 m
.23782 .71981 L
s
.21183 .70093 m
.18585 .71981 L
s
.2638 .44214 m
.29592 .44214 L
s
.2638 .44214 m
.23782 .46102 L
s
.2638 .44214 m
.23782 .42326 L
s
.2638 .44214 m
.27373 .41159 L
s
.2638 .44214 m
.23782 .46102 L
s
.2638 .54099 m
.29592 .54099 L
s
.2638 .54099 m
.23782 .52211 L
s
.2638 .54099 m
.23782 .55987 L
s
.2638 .54099 m
.23782 .55987 L
s
.2638 .54099 m
.23782 .52211 L
s
.29592 .44214 m
.26993 .46102 L
s
.29592 .44214 m
.30584 .47269 L
s
.29592 .44214 m
.30584 .41159 L
s
.29592 .44214 m
.30584 .47269 L
s
.29592 .44214 m
.30584 .41159 L
s
.29592 .44214 m
.30584 .41159 L
s
.29592 .44214 m
.30584 .41159 L
s
.29592 .54099 m
.32804 .54099 L
s
.29592 .54099 m
.26993 .52211 L
s
.29592 .54099 m
.26993 .55987 L
s
.29592 .54099 m
.30584 .51044 L
s
.29592 .54099 m
.30584 .57154 L
s
.29592 .54099 m
.30584 .51044 L
s
.29592 .54099 m
.30584 .57154 L
s
.29592 .54099 m
.30584 .57154 L
s
.29592 .54099 m
.30584 .57154 L
s
.32804 .2822 m
.33796 .25165 L
s
.32804 .2822 m
.33796 .31274 L
s
.32804 .2822 m
.33796 .31274 L
s
.32804 .2822 m
.33796 .31274 L
s
.32804 .54099 m
.33796 .57154 L
s
.32804 .54099 m
.33796 .57154 L
s
.12775 .38105 m
.11782 .41159 L
s
.12775 .38105 m
.11782 .41159 L
s
.12775 .38105 m
.11782 .41159 L
s
.12775 .38105 m
.11782 .3505 L
s
.12775 .38105 m
.11782 .41159 L
s
.12775 .38105 m
.11782 .3505 L
s
.12775 .38105 m
.15373 .36217 L
s
.12775 .38105 m
.15373 .36217 L
s
.12775 .38105 m
.15373 .36217 L
s
.12775 .38105 m
.11782 .41159 L
s
.23782 .46102 m
.26993 .46102 L
s
.23782 .46102 m
.21183 .44214 L
s
.23782 .46102 m
.22789 .49156 L
s
.23782 .46102 m
.24774 .49156 L
s
.23782 .46102 m
.21183 .44214 L
s
.23782 .46102 m
.21183 .44214 L
s
.23782 .46102 m
.24774 .49156 L
s
.23782 .52211 m
.26993 .52211 L
s
.23782 .52211 m
.21183 .54099 L
s
.23782 .52211 m
.22789 .49156 L
s
.23782 .52211 m
.24774 .49156 L
s
.23782 .52211 m
.21183 .54099 L
s
.23782 .52211 m
.21183 .54099 L
s
.23782 .52211 m
.24774 .49156 L
s
.23782 .26332 m
.26993 .26332 L
s
.23782 .26332 m
.24774 .23277 L
s
.23782 .26332 m
.21183 .2822 L
s
.23782 .26332 m
.21183 .2822 L
s
.23782 .26332 m
.22789 .23277 L
s
.23782 .26332 m
.21183 .2822 L
s
.23782 .26332 m
.21183 .2822 L
s
.23782 .42326 m
.21183 .44214 L
s
.23782 .42326 m
.24774 .39272 L
s
.23782 .42326 m
.24774 .39272 L
s
.23782 .42326 m
.21183 .44214 L
s
.23782 .42326 m
.21183 .44214 L
s
.23782 .42326 m
.24774 .39272 L
s
.23782 .55987 m
.26993 .55987 L
s
.23782 .55987 m
.21183 .54099 L
s
.23782 .55987 m
.22789 .59041 L
s
.23782 .55987 m
.24774 .59041 L
s
.23782 .55987 m
.21183 .54099 L
s
.23782 .55987 m
.21183 .54099 L
s
.23782 .55987 m
.24774 .59041 L
s
.23782 .71981 m
.26993 .71981 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .71981 m
.24774 .75036 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .71981 m
.22789 .75036 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .71981 m
.21183 .70093 L
s
.26993 .46102 m
.27986 .49156 L
s
.26993 .46102 m
.23782 .46102 L
s
.26993 .52211 m
.27986 .49156 L
s
.26993 .52211 m
.23782 .52211 L
s
.26993 .26332 m
.27986 .23277 L
s
.26993 .26332 m
.27986 .23277 L
s
.26993 .26332 m
.23782 .26332 L
s
.26993 .55987 m
.27986 .59041 L
s
.26993 .55987 m
.27986 .59041 L
s
.26993 .55987 m
.23782 .55987 L
s
.26993 .55987 m
.27986 .59041 L
s
.26993 .55987 m
.27986 .59041 L
s
.26993 .71981 m
.27986 .75036 L
s
.26993 .71981 m
.27986 .75036 L
s
.26993 .71981 m
.23782 .71981 L
s
.17971 .2822 m
.15373 .30108 L
s
.17971 .2822 m
.15373 .26332 L
s
.17971 .2822 m
.16979 .31274 L
s
.17971 .2822 m
.21183 .2822 L
s
.17971 .2822 m
.21183 .2822 L
s
.17971 .2822 m
.15373 .30108 L
s
.17971 .2822 m
.16979 .25165 L
s
.17971 .2822 m
.21183 .2822 L
s
.17971 .2822 m
.21183 .2822 L
s
.17971 .2822 m
.15373 .26332 L
s
.17971 .70093 m
.21183 .70093 L
s
.17971 .70093 m
.15373 .71981 L
s
.17971 .70093 m
.16979 .67039 L
s
.17971 .70093 m
.21183 .70093 L
s
.17971 .70093 m
.21183 .70093 L
s
.17971 .70093 m
.15373 .71981 L
s
.17971 .70093 m
.21183 .70093 L
s
.17971 .70093 m
.21183 .70093 L
s
.17971 .70093 m
.15373 .71981 L
s
.21183 .44214 m
.20191 .47269 L
s
.21183 .44214 m
.20191 .41159 L
s
.21183 .44214 m
.20191 .47269 L
s
.21183 .44214 m
.22176 .41159 L
s
.21183 .44214 m
.18585 .46102 L
s
.21183 .44214 m
.17971 .44214 L
s
.21183 .44214 m
.23782 .46102 L
s
.21183 .44214 m
.22176 .41159 L
s
.21183 .54099 m
.20191 .51044 L
s
.21183 .54099 m
.20191 .57154 L
s
.21183 .54099 m
.20191 .51044 L
s
.21183 .54099 m
.18585 .52211 L
s
.21183 .54099 m
.23782 .55987 L
s
.21183 .54099 m
.17971 .54099 L
s
.21183 .54099 m
.23782 .52211 L
s
.21183 .70093 m
.18585 .71981 L
s
.21183 .70093 m
.20191 .67039 L
s
.21183 .70093 m
.20191 .67039 L
s
.21183 .70093 m
.23782 .68205 L
s
.21183 .70093 m
.17971 .70093 L
s
.21183 .70093 m
.20191 .73148 L
s
.21183 .70093 m
.20191 .73148 L
s
.21183 .70093 m
.23782 .71981 L
s
.21183 .70093 m
.18585 .71981 L
s
.15373 .30108 m
.12775 .2822 L
s
.15373 .30108 m
.1438 .33162 L
s
.15373 .30108 m
.17971 .2822 L
s
.15373 .30108 m
.12775 .2822 L
s
.15373 .30108 m
.17971 .2822 L
s
.15373 .30108 m
.12775 .2822 L
s
.15373 .30108 m
.12775 .2822 L
s
.15373 .26332 m
.12775 .2822 L
s
.15373 .26332 m
.17971 .2822 L
s
.15373 .26332 m
.12775 .2822 L
s
.15373 .26332 m
.1438 .23277 L
s
.15373 .26332 m
.17971 .2822 L
s
.15373 .26332 m
.12775 .2822 L
s
.15373 .26332 m
.12775 .2822 L
s
.15373 .62096 m
.1438 .59041 L
s
.15373 .62096 m
.1438 .59041 L
s
.15373 .62096 m
.1438 .65151 L
s
.15373 .62096 m
.18585 .62096 L
s
.15373 .62096 m
.18585 .62096 L
s
.15373 .62096 m
.18585 .62096 L
s
.15373 .71981 m
.18585 .71981 L
s
.15373 .71981 m
.1438 .68926 L
s
.15373 .71981 m
.17971 .70093 L
s
.15373 .71981 m
.12775 .70093 L
s
.15373 .71981 m
.1438 .75036 L
s
.15373 .71981 m
.18585 .71981 L
s
.15373 .71981 m
.12775 .70093 L
s
.15373 .71981 m
.12775 .70093 L
s
.18585 .71981 m
.21183 .70093 L
s
.18585 .71981 m
.21183 .70093 L
s
.18585 .71981 m
.15373 .71981 L
s
.18585 .71981 m
.17592 .75036 L
s
.18585 .71981 m
.21183 .70093 L
s
.18585 .71981 m
.21183 .70093 L
s
.18585 .71981 m
.15373 .71981 L
s
.12775 .2822 m
.11782 .31274 L
s
.12775 .2822 m
.15373 .30108 L
s
.12775 .2822 m
.11782 .31274 L
s
.12775 .2822 m
.11782 .25165 L
s
.12775 .2822 m
.11782 .25165 L
s
.12775 .2822 m
.15373 .26332 L
s
.1438 .49156 m
.17592 .49156 L
s
.1438 .49156 m
.11782 .47269 L
s
.1438 .49156 m
.11782 .51044 L
s
.1438 .49156 m
.11782 .51044 L
s
.1438 .49156 m
.11782 .47269 L
s
.1438 .49156 m
.17592 .49156 L
s
.1438 .49156 m
.15373 .46102 L
s
.1438 .49156 m
.15373 .52211 L
s
.1438 .49156 m
.11782 .51044 L
s
.1438 .49156 m
.11782 .47269 L
s
.1438 .43047 m
.11782 .41159 L
s
.1438 .43047 m
.16979 .41159 L
s
.1438 .43047 m
.11782 .41159 L
s
.1438 .43047 m
.11782 .41159 L
s
.1438 .43047 m
.11782 .41159 L
s
.1438 .43047 m
.15373 .46102 L
s
.1438 .43047 m
.11782 .41159 L
s
.1438 .55266 m
.11782 .57154 L
s
.1438 .55266 m
.16979 .57154 L
s
.1438 .55266 m
.11782 .57154 L
s
.1438 .55266 m
.11782 .57154 L
s
.1438 .55266 m
.11782 .57154 L
s
.1438 .55266 m
.15373 .52211 L
s
.1438 .55266 m
.11782 .57154 L
s
.1438 .39272 m
.11782 .41159 L
s
.1438 .39272 m
.16979 .41159 L
s
.1438 .39272 m
.11782 .41159 L
s
.1438 .39272 m
.11782 .41159 L
s
.1438 .39272 m
.11782 .41159 L
s
.1438 .39272 m
.15373 .36217 L
s
.1438 .39272 m
.15373 .36217 L
s
.1438 .39272 m
.15373 .36217 L
s
.1438 .39272 m
.11782 .41159 L
s
.1438 .59041 m
.17592 .59041 L
s
.1438 .59041 m
.11782 .57154 L
s
.1438 .59041 m
.16979 .57154 L
s
.1438 .59041 m
.11782 .57154 L
s
.1438 .59041 m
.11782 .57154 L
s
.1438 .59041 m
.17592 .59041 L
s
.1438 .59041 m
.11782 .57154 L
s
.1438 .59041 m
.13388 .62096 L
s
.1438 .59041 m
.15373 .62096 L
s
.1438 .59041 m
.15373 .62096 L
s
.1438 .59041 m
.11782 .57154 L
s
.17592 .49156 m
.20191 .47269 L
s
.17592 .49156 m
.20191 .51044 L
s
.17592 .49156 m
.20191 .47269 L
s
.17592 .49156 m
.20191 .51044 L
s
.17592 .49156 m
.18585 .46102 L
s
.17592 .49156 m
.18585 .52211 L
s
.17592 .59041 m
.20191 .57154 L
s
.17592 .59041 m
.1438 .59041 L
s
.17592 .59041 m
.18585 .62096 L
s
.17592 .59041 m
.18585 .62096 L
s
.17592 .59041 m
.18585 .62096 L
s
.72014 .23277 m
.75226 .23277 L
s
.72014 .23277 m
.69416 .25165 L
s
.72014 .23277 m
.69416 .25165 L
s
.72014 .23277 m
.73007 .20223 L
s
.72014 .23277 m
.73007 .26332 L
s
.72014 .23277 m
.73007 .20223 L
s
.72014 .23277 m
.73007 .20223 L
s
.72014 .75036 m
.75226 .75036 L
s
.72014 .75036 m
.69416 .73148 L
s
.72014 .75036 m
.69416 .73148 L
s
.72014 .75036 m
.69416 .76923 L
s
.72014 .75036 m
.73007 .71981 L
s
.72014 .75036 m
.73007 .7809 L
s
.72014 .75036 m
.73007 .7809 L
s
.75226 .23277 m
.76218 .20223 L
s
.75226 .23277 m
.76218 .26332 L
s
.75226 .23277 m
.76218 .20223 L
s
.75226 .23277 m
.76218 .26332 L
s
.75226 .23277 m
.76218 .20223 L
s
.75226 .23277 m
.76218 .20223 L
s
.75226 .75036 m
.76218 .71981 L
s
.75226 .75036 m
.76218 .7809 L
s
.75226 .75036 m
.76218 .7809 L
s
.75226 .75036 m
.76218 .7809 L
s
.75226 .75036 m
.76218 .71981 L
s
.75226 .75036 m
.76218 .7809 L
s
.75226 .75036 m
.76218 .7809 L
s
.66204 .25165 m
.69416 .25165 L
s
.66204 .25165 m
.69416 .25165 L
s
.66204 .25165 m
.67196 .2822 L
s
.66204 .25165 m
.63605 .23277 L
s
.69416 .25165 m
.70408 .22111 L
s
.69416 .25165 m
.70408 .2822 L
s
.69416 .25165 m
.70408 .22111 L
s
.69416 .25165 m
.70408 .2822 L
s
.69416 .25165 m
.70408 .22111 L
s
.69416 .25165 m
.66817 .23277 L
s
.69416 .25165 m
.70408 .2822 L
s
.69416 .73148 m
.66817 .75036 L
s
.69416 .73148 m
.70408 .70093 L
s
.69416 .73148 m
.70408 .70093 L
s
.69416 .73148 m
.66817 .75036 L
s
.69416 .73148 m
.70408 .70093 L
s
.11782 .47269 m
.09184 .49156 L
s
.11782 .47269 m
.0857 .47269 L
s
.11782 .47269 m
.09184 .49156 L
s
.11782 .47269 m
.1079 .44214 L
s
.11782 .47269 m
.12775 .44214 L
s
.11782 .47269 m
.0857 .47269 L
s
.11782 .47269 m
.12775 .44214 L
s
.11782 .51044 m
.09184 .49156 L
s
.11782 .51044 m
.0857 .51044 L
s
.11782 .51044 m
.09184 .49156 L
s
.11782 .51044 m
.1079 .54099 L
s
.11782 .51044 m
.12775 .54099 L
s
.11782 .51044 m
.0857 .51044 L
s
.11782 .51044 m
.12775 .54099 L
s
.11782 .41159 m
.0857 .41159 L
s
.11782 .41159 m
.1438 .39272 L
s
.11782 .41159 m
.1079 .44214 L
s
.11782 .41159 m
.1079 .38105 L
s
.11782 .41159 m
.12775 .44214 L
s
.11782 .41159 m
.12775 .38105 L
s
.11782 .41159 m
.12775 .38105 L
s
.11782 .41159 m
.0857 .41159 L
s
.11782 .41159 m
.12775 .44214 L
s
.11782 .57154 m
.0857 .57154 L
s
.11782 .57154 m
.09184 .59041 L
s
.11782 .57154 m
.1438 .59041 L
s
.11782 .57154 m
.1079 .54099 L
s
.11782 .57154 m
.1079 .60208 L
s
.11782 .57154 m
.1079 .60208 L
s
.11782 .57154 m
.12775 .54099 L
s
.11782 .57154 m
.0857 .57154 L
s
.11782 .57154 m
.12775 .54099 L
s
.69416 .25165 m
.70408 .22111 L
s
.69416 .25165 m
.70408 .2822 L
s
.69416 .25165 m
.70408 .22111 L
s
.69416 .25165 m
.70408 .2822 L
s
.69416 .25165 m
.70408 .22111 L
s
.69416 .25165 m
.66817 .23277 L
s
.69416 .25165 m
.70408 .2822 L
s
.69416 .73148 m
.66817 .75036 L
s
.69416 .73148 m
.70408 .70093 L
s
.69416 .73148 m
.70408 .70093 L
s
.69416 .73148 m
.66817 .75036 L
s
.69416 .73148 m
.70408 .70093 L
s
.69416 .76923 m
.66817 .75036 L
s
.69416 .76923 m
.70408 .79978 L
s
.69416 .76923 m
.70408 .79978 L
s
.69416 .76923 m
.70408 .79978 L
s
.69416 .76923 m
.66817 .75036 L
s
.09184 .49156 m
.11782 .51044 L
s
.09184 .49156 m
.11782 .47269 L
s
.09184 .49156 m
.05972 .49156 L
s
.09184 .49156 m
.11782 .51044 L
s
.09184 .49156 m
.11782 .47269 L
s
.09184 .49156 m
.05972 .49156 L
s
.09184 .49156 m
.05972 .49156 L
s
.22789 .59041 m
.20191 .57154 L
s
.22789 .59041 m
.23782 .55987 L
s
.22789 .59041 m
.23782 .62096 L
s
.22789 .59041 m
.23782 .62096 L
s
.22789 .33162 m
.20191 .31274 L
s
.22789 .33162 m
.20191 .31274 L
s
.22789 .33162 m
.23782 .36217 L
s
.22789 .33162 m
.23782 .30108 L
s
.22789 .33162 m
.23782 .36217 L
s
.22789 .65151 m
.20191 .67039 L
s
.22789 .65151 m
.20191 .67039 L
s
.22789 .65151 m
.23782 .62096 L
s
.22789 .65151 m
.23782 .62096 L
s
.22789 .65151 m
.23782 .68205 L
s
.66817 .75036 m
.6781 .7809 L
s
.66817 .75036 m
.6781 .7809 L
s
.66817 .75036 m
.6781 .71981 L
s
.66817 .75036 m
.63605 .75036 L
s
.66817 .75036 m
.6781 .71981 L
s
.66817 .75036 m
.6781 .7809 L
s
.66817 .75036 m
.6781 .7809 L
s
.16979 .41159 m
.20191 .41159 L
s
.16979 .41159 m
.1438 .39272 L
s
.16979 .41159 m
.17971 .38105 L
s
.16979 .41159 m
.17971 .44214 L
s
.16979 .57154 m
.20191 .57154 L
s
.16979 .57154 m
.1438 .59041 L
s
.16979 .57154 m
.17971 .54099 L
s
.20191 .47269 m
.22789 .49156 L
s
.20191 .47269 m
.17592 .49156 L
s
.20191 .47269 m
.21183 .44214 L
s
.20191 .47269 m
.21183 .44214 L
s
.20191 .51044 m
.22789 .49156 L
s
.20191 .51044 m
.17592 .49156 L
s
.20191 .51044 m
.21183 .54099 L
s
.20191 .51044 m
.21183 .54099 L
s
.20191 .41159 m
.21183 .38105 L
s
.20191 .41159 m
.21183 .44214 L
s
.20191 .41159 m
.21183 .44214 L
s
.20191 .57154 m
.17592 .59041 L
s
.20191 .57154 m
.21183 .54099 L
s
.20191 .57154 m
.21183 .60208 L
s
.20191 .57154 m
.21183 .54099 L
s
.20191 .31274 m
.16979 .31274 L
s
.20191 .31274 m
.17592 .33162 L
s
.20191 .31274 m
.21183 .34329 L
s
.20191 .31274 m
.21183 .2822 L
s
.20191 .31274 m
.21183 .34329 L
s
.20191 .31274 m
.21183 .2822 L
s
.20191 .31274 m
.21183 .34329 L
s
.20191 .31274 m
.21183 .2822 L
s
.20191 .31274 m
.21183 .2822 L
s
.20191 .67039 m
.16979 .67039 L
s
.20191 .67039 m
.17592 .65151 L
s
.20191 .67039 m
.21183 .63984 L
s
.20191 .67039 m
.21183 .63984 L
s
.20191 .67039 m
.21183 .70093 L
s
.20191 .67039 m
.21183 .63984 L
s
.20191 .67039 m
.21183 .70093 L
s
.20191 .67039 m
.21183 .70093 L
s
.20191 .67039 m
.21183 .70093 L
s
.0857 .51044 m
.11782 .51044 L
s
.0857 .51044 m
.05972 .49156 L
s
.0857 .51044 m
.07578 .54099 L
s
.0857 .51044 m
.11782 .51044 L
s
.0857 .51044 m
.05972 .49156 L
s
.0857 .51044 m
.05972 .49156 L
s
.0857 .47269 m
.11782 .47269 L
s
.0857 .47269 m
.05972 .49156 L
s
.0857 .47269 m
.07578 .44214 L
s
.0857 .47269 m
.11782 .47269 L
s
.0857 .47269 m
.05972 .49156 L
s
.0857 .47269 m
.05972 .49156 L
s
.0857 .41159 m
.11782 .41159 L
s
.0857 .41159 m
.11782 .41159 L
s
.0857 .41159 m
.05972 .43047 L
s
.0857 .41159 m
.05972 .39272 L
s
.0857 .41159 m
.11782 .41159 L
s
.0857 .41159 m
.07578 .44214 L
s
.0857 .41159 m
.07578 .38105 L
s
.0857 .41159 m
.11782 .41159 L
s
.0857 .41159 m
.05972 .43047 L
s
.0857 .41159 m
.05972 .43047 L
s
.0857 .57154 m
.11782 .57154 L
s
.0857 .57154 m
.11782 .57154 L
s
.0857 .57154 m
.05972 .59041 L
s
.0857 .57154 m
.11782 .57154 L
s
.0857 .57154 m
.07578 .54099 L
s
.0857 .57154 m
.11782 .57154 L
s
.0857 .57154 m
.05972 .59041 L
s
.0857 .3505 m
.11782 .3505 L
s
.0857 .3505 m
.05972 .33162 L
s
.0857 .3505 m
.11782 .3505 L
s
.0857 .3505 m
.05972 .33162 L
s
.0857 .3505 m
.07578 .38105 L
s
.0857 .3505 m
.05972 .33162 L
s
.11782 .51044 m
.09184 .49156 L
s
.11782 .51044 m
.1079 .54099 L
s
.11782 .51044 m
.12775 .54099 L
s
.11782 .51044 m
.0857 .51044 L
s
.11782 .51044 m
.12775 .54099 L
s
.11782 .47269 m
.09184 .49156 L
s
.11782 .47269 m
.1079 .44214 L
s
.11782 .47269 m
.12775 .44214 L
s
.11782 .47269 m
.0857 .47269 L
s
.11782 .47269 m
.12775 .44214 L
s
.11782 .41159 m
.1438 .39272 L
s
.11782 .41159 m
.1079 .44214 L
s
.11782 .41159 m
.1079 .38105 L
s
.11782 .41159 m
.12775 .44214 L
s
.11782 .41159 m
.12775 .38105 L
s
.11782 .41159 m
.12775 .38105 L
s
.11782 .41159 m
.0857 .41159 L
s
.11782 .41159 m
.12775 .44214 L
s
.11782 .41159 m
.1438 .39272 L
s
.11782 .41159 m
.1079 .44214 L
s
.11782 .41159 m
.1079 .38105 L
s
.11782 .41159 m
.12775 .44214 L
s
.11782 .41159 m
.12775 .38105 L
s
.11782 .41159 m
.12775 .38105 L
s
.11782 .41159 m
.0857 .41159 L
s
.11782 .41159 m
.12775 .44214 L
s
.11782 .57154 m
.09184 .59041 L
s
.11782 .57154 m
.1438 .59041 L
s
.11782 .57154 m
.1079 .54099 L
s
.11782 .57154 m
.1079 .60208 L
s
.11782 .57154 m
.1079 .60208 L
s
.11782 .57154 m
.12775 .54099 L
s
.11782 .57154 m
.0857 .57154 L
s
.11782 .57154 m
.12775 .54099 L
s
.11782 .57154 m
.09184 .59041 L
s
.11782 .57154 m
.1438 .59041 L
s
.11782 .57154 m
.1079 .54099 L
s
.11782 .57154 m
.1079 .60208 L
s
.11782 .57154 m
.1079 .60208 L
s
.11782 .57154 m
.12775 .54099 L
s
.11782 .57154 m
.0857 .57154 L
s
.11782 .57154 m
.12775 .54099 L
s
.11782 .3505 m
.09184 .33162 L
s
.11782 .3505 m
.1438 .33162 L
s
.11782 .3505 m
.09184 .33162 L
s
.11782 .3505 m
.1079 .38105 L
s
.11782 .3505 m
.12775 .38105 L
s
.11782 .3505 m
.12775 .38105 L
s
.22789 .49156 m
.20191 .47269 L
s
.22789 .49156 m
.20191 .51044 L
s
.22789 .49156 m
.23782 .46102 L
s
.22789 .49156 m
.23782 .52211 L
s
.05972 .49156 m
.09184 .49156 L
s
.05972 .49156 m
.04979 .46102 L
s
.05972 .49156 m
.04979 .52211 L
s
.05972 .49156 m
.04979 .46102 L
s
.05972 .49156 m
.04979 .52211 L
s
.05972 .49156 m
.0857 .51044 L
s
.05972 .49156 m
.0857 .47269 L
s
.05972 .49156 m
.0276 .49156 L
s
.05972 .49156 m
.03373 .51044 L
s
.05972 .43047 m
.03373 .41159 L
s
.05972 .43047 m
.04979 .46102 L
s
.05972 .43047 m
.04979 .46102 L
s
.05972 .43047 m
.0857 .41159 L
s
.05972 .43047 m
.03373 .41159 L
s
.05972 .39272 m
.03373 .41159 L
s
.05972 .39272 m
.04979 .36217 L
s
.05972 .39272 m
.0857 .41159 L
s
.05972 .39272 m
.03373 .41159 L
s
.05972 .59041 m
.09184 .59041 L
s
.05972 .59041 m
.03373 .57154 L
s
.05972 .59041 m
.04979 .55987 L
s
.05972 .59041 m
.04979 .62096 L
s
.05972 .59041 m
.0857 .57154 L
s
.05972 .59041 m
.03373 .57154 L
s
.05972 .33162 m
.09184 .33162 L
s
.05972 .33162 m
.0857 .31274 L
s
.05972 .33162 m
.09184 .33162 L
s
.05972 .33162 m
.04979 .36217 L
s
.05972 .33162 m
.0857 .31274 L
s
.05972 .65151 m
.09184 .65151 L
s
.05972 .65151 m
.0857 .67039 L
s
.05972 .65151 m
.09184 .65151 L
s
.05972 .65151 m
.04979 .62096 L
s
.05972 .65151 m
.0857 .67039 L
s
.09184 .49156 m
.11782 .51044 L
s
.09184 .49156 m
.11782 .47269 L
s
.09184 .49156 m
.05972 .49156 L
s
.09184 .49156 m
.05972 .49156 L
s
.09184 .59041 m
.11782 .57154 L
s
.09184 .59041 m
.08191 .62096 L
s
.09184 .59041 m
.08191 .62096 L
s
.09184 .59041 m
.11782 .57154 L
s
.09184 .59041 m
.05972 .59041 L
s
.09184 .33162 m
.11782 .31274 L
s
.09184 .33162 m
.11782 .3505 L
s
.09184 .33162 m
.05972 .33162 L
s
.09184 .33162 m
.11782 .31274 L
s
.09184 .33162 m
.05972 .33162 L
s
.09184 .65151 m
.11782 .67039 L
s
.09184 .65151 m
.11782 .67039 L
s
.09184 .65151 m
.05972 .65151 L
s
.09184 .65151 m
.08191 .62096 L
s
.09184 .65151 m
.08191 .62096 L
s
.09184 .65151 m
.11782 .67039 L
s
.09184 .65151 m
.05972 .65151 L
s
.16979 .1528 m
.20191 .1528 L
s
.16979 .1528 m
.1438 .17168 L
s
.16979 .1528 m
.17971 .18335 L
s
.16979 .1528 m
.17971 .18335 L
s
.16979 .31274 m
.20191 .31274 L
s
.16979 .31274 m
.1438 .33162 L
s
.16979 .31274 m
.17971 .2822 L
s
.16979 .31274 m
.17971 .2822 L
s
.16979 .67039 m
.20191 .67039 L
s
.16979 .67039 m
.1438 .65151 L
s
.16979 .67039 m
.1438 .68926 L
s
.16979 .67039 m
.17971 .70093 L
s
.16979 .83033 m
.20191 .83033 L
s
.16979 .83033 m
.1438 .81145 L
s
.16979 .83033 m
.17971 .79978 L
s
.16979 .83033 m
.17971 .79978 L
s
.20191 .47269 m
.17592 .49156 L
s
.20191 .47269 m
.21183 .44214 L
s
.20191 .47269 m
.21183 .44214 L
s
.20191 .51044 m
.17592 .49156 L
s
.20191 .51044 m
.21183 .54099 L
s
.20191 .51044 m
.21183 .54099 L
s
.20191 .1528 m
.21183 .12226 L
s
.20191 .1528 m
.21183 .12226 L
s
.20191 .1528 m
.21183 .12226 L
s
.20191 .1528 m
.21183 .18335 L
s
.20191 .1528 m
.21183 .18335 L
s
.20191 .1528 m
.21183 .18335 L
s
.20191 .31274 m
.17592 .33162 L
s
.20191 .31274 m
.21183 .34329 L
s
.20191 .31274 m
.21183 .2822 L
s
.20191 .31274 m
.21183 .34329 L
s
.20191 .31274 m
.21183 .2822 L
s
.20191 .31274 m
.21183 .34329 L
s
.20191 .31274 m
.21183 .2822 L
s
.20191 .31274 m
.21183 .2822 L
s
.20191 .67039 m
.17592 .65151 L
s
.20191 .67039 m
.21183 .63984 L
s
.20191 .67039 m
.21183 .63984 L
s
.20191 .67039 m
.21183 .70093 L
s
.20191 .67039 m
.21183 .63984 L
s
.20191 .67039 m
.21183 .70093 L
s
.20191 .67039 m
.21183 .70093 L
s
.20191 .67039 m
.21183 .70093 L
s
.20191 .83033 m
.21183 .86087 L
s
.20191 .83033 m
.21183 .79978 L
s
.20191 .83033 m
.21183 .86087 L
s
.20191 .83033 m
.21183 .79978 L
s
.20191 .83033 m
.21183 .79978 L
s
.03373 .41159 m
.02381 .44214 L
s
.03373 .41159 m
.05972 .43047 L
s
.03373 .41159 m
.05972 .43047 L
s
.03373 .57154 m
.02381 .54099 L
s
.03373 .57154 m
.02381 .54099 L
s
.03373 .57154 m
.05972 .59041 L
s
.1438 .39272 m
.11782 .41159 L
s
.1438 .39272 m
.15373 .36217 L
s
.1438 .39272 m
.15373 .36217 L
s
.1438 .39272 m
.15373 .36217 L
s
.1438 .39272 m
.11782 .41159 L
s
.1438 .59041 m
.17592 .59041 L
s
.1438 .59041 m
.11782 .57154 L
s
.1438 .59041 m
.13388 .62096 L
s
.1438 .59041 m
.15373 .62096 L
s
.1438 .59041 m
.15373 .62096 L
s
.1438 .59041 m
.11782 .57154 L
s
.1438 .17168 m
.15373 .20223 L
s
.1438 .17168 m
.15373 .20223 L
s
.1438 .33162 m
.17592 .33162 L
s
.1438 .33162 m
.11782 .31274 L
s
.1438 .33162 m
.11782 .3505 L
s
.1438 .33162 m
.15373 .36217 L
s
.1438 .33162 m
.15373 .36217 L
s
.1438 .33162 m
.15373 .30108 L
s
.1438 .33162 m
.15373 .36217 L
s
.1438 .33162 m
.11782 .31274 L
s
.1438 .65151 m
.17592 .65151 L
s
.1438 .65151 m
.11782 .67039 L
s
.1438 .65151 m
.11782 .67039 L
s
.1438 .65151 m
.13388 .62096 L
s
.1438 .65151 m
.15373 .62096 L
s
.1438 .65151 m
.15373 .62096 L
s
.1438 .65151 m
.11782 .67039 L
s
.1438 .68926 m
.11782 .67039 L
s
.1438 .68926 m
.11782 .67039 L
s
.1438 .68926 m
.15373 .71981 L
s
.1438 .68926 m
.11782 .67039 L
s
.1438 .68926 m
.15373 .71981 L
s
.1438 .81145 m
.15373 .7809 L
s
.1438 .81145 m
.15373 .7809 L
s
.17592 .49156 m
.18585 .46102 L
s
.17592 .49156 m
.18585 .52211 L
s
.17592 .59041 m
.18585 .62096 L
s
.17592 .59041 m
.18585 .62096 L
s
.17592 .59041 m
.18585 .62096 L
s
.17592 .33162 m
.18585 .36217 L
s
.17592 .33162 m
.18585 .36217 L
s
.17592 .65151 m
.18585 .62096 L
s
.17592 .65151 m
.18585 .62096 L
s
.17592 .65151 m
.18585 .62096 L
s
.0857 .31274 m
.11782 .31274 L
s
.0857 .31274 m
.05972 .33162 L
s
.0857 .31274 m
.07578 .2822 L
s
.0857 .31274 m
.11782 .31274 L
s
.0857 .31274 m
.05972 .33162 L
s
.0857 .67039 m
.11782 .67039 L
s
.0857 .67039 m
.11782 .67039 L
s
.0857 .67039 m
.05972 .65151 L
s
.0857 .67039 m
.07578 .70093 L
s
.0857 .67039 m
.11782 .67039 L
s
.0857 .67039 m
.05972 .65151 L
s
.11782 .2139 m
.1438 .23277 L
s
.11782 .41159 m
.1079 .44214 L
s
.11782 .41159 m
.1079 .38105 L
s
.11782 .41159 m
.12775 .44214 L
s
.11782 .41159 m
.12775 .38105 L
s
.11782 .41159 m
.12775 .38105 L
s
.11782 .41159 m
.0857 .41159 L
s
.11782 .41159 m
.12775 .44214 L
s
.11782 .57154 m
.1079 .54099 L
s
.11782 .57154 m
.1079 .60208 L
s
.11782 .57154 m
.1079 .60208 L
s
.11782 .57154 m
.12775 .54099 L
s
.11782 .57154 m
.0857 .57154 L
s
.11782 .57154 m
.12775 .54099 L
s
.11782 .76923 m
.1438 .75036 L
s
.11782 .31274 m
.09184 .33162 L
s
.11782 .31274 m
.1079 .2822 L
s
.11782 .31274 m
.12775 .2822 L
s
.11782 .31274 m
.0857 .31274 L
s
.11782 .31274 m
.12775 .2822 L
s
.11782 .31274 m
.12775 .2822 L
s
.11782 .3505 m
.09184 .33162 L
s
.11782 .3505 m
.1079 .38105 L
s
.11782 .3505 m
.12775 .38105 L
s
.11782 .3505 m
.12775 .38105 L
s
.11782 .67039 m
.09184 .65151 L
s
.11782 .67039 m
.1079 .63984 L
s
.11782 .67039 m
.1079 .70093 L
s
.11782 .67039 m
.12775 .70093 L
s
.11782 .67039 m
.0857 .67039 L
s
.11782 .67039 m
.12775 .70093 L
s
.11782 .67039 m
.12775 .70093 L
s
.11782 .67039 m
.09184 .65151 L
s
.11782 .67039 m
.1079 .63984 L
s
.11782 .67039 m
.1079 .70093 L
s
.11782 .67039 m
.12775 .70093 L
s
.11782 .67039 m
.0857 .67039 L
s
.11782 .67039 m
.12775 .70093 L
s
.11782 .67039 m
.12775 .70093 L
s
.05972 .33162 m
.09184 .33162 L
s
.05972 .33162 m
.04979 .36217 L
s
.05972 .33162 m
.0857 .31274 L
s
.05972 .65151 m
.09184 .65151 L
s
.05972 .65151 m
.04979 .62096 L
s
.05972 .65151 m
.0857 .67039 L
s
.09184 .33162 m
.11782 .31274 L
s
.09184 .33162 m
.05972 .33162 L
s
.09184 .65151 m
.08191 .62096 L
s
.09184 .65151 m
.08191 .62096 L
s
.09184 .65151 m
.11782 .67039 L
s
.09184 .65151 m
.05972 .65151 L
s
.07578 .44214 m
.1079 .44214 L
s
.07578 .44214 m
.04979 .46102 L
s
.07578 .44214 m
.04979 .46102 L
s
.07578 .44214 m
.0857 .47269 L
s
.07578 .44214 m
.0857 .41159 L
s
.07578 .54099 m
.1079 .54099 L
s
.07578 .54099 m
.04979 .52211 L
s
.07578 .54099 m
.04979 .55987 L
s
.07578 .54099 m
.04979 .52211 L
s
.07578 .54099 m
.0857 .51044 L
s
.07578 .54099 m
.0857 .57154 L
s
.1079 .44214 m
.11782 .47269 L
s
.1079 .44214 m
.11782 .41159 L
s
.1079 .54099 m
.11782 .51044 L
s
.1079 .54099 m
.11782 .57154 L
s
.04979 .46102 m
.02381 .44214 L
s
.04979 .46102 m
.05972 .49156 L
s
.04979 .46102 m
.05972 .43047 L
s
.04979 .46102 m
.05972 .49156 L
s
.04979 .46102 m
.05972 .43047 L
s
.04979 .52211 m
.02381 .54099 L
s
.04979 .52211 m
.02381 .54099 L
s
.04979 .52211 m
.05972 .49156 L
s
.04979 .52211 m
.05972 .49156 L
s
.04979 .55987 m
.02381 .54099 L
s
.04979 .55987 m
.02381 .54099 L
s
.04979 .55987 m
.05972 .59041 L
s
.02381 .54099 m
.04979 .52211 L
s
.02381 .54099 m
.03373 .57154 L
s
.02381 .54099 m
.03373 .51044 L
s
.04979 .46102 m
.02381 .44214 L
s
.04979 .46102 m
.05972 .49156 L
s
.04979 .46102 m
.05972 .43047 L
s
.04979 .46102 m
.05972 .49156 L
s
.04979 .46102 m
.05972 .43047 L
s
.04979 .52211 m
.02381 .54099 L
s
.04979 .52211 m
.05972 .49156 L
s
.04979 .52211 m
.05972 .49156 L
s
.02381 .44214 m
.03373 .41159 L
s
.02381 .54099 m
.03373 .57154 L
s
.02381 .54099 m
.03373 .51044 L
s
.2638 .12226 m
.29592 .12226 L
s
.2638 .12226 m
.23782 .10338 L
s
.2638 .12226 m
.23782 .14114 L
s
.2638 .12226 m
.29592 .12226 L
s
.29592 .12226 m
.26993 .10338 L
s
.29592 .12226 m
.30584 .09171 L
s
.29592 .12226 m
.30584 .1528 L
s
.29592 .12226 m
.30584 .09171 L
s
.29592 .12226 m
.3219 .10338 L
s
.29592 .86087 m
.26993 .87975 L
s
.29592 .86087 m
.30584 .83033 L
s
.29592 .86087 m
.3219 .87975 L
s
.29592 .86087 m
.26993 .87975 L
s
.23782 .10338 m
.26993 .10338 L
s
.23782 .10338 m
.21183 .12226 L
s
.23782 .10338 m
.21183 .12226 L
s
.23782 .10338 m
.21183 .12226 L
s
.23782 .14114 m
.21183 .12226 L
s
.23782 .14114 m
.21183 .12226 L
s
.23782 .14114 m
.21183 .12226 L
s
.23782 .87975 m
.26993 .87975 L
s
.23782 .87975 m
.21183 .86087 L
s
.23782 .87975 m
.21183 .86087 L
s
.23782 .87975 m
.26993 .87975 L
s
.26993 .10338 m
.27986 .07283 L
s
.26993 .10338 m
.29592 .12226 L
s
.26993 .87975 m
.27986 .9103 L
s
.26993 .87975 m
.29592 .86087 L
s
.26993 .87975 m
.29592 .89863 L
s
.21183 .12226 m
.22176 .1528 L
s
.21183 .12226 m
.22176 .1528 L
s
.21183 .86087 m
.22176 .83033 L
s
.07578 .38105 m
.1079 .38105 L
s
.07578 .38105 m
.04979 .36217 L
s
.07578 .38105 m
.0857 .41159 L
s
.1079 .38105 m
.11782 .41159 L
s
.1079 .60208 m
.08191 .62096 L
s
.1079 .60208 m
.13388 .62096 L
s
.1079 .60208 m
.08191 .62096 L
s
.1079 .60208 m
.11782 .57154 L
s
.04979 .36217 m
.05972 .33162 L
s
.04979 .62096 m
.08191 .62096 L
s
.04979 .62096 m
.08191 .62096 L
s
.04979 .62096 m
.05972 .59041 L
s
.04979 .62096 m
.05972 .65151 L
s
.08191 .62096 m
.1079 .60208 L
s
.08191 .62096 m
.1079 .63984 L
s
.13388 .62096 m
.1079 .60208 L
s
.13388 .62096 m
.1079 .63984 L
s
.1079 .60208 m
.08191 .62096 L
s
.1079 .60208 m
.11782 .57154 L
s
.1079 .63984 m
.08191 .62096 L
s
.1079 .63984 m
.11782 .67039 L
s
.54204 .46102 m
.57416 .46102 L
s
.54204 .46102 m
.51606 .44214 L
s
.54204 .46102 m
.51606 .4799 L
s
.54204 .46102 m
.55197 .49156 L
s
.54204 .46102 m
.55197 .43047 L
s
.54204 .46102 m
.51606 .44214 L
s
.54204 .46102 m
.56803 .44214 L
s
.54204 .46102 m
.57416 .46102 L
s
.54204 .46102 m
.55197 .49156 L
s
.54204 .46102 m
.55197 .43047 L
s
.54204 .52211 m
.51606 .54099 L
s
.54204 .52211 m
.55197 .49156 L
s
.54204 .52211 m
.51606 .54099 L
s
.54204 .52211 m
.56803 .54099 L
s
.54204 .52211 m
.51606 .54099 L
s
.54204 .52211 m
.55197 .49156 L
s
.54204 .04229 m
.51606 .02341 L
s
.54204 .04229 m
.51606 .02341 L
s
.54204 .04229 m
.56803 .02341 L
s
.54204 .04229 m
.51606 .02341 L
s
.54204 .04229 m
.55197 .07283 L
s
.54204 .04229 m
.55197 .07283 L
s
.54204 .04229 m
.55197 .07283 L
s
.54204 .04229 m
.55197 .07283 L
s
.54204 .04229 m
.51606 .02341 L
s
.54204 .04229 m
.51606 .02341 L
s
.54204 .04229 m
.56803 .02341 L
s
.54204 .04229 m
.51606 .02341 L
s
.54204 .04229 m
.55197 .07283 L
s
.54204 .04229 m
.55197 .07283 L
s
.54204 .04229 m
.55197 .07283 L
s
.54204 .04229 m
.55197 .07283 L
s
.54204 .94084 m
.51606 .95972 L
s
.54204 .94084 m
.51606 .95972 L
s
.54204 .94084 m
.56803 .95972 L
s
.54204 .94084 m
.51606 .95972 L
s
.54204 .94084 m
.55197 .9103 L
s
.54204 .94084 m
.55197 .9103 L
s
.54204 .94084 m
.55197 .9103 L
s
.54204 .94084 m
.55197 .9103 L
s
.54204 .94084 m
.51606 .95972 L
s
.54204 .94084 m
.51606 .95972 L
s
.54204 .94084 m
.56803 .95972 L
s
.54204 .94084 m
.51606 .95972 L
s
.54204 .94084 m
.55197 .9103 L
s
.54204 .94084 m
.55197 .9103 L
s
.54204 .94084 m
.55197 .9103 L
s
.54204 .94084 m
.55197 .9103 L
s
.57416 .46102 m
.58409 .49156 L
s
.57416 .46102 m
.60015 .44214 L
s
.57416 .46102 m
.54204 .46102 L
s
.57416 .46102 m
.58409 .49156 L
s
.57416 .46102 m
.60015 .44214 L
s
.57416 .46102 m
.58409 .49156 L
s
.37387 .46102 m
.39985 .44214 L
s
.37387 .46102 m
.36395 .49156 L
s
.37387 .46102 m
.36395 .43047 L
s
.37387 .46102 m
.36395 .49156 L
s
.37387 .46102 m
.36395 .43047 L
s
.37387 .46102 m
.39985 .44214 L
s
.95021 .46102 m
.97619 .44214 L
s
.95021 .46102 m
.92422 .44214 L
s
.95021 .46102 m
.92422 .44214 L
s
.95021 .52211 m
.97619 .54099 L
s
.95021 .52211 m
.92422 .54099 L
s
.95021 .52211 m
.92422 .54099 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .62096 m
.91809 .62096 L
s
.95021 .62096 m
.92422 .60208 L
s
.95021 .62096 m
.92422 .60208 L
s
.95021 .62096 m
.92422 .60208 L
s
.91809 .62096 m
.95021 .62096 L
s
.91809 .62096 m
.95021 .62096 L
s
.91809 .62096 m
.8921 .60208 L
s
.91809 .62096 m
.8921 .60208 L
s
.91809 .62096 m
.8921 .60208 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .62096 m
.92422 .60208 L
s
.95021 .62096 m
.92422 .60208 L
s
.95021 .62096 m
.92422 .60208 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .36217 m
.92422 .38105 L
s
.95021 .62096 m
.92422 .60208 L
s
.95021 .62096 m
.92422 .60208 L
s
.95021 .62096 m
.92422 .60208 L
s
.8921 .60208 m
.92422 .60208 L
s
.8921 .60208 m
.92422 .60208 L
s
.8921 .60208 m
.92422 .60208 L
s
.8921 .60208 m
.86612 .62096 L
s
.8921 .60208 m
.86612 .62096 L
s
.8921 .60208 m
.86612 .62096 L
s
.92422 .38105 m
.8921 .38105 L
s
.92422 .38105 m
.8921 .38105 L
s
.92422 .38105 m
.8921 .38105 L
s
.92422 .60208 m
.8921 .60208 L
s
.92422 .60208 m
.8921 .60208 L
s
.92422 .2822 m
.9143 .31274 L
s
.92422 .2822 m
.8921 .2822 L
s
.92422 .2822 m
.8921 .2822 L
s
.92422 .2822 m
.9143 .25165 L
s
.92422 .2822 m
.8921 .2822 L
s
.92422 .38105 m
.8921 .38105 L
s
.92422 .38105 m
.8921 .38105 L
s
.92422 .38105 m
.8921 .38105 L
s
.92422 .60208 m
.8921 .60208 L
s
.92422 .60208 m
.8921 .60208 L
s
.92422 .70093 m
.9143 .67039 L
s
.92422 .70093 m
.8921 .70093 L
s
.92422 .70093 m
.8921 .70093 L
s
.92422 .70093 m
.9143 .73148 L
s
.92422 .70093 m
.8921 .70093 L
s
.48394 .02341 m
.51606 .02341 L
s
.48394 .02341 m
.51606 .02341 L
s
.48394 .02341 m
.51606 .02341 L
s
.48394 .02341 m
.45796 .04229 L
s
.48394 .0845 m
.51606 .0845 L
s
.48394 .0845 m
.51606 .0845 L
s
.48394 .0845 m
.51606 .0845 L
s
.48394 .0845 m
.45796 .10338 L
s
.48394 .0845 m
.45796 .10338 L
s
.48394 .0845 m
.45796 .10338 L
s
.48394 .0845 m
.45796 .10338 L
s
.48394 .0845 m
.45796 .10338 L
s
.48394 .89863 m
.51606 .89863 L
s
.48394 .89863 m
.51606 .89863 L
s
.48394 .89863 m
.51606 .89863 L
s
.48394 .89863 m
.45796 .87975 L
s
.48394 .89863 m
.45796 .87975 L
s
.48394 .89863 m
.45796 .87975 L
s
.48394 .89863 m
.45796 .87975 L
s
.48394 .89863 m
.45796 .87975 L
s
.48394 .95972 m
.51606 .95972 L
s
.48394 .95972 m
.51606 .95972 L
s
.48394 .95972 m
.51606 .95972 L
s
.48394 .95972 m
.45796 .94084 L
s
.51606 .02341 m
.52598 .05395 L
s
.51606 .02341 m
.52598 .05395 L
s
.51606 .02341 m
.52598 .05395 L
s
.51606 .0845 m
.52598 .05395 L
s
.51606 .0845 m
.52598 .05395 L
s
.51606 .0845 m
.54204 .10338 L
s
.51606 .0845 m
.48394 .0845 L
s
.51606 .0845 m
.49007 .10338 L
s
.51606 .0845 m
.52598 .05395 L
s
.51606 .0845 m
.54204 .10338 L
s
.51606 .0845 m
.49007 .10338 L
s
.51606 .0845 m
.49007 .10338 L
s
.51606 .89863 m
.52598 .92918 L
s
.51606 .89863 m
.52598 .92918 L
s
.51606 .89863 m
.54204 .87975 L
s
.51606 .89863 m
.48394 .89863 L
s
.51606 .89863 m
.49007 .87975 L
s
.51606 .89863 m
.52598 .92918 L
s
.51606 .89863 m
.54204 .87975 L
s
.51606 .89863 m
.49007 .87975 L
s
.51606 .89863 m
.49007 .87975 L
s
.51606 .95972 m
.52598 .92918 L
s
.51606 .95972 m
.52598 .92918 L
s
.51606 .95972 m
.52598 .92918 L
s
.8921 .38105 m
.92422 .38105 L
s
.8921 .38105 m
.92422 .38105 L
s
.8921 .44214 m
.92422 .44214 L
s
.8921 .44214 m
.92422 .44214 L
s
.8921 .54099 m
.92422 .54099 L
s
.8921 .54099 m
.92422 .54099 L
s
.8921 .60208 m
.92422 .60208 L
s
.8921 .60208 m
.86612 .62096 L
s
.8921 .60208 m
.86612 .62096 L
s
.8921 .60208 m
.86612 .62096 L
s
.8921 .38105 m
.92422 .38105 L
s
.8921 .38105 m
.92422 .38105 L
s
.8921 .60208 m
.92422 .60208 L
s
.8921 .60208 m
.86612 .62096 L
s
.8921 .60208 m
.86612 .62096 L
s
.8921 .60208 m
.86612 .62096 L
s
.92422 .38105 m
.8921 .38105 L
s
.92422 .44214 m
.8921 .44214 L
s
.92422 .54099 m
.8921 .54099 L
s
.92422 .38105 m
.8921 .38105 L
s
.48394 .44214 m
.51606 .44214 L
s
.48394 .44214 m
.45796 .46102 L
s
.48394 .44214 m
.47402 .41159 L
s
.48394 .44214 m
.51606 .44214 L
s
.48394 .44214 m
.45796 .46102 L
s
.48394 .4799 m
.51606 .4799 L
s
.48394 .4799 m
.45796 .46102 L
s
.48394 .4799 m
.45796 .46102 L
s
.48394 .54099 m
.51606 .54099 L
s
.48394 .54099 m
.45796 .52211 L
s
.48394 .54099 m
.45796 .55987 L
s
.48394 .54099 m
.47402 .57154 L
s
.48394 .54099 m
.51606 .54099 L
s
.48394 .54099 m
.45796 .55987 L
s
.48394 .54099 m
.51606 .54099 L
s
.51606 .02341 m
.52598 .05395 L
s
.51606 .02341 m
.52598 .05395 L
s
.51606 .02341 m
.52598 .05395 L
s
.51606 .44214 m
.49007 .46102 L
s
.51606 .44214 m
.50613 .41159 L
s
.51606 .44214 m
.52598 .41159 L
s
.51606 .44214 m
.48394 .44214 L
s
.51606 .44214 m
.52598 .41159 L
s
.51606 .44214 m
.54204 .46102 L
s
.51606 .44214 m
.52598 .41159 L
s
.51606 .44214 m
.52598 .41159 L
s
.51606 .4799 m
.49007 .46102 L
s
.51606 .4799 m
.52598 .51044 L
s
.51606 .4799 m
.54204 .46102 L
s
.51606 .54099 m
.50613 .57154 L
s
.51606 .54099 m
.52598 .51044 L
s
.51606 .54099 m
.48394 .54099 L
s
.51606 .54099 m
.52598 .57154 L
s
.51606 .54099 m
.54204 .52211 L
s
.51606 .54099 m
.54204 .55987 L
s
.51606 .54099 m
.52598 .57154 L
s
.51606 .54099 m
.52598 .57154 L
s
.51606 .95972 m
.52598 .92918 L
s
.51606 .95972 m
.52598 .92918 L
s
.51606 .95972 m
.52598 .92918 L
s
.92422 .44214 m
.8921 .44214 L
s
.92422 .54099 m
.8921 .54099 L
s
.42584 .46102 m
.45796 .46102 L
s
.42584 .46102 m
.39985 .44214 L
s
.42584 .46102 m
.45796 .46102 L
s
.42584 .46102 m
.39985 .44214 L
s
.45796 .46102 m
.49007 .46102 L
s
.45796 .46102 m
.43197 .44214 L
s
.45796 .46102 m
.44803 .43047 L
s
.45796 .46102 m
.48394 .44214 L
s
.45796 .46102 m
.43197 .44214 L
s
.45796 .52211 m
.43197 .54099 L
s
.45796 .52211 m
.48394 .54099 L
s
.45796 .52211 m
.43197 .54099 L
s
.45796 .55987 m
.43197 .54099 L
s
.45796 .55987 m
.44803 .59041 L
s
.45796 .55987 m
.48394 .54099 L
s
.45796 .55987 m
.43197 .54099 L
s
.49007 .46102 m
.51606 .44214 L
s
.49007 .46102 m
.45796 .46102 L
s
.39985 .2822 m
.43197 .2822 L
s
.39985 .2822 m
.38993 .25165 L
s
.39985 .2822 m
.38993 .31274 L
s
.39985 .2822 m
.38993 .31274 L
s
.39985 .2822 m
.43197 .2822 L
s
.39985 .2822 m
.38993 .25165 L
s
.39985 .2822 m
.43197 .2822 L
s
.39985 .2822 m
.43197 .2822 L
s
.39985 .44214 m
.43197 .44214 L
s
.39985 .44214 m
.38993 .41159 L
s
.39985 .44214 m
.37387 .46102 L
s
.39985 .44214 m
.37387 .46102 L
s
.39985 .44214 m
.43197 .44214 L
s
.39985 .54099 m
.43197 .54099 L
s
.39985 .54099 m
.38993 .51044 L
s
.39985 .54099 m
.38993 .57154 L
s
.39985 .54099 m
.43197 .54099 L
s
.39985 .70093 m
.43197 .70093 L
s
.39985 .70093 m
.38993 .73148 L
s
.39985 .70093 m
.38993 .67039 L
s
.39985 .70093 m
.38993 .67039 L
s
.39985 .70093 m
.43197 .70093 L
s
.39985 .70093 m
.38993 .73148 L
s
.39985 .70093 m
.43197 .70093 L
s
.39985 .70093 m
.43197 .70093 L
s
.43197 .2822 m
.39985 .2822 L
s
.43197 .2822 m
.42205 .31274 L
s
.43197 .2822 m
.45796 .30108 L
s
.43197 .2822 m
.39985 .2822 L
s
.43197 .2822 m
.42205 .25165 L
s
.43197 .2822 m
.45796 .26332 L
s
.43197 .2822 m
.45796 .30108 L
s
.43197 .2822 m
.45796 .26332 L
s
.43197 .2822 m
.45796 .30108 L
s
.43197 .44214 m
.42205 .41159 L
s
.43197 .44214 m
.45796 .46102 L
s
.43197 .44214 m
.39985 .44214 L
s
.43197 .54099 m
.42205 .57154 L
s
.43197 .54099 m
.45796 .55987 L
s
.43197 .54099 m
.39985 .54099 L
s
.43197 .70093 m
.39985 .70093 L
s
.43197 .70093 m
.42205 .67039 L
s
.43197 .70093 m
.45796 .68205 L
s
.43197 .70093 m
.39985 .70093 L
s
.43197 .70093 m
.42205 .73148 L
s
.43197 .70093 m
.45796 .71981 L
s
.43197 .70093 m
.45796 .68205 L
s
.43197 .70093 m
.45796 .71981 L
s
.43197 .70093 m
.45796 .68205 L
s
.56803 .02341 m
.60015 .02341 L
s
.56803 .02341 m
.57795 .05395 L
s
.56803 .02341 m
.57795 .05395 L
s
.56803 .95972 m
.60015 .95972 L
s
.56803 .95972 m
.57795 .92918 L
s
.56803 .95972 m
.57795 .92918 L
s
.60015 .02341 m
.61007 .05395 L
s
.60015 .02341 m
.61007 .05395 L
s
.60015 .95972 m
.61007 .92918 L
s
.60015 .95972 m
.61007 .92918 L
s
.51606 .02341 m
.52598 .05395 L
s
.51606 .02341 m
.52598 .05395 L
s
.51606 .02341 m
.52598 .05395 L
s
.51606 .95972 m
.52598 .92918 L
s
.51606 .95972 m
.52598 .92918 L
s
.51606 .95972 m
.52598 .92918 L
s
.07578 .2822 m
.1079 .2822 L
s
.07578 .2822 m
.0857 .31274 L
s
.07578 .2822 m
.0857 .25165 L
s
.07578 .70093 m
.1079 .70093 L
s
.07578 .70093 m
.0857 .67039 L
s
.07578 .70093 m
.0857 .73148 L
s
.1079 .2822 m
.11782 .31274 L
s
.1079 .2822 m
.11782 .25165 L
s
.1079 .2822 m
.11782 .25165 L
s
.1079 .70093 m
.11782 .67039 L
s
.1079 .70093 m
.11782 .73148 L
s
.1079 .70093 m
.11782 .73148 L
s
.33183 .49156 m
.36395 .49156 L
s
.33183 .49156 m
.36395 .49156 L
s
.33183 .49156 m
.30584 .47269 L
s
.33183 .49156 m
.30584 .51044 L
s
.33183 .49156 m
.30584 .47269 L
s
.33183 .49156 m
.30584 .51044 L
s
.33183 .43047 m
.36395 .43047 L
s
.33183 .43047 m
.36395 .43047 L
s
.33183 .43047 m
.30584 .41159 L
s
.33183 .43047 m
.30584 .41159 L
s
.33183 .43047 m
.30584 .41159 L
s
.33183 .43047 m
.30584 .41159 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .75036 m
.30584 .73148 L
s
.33183 .75036 m
.3219 .7809 L
s
.33183 .75036 m
.36395 .75036 L
s
.33183 .75036 m
.36395 .75036 L
s
.36395 .49156 m
.38993 .51044 L
s
.36395 .49156 m
.37387 .46102 L
s
.36395 .49156 m
.37387 .46102 L
s
.36395 .43047 m
.33183 .43047 L
s
.36395 .43047 m
.33796 .41159 L
s
.36395 .43047 m
.38993 .41159 L
s
.36395 .43047 m
.33796 .41159 L
s
.36395 .43047 m
.37387 .46102 L
s
.36395 .43047 m
.37387 .46102 L
s
.36395 .55266 m
.33796 .57154 L
s
.36395 .55266 m
.38993 .57154 L
s
.36395 .55266 m
.33796 .57154 L
s
.36395 .23277 m
.33796 .25165 L
s
.36395 .23277 m
.38993 .25165 L
s
.36395 .23277 m
.35402 .20223 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .23277 m
.38993 .2139 L
s
.36395 .23277 m
.38993 .2139 L
s
.36395 .23277 m
.38993 .25165 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .39272 m
.33183 .39272 L
s
.36395 .39272 m
.33796 .41159 L
s
.36395 .39272 m
.38993 .41159 L
s
.36395 .39272 m
.33796 .41159 L
s
.36395 .39272 m
.35402 .36217 L
s
.36395 .39272 m
.37387 .36217 L
s
.36395 .39272 m
.33183 .39272 L
s
.36395 .39272 m
.37387 .36217 L
s
.36395 .39272 m
.37387 .36217 L
s
.36395 .59041 m
.33183 .59041 L
s
.36395 .59041 m
.33796 .57154 L
s
.36395 .59041 m
.38993 .57154 L
s
.36395 .59041 m
.33796 .57154 L
s
.36395 .59041 m
.35402 .62096 L
s
.36395 .59041 m
.37387 .62096 L
s
.36395 .59041 m
.33183 .59041 L
s
.36395 .59041 m
.37387 .62096 L
s
.36395 .59041 m
.37387 .62096 L
s
.36395 .75036 m
.38993 .73148 L
s
.36395 .75036 m
.35402 .7809 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .75036 m
.38993 .76923 L
s
.36395 .75036 m
.38993 .73148 L
s
.36395 .75036 m
.38993 .76923 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .33162 m
.33796 .31274 L
s
.36395 .33162 m
.33796 .31274 L
s
.36395 .33162 m
.38993 .31274 L
s
.36395 .33162 m
.35402 .36217 L
s
.36395 .33162 m
.37387 .36217 L
s
.36395 .33162 m
.33183 .33162 L
s
.36395 .33162 m
.33183 .33162 L
s
.36395 .33162 m
.33796 .31274 L
s
.36395 .33162 m
.38993 .31274 L
s
.36395 .33162 m
.38993 .3505 L
s
.36395 .33162 m
.37387 .36217 L
s
.36395 .33162 m
.37387 .36217 L
s
.36395 .68926 m
.33796 .67039 L
s
.36395 .68926 m
.38993 .67039 L
s
.36395 .68926 m
.33796 .67039 L
s
.36395 .68926 m
.38993 .67039 L
s
.36395 .68926 m
.33796 .67039 L
s
.33183 .43047 m
.36395 .43047 L
s
.33183 .43047 m
.30584 .41159 L
s
.33183 .43047 m
.30584 .41159 L
s
.33183 .43047 m
.30584 .41159 L
s
.33183 .43047 m
.30584 .41159 L
s
.33183 .39272 m
.36395 .39272 L
s
.33183 .39272 m
.30584 .41159 L
s
.33183 .39272 m
.30584 .41159 L
s
.33183 .39272 m
.3219 .36217 L
s
.33183 .39272 m
.3219 .36217 L
s
.33183 .39272 m
.36395 .39272 L
s
.33183 .39272 m
.30584 .41159 L
s
.33183 .39272 m
.30584 .41159 L
s
.33183 .59041 m
.36395 .59041 L
s
.33183 .59041 m
.30584 .57154 L
s
.33183 .59041 m
.30584 .57154 L
s
.33183 .59041 m
.3219 .62096 L
s
.33183 .59041 m
.3219 .62096 L
s
.33183 .59041 m
.36395 .59041 L
s
.33183 .59041 m
.30584 .57154 L
s
.33183 .59041 m
.30584 .57154 L
s
.36395 .49156 m
.38993 .51044 L
s
.36395 .49156 m
.37387 .46102 L
s
.36395 .49156 m
.37387 .46102 L
s
.36395 .43047 m
.33796 .41159 L
s
.36395 .43047 m
.38993 .41159 L
s
.36395 .43047 m
.33796 .41159 L
s
.36395 .43047 m
.37387 .46102 L
s
.36395 .43047 m
.37387 .46102 L
s
.36395 .55266 m
.33796 .57154 L
s
.36395 .55266 m
.38993 .57154 L
s
.36395 .55266 m
.33796 .57154 L
s
.36395 .23277 m
.33796 .25165 L
s
.36395 .23277 m
.38993 .25165 L
s
.36395 .23277 m
.35402 .20223 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .23277 m
.38993 .2139 L
s
.36395 .23277 m
.38993 .2139 L
s
.36395 .23277 m
.38993 .25165 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .39272 m
.33796 .41159 L
s
.36395 .39272 m
.38993 .41159 L
s
.36395 .39272 m
.33796 .41159 L
s
.36395 .39272 m
.35402 .36217 L
s
.36395 .39272 m
.37387 .36217 L
s
.36395 .39272 m
.33183 .39272 L
s
.36395 .39272 m
.37387 .36217 L
s
.36395 .39272 m
.37387 .36217 L
s
.36395 .59041 m
.33796 .57154 L
s
.36395 .59041 m
.38993 .57154 L
s
.36395 .59041 m
.33796 .57154 L
s
.36395 .59041 m
.35402 .62096 L
s
.36395 .59041 m
.37387 .62096 L
s
.36395 .59041 m
.33183 .59041 L
s
.36395 .59041 m
.37387 .62096 L
s
.36395 .59041 m
.37387 .62096 L
s
.36395 .75036 m
.38993 .73148 L
s
.36395 .75036 m
.35402 .7809 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .75036 m
.38993 .76923 L
s
.36395 .75036 m
.38993 .73148 L
s
.36395 .75036 m
.38993 .76923 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .33162 m
.33796 .31274 L
s
.36395 .33162 m
.33796 .31274 L
s
.36395 .33162 m
.38993 .31274 L
s
.36395 .33162 m
.35402 .36217 L
s
.36395 .33162 m
.37387 .36217 L
s
.36395 .33162 m
.33183 .33162 L
s
.36395 .33162 m
.33183 .33162 L
s
.36395 .33162 m
.33796 .31274 L
s
.36395 .33162 m
.38993 .31274 L
s
.36395 .33162 m
.38993 .3505 L
s
.36395 .33162 m
.37387 .36217 L
s
.36395 .33162 m
.37387 .36217 L
s
.36395 .68926 m
.33796 .67039 L
s
.36395 .68926 m
.38993 .67039 L
s
.36395 .68926 m
.33796 .67039 L
s
.36395 .68926 m
.38993 .67039 L
s
.36395 .68926 m
.33796 .67039 L
s
.47402 .41159 m
.50613 .41159 L
s
.47402 .41159 m
.44803 .43047 L
s
.47402 .41159 m
.44803 .39272 L
s
.47402 .41159 m
.48394 .38105 L
s
.47402 .41159 m
.48394 .44214 L
s
.47402 .57154 m
.50613 .57154 L
s
.47402 .57154 m
.44803 .59041 L
s
.47402 .57154 m
.48394 .54099 L
s
.47402 .57154 m
.48394 .60208 L
s
.50613 .41159 m
.51606 .38105 L
s
.50613 .41159 m
.51606 .44214 L
s
.50613 .41159 m
.51606 .38105 L
s
.50613 .57154 m
.51606 .54099 L
s
.50613 .57154 m
.51606 .60208 L
s
.50613 .57154 m
.51606 .54099 L
s
.50613 .57154 m
.51606 .60208 L
s
.30584 .47269 m
.27986 .49156 L
s
.30584 .51044 m
.27986 .49156 L
s
.30584 .25165 m
.33796 .25165 L
s
.30584 .25165 m
.27986 .23277 L
s
.30584 .25165 m
.27986 .23277 L
s
.30584 .25165 m
.29592 .22111 L
s
.30584 .41159 m
.33796 .41159 L
s
.30584 .41159 m
.27373 .41159 L
s
.30584 .41159 m
.33796 .41159 L
s
.30584 .41159 m
.27986 .39272 L
s
.30584 .41159 m
.29592 .38105 L
s
.30584 .41159 m
.29592 .38105 L
s
.30584 .41159 m
.33183 .39272 L
s
.30584 .41159 m
.27986 .39272 L
s
.30584 .41159 m
.27986 .39272 L
s
.30584 .57154 m
.33796 .57154 L
s
.30584 .57154 m
.27986 .59041 L
s
.30584 .57154 m
.33796 .57154 L
s
.30584 .57154 m
.27986 .59041 L
s
.30584 .57154 m
.29592 .60208 L
s
.30584 .57154 m
.29592 .60208 L
s
.30584 .57154 m
.33183 .59041 L
s
.30584 .57154 m
.27986 .59041 L
s
.30584 .57154 m
.27986 .59041 L
s
.30584 .73148 m
.27986 .75036 L
s
.30584 .73148 m
.27986 .75036 L
s
.30584 .31274 m
.33796 .31274 L
s
.30584 .31274 m
.33796 .31274 L
s
.30584 .31274 m
.27986 .33162 L
s
.30584 .31274 m
.29592 .34329 L
s
.30584 .31274 m
.29592 .34329 L
s
.30584 .31274 m
.33183 .33162 L
s
.30584 .31274 m
.33183 .33162 L
s
.30584 .31274 m
.33796 .31274 L
s
.30584 .31274 m
.27986 .33162 L
s
.30584 .67039 m
.33796 .67039 L
s
.30584 .67039 m
.27986 .65151 L
s
.30584 .67039 m
.29592 .63984 L
s
.30584 .67039 m
.29592 .63984 L
s
.30584 .67039 m
.33183 .65151 L
s
.30584 .67039 m
.33183 .65151 L
s
.30584 .67039 m
.33796 .67039 L
s
.30584 .67039 m
.27986 .65151 L
s
.30584 .67039 m
.33796 .67039 L
s
.33796 .25165 m
.36395 .23277 L
s
.33796 .25165 m
.36395 .23277 L
s
.33796 .41159 m
.30584 .41159 L
s
.33796 .41159 m
.36395 .39272 L
s
.33796 .41159 m
.30584 .41159 L
s
.33796 .41159 m
.30584 .41159 L
s
.33796 .57154 m
.30584 .57154 L
s
.33796 .57154 m
.36395 .59041 L
s
.33796 .57154 m
.30584 .57154 L
s
.33796 .57154 m
.30584 .57154 L
s
.33796 .31274 m
.36395 .33162 L
s
.33796 .31274 m
.36395 .33162 L
s
.33796 .31274 m
.30584 .31274 L
s
.33796 .31274 m
.30584 .31274 L
s
.33796 .31274 m
.36395 .33162 L
s
.33796 .31274 m
.36395 .33162 L
s
.33796 .31274 m
.30584 .31274 L
s
.33796 .31274 m
.30584 .31274 L
s
.33796 .67039 m
.36395 .65151 L
s
.33796 .67039 m
.36395 .65151 L
s
.33796 .67039 m
.36395 .68926 L
s
.33796 .67039 m
.30584 .67039 L
s
.33796 .67039 m
.30584 .67039 L
s
.41591 .59041 m
.44803 .59041 L
s
.41591 .59041 m
.38993 .57154 L
s
.41591 .59041 m
.42584 .62096 L
s
.41591 .59041 m
.42584 .62096 L
s
.44803 .43047 m
.42205 .41159 L
s
.44803 .43047 m
.45796 .46102 L
s
.44803 .39272 m
.42205 .41159 L
s
.44803 .39272 m
.45796 .36217 L
s
.44803 .39272 m
.45796 .36217 L
s
.44803 .39272 m
.45796 .36217 L
s
.44803 .39272 m
.45796 .36217 L
s
.44803 .59041 m
.42205 .57154 L
s
.44803 .59041 m
.45796 .55987 L
s
.44803 .59041 m
.45796 .62096 L
s
.44803 .59041 m
.45796 .62096 L
s
.44803 .59041 m
.45796 .62096 L
s
.44803 .59041 m
.45796 .62096 L
s
.24774 .39272 m
.22176 .41159 L
s
.24774 .39272 m
.27373 .41159 L
s
.24774 .39272 m
.27986 .39272 L
s
.24774 .39272 m
.23782 .36217 L
s
.24774 .39272 m
.23782 .36217 L
s
.24774 .39272 m
.27986 .39272 L
s
.24774 .39272 m
.22176 .41159 L
s
.24774 .39272 m
.27986 .39272 L
s
.24774 .59041 m
.27986 .59041 L
s
.24774 .59041 m
.27986 .59041 L
s
.24774 .59041 m
.23782 .55987 L
s
.24774 .59041 m
.23782 .62096 L
s
.24774 .59041 m
.23782 .62096 L
s
.24774 .59041 m
.27986 .59041 L
s
.24774 .59041 m
.27986 .59041 L
s
.24774 .33162 m
.27986 .33162 L
s
.24774 .33162 m
.23782 .36217 L
s
.24774 .33162 m
.23782 .30108 L
s
.24774 .33162 m
.23782 .36217 L
s
.24774 .33162 m
.27986 .33162 L
s
.24774 .65151 m
.27986 .65151 L
s
.24774 .65151 m
.23782 .62096 L
s
.24774 .65151 m
.23782 .62096 L
s
.24774 .65151 m
.23782 .68205 L
s
.24774 .65151 m
.27986 .65151 L
s
.27986 .23277 m
.24774 .23277 L
s
.27986 .23277 m
.26993 .20223 L
s
.27986 .23277 m
.26993 .20223 L
s
.27986 .59041 m
.30584 .57154 L
s
.27986 .59041 m
.26993 .62096 L
s
.27986 .59041 m
.26993 .62096 L
s
.27986 .59041 m
.26993 .62096 L
s
.27986 .59041 m
.30584 .57154 L
s
.27986 .59041 m
.24774 .59041 L
s
.27986 .59041 m
.30584 .57154 L
s
.27986 .75036 m
.24774 .75036 L
s
.27986 .75036 m
.26993 .7809 L
s
.27986 .33162 m
.26993 .36217 L
s
.27986 .33162 m
.26993 .36217 L
s
.27986 .33162 m
.26993 .36217 L
s
.27986 .33162 m
.30584 .31274 L
s
.27986 .33162 m
.30584 .31274 L
s
.27986 .33162 m
.24774 .33162 L
s
.27986 .65151 m
.26993 .62096 L
s
.27986 .65151 m
.26993 .62096 L
s
.27986 .65151 m
.26993 .62096 L
s
.27986 .65151 m
.30584 .67039 L
s
.27986 .65151 m
.30584 .67039 L
s
.27986 .65151 m
.24774 .65151 L
s
.38993 .51044 m
.39985 .54099 L
s
.38993 .25165 m
.39985 .2822 L
s
.38993 .25165 m
.39985 .2822 L
s
.38993 .25165 m
.42205 .25165 L
s
.38993 .25165 m
.36395 .23277 L
s
.38993 .25165 m
.41591 .23277 L
s
.38993 .25165 m
.36395 .23277 L
s
.38993 .41159 m
.42205 .41159 L
s
.38993 .41159 m
.39985 .38105 L
s
.38993 .41159 m
.39985 .44214 L
s
.38993 .41159 m
.36395 .39272 L
s
.38993 .41159 m
.39985 .38105 L
s
.38993 .57154 m
.42205 .57154 L
s
.38993 .57154 m
.39985 .54099 L
s
.38993 .57154 m
.39985 .60208 L
s
.38993 .57154 m
.36395 .59041 L
s
.38993 .73148 m
.39985 .70093 L
s
.38993 .73148 m
.39985 .70093 L
s
.38993 .73148 m
.42205 .73148 L
s
.38993 .73148 m
.36395 .75036 L
s
.38993 .73148 m
.41591 .75036 L
s
.38993 .73148 m
.36395 .75036 L
s
.38993 .31274 m
.39985 .2822 L
s
.38993 .31274 m
.36395 .33162 L
s
.38993 .31274 m
.36395 .33162 L
s
.38993 .31274 m
.41591 .33162 L
s
.38993 .31274 m
.42205 .31274 L
s
.38993 .31274 m
.39985 .2822 L
s
.38993 .67039 m
.39985 .63984 L
s
.38993 .67039 m
.39985 .70093 L
s
.38993 .67039 m
.36395 .65151 L
s
.38993 .67039 m
.36395 .65151 L
s
.38993 .67039 m
.36395 .68926 L
s
.38993 .67039 m
.41591 .65151 L
s
.38993 .67039 m
.42205 .67039 L
s
.38993 .67039 m
.39985 .63984 L
s
.38993 .67039 m
.39985 .70093 L
s
.42205 .41159 m
.43197 .38105 L
s
.42205 .41159 m
.43197 .44214 L
s
.42205 .57154 m
.43197 .54099 L
s
.22176 .41159 m
.24774 .39272 L
s
.22176 .41159 m
.21183 .38105 L
s
.22176 .41159 m
.21183 .44214 L
s
.22176 .41159 m
.21183 .44214 L
s
.22176 .41159 m
.24774 .39272 L
s
.27373 .41159 m
.30584 .41159 L
s
.27373 .41159 m
.24774 .39272 L
s
.27373 .41159 m
.30584 .41159 L
s
.27373 .41159 m
.24774 .39272 L
s
.27373 .41159 m
.30584 .41159 L
s
.30584 .47269 m
.27986 .49156 L
s
.30584 .51044 m
.27986 .49156 L
s
.30584 .41159 m
.33796 .41159 L
s
.30584 .41159 m
.27986 .39272 L
s
.30584 .41159 m
.29592 .38105 L
s
.30584 .41159 m
.29592 .38105 L
s
.30584 .41159 m
.33183 .39272 L
s
.30584 .41159 m
.27986 .39272 L
s
.30584 .41159 m
.27986 .39272 L
s
.30584 .57154 m
.33796 .57154 L
s
.30584 .57154 m
.27986 .59041 L
s
.30584 .57154 m
.29592 .60208 L
s
.30584 .57154 m
.29592 .60208 L
s
.30584 .57154 m
.33183 .59041 L
s
.30584 .57154 m
.27986 .59041 L
s
.30584 .57154 m
.27986 .59041 L
s
.33796 .41159 m
.36395 .39272 L
s
.33796 .41159 m
.30584 .41159 L
s
.33796 .41159 m
.30584 .41159 L
s
.33796 .57154 m
.36395 .59041 L
s
.33796 .57154 m
.30584 .57154 L
s
.33796 .57154 m
.30584 .57154 L
s
.24774 .49156 m
.27986 .49156 L
s
.24774 .49156 m
.23782 .46102 L
s
.24774 .49156 m
.23782 .52211 L
s
.24774 .23277 m
.27986 .23277 L
s
.24774 .23277 m
.23782 .20223 L
s
.24774 .23277 m
.23782 .26332 L
s
.24774 .39272 m
.27986 .39272 L
s
.24774 .39272 m
.23782 .36217 L
s
.24774 .39272 m
.23782 .36217 L
s
.24774 .39272 m
.27986 .39272 L
s
.24774 .39272 m
.22176 .41159 L
s
.24774 .39272 m
.27986 .39272 L
s
.24774 .75036 m
.27986 .75036 L
s
.24774 .75036 m
.23782 .71981 L
s
.24774 .75036 m
.23782 .7809 L
s
.27986 .49156 m
.24774 .49156 L
s
.27986 .23277 m
.26993 .20223 L
s
.27986 .23277 m
.26993 .20223 L
s
.27986 .39272 m
.26993 .36217 L
s
.27986 .39272 m
.26993 .36217 L
s
.27986 .39272 m
.26993 .36217 L
s
.27986 .39272 m
.30584 .41159 L
s
.27986 .39272 m
.24774 .39272 L
s
.27986 .39272 m
.30584 .41159 L
s
.27986 .59041 m
.26993 .62096 L
s
.27986 .59041 m
.26993 .62096 L
s
.27986 .59041 m
.26993 .62096 L
s
.27986 .59041 m
.30584 .57154 L
s
.27986 .59041 m
.24774 .59041 L
s
.27986 .59041 m
.30584 .57154 L
s
.27986 .75036 m
.26993 .7809 L
s
.15373 .46102 m
.18585 .46102 L
s
.15373 .46102 m
.12775 .44214 L
s
.15373 .46102 m
.17971 .44214 L
s
.15373 .46102 m
.12775 .44214 L
s
.15373 .52211 m
.18585 .52211 L
s
.15373 .52211 m
.12775 .54099 L
s
.15373 .52211 m
.17971 .54099 L
s
.15373 .52211 m
.12775 .54099 L
s
.15373 .36217 m
.18585 .36217 L
s
.15373 .36217 m
.17971 .38105 L
s
.15373 .36217 m
.18585 .36217 L
s
.15373 .36217 m
.12775 .38105 L
s
.15373 .36217 m
.12775 .38105 L
s
.18585 .46102 m
.21183 .44214 L
s
.18585 .46102 m
.21183 .44214 L
s
.18585 .52211 m
.21183 .54099 L
s
.18585 .52211 m
.21183 .54099 L
s
.18585 .36217 m
.21183 .34329 L
s
.18585 .36217 m
.21183 .38105 L
s
.18585 .36217 m
.21183 .34329 L
s
.18585 .36217 m
.21183 .34329 L
s
.18585 .36217 m
.15373 .36217 L
s
.18585 .36217 m
.15373 .36217 L
s
.18585 .62096 m
.21183 .60208 L
s
.18585 .62096 m
.21183 .63984 L
s
.18585 .62096 m
.21183 .63984 L
s
.18585 .62096 m
.21183 .63984 L
s
.18585 .62096 m
.15373 .62096 L
s
.18585 .62096 m
.15373 .62096 L
s
.3219 .36217 m
.35402 .36217 L
s
.3219 .36217 m
.29592 .34329 L
s
.3219 .36217 m
.29592 .38105 L
s
.3219 .36217 m
.29592 .34329 L
s
.3219 .36217 m
.29592 .38105 L
s
.3219 .36217 m
.33183 .39272 L
s
.3219 .36217 m
.33183 .33162 L
s
.3219 .36217 m
.33183 .33162 L
s
.3219 .62096 m
.35402 .62096 L
s
.3219 .62096 m
.29592 .60208 L
s
.3219 .62096 m
.29592 .63984 L
s
.3219 .62096 m
.29592 .63984 L
s
.3219 .62096 m
.29592 .60208 L
s
.3219 .62096 m
.33183 .59041 L
s
.3219 .62096 m
.33183 .65151 L
s
.3219 .62096 m
.33183 .65151 L
s
.35402 .36217 m
.3219 .36217 L
s
.35402 .36217 m
.36395 .39272 L
s
.35402 .36217 m
.36395 .33162 L
s
.35402 .36217 m
.36395 .33162 L
s
.35402 .62096 m
.3219 .62096 L
s
.35402 .62096 m
.36395 .59041 L
s
.35402 .62096 m
.36395 .65151 L
s
.35402 .62096 m
.36395 .65151 L
s
.3219 .36217 m
.29592 .34329 L
s
.3219 .36217 m
.29592 .38105 L
s
.3219 .36217 m
.29592 .34329 L
s
.3219 .36217 m
.29592 .38105 L
s
.3219 .36217 m
.33183 .39272 L
s
.3219 .36217 m
.33183 .33162 L
s
.3219 .36217 m
.33183 .33162 L
s
.3219 .62096 m
.29592 .60208 L
s
.3219 .62096 m
.29592 .63984 L
s
.3219 .62096 m
.29592 .63984 L
s
.3219 .62096 m
.29592 .60208 L
s
.3219 .62096 m
.33183 .59041 L
s
.3219 .62096 m
.33183 .65151 L
s
.3219 .62096 m
.33183 .65151 L
s
.73007 .20223 m
.76218 .20223 L
s
.73007 .20223 m
.70408 .22111 L
s
.73007 .20223 m
.70408 .22111 L
s
.73007 .20223 m
.72014 .17168 L
s
.73007 .20223 m
.76218 .20223 L
s
.73007 .20223 m
.70408 .18335 L
s
.73007 .20223 m
.70408 .18335 L
s
.73007 .20223 m
.70408 .22111 L
s
.73007 .20223 m
.76218 .20223 L
s
.73007 .20223 m
.76218 .20223 L
s
.73007 .26332 m
.76218 .26332 L
s
.73007 .26332 m
.70408 .2822 L
s
.73007 .26332 m
.70408 .2822 L
s
.73007 .26332 m
.76218 .26332 L
s
.73007 .26332 m
.70408 .2822 L
s
.73007 .71981 m
.76218 .71981 L
s
.73007 .71981 m
.70408 .70093 L
s
.73007 .71981 m
.70408 .70093 L
s
.73007 .71981 m
.76218 .71981 L
s
.73007 .71981 m
.70408 .70093 L
s
.73007 .7809 m
.76218 .7809 L
s
.73007 .7809 m
.70408 .79978 L
s
.73007 .7809 m
.76218 .7809 L
s
.73007 .7809 m
.70408 .79978 L
s
.73007 .7809 m
.76218 .7809 L
s
.73007 .7809 m
.70408 .79978 L
s
.73007 .7809 m
.76218 .7809 L
s
.73007 .7809 m
.76218 .7809 L
s
.76218 .20223 m
.75226 .17168 L
s
.76218 .20223 m
.77211 .23277 L
s
.76218 .20223 m
.73007 .20223 L
s
.76218 .20223 m
.78817 .18335 L
s
.76218 .20223 m
.73007 .20223 L
s
.76218 .20223 m
.78817 .18335 L
s
.76218 .20223 m
.77211 .23277 L
s
.76218 .20223 m
.78817 .18335 L
s
.76218 .20223 m
.78817 .22111 L
s
.76218 .20223 m
.77211 .23277 L
s
.76218 .26332 m
.77211 .23277 L
s
.76218 .26332 m
.78817 .2822 L
s
.76218 .26332 m
.7362 .2822 L
s
.76218 .26332 m
.77211 .23277 L
s
.76218 .26332 m
.77211 .23277 L
s
.76218 .26332 m
.7362 .2822 L
s
.76218 .71981 m
.77211 .75036 L
s
.76218 .71981 m
.78817 .70093 L
s
.76218 .71981 m
.7362 .70093 L
s
.76218 .71981 m
.77211 .75036 L
s
.76218 .71981 m
.77211 .75036 L
s
.76218 .71981 m
.7362 .70093 L
s
.76218 .7809 m
.75226 .81145 L
s
.76218 .7809 m
.77211 .75036 L
s
.76218 .7809 m
.78817 .79978 L
s
.76218 .7809 m
.7362 .79978 L
s
.76218 .7809 m
.73007 .7809 L
s
.76218 .7809 m
.78817 .79978 L
s
.76218 .7809 m
.7362 .79978 L
s
.76218 .7809 m
.77211 .75036 L
s
.76218 .7809 m
.78817 .76202 L
s
.76218 .7809 m
.78817 .79978 L
s
.76218 .7809 m
.77211 .75036 L
s
.67196 .2822 m
.70408 .2822 L
s
.67196 .2822 m
.70408 .2822 L
s
.67196 .2822 m
.66204 .31274 L
s
.67196 .2822 m
.64598 .30108 L
s
.67196 .2822 m
.64598 .26332 L
s
.67196 .2822 m
.64598 .26332 L
s
.67196 .2822 m
.70408 .2822 L
s
.70408 .22111 m
.73007 .20223 L
s
.70408 .22111 m
.6781 .20223 L
s
.70408 .22111 m
.73007 .20223 L
s
.70408 .22111 m
.6781 .20223 L
s
.70408 .22111 m
.6781 .20223 L
s
.70408 .22111 m
.6781 .20223 L
s
.70408 .2822 m
.69416 .31274 L
s
.70408 .2822 m
.73007 .30108 L
s
.70408 .2822 m
.7362 .2822 L
s
.70408 .2822 m
.7362 .2822 L
s
.70408 .2822 m
.69416 .31274 L
s
.70408 .70093 m
.69416 .67039 L
s
.70408 .70093 m
.73007 .68205 L
s
.70408 .70093 m
.7362 .70093 L
s
.70408 .70093 m
.6781 .71981 L
s
.70408 .70093 m
.6781 .71981 L
s
.70408 .70093 m
.7362 .70093 L
s
.70408 .70093 m
.69416 .67039 L
s
.12775 .44214 m
.11782 .47269 L
s
.12775 .44214 m
.11782 .41159 L
s
.12775 .54099 m
.11782 .51044 L
s
.12775 .54099 m
.11782 .57154 L
s
.29592 .34329 m
.26993 .36217 L
s
.29592 .34329 m
.26993 .36217 L
s
.29592 .34329 m
.26993 .36217 L
s
.29592 .34329 m
.30584 .31274 L
s
.29592 .34329 m
.30584 .31274 L
s
.29592 .38105 m
.26993 .36217 L
s
.29592 .38105 m
.26993 .36217 L
s
.29592 .38105 m
.26993 .36217 L
s
.29592 .38105 m
.30584 .41159 L
s
.29592 .38105 m
.30584 .41159 L
s
.29592 .34329 m
.26993 .36217 L
s
.29592 .34329 m
.26993 .36217 L
s
.29592 .34329 m
.26993 .36217 L
s
.29592 .34329 m
.30584 .31274 L
s
.29592 .34329 m
.30584 .31274 L
s
.29592 .60208 m
.26993 .62096 L
s
.29592 .60208 m
.26993 .62096 L
s
.29592 .60208 m
.26993 .62096 L
s
.29592 .60208 m
.30584 .57154 L
s
.29592 .60208 m
.30584 .57154 L
s
.29592 .63984 m
.26993 .62096 L
s
.29592 .63984 m
.26993 .62096 L
s
.29592 .63984 m
.26993 .62096 L
s
.29592 .63984 m
.30584 .67039 L
s
.29592 .63984 m
.30584 .67039 L
s
.29592 .63984 m
.26993 .62096 L
s
.29592 .63984 m
.26993 .62096 L
s
.29592 .63984 m
.26993 .62096 L
s
.29592 .63984 m
.30584 .67039 L
s
.29592 .63984 m
.30584 .67039 L
s
.70408 .22111 m
.73007 .20223 L
s
.70408 .22111 m
.6781 .20223 L
s
.70408 .22111 m
.73007 .20223 L
s
.70408 .22111 m
.6781 .20223 L
s
.70408 .22111 m
.6781 .20223 L
s
.70408 .22111 m
.6781 .20223 L
s
.70408 .2822 m
.69416 .31274 L
s
.70408 .2822 m
.73007 .30108 L
s
.70408 .2822 m
.7362 .2822 L
s
.70408 .2822 m
.7362 .2822 L
s
.70408 .2822 m
.69416 .31274 L
s
.70408 .70093 m
.69416 .67039 L
s
.70408 .70093 m
.73007 .68205 L
s
.70408 .70093 m
.7362 .70093 L
s
.70408 .70093 m
.6781 .71981 L
s
.70408 .70093 m
.6781 .71981 L
s
.70408 .70093 m
.7362 .70093 L
s
.70408 .70093 m
.69416 .67039 L
s
.70408 .79978 m
.6781 .7809 L
s
.70408 .79978 m
.69416 .83033 L
s
.70408 .79978 m
.7362 .79978 L
s
.70408 .79978 m
.6781 .7809 L
s
.70408 .79978 m
.73007 .7809 L
s
.70408 .79978 m
.7362 .79978 L
s
.70408 .79978 m
.6781 .7809 L
s
.70408 .79978 m
.6781 .7809 L
s
.23782 .36217 m
.26993 .36217 L
s
.23782 .36217 m
.26993 .36217 L
s
.23782 .36217 m
.21183 .34329 L
s
.23782 .36217 m
.21183 .38105 L
s
.23782 .36217 m
.21183 .34329 L
s
.23782 .36217 m
.26993 .36217 L
s
.23782 .36217 m
.21183 .34329 L
s
.23782 .36217 m
.24774 .39272 L
s
.23782 .36217 m
.24774 .33162 L
s
.23782 .55987 m
.21183 .54099 L
s
.23782 .55987 m
.21183 .54099 L
s
.23782 .55987 m
.24774 .59041 L
s
.23782 .62096 m
.26993 .62096 L
s
.23782 .62096 m
.26993 .62096 L
s
.23782 .62096 m
.21183 .60208 L
s
.23782 .62096 m
.21183 .63984 L
s
.23782 .62096 m
.21183 .63984 L
s
.23782 .62096 m
.26993 .62096 L
s
.23782 .62096 m
.21183 .63984 L
s
.23782 .62096 m
.24774 .59041 L
s
.23782 .62096 m
.24774 .65151 L
s
.23782 .30108 m
.21183 .2822 L
s
.23782 .30108 m
.21183 .2822 L
s
.23782 .30108 m
.24774 .33162 L
s
.23782 .30108 m
.21183 .2822 L
s
.23782 .30108 m
.21183 .2822 L
s
.23782 .36217 m
.26993 .36217 L
s
.23782 .36217 m
.26993 .36217 L
s
.23782 .36217 m
.21183 .34329 L
s
.23782 .36217 m
.21183 .38105 L
s
.23782 .36217 m
.21183 .34329 L
s
.23782 .36217 m
.26993 .36217 L
s
.23782 .36217 m
.21183 .34329 L
s
.23782 .36217 m
.24774 .39272 L
s
.23782 .36217 m
.24774 .33162 L
s
.23782 .62096 m
.26993 .62096 L
s
.23782 .62096 m
.26993 .62096 L
s
.23782 .62096 m
.21183 .60208 L
s
.23782 .62096 m
.21183 .63984 L
s
.23782 .62096 m
.21183 .63984 L
s
.23782 .62096 m
.26993 .62096 L
s
.23782 .62096 m
.21183 .63984 L
s
.23782 .62096 m
.24774 .59041 L
s
.23782 .62096 m
.24774 .65151 L
s
.23782 .68205 m
.21183 .70093 L
s
.23782 .68205 m
.21183 .70093 L
s
.23782 .68205 m
.24774 .65151 L
s
.23782 .68205 m
.21183 .70093 L
s
.23782 .68205 m
.21183 .70093 L
s
.26993 .36217 m
.29592 .38105 L
s
.26993 .36217 m
.27986 .39272 L
s
.26993 .36217 m
.27986 .33162 L
s
.26993 .36217 m
.27986 .39272 L
s
.26993 .36217 m
.29592 .38105 L
s
.26993 .36217 m
.27986 .39272 L
s
.26993 .36217 m
.27986 .33162 L
s
.26993 .36217 m
.27986 .39272 L
s
.26993 .62096 m
.29592 .60208 L
s
.26993 .62096 m
.27986 .59041 L
s
.26993 .62096 m
.27986 .65151 L
s
.26993 .62096 m
.27986 .59041 L
s
.26993 .62096 m
.29592 .60208 L
s
.26993 .62096 m
.27986 .59041 L
s
.26993 .62096 m
.27986 .65151 L
s
.26993 .62096 m
.27986 .59041 L
s
.6781 .7809 m
.66817 .81145 L
s
.6781 .7809 m
.70408 .79978 L
s
.6781 .7809 m
.70408 .79978 L
s
.6781 .7809 m
.64598 .7809 L
s
.6781 .7809 m
.66817 .75036 L
s
.6781 .7809 m
.64598 .7809 L
s
.6781 .7809 m
.66817 .81145 L
s
.6781 .7809 m
.64598 .7809 L
s
.17971 .38105 m
.21183 .38105 L
s
.17971 .38105 m
.15373 .36217 L
s
.17971 .38105 m
.15373 .36217 L
s
.17971 .44214 m
.21183 .44214 L
s
.17971 .44214 m
.21183 .44214 L
s
.17971 .54099 m
.21183 .54099 L
s
.17971 .54099 m
.21183 .54099 L
s
.21183 .34329 m
.18585 .36217 L
s
.21183 .38105 m
.18585 .36217 L
s
.21183 .38105 m
.22176 .41159 L
s
.21183 .44214 m
.23782 .46102 L
s
.21183 .44214 m
.22176 .41159 L
s
.21183 .54099 m
.23782 .52211 L
s
.21183 .60208 m
.18585 .62096 L
s
.21183 .60208 m
.18585 .62096 L
s
.21183 .63984 m
.18585 .62096 L
s
.21183 .63984 m
.18585 .62096 L
s
.21183 .2822 m
.17971 .2822 L
s
.21183 .2822 m
.20191 .25165 L
s
.21183 .2822 m
.20191 .25165 L
s
.21183 .2822 m
.23782 .26332 L
s
.21183 .2822 m
.17971 .2822 L
s
.21183 .34329 m
.18585 .36217 L
s
.21183 .63984 m
.18585 .62096 L
s
.21183 .63984 m
.18585 .62096 L
s
.21183 .70093 m
.17971 .70093 L
s
.21183 .70093 m
.20191 .73148 L
s
.21183 .70093 m
.20191 .73148 L
s
.21183 .70093 m
.23782 .71981 L
s
.21183 .70093 m
.18585 .71981 L
s
.29592 .38105 m
.26993 .36217 L
s
.29592 .38105 m
.30584 .41159 L
s
.29592 .38105 m
.30584 .41159 L
s
.29592 .60208 m
.26993 .62096 L
s
.29592 .60208 m
.30584 .57154 L
s
.29592 .60208 m
.30584 .57154 L
s
.23782 .46102 m
.21183 .44214 L
s
.23782 .46102 m
.24774 .49156 L
s
.23782 .52211 m
.21183 .54099 L
s
.23782 .52211 m
.24774 .49156 L
s
.26993 .36217 m
.27986 .39272 L
s
.26993 .36217 m
.27986 .33162 L
s
.26993 .36217 m
.27986 .39272 L
s
.26993 .62096 m
.27986 .59041 L
s
.26993 .62096 m
.27986 .65151 L
s
.26993 .62096 m
.27986 .59041 L
s
.17971 .18335 m
.21183 .18335 L
s
.17971 .18335 m
.15373 .20223 L
s
.17971 .18335 m
.21183 .18335 L
s
.17971 .18335 m
.21183 .18335 L
s
.17971 .18335 m
.15373 .20223 L
s
.17971 .2822 m
.21183 .2822 L
s
.17971 .2822 m
.15373 .30108 L
s
.17971 .2822 m
.16979 .25165 L
s
.17971 .2822 m
.21183 .2822 L
s
.17971 .2822 m
.21183 .2822 L
s
.17971 .2822 m
.15373 .26332 L
s
.17971 .70093 m
.21183 .70093 L
s
.17971 .70093 m
.15373 .71981 L
s
.17971 .70093 m
.21183 .70093 L
s
.17971 .70093 m
.21183 .70093 L
s
.17971 .70093 m
.15373 .71981 L
s
.17971 .79978 m
.21183 .79978 L
s
.17971 .79978 m
.15373 .7809 L
s
.17971 .79978 m
.21183 .79978 L
s
.17971 .79978 m
.21183 .79978 L
s
.17971 .79978 m
.15373 .7809 L
s
.21183 .44214 m
.22176 .41159 L
s
.21183 .12226 m
.22176 .1528 L
s
.21183 .18335 m
.22176 .1528 L
s
.21183 .18335 m
.23782 .20223 L
s
.21183 .18335 m
.17971 .18335 L
s
.21183 .18335 m
.18585 .20223 L
s
.21183 .2822 m
.20191 .25165 L
s
.21183 .2822 m
.20191 .25165 L
s
.21183 .2822 m
.23782 .26332 L
s
.21183 .2822 m
.17971 .2822 L
s
.21183 .34329 m
.18585 .36217 L
s
.21183 .63984 m
.18585 .62096 L
s
.21183 .63984 m
.18585 .62096 L
s
.21183 .70093 m
.20191 .73148 L
s
.21183 .70093 m
.20191 .73148 L
s
.21183 .70093 m
.23782 .71981 L
s
.21183 .70093 m
.18585 .71981 L
s
.21183 .79978 m
.20191 .76923 L
s
.21183 .79978 m
.20191 .76923 L
s
.21183 .79978 m
.22176 .83033 L
s
.21183 .79978 m
.23782 .81866 L
s
.21183 .79978 m
.23782 .7809 L
s
.21183 .79978 m
.17971 .79978 L
s
.21183 .79978 m
.18585 .7809 L
s
.21183 .86087 m
.22176 .83033 L
s
.15373 .36217 m
.18585 .36217 L
s
.15373 .36217 m
.12775 .38105 L
s
.15373 .36217 m
.12775 .38105 L
s
.15373 .62096 m
.18585 .62096 L
s
.15373 .62096 m
.18585 .62096 L
s
.15373 .20223 m
.1438 .23277 L
s
.15373 .20223 m
.17971 .18335 L
s
.15373 .20223 m
.18585 .20223 L
s
.15373 .30108 m
.12775 .2822 L
s
.15373 .30108 m
.17971 .2822 L
s
.15373 .30108 m
.12775 .2822 L
s
.15373 .30108 m
.12775 .2822 L
s
.15373 .36217 m
.18585 .36217 L
s
.15373 .36217 m
.12775 .38105 L
s
.15373 .36217 m
.12775 .38105 L
s
.15373 .62096 m
.18585 .62096 L
s
.15373 .62096 m
.18585 .62096 L
s
.15373 .71981 m
.12775 .70093 L
s
.15373 .71981 m
.1438 .75036 L
s
.15373 .71981 m
.18585 .71981 L
s
.15373 .71981 m
.12775 .70093 L
s
.15373 .71981 m
.12775 .70093 L
s
.15373 .7809 m
.1438 .75036 L
s
.15373 .7809 m
.17971 .79978 L
s
.15373 .7809 m
.18585 .7809 L
s
.12775 .38105 m
.11782 .41159 L
s
.12775 .2822 m
.11782 .31274 L
s
.12775 .2822 m
.11782 .25165 L
s
.12775 .2822 m
.11782 .25165 L
s
.12775 .2822 m
.15373 .26332 L
s
.12775 .38105 m
.11782 .41159 L
s
.12775 .70093 m
.11782 .67039 L
s
.12775 .70093 m
.11782 .73148 L
s
.12775 .70093 m
.11782 .73148 L
s
.12775 .70093 m
.15373 .71981 L
s
.0857 .51044 m
.11782 .51044 L
s
.0857 .51044 m
.05972 .49156 L
s
.0857 .51044 m
.05972 .49156 L
s
.0857 .47269 m
.11782 .47269 L
s
.0857 .47269 m
.05972 .49156 L
s
.0857 .47269 m
.05972 .49156 L
s
.0857 .41159 m
.11782 .41159 L
s
.0857 .41159 m
.05972 .43047 L
s
.0857 .41159 m
.05972 .43047 L
s
.0857 .57154 m
.11782 .57154 L
s
.0857 .57154 m
.05972 .59041 L
s
.11782 .51044 m
.12775 .54099 L
s
.11782 .47269 m
.12775 .44214 L
s
.11782 .41159 m
.12775 .44214 L
s
.11782 .57154 m
.12775 .54099 L
s
.05972 .49156 m
.0276 .49156 L
s
.05972 .49156 m
.03373 .51044 L
s
.05972 .43047 m
.03373 .41159 L
s
.05972 .59041 m
.03373 .57154 L
s
.0276 .49156 m
.05972 .49156 L
s
.05972 .49156 m
.03373 .51044 L
s
.05972 .43047 m
.03373 .41159 L
s
.55197 .49156 m
.58409 .49156 L
s
.55197 .49156 m
.52598 .51044 L
s
.55197 .49156 m
.54204 .46102 L
s
.55197 .49156 m
.54204 .52211 L
s
.55197 .49156 m
.57795 .51044 L
s
.55197 .49156 m
.58409 .49156 L
s
.55197 .49156 m
.58409 .49156 L
s
.55197 .43047 m
.52598 .41159 L
s
.55197 .43047 m
.52598 .41159 L
s
.55197 .43047 m
.54204 .46102 L
s
.55197 .43047 m
.57795 .41159 L
s
.55197 .43047 m
.52598 .41159 L
s
.55197 .43047 m
.57795 .41159 L
s
.55197 .43047 m
.52598 .41159 L
s
.55197 .07283 m
.52598 .05395 L
s
.55197 .07283 m
.52598 .05395 L
s
.55197 .07283 m
.57795 .05395 L
s
.55197 .07283 m
.54204 .10338 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .07283 m
.52598 .05395 L
s
.55197 .07283 m
.57795 .05395 L
s
.55197 .07283 m
.54204 .10338 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .07283 m
.52598 .05395 L
s
.55197 .07283 m
.52598 .05395 L
s
.55197 .07283 m
.57795 .05395 L
s
.55197 .07283 m
.54204 .10338 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .07283 m
.52598 .05395 L
s
.55197 .07283 m
.57795 .05395 L
s
.55197 .07283 m
.54204 .10338 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .9103 m
.52598 .92918 L
s
.55197 .9103 m
.52598 .92918 L
s
.55197 .9103 m
.57795 .92918 L
s
.55197 .9103 m
.54204 .87975 L
s
.55197 .9103 m
.58409 .9103 L
s
.55197 .9103 m
.58409 .9103 L
s
.55197 .9103 m
.52598 .92918 L
s
.55197 .9103 m
.57795 .92918 L
s
.55197 .9103 m
.54204 .87975 L
s
.55197 .9103 m
.58409 .9103 L
s
.55197 .9103 m
.52598 .92918 L
s
.55197 .9103 m
.52598 .92918 L
s
.55197 .9103 m
.57795 .92918 L
s
.55197 .9103 m
.54204 .87975 L
s
.55197 .9103 m
.58409 .9103 L
s
.55197 .9103 m
.58409 .9103 L
s
.55197 .9103 m
.52598 .92918 L
s
.55197 .9103 m
.57795 .92918 L
s
.55197 .9103 m
.54204 .87975 L
s
.55197 .9103 m
.58409 .9103 L
s
.58409 .49156 m
.57416 .46102 L
s
.58409 .49156 m
.61007 .47269 L
s
.58409 .49156 m
.61007 .51044 L
s
.58409 .49156 m
.55197 .49156 L
s
.58409 .49156 m
.61007 .47269 L
s
.58409 .49156 m
.61007 .51044 L
s
.72014 .49156 m
.75226 .49156 L
s
.72014 .49156 m
.69416 .47269 L
s
.72014 .49156 m
.69416 .51044 L
s
.72014 .49156 m
.73007 .46102 L
s
.72014 .49156 m
.73007 .52211 L
s
.72014 .49156 m
.69416 .47269 L
s
.72014 .49156 m
.69416 .51044 L
s
.72014 .17168 m
.75226 .17168 L
s
.72014 .17168 m
.69416 .1528 L
s
.72014 .17168 m
.73007 .20223 L
s
.72014 .17168 m
.73007 .20223 L
s
.75226 .49156 m
.76218 .46102 L
s
.75226 .49156 m
.76218 .52211 L
s
.75226 .39272 m
.76218 .36217 L
s
.75226 .39272 m
.76218 .42326 L
s
.75226 .39272 m
.76218 .36217 L
s
.75226 .39272 m
.72014 .39272 L
s
.75226 .39272 m
.76218 .36217 L
s
.75226 .39272 m
.76218 .42326 L
s
.75226 .39272 m
.76218 .36217 L
s
.75226 .39272 m
.77824 .41159 L
s
.75226 .39272 m
.76218 .36217 L
s
.75226 .39272 m
.72627 .41159 L
s
.75226 .17168 m
.77824 .1528 L
s
.75226 .17168 m
.72627 .1528 L
s
.75226 .17168 m
.76218 .14114 L
s
.75226 .17168 m
.76218 .14114 L
s
.75226 .17168 m
.76218 .20223 L
s
.75226 .17168 m
.76218 .20223 L
s
.75226 .17168 m
.76218 .20223 L
s
.75226 .84921 m
.77824 .83033 L
s
.75226 .84921 m
.72627 .83033 L
s
.75226 .84921 m
.72627 .83033 L
s
.75226 .84921 m
.72627 .83033 L
s
.75226 .84921 m
.76218 .87975 L
s
.75226 .84921 m
.76218 .87975 L
s
.75226 .84921 m
.76218 .87975 L
s
.75226 .81145 m
.77824 .83033 L
s
.75226 .81145 m
.72627 .83033 L
s
.75226 .81145 m
.72627 .83033 L
s
.75226 .81145 m
.72627 .83033 L
s
.75226 .81145 m
.76218 .7809 L
s
.75226 .81145 m
.76218 .7809 L
s
.75226 .81145 m
.76218 .7809 L
s
.75226 .81145 m
.76218 .7809 L
s
.77824 .1528 m
.78817 .12226 L
s
.77824 .1528 m
.78817 .12226 L
s
.77824 .1528 m
.78817 .18335 L
s
.77824 .1528 m
.78817 .18335 L
s
.77824 .1528 m
.78817 .18335 L
s
.77824 .83033 m
.78817 .86087 L
s
.77824 .83033 m
.78817 .79978 L
s
.77824 .83033 m
.78817 .86087 L
s
.77824 .83033 m
.78817 .79978 L
s
.77824 .83033 m
.78817 .79978 L
s
.72627 .83033 m
.69416 .83033 L
s
.72627 .83033 m
.7362 .86087 L
s
.72627 .83033 m
.7362 .79978 L
s
.72627 .83033 m
.7362 .86087 L
s
.72627 .83033 m
.7362 .86087 L
s
.72627 .83033 m
.7362 .79978 L
s
.52598 .05395 m
.51606 .0845 L
s
.52598 .05395 m
.51606 .0845 L
s
.52598 .05395 m
.55197 .07283 L
s
.52598 .05395 m
.55197 .07283 L
s
.52598 .92918 m
.51606 .89863 L
s
.52598 .92918 m
.51606 .89863 L
s
.52598 .92918 m
.55197 .9103 L
s
.52598 .92918 m
.55197 .9103 L
s
.52598 .51044 m
.51606 .54099 L
s
.52598 .51044 m
.51606 .54099 L
s
.52598 .51044 m
.55197 .49156 L
s
.52598 .05395 m
.51606 .0845 L
s
.52598 .05395 m
.51606 .0845 L
s
.52598 .05395 m
.55197 .07283 L
s
.52598 .05395 m
.55197 .07283 L
s
.52598 .41159 m
.51606 .38105 L
s
.52598 .41159 m
.51606 .44214 L
s
.52598 .41159 m
.55197 .43047 L
s
.52598 .41159 m
.55197 .39272 L
s
.52598 .41159 m
.51606 .38105 L
s
.52598 .41159 m
.55197 .39272 L
s
.52598 .92918 m
.51606 .89863 L
s
.52598 .92918 m
.51606 .89863 L
s
.52598 .92918 m
.55197 .9103 L
s
.52598 .92918 m
.55197 .9103 L
s
.66204 .1528 m
.69416 .1528 L
s
.66204 .1528 m
.63605 .17168 L
s
.66204 .1528 m
.63605 .13392 L
s
.66204 .1528 m
.63605 .13392 L
s
.66204 .1528 m
.63605 .17168 L
s
.66204 .1528 m
.63605 .17168 L
s
.66204 .83033 m
.69416 .83033 L
s
.66204 .83033 m
.63605 .81145 L
s
.66204 .83033 m
.63605 .84921 L
s
.66204 .83033 m
.63605 .84921 L
s
.66204 .83033 m
.63605 .81145 L
s
.66204 .83033 m
.63605 .81145 L
s
.69416 .47269 m
.66817 .49156 L
s
.69416 .47269 m
.70408 .44214 L
s
.69416 .47269 m
.66817 .49156 L
s
.69416 .47269 m
.66817 .49156 L
s
.69416 .47269 m
.70408 .44214 L
s
.69416 .51044 m
.66817 .49156 L
s
.69416 .51044 m
.70408 .54099 L
s
.69416 .51044 m
.66817 .49156 L
s
.69416 .51044 m
.66817 .49156 L
s
.69416 .51044 m
.70408 .54099 L
s
.69416 .1528 m
.72627 .1528 L
s
.69416 .1528 m
.66817 .17168 L
s
.69416 .1528 m
.66817 .13392 L
s
.69416 .1528 m
.70408 .12226 L
s
.69416 .1528 m
.70408 .12226 L
s
.69416 .1528 m
.70408 .18335 L
s
.69416 .1528 m
.70408 .18335 L
s
.69416 .1528 m
.70408 .12226 L
s
.69416 .1528 m
.70408 .12226 L
s
.69416 .1528 m
.66817 .17168 L
s
.69416 .83033 m
.72627 .83033 L
s
.69416 .83033 m
.72627 .83033 L
s
.69416 .83033 m
.66817 .81145 L
s
.69416 .83033 m
.66817 .84921 L
s
.69416 .83033 m
.70408 .86087 L
s
.69416 .83033 m
.70408 .79978 L
s
.69416 .83033 m
.70408 .86087 L
s
.69416 .83033 m
.70408 .79978 L
s
.69416 .83033 m
.70408 .86087 L
s
.69416 .83033 m
.70408 .86087 L
s
.69416 .83033 m
.66817 .81145 L
s
.72627 .1528 m
.7362 .12226 L
s
.72627 .1528 m
.7362 .12226 L
s
.72627 .1528 m
.7362 .12226 L
s
.72627 .83033 m
.7362 .86087 L
s
.72627 .83033 m
.7362 .79978 L
s
.72627 .83033 m
.7362 .86087 L
s
.72627 .83033 m
.7362 .86087 L
s
.72627 .83033 m
.7362 .79978 L
s
.72627 .83033 m
.7362 .86087 L
s
.72627 .83033 m
.7362 .79978 L
s
.72627 .83033 m
.7362 .86087 L
s
.72627 .83033 m
.7362 .86087 L
s
.72627 .83033 m
.7362 .79978 L
s
.63605 .17168 m
.66817 .17168 L
s
.63605 .17168 m
.61007 .1528 L
s
.63605 .17168 m
.61007 .1528 L
s
.63605 .17168 m
.61007 .1528 L
s
.63605 .17168 m
.61007 .1528 L
s
.63605 .17168 m
.64598 .20223 L
s
.63605 .17168 m
.61007 .1528 L
s
.63605 .17168 m
.62613 .20223 L
s
.63605 .17168 m
.64598 .20223 L
s
.63605 .17168 m
.66817 .17168 L
s
.63605 .17168 m
.64598 .20223 L
s
.63605 .13392 m
.66817 .13392 L
s
.63605 .13392 m
.61007 .1528 L
s
.63605 .13392 m
.64598 .10338 L
s
.63605 .13392 m
.62613 .10338 L
s
.63605 .13392 m
.61007 .1528 L
s
.63605 .13392 m
.64598 .10338 L
s
.63605 .13392 m
.61007 .1528 L
s
.63605 .13392 m
.61007 .1528 L
s
.63605 .13392 m
.61007 .1528 L
s
.63605 .81145 m
.66817 .81145 L
s
.63605 .81145 m
.61007 .83033 L
s
.63605 .81145 m
.61007 .83033 L
s
.63605 .81145 m
.61007 .83033 L
s
.63605 .81145 m
.61007 .83033 L
s
.63605 .81145 m
.64598 .7809 L
s
.63605 .81145 m
.61007 .83033 L
s
.63605 .81145 m
.62613 .7809 L
s
.63605 .81145 m
.64598 .7809 L
s
.63605 .81145 m
.66817 .81145 L
s
.63605 .81145 m
.64598 .7809 L
s
.63605 .84921 m
.66817 .84921 L
s
.63605 .84921 m
.61007 .83033 L
s
.63605 .84921 m
.64598 .87975 L
s
.63605 .84921 m
.62613 .87975 L
s
.63605 .84921 m
.61007 .83033 L
s
.63605 .84921 m
.64598 .87975 L
s
.63605 .84921 m
.61007 .83033 L
s
.63605 .84921 m
.61007 .83033 L
s
.63605 .84921 m
.61007 .83033 L
s
.66817 .49156 m
.63605 .49156 L
s
.66817 .49156 m
.6781 .46102 L
s
.66817 .49156 m
.6781 .52211 L
s
.66817 .49156 m
.69416 .47269 L
s
.66817 .49156 m
.69416 .51044 L
s
.66817 .49156 m
.6781 .46102 L
s
.66817 .49156 m
.6781 .52211 L
s
.66817 .17168 m
.6781 .20223 L
s
.66817 .17168 m
.6781 .20223 L
s
.66817 .17168 m
.63605 .17168 L
s
.66817 .17168 m
.6781 .20223 L
s
.66817 .17168 m
.63605 .17168 L
s
.66817 .17168 m
.6781 .20223 L
s
.66817 .13392 m
.6781 .10338 L
s
.66817 .13392 m
.63605 .13392 L
s
.66817 .13392 m
.6781 .10338 L
s
.66817 .81145 m
.6781 .7809 L
s
.66817 .81145 m
.63605 .81145 L
s
.66817 .81145 m
.6781 .7809 L
s
.66817 .81145 m
.63605 .81145 L
s
.66817 .81145 m
.6781 .7809 L
s
.66817 .84921 m
.6781 .87975 L
s
.66817 .84921 m
.63605 .84921 L
s
.66817 .84921 m
.6781 .87975 L
s
.57795 .05395 m
.61007 .05395 L
s
.57795 .05395 m
.55197 .07283 L
s
.57795 .05395 m
.55197 .07283 L
s
.57795 .05395 m
.61007 .05395 L
s
.57795 .92918 m
.61007 .92918 L
s
.57795 .92918 m
.55197 .9103 L
s
.57795 .92918 m
.55197 .9103 L
s
.57795 .92918 m
.61007 .92918 L
s
.61007 .05395 m
.58409 .07283 L
s
.61007 .05395 m
.58409 .07283 L
s
.61007 .05395 m
.63605 .07283 L
s
.61007 .05395 m
.57795 .05395 L
s
.61007 .05395 m
.58409 .07283 L
s
.61007 .92918 m
.58409 .9103 L
s
.61007 .92918 m
.58409 .9103 L
s
.61007 .92918 m
.63605 .9103 L
s
.61007 .92918 m
.57795 .92918 L
s
.61007 .92918 m
.58409 .9103 L
s
.61007 .1528 m
.60015 .12226 L
s
.61007 .1528 m
.63605 .13392 L
s
.61007 .1528 m
.57795 .1528 L
s
.61007 .1528 m
.60015 .18335 L
s
.61007 .1528 m
.57795 .1528 L
s
.61007 .1528 m
.60015 .12226 L
s
.61007 .1528 m
.57795 .1528 L
s
.61007 .1528 m
.63605 .17168 L
s
.61007 .1528 m
.60015 .18335 L
s
.61007 .1528 m
.63605 .17168 L
s
.61007 .83033 m
.60015 .86087 L
s
.61007 .83033 m
.63605 .84921 L
s
.61007 .83033 m
.57795 .83033 L
s
.61007 .83033 m
.60015 .79978 L
s
.61007 .83033 m
.57795 .83033 L
s
.61007 .83033 m
.60015 .86087 L
s
.61007 .83033 m
.57795 .83033 L
s
.61007 .83033 m
.63605 .81145 L
s
.61007 .83033 m
.60015 .79978 L
s
.61007 .83033 m
.63605 .81145 L
s
.22789 .23277 m
.20191 .25165 L
s
.22789 .23277 m
.20191 .25165 L
s
.22789 .23277 m
.23782 .20223 L
s
.22789 .23277 m
.23782 .26332 L
s
.22789 .75036 m
.20191 .73148 L
s
.22789 .75036 m
.20191 .76923 L
s
.22789 .75036 m
.20191 .73148 L
s
.22789 .75036 m
.20191 .76923 L
s
.22789 .75036 m
.23782 .71981 L
s
.22789 .75036 m
.23782 .7809 L
s
.16979 .25165 m
.20191 .25165 L
s
.16979 .25165 m
.20191 .25165 L
s
.16979 .25165 m
.1438 .23277 L
s
.16979 .25165 m
.17971 .2822 L
s
.20191 .25165 m
.17592 .23277 L
s
.20191 .25165 m
.21183 .22111 L
s
.20191 .25165 m
.21183 .22111 L
s
.20191 .25165 m
.21183 .2822 L
s
.20191 .25165 m
.21183 .2822 L
s
.20191 .25165 m
.17592 .23277 L
s
.20191 .25165 m
.21183 .22111 L
s
.20191 .25165 m
.21183 .22111 L
s
.20191 .25165 m
.21183 .2822 L
s
.20191 .25165 m
.21183 .2822 L
s
.20191 .73148 m
.17592 .75036 L
s
.20191 .73148 m
.21183 .70093 L
s
.20191 .73148 m
.21183 .70093 L
s
.20191 .76923 m
.17592 .75036 L
s
.20191 .76923 m
.21183 .79978 L
s
.20191 .76923 m
.21183 .79978 L
s
.20191 .73148 m
.17592 .75036 L
s
.20191 .73148 m
.21183 .70093 L
s
.20191 .73148 m
.21183 .70093 L
s
.20191 .76923 m
.17592 .75036 L
s
.20191 .76923 m
.21183 .79978 L
s
.20191 .76923 m
.21183 .79978 L
s
.1438 .23277 m
.17592 .23277 L
s
.1438 .23277 m
.11782 .2139 L
s
.1438 .23277 m
.11782 .25165 L
s
.1438 .23277 m
.11782 .25165 L
s
.1438 .23277 m
.15373 .20223 L
s
.1438 .23277 m
.15373 .26332 L
s
.1438 .75036 m
.17592 .75036 L
s
.1438 .75036 m
.11782 .73148 L
s
.1438 .75036 m
.11782 .76923 L
s
.1438 .75036 m
.11782 .73148 L
s
.1438 .75036 m
.15373 .71981 L
s
.1438 .75036 m
.15373 .7809 L
s
.17592 .23277 m
.18585 .20223 L
s
.17592 .75036 m
.18585 .71981 L
s
.17592 .75036 m
.18585 .7809 L
s
.0857 .31274 m
.11782 .31274 L
s
.0857 .31274 m
.05972 .33162 L
s
.0857 .25165 m
.11782 .25165 L
s
.0857 .25165 m
.11782 .25165 L
s
.0857 .67039 m
.11782 .67039 L
s
.0857 .67039 m
.05972 .65151 L
s
.0857 .73148 m
.11782 .73148 L
s
.0857 .73148 m
.11782 .73148 L
s
.11782 .31274 m
.12775 .2822 L
s
.11782 .31274 m
.12775 .2822 L
s
.11782 .25165 m
.12775 .2822 L
s
.11782 .25165 m
.12775 .2822 L
s
.11782 .25165 m
.12775 .2822 L
s
.11782 .25165 m
.12775 .2822 L
s
.11782 .67039 m
.12775 .70093 L
s
.11782 .67039 m
.12775 .70093 L
s
.11782 .73148 m
.12775 .70093 L
s
.11782 .73148 m
.12775 .70093 L
s
.11782 .73148 m
.12775 .70093 L
s
.11782 .73148 m
.12775 .70093 L
s
.37387 .46102 m
.39985 .44214 L
s
.37387 .46102 m
.39985 .44214 L
s
.37387 .36217 m
.39985 .38105 L
s
.37387 .36217 m
.36395 .39272 L
s
.37387 .36217 m
.36395 .33162 L
s
.37387 .36217 m
.36395 .33162 L
s
.37387 .36217 m
.39985 .38105 L
s
.37387 .62096 m
.39985 .60208 L
s
.37387 .62096 m
.39985 .63984 L
s
.37387 .62096 m
.36395 .59041 L
s
.37387 .62096 m
.36395 .65151 L
s
.37387 .62096 m
.36395 .65151 L
s
.37387 .62096 m
.39985 .63984 L
s
.48394 .38105 m
.51606 .38105 L
s
.48394 .38105 m
.45796 .36217 L
s
.48394 .38105 m
.45796 .36217 L
s
.48394 .38105 m
.51606 .38105 L
s
.48394 .38105 m
.45796 .36217 L
s
.48394 .38105 m
.45796 .36217 L
s
.48394 .44214 m
.51606 .44214 L
s
.48394 .44214 m
.45796 .46102 L
s
.48394 .54099 m
.51606 .54099 L
s
.48394 .54099 m
.45796 .55987 L
s
.48394 .54099 m
.51606 .54099 L
s
.48394 .60208 m
.51606 .60208 L
s
.48394 .60208 m
.45796 .62096 L
s
.48394 .60208 m
.45796 .62096 L
s
.48394 .60208 m
.51606 .60208 L
s
.48394 .60208 m
.45796 .62096 L
s
.48394 .60208 m
.45796 .62096 L
s
.51606 .38105 m
.49007 .36217 L
s
.51606 .38105 m
.52598 .41159 L
s
.51606 .38105 m
.52598 .41159 L
s
.51606 .38105 m
.54204 .36217 L
s
.51606 .38105 m
.49007 .36217 L
s
.51606 .38105 m
.52598 .41159 L
s
.51606 .44214 m
.52598 .41159 L
s
.51606 .44214 m
.54204 .46102 L
s
.51606 .44214 m
.52598 .41159 L
s
.51606 .44214 m
.52598 .41159 L
s
.51606 .54099 m
.52598 .57154 L
s
.51606 .54099 m
.54204 .52211 L
s
.51606 .54099 m
.54204 .55987 L
s
.51606 .54099 m
.52598 .57154 L
s
.51606 .54099 m
.52598 .57154 L
s
.51606 .60208 m
.49007 .62096 L
s
.51606 .60208 m
.52598 .57154 L
s
.51606 .60208 m
.52598 .57154 L
s
.51606 .60208 m
.54204 .62096 L
s
.51606 .60208 m
.49007 .62096 L
s
.51606 .60208 m
.52598 .57154 L
s
.42584 .36217 m
.45796 .36217 L
s
.42584 .36217 m
.39985 .38105 L
s
.42584 .36217 m
.41591 .33162 L
s
.42584 .36217 m
.45796 .36217 L
s
.42584 .36217 m
.39985 .38105 L
s
.42584 .36217 m
.45796 .36217 L
s
.42584 .36217 m
.45796 .36217 L
s
.42584 .62096 m
.45796 .62096 L
s
.42584 .62096 m
.39985 .60208 L
s
.42584 .62096 m
.39985 .63984 L
s
.42584 .62096 m
.41591 .65151 L
s
.42584 .62096 m
.45796 .62096 L
s
.42584 .62096 m
.39985 .63984 L
s
.42584 .62096 m
.45796 .62096 L
s
.42584 .62096 m
.45796 .62096 L
s
.45796 .46102 m
.43197 .44214 L
s
.45796 .36217 m
.49007 .36217 L
s
.45796 .36217 m
.43197 .38105 L
s
.45796 .36217 m
.44803 .33162 L
s
.45796 .36217 m
.42584 .36217 L
s
.45796 .36217 m
.48394 .34329 L
s
.45796 .36217 m
.49007 .36217 L
s
.45796 .36217 m
.44803 .33162 L
s
.45796 .36217 m
.48394 .34329 L
s
.45796 .55987 m
.43197 .54099 L
s
.45796 .62096 m
.49007 .62096 L
s
.45796 .62096 m
.44803 .65151 L
s
.45796 .62096 m
.42584 .62096 L
s
.45796 .62096 m
.48394 .63984 L
s
.45796 .62096 m
.49007 .62096 L
s
.45796 .62096 m
.44803 .65151 L
s
.45796 .62096 m
.48394 .63984 L
s
.49007 .36217 m
.45796 .36217 L
s
.49007 .36217 m
.51606 .34329 L
s
.49007 .36217 m
.51606 .38105 L
s
.49007 .36217 m
.45796 .36217 L
s
.49007 .36217 m
.51606 .34329 L
s
.49007 .36217 m
.45796 .36217 L
s
.49007 .62096 m
.45796 .62096 L
s
.49007 .62096 m
.51606 .60208 L
s
.49007 .62096 m
.51606 .63984 L
s
.49007 .62096 m
.45796 .62096 L
s
.49007 .62096 m
.51606 .63984 L
s
.49007 .62096 m
.45796 .62096 L
s
.39985 .2822 m
.38993 .31274 L
s
.39985 .2822 m
.43197 .2822 L
s
.39985 .2822 m
.38993 .25165 L
s
.39985 .2822 m
.43197 .2822 L
s
.39985 .2822 m
.43197 .2822 L
s
.39985 .38105 m
.43197 .38105 L
s
.39985 .38105 m
.38993 .3505 L
s
.39985 .38105 m
.37387 .36217 L
s
.39985 .38105 m
.37387 .36217 L
s
.39985 .38105 m
.42584 .36217 L
s
.39985 .44214 m
.43197 .44214 L
s
.39985 .54099 m
.43197 .54099 L
s
.39985 .60208 m
.37387 .62096 L
s
.39985 .60208 m
.37387 .62096 L
s
.39985 .60208 m
.42584 .62096 L
s
.39985 .63984 m
.38993 .67039 L
s
.39985 .63984 m
.37387 .62096 L
s
.39985 .63984 m
.37387 .62096 L
s
.39985 .63984 m
.42584 .62096 L
s
.39985 .70093 m
.38993 .67039 L
s
.39985 .70093 m
.43197 .70093 L
s
.39985 .70093 m
.38993 .73148 L
s
.39985 .70093 m
.43197 .70093 L
s
.39985 .70093 m
.43197 .70093 L
s
.43197 .38105 m
.45796 .36217 L
s
.43197 .38105 m
.39985 .38105 L
s
.43197 .38105 m
.45796 .36217 L
s
.43197 .38105 m
.45796 .36217 L
s
.33183 .39272 m
.36395 .39272 L
s
.33183 .39272 m
.30584 .41159 L
s
.33183 .39272 m
.30584 .41159 L
s
.33183 .59041 m
.36395 .59041 L
s
.33183 .59041 m
.30584 .57154 L
s
.33183 .59041 m
.30584 .57154 L
s
.33183 .33162 m
.36395 .33162 L
s
.33183 .33162 m
.36395 .33162 L
s
.33183 .33162 m
.30584 .31274 L
s
.33183 .33162 m
.30584 .31274 L
s
.33183 .65151 m
.36395 .65151 L
s
.33183 .65151 m
.36395 .65151 L
s
.33183 .65151 m
.30584 .67039 L
s
.33183 .65151 m
.30584 .67039 L
s
.36395 .39272 m
.37387 .36217 L
s
.36395 .39272 m
.37387 .36217 L
s
.36395 .59041 m
.37387 .62096 L
s
.36395 .59041 m
.37387 .62096 L
s
.36395 .33162 m
.33183 .33162 L
s
.36395 .33162 m
.33796 .31274 L
s
.36395 .33162 m
.38993 .31274 L
s
.36395 .33162 m
.38993 .3505 L
s
.36395 .33162 m
.37387 .36217 L
s
.36395 .33162 m
.37387 .36217 L
s
.36395 .65151 m
.33183 .65151 L
s
.36395 .65151 m
.33796 .67039 L
s
.36395 .65151 m
.38993 .67039 L
s
.36395 .65151 m
.33796 .67039 L
s
.36395 .65151 m
.37387 .62096 L
s
.36395 .65151 m
.37387 .62096 L
s
.33183 .33162 m
.36395 .33162 L
s
.33183 .33162 m
.30584 .31274 L
s
.33183 .33162 m
.30584 .31274 L
s
.33183 .65151 m
.36395 .65151 L
s
.33183 .65151 m
.30584 .67039 L
s
.33183 .65151 m
.30584 .67039 L
s
.36395 .33162 m
.33796 .31274 L
s
.36395 .33162 m
.38993 .31274 L
s
.36395 .33162 m
.38993 .3505 L
s
.36395 .33162 m
.37387 .36217 L
s
.36395 .33162 m
.37387 .36217 L
s
.36395 .65151 m
.33796 .67039 L
s
.36395 .65151 m
.38993 .67039 L
s
.36395 .65151 m
.33796 .67039 L
s
.36395 .65151 m
.37387 .62096 L
s
.36395 .65151 m
.37387 .62096 L
s
.36395 .68926 m
.33796 .67039 L
s
.36395 .68926 m
.38993 .67039 L
s
.36395 .68926 m
.33796 .67039 L
s
.77211 .23277 m
.76218 .20223 L
s
.77211 .23277 m
.76218 .26332 L
s
.77211 .23277 m
.79809 .25165 L
s
.77211 .23277 m
.79809 .25165 L
s
.77211 .23277 m
.76218 .20223 L
s
.77211 .23277 m
.76218 .20223 L
s
.77211 .23277 m
.79809 .25165 L
s
.77211 .75036 m
.76218 .7809 L
s
.77211 .75036 m
.76218 .7809 L
s
.77211 .75036 m
.76218 .71981 L
s
.77211 .75036 m
.79809 .73148 L
s
.77211 .75036 m
.79809 .73148 L
s
.77211 .75036 m
.76218 .7809 L
s
.77211 .75036 m
.76218 .7809 L
s
.77211 .75036 m
.79809 .73148 L
s
.30584 .41159 m
.27986 .39272 L
s
.30584 .41159 m
.27986 .39272 L
s
.30584 .57154 m
.27986 .59041 L
s
.30584 .57154 m
.27986 .59041 L
s
.30584 .31274 m
.33796 .31274 L
s
.30584 .31274 m
.27986 .33162 L
s
.30584 .31274 m
.33796 .31274 L
s
.30584 .31274 m
.27986 .33162 L
s
.30584 .67039 m
.33796 .67039 L
s
.30584 .67039 m
.27986 .65151 L
s
.30584 .67039 m
.33796 .67039 L
s
.30584 .67039 m
.33796 .67039 L
s
.30584 .67039 m
.27986 .65151 L
s
.30584 .67039 m
.33796 .67039 L
s
.41591 .33162 m
.44803 .33162 L
s
.41591 .33162 m
.38993 .31274 L
s
.41591 .33162 m
.38993 .3505 L
s
.41591 .33162 m
.42584 .36217 L
s
.41591 .33162 m
.44803 .33162 L
s
.41591 .65151 m
.44803 .65151 L
s
.41591 .65151 m
.38993 .67039 L
s
.41591 .65151 m
.42584 .62096 L
s
.41591 .65151 m
.44803 .65151 L
s
.44803 .33162 m
.42205 .31274 L
s
.44803 .33162 m
.45796 .30108 L
s
.44803 .33162 m
.45796 .36217 L
s
.44803 .33162 m
.45796 .36217 L
s
.44803 .33162 m
.47402 .31274 L
s
.44803 .33162 m
.45796 .30108 L
s
.44803 .33162 m
.45796 .30108 L
s
.44803 .33162 m
.45796 .36217 L
s
.44803 .65151 m
.42205 .67039 L
s
.44803 .65151 m
.45796 .62096 L
s
.44803 .65151 m
.45796 .68205 L
s
.44803 .65151 m
.45796 .62096 L
s
.44803 .65151 m
.47402 .67039 L
s
.44803 .65151 m
.45796 .68205 L
s
.44803 .65151 m
.45796 .62096 L
s
.44803 .65151 m
.45796 .68205 L
s
.24774 .39272 m
.27986 .39272 L
s
.24774 .39272 m
.22176 .41159 L
s
.24774 .39272 m
.27986 .39272 L
s
.24774 .59041 m
.27986 .59041 L
s
.24774 .59041 m
.27986 .59041 L
s
.24774 .33162 m
.27986 .33162 L
s
.24774 .65151 m
.27986 .65151 L
s
.27986 .39272 m
.30584 .41159 L
s
.27986 .59041 m
.30584 .57154 L
s
.38993 .31274 m
.42205 .31274 L
s
.38993 .31274 m
.39985 .2822 L
s
.38993 .3505 m
.39985 .38105 L
s
.38993 .67039 m
.42205 .67039 L
s
.38993 .67039 m
.39985 .63984 L
s
.38993 .67039 m
.39985 .70093 L
s
.42205 .31274 m
.43197 .2822 L
s
.42205 .31274 m
.43197 .2822 L
s
.42205 .31274 m
.44803 .33162 L
s
.42205 .31274 m
.43197 .2822 L
s
.42205 .67039 m
.43197 .70093 L
s
.42205 .67039 m
.43197 .70093 L
s
.42205 .67039 m
.44803 .65151 L
s
.42205 .67039 m
.43197 .70093 L
s
.30584 .41159 m
.27986 .39272 L
s
.30584 .57154 m
.27986 .59041 L
s
.22176 .1528 m
.21183 .18335 L
s
.22176 .1528 m
.21183 .18335 L
s
.22176 .83033 m
.21183 .79978 L
s
.22176 .83033 m
.21183 .79978 L
s
.3219 .20223 m
.35402 .20223 L
s
.3219 .20223 m
.29592 .18335 L
s
.3219 .20223 m
.29592 .22111 L
s
.3219 .20223 m
.29592 .18335 L
s
.3219 .7809 m
.35402 .7809 L
s
.3219 .7809 m
.29592 .79978 L
s
.3219 .7809 m
.29592 .79978 L
s
.35402 .20223 m
.36395 .23277 L
s
.35402 .20223 m
.36395 .17168 L
s
.35402 .20223 m
.36395 .23277 L
s
.35402 .7809 m
.36395 .75036 L
s
.35402 .7809 m
.36395 .81145 L
s
.35402 .7809 m
.36395 .75036 L
s
.73007 .46102 m
.76218 .46102 L
s
.73007 .46102 m
.70408 .44214 L
s
.73007 .46102 m
.70408 .44214 L
s
.73007 .52211 m
.76218 .52211 L
s
.73007 .52211 m
.70408 .54099 L
s
.73007 .52211 m
.70408 .54099 L
s
.73007 .10338 m
.76218 .10338 L
s
.73007 .10338 m
.70408 .12226 L
s
.73007 .10338 m
.70408 .12226 L
s
.73007 .10338 m
.72014 .07283 L
s
.73007 .10338 m
.76218 .10338 L
s
.73007 .10338 m
.70408 .12226 L
s
.73007 .10338 m
.70408 .12226 L
s
.73007 .87975 m
.76218 .87975 L
s
.73007 .87975 m
.76218 .87975 L
s
.73007 .87975 m
.70408 .86087 L
s
.73007 .87975 m
.70408 .86087 L
s
.73007 .87975 m
.72014 .9103 L
s
.73007 .87975 m
.76218 .87975 L
s
.73007 .87975 m
.70408 .86087 L
s
.73007 .87975 m
.70408 .86087 L
s
.73007 .20223 m
.76218 .20223 L
s
.73007 .20223 m
.70408 .18335 L
s
.73007 .20223 m
.70408 .18335 L
s
.73007 .20223 m
.70408 .22111 L
s
.73007 .20223 m
.76218 .20223 L
s
.73007 .20223 m
.76218 .20223 L
s
.76218 .46102 m
.78817 .44214 L
s
.76218 .46102 m
.7362 .44214 L
s
.76218 .46102 m
.78817 .44214 L
s
.76218 .46102 m
.7362 .44214 L
s
.76218 .52211 m
.78817 .54099 L
s
.76218 .52211 m
.7362 .54099 L
s
.76218 .52211 m
.78817 .54099 L
s
.76218 .52211 m
.7362 .54099 L
s
.76218 .10338 m
.78817 .12226 L
s
.76218 .10338 m
.78817 .12226 L
s
.76218 .10338 m
.7362 .12226 L
s
.76218 .10338 m
.7362 .12226 L
s
.76218 .10338 m
.7362 .12226 L
s
.76218 .10338 m
.73007 .10338 L
s
.76218 .14114 m
.78817 .12226 L
s
.76218 .14114 m
.78817 .12226 L
s
.76218 .14114 m
.7362 .12226 L
s
.76218 .14114 m
.7362 .12226 L
s
.76218 .14114 m
.7362 .12226 L
s
.76218 .36217 m
.77211 .33162 L
s
.76218 .36217 m
.73007 .36217 L
s
.76218 .36217 m
.77211 .33162 L
s
.76218 .36217 m
.75226 .39272 L
s
.76218 .36217 m
.78817 .34329 L
s
.76218 .36217 m
.73007 .36217 L
s
.76218 .36217 m
.75226 .33162 L
s
.76218 .36217 m
.77211 .33162 L
s
.76218 .36217 m
.78817 .38105 L
s
.76218 .36217 m
.78817 .34329 L
s
.76218 .36217 m
.78817 .38105 L
s
.76218 .42326 m
.78817 .44214 L
s
.76218 .42326 m
.7362 .44214 L
s
.76218 .42326 m
.75226 .39272 L
s
.76218 .42326 m
.78817 .44214 L
s
.76218 .42326 m
.7362 .44214 L
s
.76218 .55987 m
.78817 .54099 L
s
.76218 .55987 m
.7362 .54099 L
s
.76218 .55987 m
.77211 .59041 L
s
.76218 .55987 m
.75226 .59041 L
s
.76218 .55987 m
.73007 .55987 L
s
.76218 .55987 m
.78817 .54099 L
s
.76218 .55987 m
.7362 .54099 L
s
.76218 .62096 m
.77211 .59041 L
s
.76218 .62096 m
.77211 .65151 L
s
.76218 .62096 m
.73007 .62096 L
s
.76218 .62096 m
.77211 .65151 L
s
.76218 .62096 m
.75226 .59041 L
s
.76218 .62096 m
.78817 .63984 L
s
.76218 .62096 m
.73007 .62096 L
s
.76218 .62096 m
.75226 .65151 L
s
.76218 .62096 m
.77211 .65151 L
s
.76218 .62096 m
.78817 .60208 L
s
.76218 .62096 m
.78817 .60208 L
s
.76218 .62096 m
.78817 .63984 L
s
.76218 .87975 m
.78817 .86087 L
s
.76218 .87975 m
.78817 .86087 L
s
.76218 .87975 m
.7362 .86087 L
s
.76218 .87975 m
.7362 .86087 L
s
.76218 .87975 m
.7362 .86087 L
s
.76218 .87975 m
.73007 .87975 L
s
.76218 .14114 m
.78817 .12226 L
s
.76218 .14114 m
.78817 .12226 L
s
.76218 .14114 m
.7362 .12226 L
s
.76218 .14114 m
.7362 .12226 L
s
.76218 .14114 m
.7362 .12226 L
s
.76218 .20223 m
.78817 .18335 L
s
.76218 .20223 m
.73007 .20223 L
s
.76218 .20223 m
.78817 .18335 L
s
.76218 .20223 m
.77211 .23277 L
s
.76218 .20223 m
.78817 .18335 L
s
.76218 .20223 m
.78817 .22111 L
s
.76218 .20223 m
.77211 .23277 L
s
.76218 .7809 m
.78817 .79978 L
s
.76218 .7809 m
.7362 .79978 L
s
.76218 .7809 m
.73007 .7809 L
s
.76218 .7809 m
.78817 .79978 L
s
.76218 .7809 m
.7362 .79978 L
s
.76218 .7809 m
.77211 .75036 L
s
.76218 .7809 m
.78817 .76202 L
s
.76218 .7809 m
.78817 .79978 L
s
.76218 .7809 m
.77211 .75036 L
s
.76218 .87975 m
.78817 .86087 L
s
.76218 .87975 m
.78817 .86087 L
s
.76218 .87975 m
.7362 .86087 L
s
.76218 .87975 m
.7362 .86087 L
s
.76218 .87975 m
.7362 .86087 L
s
.76218 .87975 m
.73007 .87975 L
s
.81415 .46102 m
.84627 .46102 L
s
.81415 .46102 m
.78817 .44214 L
s
.81415 .46102 m
.84627 .46102 L
s
.81415 .46102 m
.78817 .44214 L
s
.81415 .52211 m
.84627 .52211 L
s
.81415 .52211 m
.78817 .54099 L
s
.81415 .52211 m
.84627 .52211 L
s
.81415 .52211 m
.78817 .54099 L
s
.84627 .46102 m
.82029 .44214 L
s
.84627 .46102 m
.87225 .44214 L
s
.84627 .46102 m
.8562 .49156 L
s
.84627 .46102 m
.8562 .43047 L
s
.84627 .46102 m
.82029 .44214 L
s
.84627 .52211 m
.82029 .54099 L
s
.84627 .52211 m
.87225 .54099 L
s
.84627 .52211 m
.8562 .49156 L
s
.84627 .52211 m
.8562 .55266 L
s
.84627 .52211 m
.82029 .54099 L
s
.78817 .12226 m
.79809 .1528 L
s
.78817 .12226 m
.76218 .10338 L
s
.78817 .44214 m
.82029 .44214 L
s
.78817 .44214 m
.76218 .42326 L
s
.78817 .44214 m
.79809 .47269 L
s
.78817 .44214 m
.79809 .41159 L
s
.78817 .44214 m
.77824 .41159 L
s
.78817 .44214 m
.82029 .44214 L
s
.78817 .54099 m
.82029 .54099 L
s
.78817 .54099 m
.76218 .55987 L
s
.78817 .54099 m
.79809 .51044 L
s
.78817 .54099 m
.79809 .57154 L
s
.78817 .54099 m
.79809 .57154 L
s
.78817 .54099 m
.82029 .54099 L
s
.78817 .86087 m
.79809 .83033 L
s
.78817 .86087 m
.76218 .87975 L
s
.78817 .12226 m
.79809 .1528 L
s
.78817 .12226 m
.76218 .10338 L
s
.78817 .18335 m
.82029 .18335 L
s
.78817 .18335 m
.79809 .1528 L
s
.78817 .18335 m
.82029 .18335 L
s
.78817 .18335 m
.81415 .20223 L
s
.78817 .18335 m
.76218 .20223 L
s
.78817 .18335 m
.76218 .20223 L
s
.78817 .79978 m
.76218 .7809 L
s
.78817 .79978 m
.82029 .79978 L
s
.78817 .79978 m
.79809 .83033 L
s
.78817 .79978 m
.82029 .79978 L
s
.78817 .79978 m
.81415 .7809 L
s
.78817 .79978 m
.76218 .7809 L
s
.78817 .79978 m
.76218 .7809 L
s
.78817 .86087 m
.79809 .83033 L
s
.78817 .86087 m
.76218 .87975 L
s
.82029 .44214 m
.83021 .41159 L
s
.82029 .44214 m
.83021 .41159 L
s
.82029 .44214 m
.83021 .41159 L
s
.82029 .44214 m
.84627 .46102 L
s
.82029 .44214 m
.78817 .44214 L
s
.82029 .54099 m
.83021 .57154 L
s
.82029 .54099 m
.83021 .57154 L
s
.82029 .54099 m
.83021 .57154 L
s
.82029 .54099 m
.84627 .52211 L
s
.82029 .54099 m
.78817 .54099 L
s
.7362 .12226 m
.70408 .12226 L
s
.7362 .12226 m
.70408 .12226 L
s
.7362 .12226 m
.76218 .10338 L
s
.7362 .12226 m
.70408 .12226 L
s
.7362 .12226 m
.70408 .12226 L
s
.87225 .38105 m
.84627 .36217 L
s
.87225 .44214 m
.84627 .46102 L
s
.87225 .54099 m
.84627 .52211 L
s
.29592 .18335 m
.26993 .20223 L
s
.29592 .18335 m
.26993 .20223 L
s
.29592 .18335 m
.30584 .1528 L
s
.29592 .22111 m
.26993 .20223 L
s
.29592 .22111 m
.26993 .20223 L
s
.29592 .79978 m
.2638 .79978 L
s
.29592 .79978 m
.26993 .7809 L
s
.29592 .79978 m
.30584 .83033 L
s
.70408 .12226 m
.7362 .12226 L
s
.70408 .12226 m
.7362 .12226 L
s
.70408 .12226 m
.6781 .10338 L
s
.70408 .12226 m
.69416 .09171 L
s
.70408 .12226 m
.69416 .09171 L
s
.70408 .12226 m
.73007 .10338 L
s
.70408 .12226 m
.6781 .10338 L
s
.70408 .44214 m
.7362 .44214 L
s
.70408 .44214 m
.6781 .46102 L
s
.70408 .44214 m
.69416 .47269 L
s
.70408 .44214 m
.69416 .41159 L
s
.70408 .44214 m
.7362 .44214 L
s
.70408 .44214 m
.6781 .46102 L
s
.70408 .54099 m
.7362 .54099 L
s
.70408 .54099 m
.73007 .55987 L
s
.70408 .54099 m
.6781 .52211 L
s
.70408 .54099 m
.69416 .51044 L
s
.70408 .54099 m
.69416 .57154 L
s
.70408 .54099 m
.67196 .54099 L
s
.70408 .54099 m
.7362 .54099 L
s
.70408 .54099 m
.6781 .52211 L
s
.70408 .86087 m
.7362 .86087 L
s
.70408 .86087 m
.7362 .86087 L
s
.70408 .86087 m
.7362 .86087 L
s
.70408 .86087 m
.6781 .87975 L
s
.70408 .86087 m
.69416 .89142 L
s
.70408 .86087 m
.69416 .89142 L
s
.70408 .86087 m
.73007 .87975 L
s
.70408 .86087 m
.6781 .87975 L
s
.70408 .12226 m
.7362 .12226 L
s
.70408 .12226 m
.7362 .12226 L
s
.70408 .12226 m
.6781 .10338 L
s
.70408 .12226 m
.69416 .09171 L
s
.70408 .12226 m
.69416 .09171 L
s
.70408 .12226 m
.73007 .10338 L
s
.70408 .12226 m
.6781 .10338 L
s
.70408 .18335 m
.6781 .20223 L
s
.70408 .18335 m
.73007 .20223 L
s
.70408 .18335 m
.6781 .20223 L
s
.70408 .18335 m
.6781 .20223 L
s
.70408 .18335 m
.6781 .20223 L
s
.70408 .79978 m
.7362 .79978 L
s
.70408 .79978 m
.6781 .7809 L
s
.70408 .79978 m
.73007 .7809 L
s
.70408 .79978 m
.7362 .79978 L
s
.70408 .79978 m
.6781 .7809 L
s
.70408 .79978 m
.6781 .7809 L
s
.70408 .86087 m
.7362 .86087 L
s
.70408 .86087 m
.7362 .86087 L
s
.70408 .86087 m
.7362 .86087 L
s
.70408 .86087 m
.6781 .87975 L
s
.70408 .86087 m
.69416 .89142 L
s
.70408 .86087 m
.69416 .89142 L
s
.70408 .86087 m
.73007 .87975 L
s
.70408 .86087 m
.6781 .87975 L
s
.7362 .12226 m
.76218 .10338 L
s
.7362 .12226 m
.70408 .12226 L
s
.7362 .12226 m
.70408 .12226 L
s
.7362 .44214 m
.76218 .42326 L
s
.7362 .44214 m
.72627 .41159 L
s
.7362 .44214 m
.70408 .44214 L
s
.7362 .54099 m
.76218 .55987 L
s
.7362 .54099 m
.70408 .54099 L
s
.7362 .86087 m
.76218 .87975 L
s
.7362 .86087 m
.70408 .86087 L
s
.7362 .86087 m
.70408 .86087 L
s
.7362 .12226 m
.76218 .10338 L
s
.7362 .12226 m
.70408 .12226 L
s
.7362 .12226 m
.70408 .12226 L
s
.7362 .79978 m
.76218 .7809 L
s
.7362 .79978 m
.70408 .79978 L
s
.7362 .79978 m
.76218 .7809 L
s
.7362 .79978 m
.76218 .7809 L
s
.7362 .86087 m
.76218 .87975 L
s
.7362 .86087 m
.70408 .86087 L
s
.7362 .86087 m
.70408 .86087 L
s
.7362 .86087 m
.76218 .87975 L
s
.7362 .86087 m
.70408 .86087 L
s
.7362 .86087 m
.70408 .86087 L
s
.26993 .20223 m
.29592 .18335 L
s
.26993 .20223 m
.23782 .20223 L
s
.64598 .04229 m
.63605 .07283 L
s
.64598 .10338 m
.6781 .10338 L
s
.64598 .10338 m
.63605 .13392 L
s
.64598 .10338 m
.63605 .07283 L
s
.64598 .10338 m
.6781 .10338 L
s
.64598 .87975 m
.6781 .87975 L
s
.64598 .87975 m
.63605 .9103 L
s
.64598 .87975 m
.63605 .84921 L
s
.64598 .87975 m
.6781 .87975 L
s
.64598 .94084 m
.63605 .9103 L
s
.6781 .10338 m
.66817 .07283 L
s
.6781 .10338 m
.66817 .07283 L
s
.6781 .10338 m
.70408 .12226 L
s
.6781 .10338 m
.70408 .12226 L
s
.6781 .10338 m
.64598 .10338 L
s
.6781 .20223 m
.70408 .18335 L
s
.6781 .20223 m
.70408 .22111 L
s
.6781 .20223 m
.64598 .20223 L
s
.6781 .20223 m
.66817 .23277 L
s
.6781 .20223 m
.64598 .20223 L
s
.6781 .20223 m
.66817 .17168 L
s
.6781 .20223 m
.64598 .20223 L
s
.6781 .7809 m
.70408 .79978 L
s
.6781 .7809 m
.64598 .7809 L
s
.6781 .7809 m
.66817 .75036 L
s
.6781 .7809 m
.64598 .7809 L
s
.6781 .7809 m
.66817 .81145 L
s
.6781 .7809 m
.64598 .7809 L
s
.6781 .87975 m
.66817 .9103 L
s
.6781 .87975 m
.66817 .9103 L
s
.6781 .87975 m
.70408 .86087 L
s
.6781 .87975 m
.70408 .86087 L
s
.6781 .87975 m
.64598 .87975 L
s
.2638 .79978 m
.29592 .79978 L
s
.2638 .79978 m
.23782 .81866 L
s
.2638 .79978 m
.23782 .7809 L
s
.29592 .18335 m
.26993 .20223 L
s
.29592 .18335 m
.30584 .1528 L
s
.29592 .79978 m
.26993 .7809 L
s
.29592 .79978 m
.30584 .83033 L
s
.23782 .20223 m
.26993 .20223 L
s
.23782 .20223 m
.21183 .18335 L
s
.23782 .20223 m
.21183 .22111 L
s
.23782 .20223 m
.21183 .18335 L
s
.23782 .20223 m
.21183 .22111 L
s
.23782 .26332 m
.21183 .2822 L
s
.23782 .26332 m
.21183 .2822 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .71981 m
.21183 .70093 L
s
.23782 .81866 m
.21183 .79978 L
s
.23782 .81866 m
.21183 .79978 L
s
.23782 .7809 m
.26993 .7809 L
s
.23782 .7809 m
.21183 .79978 L
s
.23782 .7809 m
.21183 .79978 L
s
.17971 .18335 m
.21183 .18335 L
s
.17971 .18335 m
.21183 .18335 L
s
.17971 .18335 m
.15373 .20223 L
s
.17971 .2822 m
.21183 .2822 L
s
.17971 .2822 m
.21183 .2822 L
s
.17971 .2822 m
.15373 .26332 L
s
.17971 .79978 m
.21183 .79978 L
s
.17971 .79978 m
.21183 .79978 L
s
.17971 .79978 m
.15373 .7809 L
s
.21183 .18335 m
.18585 .20223 L
s
.21183 .22111 m
.18585 .20223 L
s
.21183 .18335 m
.18585 .20223 L
s
.21183 .22111 m
.18585 .20223 L
s
.21183 .70093 m
.18585 .71981 L
s
.21183 .70093 m
.18585 .71981 L
s
.21183 .79978 m
.18585 .7809 L
s
.21183 .79978 m
.18585 .7809 L
s
.15373 .20223 m
.18585 .20223 L
s
.15373 .26332 m
.12775 .2822 L
s
.15373 .26332 m
.12775 .2822 L
s
.15373 .71981 m
.18585 .71981 L
s
.15373 .71981 m
.12775 .70093 L
s
.15373 .71981 m
.12775 .70093 L
s
.15373 .7809 m
.18585 .7809 L
s
.66204 .31274 m
.69416 .31274 L
s
.66204 .31274 m
.63605 .33162 L
s
.66204 .31274 m
.69416 .31274 L
s
.66204 .67039 m
.69416 .67039 L
s
.66204 .67039 m
.63605 .65151 L
s
.66204 .67039 m
.63605 .68926 L
s
.66204 .67039 m
.69416 .67039 L
s
.69416 .31274 m
.72014 .33162 L
s
.69416 .31274 m
.66817 .33162 L
s
.69416 .31274 m
.70408 .2822 L
s
.69416 .31274 m
.70408 .34329 L
s
.69416 .31274 m
.70408 .34329 L
s
.69416 .67039 m
.72014 .65151 L
s
.69416 .67039 m
.66817 .65151 L
s
.69416 .67039 m
.70408 .63984 L
s
.69416 .67039 m
.70408 .70093 L
s
.69416 .67039 m
.70408 .63984 L
s
.52598 .41159 m
.55197 .43047 L
s
.52598 .41159 m
.55197 .39272 L
s
.52598 .41159 m
.51606 .38105 L
s
.52598 .41159 m
.55197 .39272 L
s
.52598 .57154 m
.51606 .54099 L
s
.52598 .57154 m
.55197 .59041 L
s
.52598 .57154 m
.51606 .60208 L
s
.52598 .57154 m
.55197 .59041 L
s
.37387 .36217 m
.39985 .38105 L
s
.37387 .62096 m
.39985 .63984 L
s
.37387 .36217 m
.39985 .38105 L
s
.37387 .62096 m
.39985 .63984 L
s
.42584 .36217 m
.45796 .36217 L
s
.42584 .36217 m
.39985 .38105 L
s
.42584 .36217 m
.45796 .36217 L
s
.42584 .36217 m
.45796 .36217 L
s
.42584 .62096 m
.45796 .62096 L
s
.42584 .62096 m
.39985 .63984 L
s
.42584 .62096 m
.45796 .62096 L
s
.42584 .62096 m
.45796 .62096 L
s
.45796 .30108 m
.43197 .2822 L
s
.45796 .30108 m
.43197 .2822 L
s
.45796 .30108 m
.48394 .2822 L
s
.45796 .30108 m
.44803 .33162 L
s
.45796 .30108 m
.43197 .2822 L
s
.45796 .30108 m
.48394 .2822 L
s
.45796 .30108 m
.48394 .2822 L
s
.45796 .36217 m
.48394 .34329 L
s
.45796 .36217 m
.49007 .36217 L
s
.45796 .36217 m
.44803 .33162 L
s
.45796 .36217 m
.48394 .34329 L
s
.45796 .62096 m
.48394 .63984 L
s
.45796 .62096 m
.49007 .62096 L
s
.45796 .62096 m
.44803 .65151 L
s
.45796 .62096 m
.48394 .63984 L
s
.45796 .68205 m
.43197 .70093 L
s
.45796 .68205 m
.43197 .70093 L
s
.45796 .68205 m
.48394 .70093 L
s
.45796 .68205 m
.44803 .65151 L
s
.45796 .68205 m
.43197 .70093 L
s
.45796 .68205 m
.48394 .70093 L
s
.45796 .68205 m
.48394 .70093 L
s
.39985 .2822 m
.43197 .2822 L
s
.39985 .2822 m
.38993 .25165 L
s
.39985 .2822 m
.43197 .2822 L
s
.39985 .2822 m
.43197 .2822 L
s
.39985 .70093 m
.43197 .70093 L
s
.39985 .70093 m
.38993 .73148 L
s
.39985 .70093 m
.43197 .70093 L
s
.39985 .70093 m
.43197 .70093 L
s
.43197 .2822 m
.42205 .25165 L
s
.43197 .2822 m
.45796 .26332 L
s
.43197 .2822 m
.45796 .30108 L
s
.43197 .2822 m
.45796 .26332 L
s
.43197 .2822 m
.45796 .30108 L
s
.43197 .70093 m
.42205 .73148 L
s
.43197 .70093 m
.45796 .71981 L
s
.43197 .70093 m
.45796 .68205 L
s
.43197 .70093 m
.45796 .71981 L
s
.43197 .70093 m
.45796 .68205 L
s
.37387 .20223 m
.36395 .23277 L
s
.37387 .20223 m
.36395 .17168 L
s
.37387 .20223 m
.36395 .23277 L
s
.37387 .20223 m
.39985 .18335 L
s
.37387 .20223 m
.39985 .18335 L
s
.37387 .20223 m
.39985 .18335 L
s
.37387 .20223 m
.39985 .18335 L
s
.37387 .7809 m
.36395 .75036 L
s
.37387 .7809 m
.36395 .81145 L
s
.37387 .7809 m
.36395 .75036 L
s
.37387 .7809 m
.39985 .79978 L
s
.37387 .7809 m
.39985 .79978 L
s
.37387 .7809 m
.39985 .79978 L
s
.37387 .7809 m
.39985 .79978 L
s
.54204 .10338 m
.57416 .10338 L
s
.54204 .10338 m
.51606 .0845 L
s
.54204 .10338 m
.51606 .0845 L
s
.54204 .10338 m
.51606 .12226 L
s
.54204 .10338 m
.55197 .13392 L
s
.54204 .10338 m
.55197 .07283 L
s
.54204 .10338 m
.55197 .07283 L
s
.54204 .10338 m
.55197 .13392 L
s
.54204 .10338 m
.56803 .12226 L
s
.54204 .10338 m
.57416 .10338 L
s
.54204 .10338 m
.55197 .13392 L
s
.54204 .10338 m
.51606 .12226 L
s
.54204 .10338 m
.51606 .12226 L
s
.54204 .87975 m
.57416 .87975 L
s
.54204 .87975 m
.51606 .89863 L
s
.54204 .87975 m
.51606 .86087 L
s
.54204 .87975 m
.51606 .89863 L
s
.54204 .87975 m
.55197 .9103 L
s
.54204 .87975 m
.55197 .9103 L
s
.54204 .87975 m
.55197 .84921 L
s
.54204 .87975 m
.55197 .84921 L
s
.54204 .87975 m
.56803 .86087 L
s
.54204 .87975 m
.57416 .87975 L
s
.54204 .87975 m
.55197 .84921 L
s
.54204 .87975 m
.51606 .86087 L
s
.54204 .87975 m
.51606 .86087 L
s
.57416 .10338 m
.60015 .12226 L
s
.57416 .10338 m
.58409 .07283 L
s
.57416 .10338 m
.58409 .07283 L
s
.57416 .10338 m
.60015 .12226 L
s
.57416 .10338 m
.54204 .10338 L
s
.57416 .10338 m
.58409 .07283 L
s
.57416 .87975 m
.60015 .86087 L
s
.57416 .87975 m
.58409 .9103 L
s
.57416 .87975 m
.58409 .9103 L
s
.57416 .87975 m
.60015 .86087 L
s
.57416 .87975 m
.54204 .87975 L
s
.57416 .87975 m
.58409 .9103 L
s
.48394 .0845 m
.51606 .0845 L
s
.48394 .0845 m
.51606 .0845 L
s
.48394 .0845 m
.45796 .10338 L
s
.48394 .0845 m
.45796 .10338 L
s
.48394 .0845 m
.45796 .10338 L
s
.48394 .0845 m
.45796 .10338 L
s
.48394 .0845 m
.45796 .10338 L
s
.48394 .89863 m
.51606 .89863 L
s
.48394 .89863 m
.51606 .89863 L
s
.48394 .89863 m
.45796 .87975 L
s
.48394 .89863 m
.45796 .87975 L
s
.48394 .89863 m
.45796 .87975 L
s
.48394 .89863 m
.45796 .87975 L
s
.48394 .89863 m
.45796 .87975 L
s
.51606 .0845 m
.49007 .10338 L
s
.51606 .0845 m
.52598 .05395 L
s
.51606 .0845 m
.54204 .10338 L
s
.51606 .0845 m
.49007 .10338 L
s
.51606 .0845 m
.49007 .10338 L
s
.51606 .89863 m
.49007 .87975 L
s
.51606 .89863 m
.52598 .92918 L
s
.51606 .89863 m
.54204 .87975 L
s
.51606 .89863 m
.49007 .87975 L
s
.51606 .89863 m
.49007 .87975 L
s
.51606 .0845 m
.49007 .10338 L
s
.51606 .0845 m
.52598 .05395 L
s
.51606 .0845 m
.54204 .10338 L
s
.51606 .0845 m
.49007 .10338 L
s
.51606 .0845 m
.49007 .10338 L
s
.51606 .12226 m
.49007 .10338 L
s
.51606 .12226 m
.52598 .1528 L
s
.51606 .12226 m
.52598 .1528 L
s
.51606 .12226 m
.54204 .10338 L
s
.51606 .12226 m
.50613 .1528 L
s
.51606 .12226 m
.52598 .1528 L
s
.51606 .12226 m
.48394 .12226 L
s
.51606 .12226 m
.52598 .1528 L
s
.51606 .12226 m
.49007 .10338 L
s
.51606 .12226 m
.49007 .10338 L
s
.51606 .12226 m
.48394 .12226 L
s
.51606 .86087 m
.49007 .87975 L
s
.51606 .86087 m
.52598 .83033 L
s
.51606 .86087 m
.52598 .83033 L
s
.51606 .86087 m
.54204 .87975 L
s
.51606 .86087 m
.50613 .83033 L
s
.51606 .86087 m
.52598 .83033 L
s
.51606 .86087 m
.48394 .86087 L
s
.51606 .86087 m
.52598 .83033 L
s
.51606 .86087 m
.49007 .87975 L
s
.51606 .86087 m
.49007 .87975 L
s
.51606 .86087 m
.48394 .86087 L
s
.51606 .89863 m
.49007 .87975 L
s
.51606 .89863 m
.52598 .92918 L
s
.51606 .89863 m
.54204 .87975 L
s
.51606 .89863 m
.49007 .87975 L
s
.51606 .89863 m
.49007 .87975 L
s
.62613 .10338 m
.60015 .12226 L
s
.62613 .10338 m
.63605 .13392 L
s
.62613 .10338 m
.63605 .07283 L
s
.62613 .10338 m
.60015 .12226 L
s
.62613 .87975 m
.60015 .86087 L
s
.62613 .87975 m
.63605 .9103 L
s
.62613 .87975 m
.63605 .84921 L
s
.62613 .87975 m
.60015 .86087 L
s
.49007 .10338 m
.45796 .10338 L
s
.49007 .10338 m
.45796 .10338 L
s
.49007 .10338 m
.45796 .10338 L
s
.49007 .10338 m
.51606 .12226 L
s
.49007 .10338 m
.45796 .10338 L
s
.49007 .10338 m
.45796 .10338 L
s
.49007 .10338 m
.51606 .12226 L
s
.49007 .87975 m
.45796 .87975 L
s
.49007 .87975 m
.45796 .87975 L
s
.49007 .87975 m
.45796 .87975 L
s
.49007 .87975 m
.51606 .86087 L
s
.49007 .87975 m
.45796 .87975 L
s
.49007 .87975 m
.45796 .87975 L
s
.49007 .87975 m
.51606 .86087 L
s
.60015 .12226 m
.61007 .1528 L
s
.60015 .12226 m
.61007 .09171 L
s
.60015 .12226 m
.61007 .1528 L
s
.60015 .12226 m
.56803 .12226 L
s
.60015 .12226 m
.57416 .10338 L
s
.60015 .12226 m
.61007 .1528 L
s
.60015 .12226 m
.61007 .09171 L
s
.60015 .12226 m
.61007 .1528 L
s
.60015 .86087 m
.61007 .89142 L
s
.60015 .86087 m
.61007 .83033 L
s
.60015 .86087 m
.61007 .83033 L
s
.60015 .86087 m
.56803 .86087 L
s
.60015 .86087 m
.57416 .87975 L
s
.60015 .86087 m
.61007 .89142 L
s
.60015 .86087 m
.61007 .83033 L
s
.60015 .86087 m
.61007 .83033 L
s
.73007 .20223 m
.70408 .18335 L
s
.73007 .20223 m
.70408 .22111 L
s
.73007 .20223 m
.76218 .20223 L
s
.73007 .20223 m
.76218 .20223 L
s
.73007 .7809 m
.76218 .7809 L
s
.73007 .7809 m
.70408 .79978 L
s
.73007 .7809 m
.76218 .7809 L
s
.73007 .7809 m
.76218 .7809 L
s
.76218 .7809 m
.78817 .79978 L
s
.76218 .7809 m
.7362 .79978 L
s
.76218 .7809 m
.77211 .75036 L
s
.76218 .7809 m
.78817 .76202 L
s
.76218 .7809 m
.78817 .79978 L
s
.76218 .7809 m
.77211 .75036 L
s
.78817 .18335 m
.82029 .18335 L
s
.78817 .18335 m
.79809 .1528 L
s
.78817 .18335 m
.82029 .18335 L
s
.78817 .18335 m
.81415 .20223 L
s
.78817 .18335 m
.76218 .20223 L
s
.78817 .18335 m
.76218 .20223 L
s
.78817 .79978 m
.82029 .79978 L
s
.78817 .79978 m
.79809 .83033 L
s
.78817 .79978 m
.82029 .79978 L
s
.78817 .79978 m
.81415 .7809 L
s
.78817 .79978 m
.76218 .7809 L
s
.78817 .79978 m
.76218 .7809 L
s
.82029 .18335 m
.83021 .1528 L
s
.82029 .18335 m
.78817 .18335 L
s
.82029 .18335 m
.84627 .20223 L
s
.82029 .18335 m
.83021 .1528 L
s
.82029 .79978 m
.83021 .83033 L
s
.82029 .79978 m
.78817 .79978 L
s
.82029 .79978 m
.84627 .7809 L
s
.82029 .79978 m
.83021 .83033 L
s
.70408 .18335 m
.6781 .20223 L
s
.70408 .18335 m
.6781 .20223 L
s
.70408 .18335 m
.6781 .20223 L
s
.70408 .22111 m
.6781 .20223 L
s
.70408 .22111 m
.6781 .20223 L
s
.70408 .22111 m
.6781 .20223 L
s
.70408 .79978 m
.7362 .79978 L
s
.70408 .79978 m
.6781 .7809 L
s
.70408 .79978 m
.6781 .7809 L
s
.7362 .79978 m
.76218 .7809 L
s
.7362 .79978 m
.76218 .7809 L
s
.6781 .20223 m
.64598 .20223 L
s
.6781 .20223 m
.66817 .23277 L
s
.6781 .20223 m
.64598 .20223 L
s
.6781 .20223 m
.66817 .17168 L
s
.6781 .20223 m
.64598 .20223 L
s
.72014 .07283 m
.69416 .05395 L
s
.72014 .07283 m
.69416 .09171 L
s
.72014 .07283 m
.69416 .09171 L
s
.72014 .07283 m
.73007 .10338 L
s
.72014 .9103 m
.69416 .89142 L
s
.72014 .9103 m
.69416 .92918 L
s
.72014 .9103 m
.69416 .89142 L
s
.72014 .9103 m
.73007 .87975 L
s
.55197 .13392 m
.52598 .1528 L
s
.55197 .13392 m
.57795 .1528 L
s
.55197 .13392 m
.57795 .1528 L
s
.55197 .13392 m
.52598 .1528 L
s
.55197 .13392 m
.54204 .10338 L
s
.55197 .13392 m
.57795 .1528 L
s
.55197 .13392 m
.52598 .1528 L
s
.55197 .13392 m
.52598 .1528 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .07283 m
.52598 .05395 L
s
.55197 .07283 m
.57795 .05395 L
s
.55197 .07283 m
.54204 .10338 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .07283 m
.52598 .05395 L
s
.55197 .07283 m
.57795 .05395 L
s
.55197 .07283 m
.54204 .10338 L
s
.55197 .07283 m
.58409 .07283 L
s
.55197 .9103 m
.58409 .9103 L
s
.55197 .9103 m
.58409 .9103 L
s
.55197 .9103 m
.52598 .92918 L
s
.55197 .9103 m
.57795 .92918 L
s
.55197 .9103 m
.54204 .87975 L
s
.55197 .9103 m
.58409 .9103 L
s
.55197 .9103 m
.58409 .9103 L
s
.55197 .9103 m
.58409 .9103 L
s
.55197 .9103 m
.52598 .92918 L
s
.55197 .9103 m
.57795 .92918 L
s
.55197 .9103 m
.54204 .87975 L
s
.55197 .9103 m
.58409 .9103 L
s
.55197 .84921 m
.52598 .83033 L
s
.55197 .84921 m
.57795 .83033 L
s
.55197 .84921 m
.57795 .83033 L
s
.55197 .84921 m
.52598 .83033 L
s
.55197 .84921 m
.54204 .87975 L
s
.55197 .84921 m
.57795 .83033 L
s
.55197 .84921 m
.52598 .83033 L
s
.55197 .84921 m
.52598 .83033 L
s
.58409 .07283 m
.61007 .05395 L
s
.58409 .07283 m
.61007 .09171 L
s
.58409 .07283 m
.57416 .10338 L
s
.58409 .07283 m
.61007 .09171 L
s
.58409 .07283 m
.61007 .05395 L
s
.58409 .07283 m
.61007 .09171 L
s
.58409 .07283 m
.57416 .10338 L
s
.58409 .07283 m
.61007 .09171 L
s
.58409 .9103 m
.61007 .89142 L
s
.58409 .9103 m
.61007 .92918 L
s
.58409 .9103 m
.57416 .87975 L
s
.58409 .9103 m
.61007 .89142 L
s
.58409 .9103 m
.61007 .89142 L
s
.58409 .9103 m
.61007 .92918 L
s
.58409 .9103 m
.57416 .87975 L
s
.58409 .9103 m
.61007 .89142 L
s
.69416 .05395 m
.66817 .07283 L
s
.69416 .05395 m
.66817 .07283 L
s
.69416 .09171 m
.66817 .07283 L
s
.69416 .09171 m
.66817 .07283 L
s
.69416 .09171 m
.70408 .12226 L
s
.69416 .09171 m
.70408 .12226 L
s
.69416 .09171 m
.66817 .07283 L
s
.69416 .09171 m
.66817 .07283 L
s
.69416 .09171 m
.70408 .12226 L
s
.69416 .09171 m
.70408 .12226 L
s
.69416 .89142 m
.66817 .9103 L
s
.69416 .89142 m
.66817 .9103 L
s
.69416 .89142 m
.70408 .86087 L
s
.69416 .89142 m
.70408 .86087 L
s
.69416 .92918 m
.66817 .9103 L
s
.69416 .92918 m
.66817 .9103 L
s
.69416 .89142 m
.66817 .9103 L
s
.69416 .89142 m
.66817 .9103 L
s
.69416 .89142 m
.70408 .86087 L
s
.69416 .89142 m
.70408 .86087 L
s
.52598 .1528 m
.55197 .17168 L
s
.52598 .1528 m
.55197 .13392 L
s
.52598 .1528 m
.55197 .17168 L
s
.52598 .1528 m
.55197 .13392 L
s
.52598 .1528 m
.55197 .17168 L
s
.52598 .1528 m
.51606 .18335 L
s
.52598 .1528 m
.51606 .18335 L
s
.52598 .1528 m
.51606 .12226 L
s
.52598 .1528 m
.51606 .18335 L
s
.52598 .1528 m
.51606 .12226 L
s
.52598 .83033 m
.55197 .81145 L
s
.52598 .83033 m
.55197 .84921 L
s
.52598 .83033 m
.55197 .81145 L
s
.52598 .83033 m
.55197 .84921 L
s
.52598 .83033 m
.55197 .81145 L
s
.52598 .83033 m
.51606 .79978 L
s
.52598 .83033 m
.51606 .79978 L
s
.52598 .83033 m
.51606 .79978 L
s
.52598 .83033 m
.51606 .86087 L
s
.52598 .83033 m
.51606 .86087 L
s
.63605 .13392 m
.61007 .1528 L
s
.63605 .13392 m
.64598 .10338 L
s
.63605 .13392 m
.61007 .1528 L
s
.63605 .13392 m
.61007 .1528 L
s
.63605 .13392 m
.61007 .1528 L
s
.63605 .07283 m
.66817 .07283 L
s
.63605 .07283 m
.66817 .07283 L
s
.63605 .07283 m
.61007 .05395 L
s
.63605 .07283 m
.61007 .09171 L
s
.63605 .07283 m
.64598 .10338 L
s
.63605 .07283 m
.61007 .09171 L
s
.63605 .07283 m
.64598 .04229 L
s
.63605 .07283 m
.64598 .04229 L
s
.63605 .9103 m
.66817 .9103 L
s
.63605 .9103 m
.66817 .9103 L
s
.63605 .9103 m
.61007 .89142 L
s
.63605 .9103 m
.61007 .92918 L
s
.63605 .9103 m
.64598 .87975 L
s
.63605 .9103 m
.61007 .89142 L
s
.63605 .9103 m
.64598 .94084 L
s
.63605 .9103 m
.64598 .94084 L
s
.63605 .84921 m
.61007 .83033 L
s
.63605 .84921 m
.64598 .87975 L
s
.63605 .84921 m
.61007 .83033 L
s
.63605 .84921 m
.61007 .83033 L
s
.63605 .84921 m
.61007 .83033 L
s
.66817 .07283 m
.6781 .10338 L
s
.66817 .07283 m
.6781 .10338 L
s
.66817 .9103 m
.6781 .87975 L
s
.66817 .9103 m
.6781 .87975 L
s
.57795 .05395 m
.61007 .05395 L
s
.57795 .92918 m
.61007 .92918 L
s
.61007 .1528 m
.57795 .1528 L
s
.61007 .1528 m
.60015 .18335 L
s
.61007 .1528 m
.57795 .1528 L
s
.61007 .1528 m
.60015 .12226 L
s
.61007 .1528 m
.57795 .1528 L
s
.61007 .1528 m
.63605 .17168 L
s
.61007 .1528 m
.60015 .18335 L
s
.61007 .1528 m
.63605 .17168 L
s
.61007 .05395 m
.58409 .07283 L
s
.61007 .09171 m
.60015 .12226 L
s
.61007 .09171 m
.58409 .07283 L
s
.61007 .89142 m
.60015 .86087 L
s
.61007 .89142 m
.58409 .9103 L
s
.61007 .92918 m
.58409 .9103 L
s
.61007 .83033 m
.57795 .83033 L
s
.61007 .83033 m
.60015 .79978 L
s
.61007 .83033 m
.57795 .83033 L
s
.61007 .83033 m
.60015 .86087 L
s
.61007 .83033 m
.57795 .83033 L
s
.61007 .83033 m
.63605 .81145 L
s
.61007 .83033 m
.60015 .79978 L
s
.61007 .83033 m
.63605 .81145 L
s
.79809 .1528 m
.83021 .1528 L
s
.79809 .1528 m
.78817 .18335 L
s
.79809 .1528 m
.83021 .1528 L
s
.79809 .83033 m
.83021 .83033 L
s
.79809 .83033 m
.78817 .79978 L
s
.79809 .83033 m
.83021 .83033 L
s
.83021 .1528 m
.82029 .18335 L
s
.83021 .1528 m
.8562 .17168 L
s
.83021 .83033 m
.82029 .79978 L
s
.83021 .83033 m
.8562 .81145 L
s
.73007 .10338 m
.76218 .10338 L
s
.73007 .10338 m
.70408 .12226 L
s
.73007 .10338 m
.70408 .12226 L
s
.73007 .87975 m
.76218 .87975 L
s
.73007 .87975 m
.70408 .86087 L
s
.73007 .87975 m
.70408 .86087 L
s
.70408 .12226 m
.6781 .10338 L
s
.70408 .12226 m
.6781 .10338 L
s
.70408 .86087 m
.6781 .87975 L
s
.70408 .86087 m
.6781 .87975 L
s
.64598 .10338 m
.6781 .10338 L
s
.64598 .87975 m
.6781 .87975 L
s
.38993 .09171 m
.36395 .07283 L
s
.38993 .09171 m
.36395 .07283 L
s
.38993 .09171 m
.39985 .12226 L
s
.38993 .09171 m
.39985 .12226 L
s
.38993 .09171 m
.41591 .07283 L
s
.38993 .09171 m
.36395 .07283 L
s
.38993 .09171 m
.39985 .12226 L
s
.38993 .09171 m
.39985 .12226 L
s
.38993 .2139 m
.36395 .23277 L
s
.38993 .2139 m
.41591 .23277 L
s
.38993 .2139 m
.36395 .23277 L
s
.38993 .2139 m
.39985 .18335 L
s
.38993 .2139 m
.39985 .18335 L
s
.38993 .2139 m
.39985 .18335 L
s
.38993 .2139 m
.39985 .18335 L
s
.38993 .76923 m
.36395 .75036 L
s
.38993 .76923 m
.41591 .75036 L
s
.38993 .76923 m
.36395 .75036 L
s
.38993 .76923 m
.39985 .79978 L
s
.38993 .76923 m
.39985 .79978 L
s
.38993 .76923 m
.39985 .79978 L
s
.38993 .76923 m
.39985 .79978 L
s
.38993 .89142 m
.36395 .9103 L
s
.38993 .89142 m
.36395 .9103 L
s
.38993 .89142 m
.36395 .9103 L
s
.38993 .89142 m
.39985 .86087 L
s
.38993 .89142 m
.39985 .86087 L
s
.38993 .89142 m
.41591 .9103 L
s
.38993 .89142 m
.36395 .9103 L
s
.38993 .89142 m
.39985 .86087 L
s
.38993 .89142 m
.39985 .86087 L
s
.38993 .1528 m
.42205 .1528 L
s
.38993 .1528 m
.36395 .17168 L
s
.38993 .1528 m
.36395 .13392 L
s
.38993 .1528 m
.36395 .13392 L
s
.38993 .1528 m
.39985 .18335 L
s
.38993 .1528 m
.39985 .12226 L
s
.38993 .1528 m
.39985 .18335 L
s
.38993 .1528 m
.39985 .12226 L
s
.38993 .1528 m
.39985 .18335 L
s
.38993 .1528 m
.39985 .18335 L
s
.38993 .1528 m
.42205 .1528 L
s
.38993 .1528 m
.42205 .1528 L
s
.38993 .1528 m
.39985 .12226 L
s
.38993 .1528 m
.39985 .12226 L
s
.38993 .83033 m
.42205 .83033 L
s
.38993 .83033 m
.36395 .81145 L
s
.38993 .83033 m
.36395 .84921 L
s
.38993 .83033 m
.36395 .84921 L
s
.38993 .83033 m
.39985 .79978 L
s
.38993 .83033 m
.39985 .79978 L
s
.38993 .83033 m
.39985 .86087 L
s
.38993 .83033 m
.39985 .79978 L
s
.38993 .83033 m
.39985 .86087 L
s
.38993 .83033 m
.39985 .79978 L
s
.38993 .83033 m
.42205 .83033 L
s
.38993 .83033 m
.42205 .83033 L
s
.38993 .83033 m
.39985 .86087 L
s
.38993 .83033 m
.39985 .86087 L
s
.38993 .2139 m
.36395 .23277 L
s
.38993 .2139 m
.41591 .23277 L
s
.38993 .2139 m
.36395 .23277 L
s
.38993 .2139 m
.39985 .18335 L
s
.38993 .2139 m
.39985 .18335 L
s
.38993 .2139 m
.39985 .18335 L
s
.38993 .2139 m
.39985 .18335 L
s
.38993 .25165 m
.42205 .25165 L
s
.38993 .25165 m
.36395 .23277 L
s
.38993 .25165 m
.41591 .23277 L
s
.38993 .25165 m
.36395 .23277 L
s
.38993 .73148 m
.42205 .73148 L
s
.38993 .73148 m
.36395 .75036 L
s
.38993 .73148 m
.41591 .75036 L
s
.38993 .73148 m
.36395 .75036 L
s
.38993 .76923 m
.36395 .75036 L
s
.38993 .76923 m
.41591 .75036 L
s
.38993 .76923 m
.36395 .75036 L
s
.38993 .76923 m
.39985 .79978 L
s
.38993 .76923 m
.39985 .79978 L
s
.38993 .76923 m
.39985 .79978 L
s
.38993 .76923 m
.39985 .79978 L
s
.42205 .25165 m
.44803 .23277 L
s
.42205 .25165 m
.43197 .2822 L
s
.42205 .25165 m
.43197 .2822 L
s
.42205 .73148 m
.44803 .75036 L
s
.42205 .73148 m
.43197 .70093 L
s
.42205 .73148 m
.43197 .70093 L
s
.42205 .1528 m
.44803 .17168 L
s
.42205 .1528 m
.43197 .18335 L
s
.42205 .1528 m
.43197 .12226 L
s
.42205 .1528 m
.43197 .18335 L
s
.42205 .1528 m
.44803 .13392 L
s
.42205 .1528 m
.44803 .17168 L
s
.42205 .1528 m
.44803 .13392 L
s
.42205 .1528 m
.43197 .12226 L
s
.42205 .1528 m
.43197 .12226 L
s
.42205 .83033 m
.44803 .81145 L
s
.42205 .83033 m
.43197 .79978 L
s
.42205 .83033 m
.43197 .79978 L
s
.42205 .83033 m
.43197 .86087 L
s
.42205 .83033 m
.44803 .84921 L
s
.42205 .83033 m
.44803 .81145 L
s
.42205 .83033 m
.44803 .84921 L
s
.42205 .83033 m
.43197 .86087 L
s
.42205 .83033 m
.43197 .86087 L
s
.79809 .31274 m
.77211 .33162 L
s
.79809 .31274 m
.78817 .2822 L
s
.79809 .31274 m
.83021 .31274 L
s
.79809 .31274 m
.77211 .33162 L
s
.79809 .31274 m
.78817 .34329 L
s
.79809 .31274 m
.77211 .33162 L
s
.79809 .31274 m
.82408 .33162 L
s
.79809 .31274 m
.83021 .31274 L
s
.79809 .31274 m
.83021 .31274 L
s
.79809 .31274 m
.78817 .34329 L
s
.79809 .67039 m
.77211 .65151 L
s
.79809 .67039 m
.78817 .70093 L
s
.79809 .67039 m
.83021 .67039 L
s
.79809 .67039 m
.77211 .65151 L
s
.79809 .67039 m
.78817 .63984 L
s
.79809 .67039 m
.77211 .65151 L
s
.79809 .67039 m
.82408 .65151 L
s
.79809 .67039 m
.83021 .67039 L
s
.79809 .67039 m
.83021 .67039 L
s
.79809 .67039 m
.78817 .63984 L
s
.83021 .41159 m
.8562 .43047 L
s
.83021 .41159 m
.8562 .39272 L
s
.83021 .41159 m
.79809 .41159 L
s
.83021 .41159 m
.82029 .38105 L
s
.83021 .41159 m
.82029 .44214 L
s
.83021 .41159 m
.82029 .38105 L
s
.83021 .57154 m
.8562 .55266 L
s
.83021 .57154 m
.8562 .59041 L
s
.83021 .57154 m
.79809 .57154 L
s
.83021 .57154 m
.79809 .57154 L
s
.83021 .57154 m
.82029 .54099 L
s
.77211 .59041 m
.76218 .62096 L
s
.77211 .59041 m
.76218 .55987 L
s
.77211 .59041 m
.76218 .62096 L
s
.77211 .59041 m
.76218 .62096 L
s
.77211 .59041 m
.79809 .57154 L
s
.77211 .59041 m
.79809 .57154 L
s
.77211 .59041 m
.76218 .62096 L
s
.36395 .07283 m
.33183 .07283 L
s
.36395 .07283 m
.33183 .07283 L
s
.36395 .07283 m
.35402 .04229 L
s
.36395 .07283 m
.35402 .10338 L
s
.36395 .07283 m
.37387 .10338 L
s
.36395 .07283 m
.37387 .10338 L
s
.36395 .07283 m
.37387 .10338 L
s
.36395 .07283 m
.38993 .05395 L
s
.36395 .07283 m
.38993 .09171 L
s
.36395 .07283 m
.38993 .05395 L
s
.36395 .07283 m
.35402 .04229 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .9103 m
.33183 .9103 L
s
.36395 .9103 m
.33183 .9103 L
s
.36395 .9103 m
.33796 .92918 L
s
.36395 .9103 m
.35402 .87975 L
s
.36395 .9103 m
.37387 .87975 L
s
.36395 .9103 m
.37387 .87975 L
s
.36395 .9103 m
.37387 .87975 L
s
.36395 .9103 m
.38993 .89142 L
s
.36395 .9103 m
.38993 .92918 L
s
.36395 .9103 m
.38993 .92918 L
s
.36395 .9103 m
.35402 .94084 L
s
.36395 .17168 m
.33796 .1528 L
s
.36395 .17168 m
.33796 .1528 L
s
.36395 .17168 m
.37387 .20223 L
s
.36395 .17168 m
.37387 .20223 L
s
.36395 .13392 m
.33796 .1528 L
s
.36395 .13392 m
.33183 .13392 L
s
.36395 .13392 m
.33796 .1528 L
s
.36395 .13392 m
.35402 .10338 L
s
.36395 .13392 m
.37387 .10338 L
s
.36395 .13392 m
.37387 .10338 L
s
.36395 .13392 m
.37387 .10338 L
s
.36395 .81145 m
.33796 .83033 L
s
.36395 .81145 m
.33796 .83033 L
s
.36395 .81145 m
.37387 .7809 L
s
.36395 .81145 m
.37387 .7809 L
s
.36395 .84921 m
.33796 .83033 L
s
.36395 .84921 m
.33183 .84921 L
s
.36395 .84921 m
.33796 .83033 L
s
.36395 .84921 m
.35402 .87975 L
s
.36395 .84921 m
.37387 .87975 L
s
.36395 .84921 m
.37387 .87975 L
s
.36395 .84921 m
.37387 .87975 L
s
.77211 .33162 m
.76218 .30108 L
s
.77211 .33162 m
.76218 .36217 L
s
.77211 .33162 m
.76218 .30108 L
s
.77211 .33162 m
.79809 .31274 L
s
.77211 .33162 m
.76218 .36217 L
s
.77211 .33162 m
.76218 .36217 L
s
.77211 .33162 m
.79809 .31274 L
s
.77211 .33162 m
.76218 .36217 L
s
.77211 .65151 m
.76218 .62096 L
s
.77211 .65151 m
.76218 .68205 L
s
.77211 .65151 m
.76218 .68205 L
s
.77211 .65151 m
.79809 .67039 L
s
.77211 .65151 m
.76218 .62096 L
s
.77211 .65151 m
.76218 .62096 L
s
.77211 .65151 m
.79809 .67039 L
s
.77211 .65151 m
.76218 .62096 L
s
.47402 .25165 m
.50613 .25165 L
s
.47402 .25165 m
.44803 .23277 L
s
.47402 .25165 m
.48394 .22111 L
s
.47402 .25165 m
.48394 .22111 L
s
.47402 .25165 m
.48394 .2822 L
s
.47402 .25165 m
.48394 .2822 L
s
.47402 .25165 m
.48394 .2822 L
s
.47402 .73148 m
.50613 .73148 L
s
.47402 .73148 m
.44803 .75036 L
s
.47402 .73148 m
.48394 .76202 L
s
.47402 .73148 m
.48394 .70093 L
s
.47402 .73148 m
.48394 .76202 L
s
.47402 .73148 m
.48394 .70093 L
s
.47402 .73148 m
.48394 .70093 L
s
.50613 .25165 m
.51606 .22111 L
s
.50613 .25165 m
.51606 .22111 L
s
.50613 .25165 m
.51606 .2822 L
s
.50613 .25165 m
.51606 .2822 L
s
.50613 .25165 m
.51606 .2822 L
s
.50613 .25165 m
.51606 .22111 L
s
.50613 .25165 m
.51606 .2822 L
s
.50613 .25165 m
.51606 .2822 L
s
.50613 .73148 m
.51606 .76202 L
s
.50613 .73148 m
.51606 .70093 L
s
.50613 .73148 m
.51606 .76202 L
s
.50613 .73148 m
.51606 .70093 L
s
.50613 .73148 m
.51606 .70093 L
s
.50613 .73148 m
.51606 .76202 L
s
.50613 .73148 m
.51606 .70093 L
s
.50613 .73148 m
.51606 .70093 L
s
.33796 .1528 m
.36395 .13392 L
s
.33796 .1528 m
.30584 .1528 L
s
.33796 .83033 m
.36395 .84921 L
s
.33796 .83033 m
.30584 .83033 L
s
.41591 .23277 m
.44803 .23277 L
s
.41591 .23277 m
.42584 .20223 L
s
.41591 .23277 m
.42584 .20223 L
s
.41591 .75036 m
.44803 .75036 L
s
.41591 .75036 m
.42584 .7809 L
s
.41591 .75036 m
.42584 .7809 L
s
.44803 .23277 m
.45796 .20223 L
s
.44803 .23277 m
.45796 .20223 L
s
.44803 .23277 m
.45796 .26332 L
s
.44803 .23277 m
.45796 .20223 L
s
.44803 .23277 m
.45796 .26332 L
s
.44803 .23277 m
.45796 .20223 L
s
.44803 .23277 m
.45796 .20223 L
s
.44803 .75036 m
.45796 .7809 L
s
.44803 .75036 m
.45796 .71981 L
s
.44803 .75036 m
.45796 .7809 L
s
.44803 .75036 m
.45796 .7809 L
s
.44803 .75036 m
.45796 .71981 L
s
.44803 .75036 m
.45796 .7809 L
s
.44803 .75036 m
.45796 .7809 L
s
.44803 .17168 m
.45796 .20223 L
s
.44803 .17168 m
.45796 .20223 L
s
.44803 .17168 m
.45796 .20223 L
s
.44803 .17168 m
.42205 .1528 L
s
.44803 .17168 m
.47402 .1528 L
s
.44803 .17168 m
.42205 .1528 L
s
.44803 .17168 m
.45796 .20223 L
s
.44803 .17168 m
.45796 .20223 L
s
.44803 .81145 m
.45796 .7809 L
s
.44803 .81145 m
.45796 .7809 L
s
.44803 .81145 m
.45796 .7809 L
s
.44803 .81145 m
.42205 .83033 L
s
.44803 .81145 m
.47402 .83033 L
s
.44803 .81145 m
.42205 .83033 L
s
.44803 .81145 m
.45796 .7809 L
s
.44803 .81145 m
.45796 .7809 L
s
.33183 .07283 m
.36395 .07283 L
s
.33183 .07283 m
.30584 .05395 L
s
.33183 .07283 m
.30584 .09171 L
s
.33183 .07283 m
.30584 .09171 L
s
.33183 .07283 m
.3219 .10338 L
s
.33183 .07283 m
.36395 .07283 L
s
.33183 .9103 m
.36395 .9103 L
s
.33183 .9103 m
.36395 .9103 L
s
.33183 .9103 m
.30584 .92918 L
s
.33183 .9103 m
.30584 .92918 L
s
.33183 .9103 m
.3219 .87975 L
s
.33183 .9103 m
.36395 .9103 L
s
.33183 .13392 m
.36395 .13392 L
s
.33183 .13392 m
.30584 .1528 L
s
.33183 .13392 m
.3219 .10338 L
s
.33183 .07283 m
.36395 .07283 L
s
.33183 .07283 m
.30584 .05395 L
s
.33183 .07283 m
.30584 .09171 L
s
.33183 .07283 m
.30584 .09171 L
s
.33183 .07283 m
.3219 .10338 L
s
.33183 .07283 m
.36395 .07283 L
s
.33183 .9103 m
.36395 .9103 L
s
.33183 .9103 m
.36395 .9103 L
s
.33183 .9103 m
.30584 .92918 L
s
.33183 .9103 m
.30584 .92918 L
s
.33183 .9103 m
.3219 .87975 L
s
.33183 .9103 m
.36395 .9103 L
s
.33183 .84921 m
.36395 .84921 L
s
.33183 .84921 m
.30584 .83033 L
s
.33183 .84921 m
.3219 .87975 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .23277 m
.37387 .20223 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .75036 m
.37387 .7809 L
s
.36395 .9103 m
.33796 .92918 L
s
.36395 .9103 m
.35402 .87975 L
s
.36395 .9103 m
.37387 .87975 L
s
.36395 .9103 m
.37387 .87975 L
s
.36395 .9103 m
.37387 .87975 L
s
.36395 .9103 m
.38993 .89142 L
s
.36395 .9103 m
.38993 .92918 L
s
.36395 .9103 m
.38993 .92918 L
s
.36395 .9103 m
.35402 .94084 L
s
.36395 .13392 m
.33796 .1528 L
s
.36395 .13392 m
.35402 .10338 L
s
.36395 .13392 m
.37387 .10338 L
s
.36395 .13392 m
.37387 .10338 L
s
.36395 .13392 m
.37387 .10338 L
s
.36395 .07283 m
.35402 .04229 L
s
.36395 .07283 m
.35402 .10338 L
s
.36395 .07283 m
.37387 .10338 L
s
.36395 .07283 m
.37387 .10338 L
s
.36395 .07283 m
.37387 .10338 L
s
.36395 .07283 m
.38993 .05395 L
s
.36395 .07283 m
.38993 .09171 L
s
.36395 .07283 m
.38993 .05395 L
s
.36395 .07283 m
.35402 .04229 L
s
.36395 .9103 m
.33796 .92918 L
s
.36395 .9103 m
.35402 .87975 L
s
.36395 .9103 m
.37387 .87975 L
s
.36395 .9103 m
.37387 .87975 L
s
.36395 .9103 m
.37387 .87975 L
s
.36395 .9103 m
.38993 .89142 L
s
.36395 .9103 m
.38993 .92918 L
s
.36395 .9103 m
.38993 .92918 L
s
.36395 .9103 m
.35402 .94084 L
s
.36395 .84921 m
.33796 .83033 L
s
.36395 .84921 m
.35402 .87975 L
s
.36395 .84921 m
.37387 .87975 L
s
.36395 .84921 m
.37387 .87975 L
s
.36395 .84921 m
.37387 .87975 L
s
.30584 .05395 m
.27986 .07283 L
s
.30584 .09171 m
.27986 .07283 L
s
.30584 .09171 m
.29592 .12226 L
s
.30584 .92918 m
.33796 .92918 L
s
.30584 .92918 m
.27986 .9103 L
s
.30584 .92918 m
.29592 .89863 L
s
.30584 .1528 m
.33796 .1528 L
s
.30584 .1528 m
.29592 .12226 L
s
.30584 .09171 m
.27986 .07283 L
s
.30584 .09171 m
.29592 .12226 L
s
.30584 .92918 m
.33796 .92918 L
s
.30584 .92918 m
.27986 .9103 L
s
.30584 .92918 m
.29592 .89863 L
s
.30584 .83033 m
.33796 .83033 L
s
.30584 .83033 m
.29592 .86087 L
s
.33796 .92918 m
.36395 .9103 L
s
.27986 .9103 m
.26993 .87975 L
s
.62 .2822 m
.64598 .30108 L
s
.62 .2822 m
.64598 .26332 L
s
.62 .2822 m
.61007 .25165 L
s
.62 .2822 m
.61007 .31274 L
s
.62 .2822 m
.61007 .25165 L
s
.62 .2822 m
.61007 .25165 L
s
.62 .2822 m
.64598 .26332 L
s
.62 .2822 m
.61007 .31274 L
s
.78817 .2822 m
.82029 .2822 L
s
.78817 .2822 m
.76218 .30108 L
s
.78817 .2822 m
.76218 .26332 L
s
.78817 .2822 m
.76218 .30108 L
s
.78817 .2822 m
.79809 .31274 L
s
.78817 .2822 m
.79809 .25165 L
s
.78817 .2822 m
.79809 .25165 L
s
.78817 .2822 m
.79809 .25165 L
s
.78817 .2822 m
.79809 .31274 L
s
.78817 .2822 m
.82029 .2822 L
s
.78817 .2822 m
.82029 .2822 L
s
.78817 .70093 m
.82029 .70093 L
s
.78817 .70093 m
.76218 .68205 L
s
.78817 .70093 m
.76218 .71981 L
s
.78817 .70093 m
.76218 .68205 L
s
.78817 .70093 m
.79809 .67039 L
s
.78817 .70093 m
.79809 .73148 L
s
.78817 .70093 m
.79809 .73148 L
s
.78817 .70093 m
.79809 .73148 L
s
.78817 .70093 m
.79809 .67039 L
s
.78817 .70093 m
.82029 .70093 L
s
.78817 .70093 m
.82029 .70093 L
s
.82029 .2822 m
.84627 .26332 L
s
.82029 .2822 m
.83021 .31274 L
s
.82029 .2822 m
.83021 .25165 L
s
.82029 .2822 m
.83021 .25165 L
s
.82029 .2822 m
.83021 .31274 L
s
.82029 .2822 m
.84627 .30108 L
s
.82029 .2822 m
.84627 .26332 L
s
.82029 .2822 m
.84627 .30108 L
s
.82029 .2822 m
.83021 .31274 L
s
.82029 .70093 m
.84627 .71981 L
s
.82029 .70093 m
.83021 .67039 L
s
.82029 .70093 m
.83021 .73148 L
s
.82029 .70093 m
.83021 .73148 L
s
.82029 .70093 m
.83021 .67039 L
s
.82029 .70093 m
.84627 .68205 L
s
.82029 .70093 m
.84627 .71981 L
s
.82029 .70093 m
.84627 .68205 L
s
.82029 .70093 m
.83021 .67039 L
s
.84627 .26332 m
.8562 .23277 L
s
.84627 .26332 m
.8562 .23277 L
s
.84627 .26332 m
.8562 .23277 L
s
.84627 .26332 m
.87225 .2822 L
s
.84627 .26332 m
.82029 .2822 L
s
.84627 .26332 m
.82029 .2822 L
s
.84627 .26332 m
.8562 .23277 L
s
.84627 .71981 m
.8562 .75036 L
s
.84627 .71981 m
.8562 .75036 L
s
.84627 .71981 m
.8562 .75036 L
s
.84627 .71981 m
.87225 .70093 L
s
.84627 .71981 m
.82029 .70093 L
s
.84627 .71981 m
.82029 .70093 L
s
.84627 .71981 m
.8562 .75036 L
s
.73007 .30108 m
.76218 .30108 L
s
.73007 .30108 m
.76218 .30108 L
s
.73007 .30108 m
.72014 .33162 L
s
.73007 .30108 m
.70408 .2822 L
s
.73007 .36217 m
.76218 .36217 L
s
.73007 .36217 m
.72014 .39272 L
s
.73007 .36217 m
.76218 .36217 L
s
.73007 .36217 m
.76218 .36217 L
s
.73007 .36217 m
.72014 .33162 L
s
.73007 .36217 m
.76218 .36217 L
s
.73007 .36217 m
.70408 .34329 L
s
.73007 .36217 m
.70408 .34329 L
s
.73007 .36217 m
.70408 .38105 L
s
.73007 .62096 m
.76218 .62096 L
s
.73007 .62096 m
.72014 .59041 L
s
.73007 .62096 m
.76218 .62096 L
s
.73007 .62096 m
.76218 .62096 L
s
.73007 .62096 m
.72014 .65151 L
s
.73007 .62096 m
.76218 .62096 L
s
.73007 .62096 m
.70408 .63984 L
s
.73007 .62096 m
.70408 .60208 L
s
.73007 .62096 m
.70408 .63984 L
s
.73007 .68205 m
.76218 .68205 L
s
.73007 .68205 m
.76218 .68205 L
s
.73007 .68205 m
.72014 .65151 L
s
.73007 .68205 m
.70408 .70093 L
s
.76218 .30108 m
.7362 .2822 L
s
.76218 .30108 m
.77211 .33162 L
s
.76218 .30108 m
.75226 .33162 L
s
.76218 .30108 m
.77211 .33162 L
s
.76218 .30108 m
.7362 .2822 L
s
.76218 .36217 m
.77211 .33162 L
s
.76218 .36217 m
.75226 .39272 L
s
.76218 .36217 m
.78817 .34329 L
s
.76218 .36217 m
.73007 .36217 L
s
.76218 .36217 m
.75226 .33162 L
s
.76218 .36217 m
.77211 .33162 L
s
.76218 .36217 m
.78817 .38105 L
s
.76218 .36217 m
.78817 .34329 L
s
.76218 .36217 m
.78817 .38105 L
s
.76218 .62096 m
.77211 .65151 L
s
.76218 .62096 m
.75226 .59041 L
s
.76218 .62096 m
.78817 .63984 L
s
.76218 .62096 m
.73007 .62096 L
s
.76218 .62096 m
.75226 .65151 L
s
.76218 .62096 m
.77211 .65151 L
s
.76218 .62096 m
.78817 .60208 L
s
.76218 .62096 m
.78817 .60208 L
s
.76218 .62096 m
.78817 .63984 L
s
.76218 .68205 m
.7362 .70093 L
s
.76218 .68205 m
.77211 .65151 L
s
.76218 .68205 m
.75226 .65151 L
s
.76218 .68205 m
.77211 .65151 L
s
.76218 .68205 m
.7362 .70093 L
s
.76218 .26332 m
.7362 .2822 L
s
.76218 .26332 m
.77211 .23277 L
s
.76218 .26332 m
.77211 .23277 L
s
.76218 .26332 m
.7362 .2822 L
s
.76218 .30108 m
.7362 .2822 L
s
.76218 .30108 m
.77211 .33162 L
s
.76218 .30108 m
.75226 .33162 L
s
.76218 .30108 m
.77211 .33162 L
s
.76218 .30108 m
.7362 .2822 L
s
.76218 .71981 m
.7362 .70093 L
s
.76218 .71981 m
.77211 .75036 L
s
.76218 .71981 m
.77211 .75036 L
s
.76218 .71981 m
.7362 .70093 L
s
.76218 .68205 m
.7362 .70093 L
s
.76218 .68205 m
.77211 .65151 L
s
.76218 .68205 m
.75226 .65151 L
s
.76218 .68205 m
.77211 .65151 L
s
.76218 .68205 m
.7362 .70093 L
s
.7362 .2822 m
.70408 .2822 L
s
.7362 .70093 m
.70408 .70093 L
s
.35402 .04229 m
.36395 .07283 L
s
.57795 .1528 m
.61007 .1528 L
s
.57795 .1528 m
.55197 .17168 L
s
.57795 .1528 m
.56803 .18335 L
s
.57795 .1528 m
.55197 .13392 L
s
.57795 .1528 m
.55197 .17168 L
s
.57795 .1528 m
.56803 .12226 L
s
.57795 .1528 m
.61007 .1528 L
s
.57795 .1528 m
.55197 .13392 L
s
.57795 .1528 m
.61007 .1528 L
s
.57795 .1528 m
.55197 .17168 L
s
.57795 .83033 m
.61007 .83033 L
s
.57795 .83033 m
.55197 .81145 L
s
.57795 .83033 m
.56803 .79978 L
s
.57795 .83033 m
.55197 .84921 L
s
.57795 .83033 m
.55197 .81145 L
s
.57795 .83033 m
.56803 .86087 L
s
.57795 .83033 m
.61007 .83033 L
s
.57795 .83033 m
.55197 .84921 L
s
.57795 .83033 m
.61007 .83033 L
s
.57795 .83033 m
.55197 .81145 L
s
.61007 .1528 m
.60015 .18335 L
s
.61007 .1528 m
.57795 .1528 L
s
.61007 .1528 m
.60015 .12226 L
s
.61007 .1528 m
.57795 .1528 L
s
.61007 .1528 m
.63605 .17168 L
s
.61007 .1528 m
.60015 .18335 L
s
.61007 .1528 m
.63605 .17168 L
s
.61007 .2139 m
.58409 .23277 L
s
.61007 .2139 m
.60015 .18335 L
s
.61007 .2139 m
.63605 .23277 L
s
.61007 .2139 m
.58409 .23277 L
s
.61007 .2139 m
.60015 .18335 L
s
.61007 .76923 m
.58409 .75036 L
s
.61007 .76923 m
.60015 .79978 L
s
.61007 .76923 m
.63605 .75036 L
s
.61007 .76923 m
.58409 .75036 L
s
.61007 .76923 m
.60015 .79978 L
s
.61007 .83033 m
.60015 .79978 L
s
.61007 .83033 m
.57795 .83033 L
s
.61007 .83033 m
.60015 .86087 L
s
.61007 .83033 m
.57795 .83033 L
s
.61007 .83033 m
.63605 .81145 L
s
.61007 .83033 m
.60015 .79978 L
s
.61007 .83033 m
.63605 .81145 L
s
.55197 .17168 m
.54204 .20223 L
s
.55197 .17168 m
.57795 .1528 L
s
.55197 .17168 m
.52598 .1528 L
s
.55197 .17168 m
.57795 .1528 L
s
.55197 .17168 m
.52598 .1528 L
s
.55197 .17168 m
.54204 .20223 L
s
.55197 .17168 m
.52598 .1528 L
s
.55197 .33162 m
.52598 .31274 L
s
.55197 .33162 m
.54204 .36217 L
s
.55197 .33162 m
.58409 .33162 L
s
.55197 .33162 m
.52598 .31274 L
s
.55197 .33162 m
.54204 .30108 L
s
.55197 .33162 m
.57795 .31274 L
s
.55197 .33162 m
.57795 .31274 L
s
.55197 .33162 m
.58409 .33162 L
s
.55197 .33162 m
.54204 .30108 L
s
.55197 .65151 m
.52598 .67039 L
s
.55197 .65151 m
.54204 .62096 L
s
.55197 .65151 m
.58409 .65151 L
s
.55197 .65151 m
.52598 .67039 L
s
.55197 .65151 m
.54204 .68205 L
s
.55197 .65151 m
.57795 .67039 L
s
.55197 .65151 m
.57795 .67039 L
s
.55197 .65151 m
.58409 .65151 L
s
.55197 .65151 m
.54204 .68205 L
s
.55197 .81145 m
.54204 .7809 L
s
.55197 .81145 m
.57795 .83033 L
s
.55197 .81145 m
.52598 .83033 L
s
.55197 .81145 m
.57795 .83033 L
s
.55197 .81145 m
.52598 .83033 L
s
.55197 .81145 m
.54204 .7809 L
s
.55197 .81145 m
.52598 .83033 L
s
.58409 .23277 m
.57416 .20223 L
s
.58409 .23277 m
.61007 .25165 L
s
.58409 .23277 m
.61007 .25165 L
s
.58409 .23277 m
.61007 .2139 L
s
.58409 .23277 m
.61007 .25165 L
s
.58409 .23277 m
.55197 .23277 L
s
.58409 .23277 m
.55197 .23277 L
s
.58409 .23277 m
.57416 .20223 L
s
.58409 .75036 m
.57416 .7809 L
s
.58409 .75036 m
.61007 .73148 L
s
.58409 .75036 m
.61007 .73148 L
s
.58409 .75036 m
.61007 .73148 L
s
.58409 .75036 m
.61007 .76923 L
s
.58409 .75036 m
.55197 .75036 L
s
.58409 .75036 m
.55197 .75036 L
s
.58409 .75036 m
.57416 .7809 L
s
.52598 .31274 m
.51606 .2822 L
s
.52598 .31274 m
.51606 .34329 L
s
.52598 .31274 m
.55197 .33162 L
s
.52598 .31274 m
.51606 .2822 L
s
.52598 .31274 m
.51606 .2822 L
s
.52598 .31274 m
.51606 .34329 L
s
.52598 .31274 m
.55197 .33162 L
s
.52598 .31274 m
.55197 .33162 L
s
.52598 .31274 m
.51606 .2822 L
s
.52598 .31274 m
.51606 .2822 L
s
.52598 .67039 m
.51606 .70093 L
s
.52598 .67039 m
.51606 .63984 L
s
.52598 .67039 m
.55197 .65151 L
s
.52598 .67039 m
.51606 .70093 L
s
.52598 .67039 m
.51606 .63984 L
s
.52598 .67039 m
.51606 .70093 L
s
.52598 .67039 m
.55197 .65151 L
s
.52598 .67039 m
.55197 .65151 L
s
.52598 .67039 m
.51606 .70093 L
s
.52598 .67039 m
.51606 .70093 L
s
.3219 .10338 m
.35402 .10338 L
s
.3219 .10338 m
.29592 .12226 L
s
.3219 .87975 m
.35402 .87975 L
s
.3219 .87975 m
.29592 .86087 L
s
.3219 .87975 m
.29592 .89863 L
s
.35402 .10338 m
.36395 .07283 L
s
.35402 .87975 m
.36395 .9103 L
s
.29592 .86087 m
.26993 .87975 L
s
.29592 .89863 m
.26993 .87975 L
s
.39985 .18335 m
.43197 .18335 L
s
.39985 .18335 m
.42584 .20223 L
s
.39985 .18335 m
.43197 .18335 L
s
.39985 .18335 m
.37387 .20223 L
s
.39985 .18335 m
.37387 .20223 L
s
.39985 .18335 m
.42584 .20223 L
s
.39985 .79978 m
.43197 .79978 L
s
.39985 .79978 m
.42584 .7809 L
s
.39985 .79978 m
.43197 .79978 L
s
.39985 .79978 m
.37387 .7809 L
s
.39985 .79978 m
.37387 .7809 L
s
.39985 .79978 m
.42584 .7809 L
s
.43197 .18335 m
.45796 .20223 L
s
.43197 .18335 m
.39985 .18335 L
s
.43197 .18335 m
.39985 .18335 L
s
.43197 .18335 m
.39985 .18335 L
s
.43197 .18335 m
.45796 .20223 L
s
.43197 .18335 m
.45796 .20223 L
s
.43197 .18335 m
.42205 .1528 L
s
.43197 .18335 m
.42205 .1528 L
s
.43197 .18335 m
.45796 .20223 L
s
.43197 .18335 m
.45796 .20223 L
s
.43197 .79978 m
.45796 .7809 L
s
.43197 .79978 m
.39985 .79978 L
s
.43197 .79978 m
.39985 .79978 L
s
.43197 .79978 m
.39985 .79978 L
s
.43197 .79978 m
.45796 .7809 L
s
.43197 .79978 m
.45796 .7809 L
s
.43197 .79978 m
.42205 .83033 L
s
.43197 .79978 m
.42205 .83033 L
s
.43197 .79978 m
.45796 .7809 L
s
.43197 .79978 m
.45796 .7809 L
s
.56803 .18335 m
.60015 .18335 L
s
.56803 .18335 m
.54204 .20223 L
s
.56803 .18335 m
.57795 .1528 L
s
.56803 .18335 m
.57795 .1528 L
s
.56803 .18335 m
.60015 .18335 L
s
.56803 .18335 m
.54204 .20223 L
s
.56803 .79978 m
.60015 .79978 L
s
.56803 .79978 m
.54204 .7809 L
s
.56803 .79978 m
.57795 .83033 L
s
.56803 .79978 m
.57795 .83033 L
s
.56803 .79978 m
.60015 .79978 L
s
.56803 .79978 m
.54204 .7809 L
s
.60015 .18335 m
.57416 .20223 L
s
.60015 .18335 m
.61007 .1528 L
s
.60015 .18335 m
.61007 .1528 L
s
.60015 .18335 m
.61007 .2139 L
s
.60015 .18335 m
.62613 .20223 L
s
.60015 .18335 m
.57416 .20223 L
s
.60015 .79978 m
.57416 .7809 L
s
.60015 .79978 m
.61007 .83033 L
s
.60015 .79978 m
.61007 .76923 L
s
.60015 .79978 m
.61007 .83033 L
s
.60015 .79978 m
.62613 .7809 L
s
.60015 .79978 m
.57416 .7809 L
s
.54204 .20223 m
.57416 .20223 L
s
.54204 .20223 m
.51606 .22111 L
s
.54204 .20223 m
.51606 .22111 L
s
.54204 .20223 m
.55197 .17168 L
s
.54204 .20223 m
.55197 .23277 L
s
.54204 .20223 m
.55197 .17168 L
s
.54204 .20223 m
.55197 .23277 L
s
.54204 .20223 m
.57416 .20223 L
s
.54204 .20223 m
.51606 .18335 L
s
.54204 .20223 m
.51606 .18335 L
s
.54204 .20223 m
.51606 .22111 L
s
.54204 .20223 m
.51606 .18335 L
s
.54204 .7809 m
.57416 .7809 L
s
.54204 .7809 m
.51606 .76202 L
s
.54204 .7809 m
.51606 .76202 L
s
.54204 .7809 m
.55197 .81145 L
s
.54204 .7809 m
.55197 .75036 L
s
.54204 .7809 m
.55197 .75036 L
s
.54204 .7809 m
.55197 .81145 L
s
.54204 .7809 m
.57416 .7809 L
s
.54204 .7809 m
.51606 .79978 L
s
.54204 .7809 m
.51606 .76202 L
s
.54204 .7809 m
.51606 .79978 L
s
.54204 .7809 m
.51606 .79978 L
s
.57416 .20223 m
.58409 .23277 L
s
.57416 .20223 m
.60015 .18335 L
s
.57416 .20223 m
.54204 .20223 L
s
.57416 .7809 m
.58409 .75036 L
s
.57416 .7809 m
.60015 .79978 L
s
.57416 .7809 m
.54204 .7809 L
s
.48394 .22111 m
.51606 .22111 L
s
.48394 .22111 m
.45796 .20223 L
s
.48394 .22111 m
.51606 .22111 L
s
.48394 .22111 m
.45796 .20223 L
s
.48394 .22111 m
.45796 .20223 L
s
.48394 .22111 m
.45796 .20223 L
s
.48394 .22111 m
.51606 .22111 L
s
.48394 .22111 m
.45796 .20223 L
s
.48394 .76202 m
.51606 .76202 L
s
.48394 .76202 m
.45796 .7809 L
s
.48394 .76202 m
.51606 .76202 L
s
.48394 .76202 m
.45796 .7809 L
s
.48394 .76202 m
.45796 .7809 L
s
.48394 .76202 m
.45796 .7809 L
s
.48394 .76202 m
.51606 .76202 L
s
.48394 .76202 m
.45796 .7809 L
s
.51606 .22111 m
.49007 .20223 L
s
.51606 .22111 m
.48394 .22111 L
s
.51606 .22111 m
.52598 .25165 L
s
.51606 .22111 m
.52598 .25165 L
s
.51606 .22111 m
.52598 .25165 L
s
.51606 .22111 m
.49007 .20223 L
s
.51606 .22111 m
.54204 .20223 L
s
.51606 .76202 m
.49007 .7809 L
s
.51606 .76202 m
.48394 .76202 L
s
.51606 .76202 m
.52598 .73148 L
s
.51606 .76202 m
.52598 .73148 L
s
.51606 .76202 m
.52598 .73148 L
s
.51606 .76202 m
.49007 .7809 L
s
.51606 .76202 m
.54204 .7809 L
s
.42584 .20223 m
.45796 .20223 L
s
.42584 .20223 m
.39985 .18335 L
s
.42584 .20223 m
.39985 .18335 L
s
.42584 .20223 m
.39985 .18335 L
s
.42584 .20223 m
.45796 .20223 L
s
.42584 .20223 m
.45796 .20223 L
s
.42584 .20223 m
.45796 .20223 L
s
.42584 .20223 m
.45796 .20223 L
s
.42584 .7809 m
.45796 .7809 L
s
.42584 .7809 m
.39985 .79978 L
s
.42584 .7809 m
.39985 .79978 L
s
.42584 .7809 m
.39985 .79978 L
s
.42584 .7809 m
.45796 .7809 L
s
.42584 .7809 m
.45796 .7809 L
s
.42584 .7809 m
.45796 .7809 L
s
.42584 .7809 m
.45796 .7809 L
s
.45796 .20223 m
.49007 .20223 L
s
.45796 .20223 m
.43197 .18335 L
s
.45796 .20223 m
.48394 .22111 L
s
.45796 .20223 m
.42584 .20223 L
s
.45796 .20223 m
.44803 .17168 L
s
.45796 .20223 m
.49007 .20223 L
s
.45796 .20223 m
.48394 .18335 L
s
.45796 .20223 m
.48394 .18335 L
s
.45796 .7809 m
.49007 .7809 L
s
.45796 .7809 m
.43197 .79978 L
s
.45796 .7809 m
.48394 .76202 L
s
.45796 .7809 m
.42584 .7809 L
s
.45796 .7809 m
.44803 .81145 L
s
.45796 .7809 m
.49007 .7809 L
s
.45796 .7809 m
.48394 .79978 L
s
.45796 .7809 m
.48394 .79978 L
s
.49007 .20223 m
.51606 .22111 L
s
.49007 .20223 m
.45796 .20223 L
s
.49007 .20223 m
.45796 .20223 L
s
.49007 .20223 m
.45796 .20223 L
s
.49007 .20223 m
.51606 .18335 L
s
.49007 .20223 m
.51606 .18335 L
s
.49007 .20223 m
.51606 .22111 L
s
.49007 .20223 m
.45796 .20223 L
s
.49007 .20223 m
.51606 .18335 L
s
.49007 .7809 m
.51606 .76202 L
s
.49007 .7809 m
.45796 .7809 L
s
.49007 .7809 m
.45796 .7809 L
s
.49007 .7809 m
.45796 .7809 L
s
.49007 .7809 m
.51606 .79978 L
s
.49007 .7809 m
.51606 .76202 L
s
.49007 .7809 m
.51606 .79978 L
s
.49007 .7809 m
.45796 .7809 L
s
.49007 .7809 m
.51606 .79978 L
s
.37387 .10338 m
.39985 .12226 L
s
.37387 .10338 m
.39985 .12226 L
s
.37387 .10338 m
.36395 .07283 L
s
.37387 .10338 m
.39985 .12226 L
s
.37387 .10338 m
.39985 .12226 L
s
.37387 .87975 m
.39985 .86087 L
s
.37387 .87975 m
.39985 .86087 L
s
.37387 .87975 m
.36395 .9103 L
s
.37387 .87975 m
.39985 .86087 L
s
.37387 .87975 m
.39985 .86087 L
s
.56803 .44214 m
.60015 .44214 L
s
.56803 .44214 m
.54204 .46102 L
s
.56803 .44214 m
.57795 .41159 L
s
.56803 .44214 m
.57795 .41159 L
s
.56803 .44214 m
.60015 .44214 L
s
.56803 .54099 m
.60015 .54099 L
s
.56803 .54099 m
.54204 .52211 L
s
.56803 .54099 m
.54204 .55987 L
s
.56803 .54099 m
.57795 .51044 L
s
.56803 .54099 m
.57795 .57154 L
s
.60015 .44214 m
.57416 .46102 L
s
.60015 .44214 m
.61007 .47269 L
s
.60015 .44214 m
.61007 .41159 L
s
.60015 .44214 m
.61007 .41159 L
s
.60015 .44214 m
.62613 .46102 L
s
.60015 .44214 m
.61007 .47269 L
s
.60015 .44214 m
.61007 .41159 L
s
.60015 .44214 m
.61007 .41159 L
s
.60015 .44214 m
.61007 .41159 L
s
.60015 .54099 m
.61007 .51044 L
s
.60015 .54099 m
.61007 .57154 L
s
.60015 .54099 m
.61007 .57154 L
s
.60015 .54099 m
.61007 .51044 L
s
.60015 .54099 m
.61007 .57154 L
s
.60015 .54099 m
.61007 .57154 L
s
.60015 .54099 m
.61007 .57154 L
s
.39985 .12226 m
.43197 .12226 L
s
.39985 .12226 m
.37387 .10338 L
s
.39985 .12226 m
.37387 .10338 L
s
.39985 .12226 m
.38993 .09171 L
s
.39985 .12226 m
.42584 .10338 L
s
.39985 .12226 m
.43197 .12226 L
s
.39985 .12226 m
.42584 .10338 L
s
.39985 .12226 m
.43197 .12226 L
s
.39985 .18335 m
.43197 .18335 L
s
.39985 .18335 m
.37387 .20223 L
s
.39985 .18335 m
.37387 .20223 L
s
.39985 .18335 m
.42584 .20223 L
s
.39985 .79978 m
.43197 .79978 L
s
.39985 .79978 m
.37387 .7809 L
s
.39985 .79978 m
.37387 .7809 L
s
.39985 .79978 m
.42584 .7809 L
s
.39985 .86087 m
.43197 .86087 L
s
.39985 .86087 m
.37387 .87975 L
s
.39985 .86087 m
.37387 .87975 L
s
.39985 .86087 m
.38993 .89142 L
s
.39985 .86087 m
.42584 .87975 L
s
.39985 .86087 m
.43197 .86087 L
s
.39985 .86087 m
.42584 .87975 L
s
.39985 .86087 m
.43197 .86087 L
s
.39985 .12226 m
.43197 .12226 L
s
.39985 .12226 m
.37387 .10338 L
s
.39985 .12226 m
.37387 .10338 L
s
.39985 .12226 m
.38993 .09171 L
s
.39985 .12226 m
.42584 .10338 L
s
.39985 .12226 m
.43197 .12226 L
s
.39985 .12226 m
.42584 .10338 L
s
.39985 .12226 m
.43197 .12226 L
s
.39985 .18335 m
.43197 .18335 L
s
.39985 .18335 m
.37387 .20223 L
s
.39985 .18335 m
.37387 .20223 L
s
.39985 .18335 m
.42584 .20223 L
s
.39985 .79978 m
.43197 .79978 L
s
.39985 .79978 m
.37387 .7809 L
s
.39985 .79978 m
.37387 .7809 L
s
.39985 .79978 m
.42584 .7809 L
s
.39985 .86087 m
.43197 .86087 L
s
.39985 .86087 m
.37387 .87975 L
s
.39985 .86087 m
.37387 .87975 L
s
.39985 .86087 m
.38993 .89142 L
s
.39985 .86087 m
.42584 .87975 L
s
.39985 .86087 m
.43197 .86087 L
s
.39985 .86087 m
.42584 .87975 L
s
.39985 .86087 m
.43197 .86087 L
s
.39985 .18335 m
.43197 .18335 L
s
.39985 .18335 m
.37387 .20223 L
s
.39985 .18335 m
.37387 .20223 L
s
.39985 .18335 m
.42584 .20223 L
s
.39985 .79978 m
.43197 .79978 L
s
.39985 .79978 m
.37387 .7809 L
s
.39985 .79978 m
.37387 .7809 L
s
.39985 .79978 m
.42584 .7809 L
s
.43197 .02341 m
.42205 .05395 L
s
.43197 .02341 m
.42205 .05395 L
s
.43197 .02341 m
.45796 .04229 L
s
.43197 .02341 m
.39985 .02341 L
s
.43197 .2822 m
.45796 .26332 L
s
.43197 .2822 m
.45796 .30108 L
s
.43197 .2822 m
.45796 .26332 L
s
.43197 .2822 m
.45796 .30108 L
s
.43197 .70093 m
.45796 .71981 L
s
.43197 .70093 m
.45796 .68205 L
s
.43197 .70093 m
.45796 .71981 L
s
.43197 .70093 m
.45796 .68205 L
s
.43197 .95972 m
.42205 .92918 L
s
.43197 .95972 m
.42205 .92918 L
s
.43197 .95972 m
.45796 .94084 L
s
.43197 .95972 m
.39985 .95972 L
s
.43197 .12226 m
.42205 .1528 L
s
.43197 .12226 m
.42205 .1528 L
s
.43197 .12226 m
.45796 .10338 L
s
.43197 .12226 m
.45796 .10338 L
s
.43197 .12226 m
.45796 .10338 L
s
.43197 .12226 m
.39985 .12226 L
s
.43197 .12226 m
.45796 .10338 L
s
.43197 .12226 m
.45796 .10338 L
s
.43197 .12226 m
.39985 .12226 L
s
.43197 .18335 m
.45796 .20223 L
s
.43197 .18335 m
.45796 .20223 L
s
.43197 .18335 m
.42205 .1528 L
s
.43197 .18335 m
.42205 .1528 L
s
.43197 .18335 m
.45796 .20223 L
s
.43197 .18335 m
.45796 .20223 L
s
.43197 .79978 m
.45796 .7809 L
s
.43197 .79978 m
.45796 .7809 L
s
.43197 .79978 m
.42205 .83033 L
s
.43197 .79978 m
.42205 .83033 L
s
.43197 .79978 m
.45796 .7809 L
s
.43197 .79978 m
.45796 .7809 L
s
.43197 .86087 m
.42205 .83033 L
s
.43197 .86087 m
.42205 .83033 L
s
.43197 .86087 m
.45796 .87975 L
s
.43197 .86087 m
.45796 .87975 L
s
.43197 .86087 m
.45796 .87975 L
s
.43197 .86087 m
.39985 .86087 L
s
.43197 .86087 m
.45796 .87975 L
s
.43197 .86087 m
.45796 .87975 L
s
.43197 .86087 m
.39985 .86087 L
s
.54204 .46102 m
.57416 .46102 L
s
.54204 .46102 m
.55197 .49156 L
s
.54204 .46102 m
.55197 .43047 L
s
.54204 .52211 m
.51606 .54099 L
s
.54204 .52211 m
.55197 .49156 L
s
.54204 .55987 m
.51606 .54099 L
s
.54204 .55987 m
.55197 .59041 L
s
.54204 .55987 m
.55197 .59041 L
s
.57416 .46102 m
.58409 .49156 L
s
.57416 .46102 m
.60015 .44214 L
s
.57416 .46102 m
.58409 .49156 L
s
.37387 .10338 m
.36395 .07283 L
s
.37387 .10338 m
.39985 .12226 L
s
.37387 .10338 m
.39985 .12226 L
s
.37387 .87975 m
.36395 .9103 L
s
.37387 .87975 m
.39985 .86087 L
s
.37387 .87975 m
.39985 .86087 L
s
.37387 .10338 m
.36395 .07283 L
s
.37387 .10338 m
.39985 .12226 L
s
.37387 .10338 m
.39985 .12226 L
s
.37387 .87975 m
.36395 .9103 L
s
.37387 .87975 m
.39985 .86087 L
s
.37387 .87975 m
.39985 .86087 L
s
.48394 .22111 m
.51606 .22111 L
s
.48394 .22111 m
.45796 .20223 L
s
.48394 .22111 m
.45796 .20223 L
s
.48394 .22111 m
.45796 .20223 L
s
.48394 .22111 m
.51606 .22111 L
s
.48394 .22111 m
.45796 .20223 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .2822 m
.45796 .26332 L
s
.48394 .2822 m
.47402 .31274 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .2822 m
.45796 .30108 L
s
.48394 .2822 m
.45796 .26332 L
s
.48394 .2822 m
.45796 .30108 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .70093 m
.45796 .71981 L
s
.48394 .70093 m
.47402 .67039 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .70093 m
.45796 .68205 L
s
.48394 .70093 m
.45796 .71981 L
s
.48394 .70093 m
.45796 .68205 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .76202 m
.51606 .76202 L
s
.48394 .76202 m
.45796 .7809 L
s
.48394 .76202 m
.45796 .7809 L
s
.48394 .76202 m
.45796 .7809 L
s
.48394 .76202 m
.51606 .76202 L
s
.48394 .76202 m
.45796 .7809 L
s
.51606 .22111 m
.52598 .25165 L
s
.51606 .22111 m
.52598 .25165 L
s
.51606 .22111 m
.52598 .25165 L
s
.51606 .22111 m
.49007 .20223 L
s
.51606 .22111 m
.54204 .20223 L
s
.51606 .2822 m
.52598 .25165 L
s
.51606 .2822 m
.50613 .31274 L
s
.51606 .2822 m
.52598 .31274 L
s
.51606 .2822 m
.54204 .30108 L
s
.51606 .2822 m
.48394 .2822 L
s
.51606 .2822 m
.48394 .2822 L
s
.51606 .2822 m
.52598 .25165 L
s
.51606 .2822 m
.52598 .25165 L
s
.51606 .2822 m
.54204 .30108 L
s
.51606 .2822 m
.54204 .26332 L
s
.51606 .54099 m
.52598 .57154 L
s
.51606 .54099 m
.52598 .57154 L
s
.51606 .70093 m
.52598 .73148 L
s
.51606 .70093 m
.50613 .67039 L
s
.51606 .70093 m
.52598 .67039 L
s
.51606 .70093 m
.54204 .68205 L
s
.51606 .70093 m
.48394 .70093 L
s
.51606 .70093 m
.48394 .70093 L
s
.51606 .70093 m
.52598 .73148 L
s
.51606 .70093 m
.52598 .73148 L
s
.51606 .70093 m
.54204 .68205 L
s
.51606 .70093 m
.54204 .71981 L
s
.51606 .76202 m
.52598 .73148 L
s
.51606 .76202 m
.52598 .73148 L
s
.51606 .76202 m
.52598 .73148 L
s
.51606 .76202 m
.49007 .7809 L
s
.51606 .76202 m
.54204 .7809 L
s
.42584 .20223 m
.45796 .20223 L
s
.42584 .20223 m
.45796 .20223 L
s
.42584 .20223 m
.45796 .20223 L
s
.42584 .20223 m
.45796 .20223 L
s
.42584 .7809 m
.45796 .7809 L
s
.42584 .7809 m
.45796 .7809 L
s
.42584 .7809 m
.45796 .7809 L
s
.42584 .7809 m
.45796 .7809 L
s
.45796 .20223 m
.44803 .17168 L
s
.45796 .20223 m
.49007 .20223 L
s
.45796 .20223 m
.48394 .18335 L
s
.45796 .20223 m
.48394 .18335 L
s
.45796 .26332 m
.43197 .2822 L
s
.45796 .26332 m
.48394 .2822 L
s
.45796 .26332 m
.48394 .2822 L
s
.45796 .71981 m
.43197 .70093 L
s
.45796 .71981 m
.48394 .70093 L
s
.45796 .71981 m
.48394 .70093 L
s
.45796 .7809 m
.44803 .81145 L
s
.45796 .7809 m
.49007 .7809 L
s
.45796 .7809 m
.48394 .79978 L
s
.45796 .7809 m
.48394 .79978 L
s
.45796 .20223 m
.44803 .17168 L
s
.45796 .20223 m
.49007 .20223 L
s
.45796 .20223 m
.48394 .18335 L
s
.45796 .20223 m
.48394 .18335 L
s
.45796 .7809 m
.44803 .81145 L
s
.45796 .7809 m
.49007 .7809 L
s
.45796 .7809 m
.48394 .79978 L
s
.45796 .7809 m
.48394 .79978 L
s
.79809 .31274 m
.83021 .31274 L
s
.79809 .31274 m
.77211 .33162 L
s
.79809 .31274 m
.78817 .34329 L
s
.79809 .31274 m
.77211 .33162 L
s
.79809 .31274 m
.82408 .33162 L
s
.79809 .31274 m
.83021 .31274 L
s
.79809 .31274 m
.83021 .31274 L
s
.79809 .31274 m
.78817 .34329 L
s
.79809 .25165 m
.83021 .25165 L
s
.79809 .25165 m
.77211 .23277 L
s
.79809 .25165 m
.83021 .25165 L
s
.79809 .25165 m
.82408 .23277 L
s
.79809 .25165 m
.78817 .22111 L
s
.79809 .25165 m
.82408 .23277 L
s
.79809 .25165 m
.77211 .23277 L
s
.79809 .67039 m
.83021 .67039 L
s
.79809 .67039 m
.77211 .65151 L
s
.79809 .67039 m
.78817 .63984 L
s
.79809 .67039 m
.77211 .65151 L
s
.79809 .67039 m
.82408 .65151 L
s
.79809 .67039 m
.83021 .67039 L
s
.79809 .67039 m
.83021 .67039 L
s
.79809 .67039 m
.78817 .63984 L
s
.79809 .73148 m
.83021 .73148 L
s
.79809 .73148 m
.77211 .75036 L
s
.79809 .73148 m
.83021 .73148 L
s
.79809 .73148 m
.82408 .75036 L
s
.79809 .73148 m
.78817 .76202 L
s
.79809 .73148 m
.82408 .75036 L
s
.79809 .73148 m
.77211 .75036 L
s
.83021 .31274 m
.8562 .33162 L
s
.83021 .31274 m
.79809 .31274 L
s
.83021 .31274 m
.82029 .2822 L
s
.83021 .31274 m
.82029 .2822 L
s
.83021 .31274 m
.8562 .33162 L
s
.83021 .31274 m
.8562 .33162 L
s
.83021 .25165 m
.8562 .23277 L
s
.83021 .25165 m
.79809 .25165 L
s
.83021 .25165 m
.8562 .23277 L
s
.83021 .25165 m
.79809 .25165 L
s
.83021 .25165 m
.8562 .23277 L
s
.83021 .25165 m
.82029 .2822 L
s
.83021 .25165 m
.82029 .2822 L
s
.83021 .25165 m
.8562 .23277 L
s
.83021 .67039 m
.8562 .65151 L
s
.83021 .67039 m
.79809 .67039 L
s
.83021 .67039 m
.82029 .70093 L
s
.83021 .67039 m
.82029 .70093 L
s
.83021 .67039 m
.8562 .65151 L
s
.83021 .67039 m
.8562 .65151 L
s
.83021 .73148 m
.8562 .75036 L
s
.83021 .73148 m
.79809 .73148 L
s
.83021 .73148 m
.8562 .75036 L
s
.83021 .73148 m
.79809 .73148 L
s
.83021 .73148 m
.8562 .75036 L
s
.83021 .73148 m
.82029 .70093 L
s
.83021 .73148 m
.82029 .70093 L
s
.83021 .73148 m
.8562 .75036 L
s
.8562 .23277 m
.83021 .25165 L
s
.8562 .23277 m
.88218 .2139 L
s
.8562 .23277 m
.82408 .23277 L
s
.8562 .23277 m
.84627 .20223 L
s
.8562 .23277 m
.88218 .2139 L
s
.8562 .23277 m
.82408 .23277 L
s
.8562 .23277 m
.84627 .26332 L
s
.8562 .23277 m
.88218 .25165 L
s
.8562 .23277 m
.88218 .25165 L
s
.8562 .23277 m
.88218 .2139 L
s
.8562 .75036 m
.83021 .73148 L
s
.8562 .75036 m
.88218 .76923 L
s
.8562 .75036 m
.82408 .75036 L
s
.8562 .75036 m
.84627 .7809 L
s
.8562 .75036 m
.88218 .76923 L
s
.8562 .75036 m
.82408 .75036 L
s
.8562 .75036 m
.84627 .71981 L
s
.8562 .75036 m
.88218 .73148 L
s
.8562 .75036 m
.88218 .73148 L
s
.8562 .75036 m
.88218 .76923 L
s
.77211 .33162 m
.76218 .36217 L
s
.77211 .33162 m
.76218 .36217 L
s
.77211 .33162 m
.79809 .31274 L
s
.77211 .33162 m
.76218 .36217 L
s
.77211 .23277 m
.79809 .25165 L
s
.77211 .23277 m
.76218 .20223 L
s
.77211 .23277 m
.76218 .20223 L
s
.77211 .23277 m
.79809 .25165 L
s
.77211 .65151 m
.76218 .62096 L
s
.77211 .65151 m
.76218 .62096 L
s
.77211 .65151 m
.79809 .67039 L
s
.77211 .65151 m
.76218 .62096 L
s
.77211 .75036 m
.79809 .73148 L
s
.77211 .75036 m
.76218 .7809 L
s
.77211 .75036 m
.76218 .7809 L
s
.77211 .75036 m
.79809 .73148 L
s
.57795 .51044 m
.61007 .51044 L
s
.57795 .51044 m
.55197 .49156 L
s
.57795 .51044 m
.61007 .51044 L
s
.57795 .41159 m
.61007 .41159 L
s
.57795 .41159 m
.55197 .43047 L
s
.57795 .41159 m
.55197 .39272 L
s
.57795 .41159 m
.56803 .38105 L
s
.57795 .41159 m
.61007 .41159 L
s
.57795 .41159 m
.55197 .39272 L
s
.57795 .41159 m
.61007 .41159 L
s
.57795 .41159 m
.61007 .41159 L
s
.57795 .41159 m
.61007 .41159 L
s
.57795 .57154 m
.61007 .57154 L
s
.57795 .57154 m
.55197 .59041 L
s
.57795 .57154 m
.61007 .57154 L
s
.57795 .57154 m
.55197 .59041 L
s
.57795 .57154 m
.61007 .57154 L
s
.57795 .57154 m
.61007 .57154 L
s
.57795 .57154 m
.61007 .57154 L
s
.57795 .1528 m
.55197 .13392 L
s
.57795 .1528 m
.55197 .17168 L
s
.57795 .1528 m
.56803 .12226 L
s
.57795 .1528 m
.61007 .1528 L
s
.57795 .1528 m
.55197 .13392 L
s
.57795 .1528 m
.61007 .1528 L
s
.57795 .1528 m
.55197 .17168 L
s
.57795 .83033 m
.55197 .84921 L
s
.57795 .83033 m
.55197 .81145 L
s
.57795 .83033 m
.56803 .86087 L
s
.57795 .83033 m
.61007 .83033 L
s
.57795 .83033 m
.55197 .84921 L
s
.57795 .83033 m
.61007 .83033 L
s
.57795 .83033 m
.55197 .81145 L
s
.61007 .47269 m
.58409 .49156 L
s
.61007 .47269 m
.60015 .44214 L
s
.61007 .47269 m
.63605 .49156 L
s
.61007 .47269 m
.58409 .49156 L
s
.61007 .51044 m
.58409 .49156 L
s
.61007 .51044 m
.62 .54099 L
s
.61007 .51044 m
.63605 .49156 L
s
.61007 .51044 m
.58409 .49156 L
s
.61007 .51044 m
.62 .54099 L
s
.61007 .41159 m
.60015 .38105 L
s
.61007 .41159 m
.57795 .41159 L
s
.61007 .41159 m
.60015 .44214 L
s
.61007 .41159 m
.63605 .43047 L
s
.61007 .41159 m
.63605 .39272 L
s
.61007 .41159 m
.60015 .38105 L
s
.61007 .41159 m
.63605 .39272 L
s
.61007 .41159 m
.63605 .43047 L
s
.61007 .41159 m
.63605 .39272 L
s
.61007 .57154 m
.58409 .59041 L
s
.61007 .57154 m
.60015 .60208 L
s
.61007 .57154 m
.62 .54099 L
s
.61007 .57154 m
.58409 .59041 L
s
.61007 .57154 m
.63605 .55266 L
s
.61007 .57154 m
.63605 .59041 L
s
.61007 .57154 m
.60015 .60208 L
s
.61007 .57154 m
.62 .54099 L
s
.61007 .57154 m
.63605 .59041 L
s
.61007 .57154 m
.63605 .55266 L
s
.61007 .57154 m
.63605 .59041 L
s
.72014 .39272 m
.75226 .39272 L
s
.72014 .39272 m
.73007 .36217 L
s
.72014 .39272 m
.69416 .41159 L
s
.72014 .59041 m
.75226 .59041 L
s
.72014 .59041 m
.73007 .55987 L
s
.72014 .59041 m
.73007 .62096 L
s
.72014 .59041 m
.69416 .57154 L
s
.75226 .39272 m
.76218 .36217 L
s
.75226 .39272 m
.76218 .42326 L
s
.75226 .39272 m
.76218 .36217 L
s
.75226 .39272 m
.77824 .41159 L
s
.75226 .39272 m
.76218 .36217 L
s
.75226 .39272 m
.72627 .41159 L
s
.75226 .59041 m
.76218 .55987 L
s
.75226 .59041 m
.76218 .62096 L
s
.75226 .59041 m
.76218 .62096 L
s
.75226 .59041 m
.76218 .62096 L
s
.55197 .49156 m
.58409 .49156 L
s
.55197 .49156 m
.58409 .49156 L
s
.55197 .43047 m
.52598 .41159 L
s
.55197 .43047 m
.57795 .41159 L
s
.55197 .43047 m
.52598 .41159 L
s
.55197 .39272 m
.52598 .41159 L
s
.55197 .39272 m
.54204 .36217 L
s
.55197 .39272 m
.57795 .41159 L
s
.55197 .39272 m
.52598 .41159 L
s
.55197 .59041 m
.58409 .59041 L
s
.55197 .59041 m
.52598 .57154 L
s
.55197 .59041 m
.54204 .62096 L
s
.55197 .59041 m
.58409 .59041 L
s
.55197 .59041 m
.52598 .57154 L
s
.55197 .13392 m
.52598 .1528 L
s
.55197 .13392 m
.54204 .10338 L
s
.55197 .13392 m
.57795 .1528 L
s
.55197 .13392 m
.52598 .1528 L
s
.55197 .13392 m
.52598 .1528 L
s
.55197 .17168 m
.52598 .1528 L
s
.55197 .17168 m
.57795 .1528 L
s
.55197 .17168 m
.52598 .1528 L
s
.55197 .17168 m
.54204 .20223 L
s
.55197 .17168 m
.52598 .1528 L
s
.55197 .84921 m
.52598 .83033 L
s
.55197 .84921 m
.54204 .87975 L
s
.55197 .84921 m
.57795 .83033 L
s
.55197 .84921 m
.52598 .83033 L
s
.55197 .84921 m
.52598 .83033 L
s
.55197 .81145 m
.52598 .83033 L
s
.55197 .81145 m
.57795 .83033 L
s
.55197 .81145 m
.52598 .83033 L
s
.55197 .81145 m
.54204 .7809 L
s
.55197 .81145 m
.52598 .83033 L
s
.58409 .49156 m
.61007 .47269 L
s
.58409 .49156 m
.61007 .51044 L
s
.58409 .59041 m
.57416 .62096 L
s
.58409 .59041 m
.61007 .57154 L
s
.58409 .59041 m
.55197 .59041 L
s
.58409 .59041 m
.61007 .57154 L
s
.58409 .59041 m
.57416 .62096 L
s
.58409 .59041 m
.61007 .57154 L
s
.58409 .59041 m
.61007 .57154 L
s
.52598 .25165 m
.51606 .2822 L
s
.52598 .25165 m
.51606 .2822 L
s
.52598 .25165 m
.55197 .23277 L
s
.52598 .25165 m
.55197 .23277 L
s
.52598 .25165 m
.51606 .22111 L
s
.52598 .25165 m
.51606 .2822 L
s
.52598 .25165 m
.51606 .2822 L
s
.52598 .41159 m
.51606 .38105 L
s
.52598 .41159 m
.55197 .39272 L
s
.52598 .57154 m
.51606 .60208 L
s
.52598 .57154 m
.55197 .59041 L
s
.52598 .73148 m
.51606 .70093 L
s
.52598 .73148 m
.51606 .70093 L
s
.52598 .73148 m
.55197 .75036 L
s
.52598 .73148 m
.55197 .75036 L
s
.52598 .73148 m
.51606 .76202 L
s
.52598 .73148 m
.51606 .70093 L
s
.52598 .73148 m
.51606 .70093 L
s
.52598 .1528 m
.55197 .13392 L
s
.52598 .1528 m
.55197 .17168 L
s
.52598 .1528 m
.51606 .18335 L
s
.52598 .1528 m
.51606 .18335 L
s
.52598 .1528 m
.51606 .12226 L
s
.52598 .1528 m
.51606 .18335 L
s
.52598 .1528 m
.51606 .12226 L
s
.52598 .83033 m
.55197 .84921 L
s
.52598 .83033 m
.55197 .81145 L
s
.52598 .83033 m
.51606 .79978 L
s
.52598 .83033 m
.51606 .79978 L
s
.52598 .83033 m
.51606 .79978 L
s
.52598 .83033 m
.51606 .86087 L
s
.52598 .83033 m
.51606 .86087 L
s
.56803 .38105 m
.60015 .38105 L
s
.56803 .38105 m
.54204 .36217 L
s
.56803 .38105 m
.57795 .41159 L
s
.56803 .38105 m
.60015 .38105 L
s
.60015 .38105 m
.57416 .36217 L
s
.60015 .38105 m
.61007 .41159 L
s
.60015 .38105 m
.61007 .3505 L
s
.60015 .38105 m
.61007 .41159 L
s
.60015 .38105 m
.62613 .36217 L
s
.60015 .38105 m
.61007 .41159 L
s
.60015 .38105 m
.61007 .3505 L
s
.60015 .38105 m
.61007 .41159 L
s
.60015 .60208 m
.57416 .62096 L
s
.60015 .60208 m
.61007 .57154 L
s
.60015 .60208 m
.61007 .57154 L
s
.60015 .60208 m
.62613 .62096 L
s
.60015 .60208 m
.57416 .62096 L
s
.60015 .60208 m
.61007 .57154 L
s
.60015 .60208 m
.61007 .57154 L
s
.54204 .36217 m
.57416 .36217 L
s
.54204 .36217 m
.51606 .34329 L
s
.54204 .36217 m
.51606 .38105 L
s
.54204 .36217 m
.55197 .39272 L
s
.54204 .36217 m
.55197 .33162 L
s
.54204 .36217 m
.51606 .34329 L
s
.54204 .36217 m
.55197 .33162 L
s
.54204 .36217 m
.55197 .33162 L
s
.54204 .62096 m
.57416 .62096 L
s
.54204 .62096 m
.51606 .60208 L
s
.54204 .62096 m
.51606 .63984 L
s
.54204 .62096 m
.55197 .59041 L
s
.54204 .62096 m
.55197 .65151 L
s
.54204 .62096 m
.51606 .63984 L
s
.54204 .62096 m
.55197 .65151 L
s
.54204 .62096 m
.57416 .62096 L
s
.54204 .62096 m
.55197 .65151 L
s
.57416 .36217 m
.58409 .33162 L
s
.57416 .36217 m
.60015 .38105 L
s
.57416 .36217 m
.58409 .33162 L
s
.57416 .62096 m
.58409 .59041 L
s
.57416 .62096 m
.58409 .65151 L
s
.57416 .62096 m
.60015 .60208 L
s
.57416 .62096 m
.60015 .63984 L
s
.57416 .62096 m
.58409 .65151 L
s
.48394 .34329 m
.51606 .34329 L
s
.48394 .34329 m
.45796 .36217 L
s
.48394 .34329 m
.47402 .31274 L
s
.48394 .34329 m
.51606 .34329 L
s
.48394 .34329 m
.45796 .36217 L
s
.48394 .63984 m
.51606 .63984 L
s
.48394 .63984 m
.45796 .62096 L
s
.48394 .63984 m
.47402 .67039 L
s
.48394 .63984 m
.51606 .63984 L
s
.48394 .63984 m
.45796 .62096 L
s
.51606 .34329 m
.49007 .36217 L
s
.51606 .34329 m
.50613 .31274 L
s
.51606 .34329 m
.52598 .31274 L
s
.51606 .34329 m
.48394 .34329 L
s
.51606 .38105 m
.49007 .36217 L
s
.51606 .38105 m
.52598 .41159 L
s
.51606 .60208 m
.49007 .62096 L
s
.51606 .60208 m
.52598 .57154 L
s
.51606 .63984 m
.49007 .62096 L
s
.51606 .63984 m
.50613 .67039 L
s
.51606 .63984 m
.52598 .67039 L
s
.51606 .63984 m
.48394 .63984 L
s
.45796 .36217 m
.49007 .36217 L
s
.45796 .36217 m
.44803 .33162 L
s
.45796 .36217 m
.48394 .34329 L
s
.45796 .62096 m
.49007 .62096 L
s
.45796 .62096 m
.44803 .65151 L
s
.45796 .62096 m
.48394 .63984 L
s
.49007 .36217 m
.51606 .34329 L
s
.49007 .36217 m
.45796 .36217 L
s
.49007 .62096 m
.51606 .63984 L
s
.49007 .62096 m
.45796 .62096 L
s
.47402 .31274 m
.50613 .31274 L
s
.47402 .31274 m
.44803 .33162 L
s
.47402 .31274 m
.48394 .2822 L
s
.47402 .31274 m
.48394 .2822 L
s
.47402 .31274 m
.48394 .34329 L
s
.47402 .67039 m
.50613 .67039 L
s
.47402 .67039 m
.44803 .65151 L
s
.47402 .67039 m
.48394 .70093 L
s
.47402 .67039 m
.48394 .63984 L
s
.47402 .67039 m
.48394 .70093 L
s
.50613 .31274 m
.51606 .2822 L
s
.50613 .31274 m
.51606 .2822 L
s
.50613 .31274 m
.51606 .34329 L
s
.50613 .31274 m
.51606 .2822 L
s
.50613 .31274 m
.51606 .2822 L
s
.50613 .67039 m
.51606 .70093 L
s
.50613 .67039 m
.51606 .63984 L
s
.50613 .67039 m
.51606 .70093 L
s
.50613 .67039 m
.51606 .70093 L
s
.50613 .67039 m
.51606 .70093 L
s
.44803 .33162 m
.45796 .30108 L
s
.44803 .33162 m
.45796 .30108 L
s
.44803 .33162 m
.45796 .36217 L
s
.44803 .65151 m
.45796 .68205 L
s
.44803 .65151 m
.45796 .62096 L
s
.44803 .65151 m
.45796 .68205 L
s
.62 .54099 m
.61007 .57154 L
s
.62 .54099 m
.61007 .51044 L
s
.62 .54099 m
.61007 .57154 L
s
.62 .54099 m
.64598 .52211 L
s
.62 .54099 m
.61007 .57154 L
s
.62 .54099 m
.61007 .57154 L
s
.62 .54099 m
.64598 .52211 L
s
.78817 .34329 m
.76218 .36217 L
s
.78817 .34329 m
.76218 .36217 L
s
.78817 .34329 m
.79809 .31274 L
s
.78817 .34329 m
.81415 .36217 L
s
.78817 .34329 m
.76218 .36217 L
s
.78817 .63984 m
.76218 .62096 L
s
.78817 .63984 m
.76218 .62096 L
s
.78817 .63984 m
.79809 .67039 L
s
.78817 .63984 m
.81415 .62096 L
s
.78817 .63984 m
.76218 .62096 L
s
.73007 .36217 m
.76218 .36217 L
s
.73007 .36217 m
.76218 .36217 L
s
.73007 .36217 m
.72014 .33162 L
s
.73007 .36217 m
.76218 .36217 L
s
.73007 .36217 m
.70408 .34329 L
s
.73007 .36217 m
.70408 .34329 L
s
.73007 .36217 m
.70408 .38105 L
s
.73007 .55987 m
.76218 .55987 L
s
.73007 .55987 m
.70408 .54099 L
s
.73007 .62096 m
.76218 .62096 L
s
.73007 .62096 m
.76218 .62096 L
s
.73007 .62096 m
.72014 .65151 L
s
.73007 .62096 m
.76218 .62096 L
s
.73007 .62096 m
.70408 .63984 L
s
.73007 .62096 m
.70408 .60208 L
s
.73007 .62096 m
.70408 .63984 L
s
.76218 .36217 m
.75226 .33162 L
s
.76218 .36217 m
.77211 .33162 L
s
.76218 .36217 m
.78817 .38105 L
s
.76218 .36217 m
.78817 .34329 L
s
.76218 .36217 m
.78817 .38105 L
s
.76218 .42326 m
.78817 .44214 L
s
.76218 .42326 m
.7362 .44214 L
s
.76218 .55987 m
.78817 .54099 L
s
.76218 .55987 m
.7362 .54099 L
s
.76218 .62096 m
.75226 .65151 L
s
.76218 .62096 m
.77211 .65151 L
s
.76218 .62096 m
.78817 .60208 L
s
.76218 .62096 m
.78817 .60208 L
s
.76218 .62096 m
.78817 .63984 L
s
.76218 .36217 m
.75226 .33162 L
s
.76218 .36217 m
.77211 .33162 L
s
.76218 .36217 m
.78817 .38105 L
s
.76218 .36217 m
.78817 .34329 L
s
.76218 .36217 m
.78817 .38105 L
s
.76218 .62096 m
.75226 .65151 L
s
.76218 .62096 m
.77211 .65151 L
s
.76218 .62096 m
.78817 .60208 L
s
.76218 .62096 m
.78817 .60208 L
s
.76218 .62096 m
.78817 .63984 L
s
.57795 .41159 m
.61007 .41159 L
s
.57795 .41159 m
.55197 .39272 L
s
.57795 .41159 m
.61007 .41159 L
s
.57795 .41159 m
.61007 .41159 L
s
.57795 .41159 m
.61007 .41159 L
s
.61007 .41159 m
.60015 .44214 L
s
.61007 .41159 m
.63605 .43047 L
s
.61007 .41159 m
.63605 .39272 L
s
.61007 .41159 m
.60015 .38105 L
s
.61007 .41159 m
.63605 .39272 L
s
.61007 .41159 m
.63605 .43047 L
s
.61007 .41159 m
.63605 .39272 L
s
.61007 .57154 m
.58409 .59041 L
s
.61007 .57154 m
.63605 .55266 L
s
.61007 .57154 m
.63605 .59041 L
s
.61007 .57154 m
.60015 .60208 L
s
.61007 .57154 m
.62 .54099 L
s
.61007 .57154 m
.63605 .59041 L
s
.61007 .57154 m
.63605 .55266 L
s
.61007 .57154 m
.63605 .59041 L
s
.61007 .3505 m
.58409 .33162 L
s
.61007 .3505 m
.60015 .38105 L
s
.61007 .3505 m
.63605 .33162 L
s
.61007 .3505 m
.58409 .33162 L
s
.61007 .67039 m
.58409 .65151 L
s
.61007 .67039 m
.62 .70093 L
s
.61007 .67039 m
.57795 .67039 L
s
.61007 .67039 m
.62 .70093 L
s
.61007 .67039 m
.60015 .63984 L
s
.61007 .67039 m
.63605 .65151 L
s
.61007 .67039 m
.63605 .68926 L
s
.61007 .67039 m
.57795 .67039 L
s
.61007 .67039 m
.58409 .65151 L
s
.61007 .67039 m
.60015 .70093 L
s
.61007 .67039 m
.62 .70093 L
s
.72014 .33162 m
.75226 .33162 L
s
.72014 .33162 m
.69416 .31274 L
s
.72014 .65151 m
.75226 .65151 L
s
.72014 .65151 m
.69416 .67039 L
s
.75226 .33162 m
.76218 .36217 L
s
.75226 .65151 m
.76218 .62096 L
s
.55197 .39272 m
.52598 .41159 L
s
.55197 .59041 m
.58409 .59041 L
s
.55197 .59041 m
.52598 .57154 L
s
.55197 .33162 m
.58409 .33162 L
s
.55197 .33162 m
.52598 .31274 L
s
.55197 .33162 m
.54204 .30108 L
s
.55197 .33162 m
.57795 .31274 L
s
.55197 .33162 m
.57795 .31274 L
s
.55197 .33162 m
.58409 .33162 L
s
.55197 .33162 m
.54204 .30108 L
s
.55197 .65151 m
.58409 .65151 L
s
.55197 .65151 m
.52598 .67039 L
s
.55197 .65151 m
.54204 .68205 L
s
.55197 .65151 m
.57795 .67039 L
s
.55197 .65151 m
.57795 .67039 L
s
.55197 .65151 m
.58409 .65151 L
s
.55197 .65151 m
.54204 .68205 L
s
.58409 .59041 m
.61007 .57154 L
s
.58409 .59041 m
.57416 .62096 L
s
.58409 .59041 m
.61007 .57154 L
s
.58409 .59041 m
.61007 .57154 L
s
.58409 .33162 m
.61007 .31274 L
s
.58409 .33162 m
.55197 .33162 L
s
.58409 .33162 m
.61007 .31274 L
s
.58409 .33162 m
.61007 .3505 L
s
.58409 .33162 m
.55197 .33162 L
s
.58409 .65151 m
.61007 .67039 L
s
.58409 .65151 m
.55197 .65151 L
s
.58409 .65151 m
.57416 .62096 L
s
.58409 .65151 m
.61007 .67039 L
s
.58409 .65151 m
.61007 .67039 L
s
.58409 .65151 m
.55197 .65151 L
s
.52598 .31274 m
.51606 .2822 L
s
.52598 .31274 m
.51606 .2822 L
s
.52598 .31274 m
.51606 .34329 L
s
.52598 .31274 m
.55197 .33162 L
s
.52598 .31274 m
.55197 .33162 L
s
.52598 .31274 m
.51606 .2822 L
s
.52598 .31274 m
.51606 .2822 L
s
.52598 .67039 m
.51606 .70093 L
s
.52598 .67039 m
.51606 .63984 L
s
.52598 .67039 m
.51606 .70093 L
s
.52598 .67039 m
.55197 .65151 L
s
.52598 .67039 m
.55197 .65151 L
s
.52598 .67039 m
.51606 .70093 L
s
.52598 .67039 m
.51606 .70093 L
s
.43197 .2822 m
.45796 .30108 L
s
.43197 .2822 m
.45796 .26332 L
s
.43197 .2822 m
.45796 .30108 L
s
.43197 .70093 m
.45796 .68205 L
s
.43197 .70093 m
.45796 .71981 L
s
.43197 .70093 m
.45796 .68205 L
s
.54204 .30108 m
.51606 .2822 L
s
.54204 .30108 m
.51606 .2822 L
s
.54204 .30108 m
.55197 .33162 L
s
.54204 .30108 m
.55197 .33162 L
s
.54204 .30108 m
.56803 .2822 L
s
.54204 .30108 m
.51606 .2822 L
s
.54204 .30108 m
.51606 .2822 L
s
.54204 .68205 m
.51606 .70093 L
s
.54204 .68205 m
.51606 .70093 L
s
.54204 .68205 m
.55197 .65151 L
s
.54204 .68205 m
.55197 .65151 L
s
.54204 .68205 m
.56803 .70093 L
s
.54204 .68205 m
.51606 .70093 L
s
.54204 .68205 m
.51606 .70093 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .2822 m
.45796 .30108 L
s
.48394 .2822 m
.45796 .26332 L
s
.48394 .2822 m
.45796 .30108 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .70093 m
.45796 .68205 L
s
.48394 .70093 m
.45796 .71981 L
s
.48394 .70093 m
.45796 .68205 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .2822 m
.45796 .30108 L
s
.48394 .2822 m
.45796 .26332 L
s
.48394 .2822 m
.45796 .30108 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .2822 m
.51606 .2822 L
s
.48394 .34329 m
.51606 .34329 L
s
.48394 .34329 m
.45796 .36217 L
s
.48394 .63984 m
.51606 .63984 L
s
.48394 .63984 m
.45796 .62096 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .70093 m
.45796 .68205 L
s
.48394 .70093 m
.45796 .71981 L
s
.48394 .70093 m
.45796 .68205 L
s
.48394 .70093 m
.51606 .70093 L
s
.48394 .70093 m
.51606 .70093 L
s
.51606 .2822 m
.52598 .25165 L
s
.51606 .2822 m
.52598 .25165 L
s
.51606 .2822 m
.54204 .30108 L
s
.51606 .2822 m
.54204 .26332 L
s
.51606 .70093 m
.52598 .73148 L
s
.51606 .70093 m
.52598 .73148 L
s
.51606 .70093 m
.54204 .68205 L
s
.51606 .70093 m
.54204 .71981 L
s
.51606 .2822 m
.52598 .25165 L
s
.51606 .2822 m
.52598 .25165 L
s
.51606 .2822 m
.54204 .30108 L
s
.51606 .2822 m
.54204 .26332 L
s
.51606 .70093 m
.52598 .73148 L
s
.51606 .70093 m
.52598 .73148 L
s
.51606 .70093 m
.54204 .68205 L
s
.51606 .70093 m
.54204 .71981 L
s
.56803 .12226 m
.60015 .12226 L
s
.56803 .12226 m
.54204 .10338 L
s
.56803 .12226 m
.57795 .1528 L
s
.56803 .86087 m
.60015 .86087 L
s
.56803 .86087 m
.54204 .87975 L
s
.56803 .86087 m
.57795 .83033 L
s
.60015 .12226 m
.57416 .10338 L
s
.60015 .12226 m
.61007 .1528 L
s
.60015 .12226 m
.61007 .09171 L
s
.60015 .12226 m
.61007 .1528 L
s
.60015 .86087 m
.57416 .87975 L
s
.60015 .86087 m
.61007 .89142 L
s
.60015 .86087 m
.61007 .83033 L
s
.60015 .86087 m
.61007 .83033 L
s
.54204 .10338 m
.57416 .10338 L
s
.54204 .10338 m
.55197 .13392 L
s
.54204 .10338 m
.51606 .12226 L
s
.54204 .10338 m
.51606 .12226 L
s
.54204 .87975 m
.57416 .87975 L
s
.54204 .87975 m
.55197 .84921 L
s
.54204 .87975 m
.51606 .86087 L
s
.54204 .87975 m
.51606 .86087 L
s
.57416 .10338 m
.58409 .07283 L
s
.57416 .87975 m
.58409 .9103 L
s
.79809 .25165 m
.83021 .25165 L
s
.79809 .25165 m
.82408 .23277 L
s
.79809 .25165 m
.78817 .22111 L
s
.79809 .25165 m
.82408 .23277 L
s
.79809 .25165 m
.77211 .23277 L
s
.79809 .73148 m
.83021 .73148 L
s
.79809 .73148 m
.82408 .75036 L
s
.79809 .73148 m
.78817 .76202 L
s
.79809 .73148 m
.82408 .75036 L
s
.79809 .73148 m
.77211 .75036 L
s
.83021 .25165 m
.8562 .23277 L
s
.83021 .25165 m
.79809 .25165 L
s
.83021 .25165 m
.8562 .23277 L
s
.83021 .25165 m
.82029 .2822 L
s
.83021 .25165 m
.82029 .2822 L
s
.83021 .25165 m
.8562 .23277 L
s
.83021 .73148 m
.8562 .75036 L
s
.83021 .73148 m
.79809 .73148 L
s
.83021 .73148 m
.8562 .75036 L
s
.83021 .73148 m
.82029 .70093 L
s
.83021 .73148 m
.82029 .70093 L
s
.83021 .73148 m
.8562 .75036 L
s
.88218 .2139 m
.8562 .23277 L
s
.88218 .2139 m
.8562 .23277 L
s
.88218 .2139 m
.8562 .23277 L
s
.88218 .76923 m
.8562 .75036 L
s
.88218 .76923 m
.8562 .75036 L
s
.88218 .76923 m
.8562 .75036 L
s
.82408 .23277 m
.8562 .23277 L
s
.82408 .23277 m
.81415 .20223 L
s
.82408 .23277 m
.79809 .25165 L
s
.82408 .23277 m
.8562 .23277 L
s
.82408 .23277 m
.8562 .23277 L
s
.82408 .75036 m
.8562 .75036 L
s
.82408 .75036 m
.81415 .7809 L
s
.82408 .75036 m
.79809 .73148 L
s
.82408 .75036 m
.8562 .75036 L
s
.82408 .75036 m
.8562 .75036 L
s
.8562 .23277 m
.84627 .20223 L
s
.8562 .23277 m
.88218 .2139 L
s
.8562 .23277 m
.82408 .23277 L
s
.8562 .23277 m
.84627 .26332 L
s
.8562 .23277 m
.88218 .25165 L
s
.8562 .23277 m
.88218 .25165 L
s
.8562 .23277 m
.88218 .2139 L
s
.8562 .75036 m
.84627 .7809 L
s
.8562 .75036 m
.88218 .76923 L
s
.8562 .75036 m
.82408 .75036 L
s
.8562 .75036 m
.84627 .71981 L
s
.8562 .75036 m
.88218 .73148 L
s
.8562 .75036 m
.88218 .73148 L
s
.8562 .75036 m
.88218 .76923 L
s
.77211 .33162 m
.79809 .31274 L
s
.77211 .33162 m
.76218 .36217 L
s
.77211 .65151 m
.79809 .67039 L
s
.77211 .65151 m
.76218 .62096 L
s
.78817 .18335 m
.82029 .18335 L
s
.78817 .18335 m
.81415 .20223 L
s
.78817 .18335 m
.76218 .20223 L
s
.78817 .18335 m
.76218 .20223 L
s
.78817 .22111 m
.81415 .20223 L
s
.78817 .22111 m
.76218 .20223 L
s
.78817 .22111 m
.76218 .20223 L
s
.78817 .22111 m
.79809 .25165 L
s
.78817 .76202 m
.81415 .7809 L
s
.78817 .76202 m
.76218 .7809 L
s
.78817 .76202 m
.76218 .7809 L
s
.78817 .76202 m
.79809 .73148 L
s
.78817 .79978 m
.82029 .79978 L
s
.78817 .79978 m
.81415 .7809 L
s
.78817 .79978 m
.76218 .7809 L
s
.78817 .79978 m
.76218 .7809 L
s
.82029 .18335 m
.84627 .20223 L
s
.82029 .18335 m
.83021 .1528 L
s
.82029 .79978 m
.84627 .7809 L
s
.82029 .79978 m
.83021 .83033 L
s
.81415 .20223 m
.84627 .20223 L
s
.81415 .20223 m
.82408 .23277 L
s
.81415 .7809 m
.84627 .7809 L
s
.81415 .7809 m
.82408 .75036 L
s
.84627 .20223 m
.8562 .23277 L
s
.84627 .20223 m
.8562 .17168 L
s
.84627 .20223 m
.8562 .23277 L
s
.84627 .7809 m
.8562 .75036 L
s
.84627 .7809 m
.8562 .81145 L
s
.84627 .7809 m
.8562 .75036 L
s
.76218 .20223 m
.77211 .23277 L
s
.76218 .7809 m
.77211 .75036 L
s
.76218 .20223 m
.77211 .23277 L
s
.76218 .7809 m
.77211 .75036 L
s
.57795 .1528 m
.61007 .1528 L
s
.57795 .1528 m
.55197 .13392 L
s
.57795 .1528 m
.61007 .1528 L
s
.57795 .1528 m
.55197 .17168 L
s
.57795 .83033 m
.61007 .83033 L
s
.57795 .83033 m
.55197 .84921 L
s
.57795 .83033 m
.61007 .83033 L
s
.57795 .83033 m
.55197 .81145 L
s
.61007 .1528 m
.63605 .17168 L
s
.61007 .1528 m
.60015 .18335 L
s
.61007 .1528 m
.63605 .17168 L
s
.61007 .09171 m
.58409 .07283 L
s
.61007 .89142 m
.58409 .9103 L
s
.61007 .83033 m
.63605 .81145 L
s
.61007 .83033 m
.60015 .79978 L
s
.61007 .83033 m
.63605 .81145 L
s
.55197 .13392 m
.52598 .1528 L
s
.55197 .13392 m
.52598 .1528 L
s
.55197 .84921 m
.52598 .83033 L
s
.55197 .84921 m
.52598 .83033 L
s
.79809 .25165 m
.82408 .23277 L
s
.79809 .25165 m
.77211 .23277 L
s
.79809 .73148 m
.82408 .75036 L
s
.79809 .73148 m
.77211 .75036 L
s
.83021 .1528 m
.8562 .17168 L
s
.83021 .83033 m
.8562 .81145 L
s
.88218 .2139 m
.8562 .23277 L
s
.88218 .2139 m
.8562 .23277 L
s
.88218 .76923 m
.8562 .75036 L
s
.88218 .76923 m
.8562 .75036 L
s
.82408 .23277 m
.8562 .23277 L
s
.82408 .23277 m
.8562 .23277 L
s
.82408 .75036 m
.8562 .75036 L
s
.82408 .75036 m
.8562 .75036 L
s
.8562 .23277 m
.84627 .26332 L
s
.8562 .23277 m
.88218 .25165 L
s
.8562 .23277 m
.88218 .25165 L
s
.8562 .23277 m
.88218 .2139 L
s
.8562 .75036 m
.84627 .71981 L
s
.8562 .75036 m
.88218 .73148 L
s
.8562 .75036 m
.88218 .73148 L
s
.8562 .75036 m
.88218 .76923 L
s
.41591 .07283 m
.44803 .07283 L
s
.41591 .07283 m
.38993 .05395 L
s
.41591 .07283 m
.38993 .09171 L
s
.41591 .07283 m
.38993 .05395 L
s
.41591 .07283 m
.42584 .10338 L
s
.41591 .07283 m
.42584 .10338 L
s
.41591 .9103 m
.44803 .9103 L
s
.41591 .9103 m
.38993 .89142 L
s
.41591 .9103 m
.38993 .92918 L
s
.41591 .9103 m
.38993 .92918 L
s
.41591 .9103 m
.42584 .87975 L
s
.41591 .9103 m
.42584 .87975 L
s
.44803 .07283 m
.42205 .05395 L
s
.44803 .07283 m
.42205 .05395 L
s
.44803 .07283 m
.45796 .04229 L
s
.44803 .07283 m
.45796 .10338 L
s
.44803 .07283 m
.45796 .10338 L
s
.44803 .07283 m
.45796 .10338 L
s
.44803 .07283 m
.45796 .10338 L
s
.44803 .07283 m
.45796 .10338 L
s
.44803 .9103 m
.42205 .92918 L
s
.44803 .9103 m
.42205 .92918 L
s
.44803 .9103 m
.45796 .87975 L
s
.44803 .9103 m
.45796 .94084 L
s
.44803 .9103 m
.45796 .87975 L
s
.44803 .9103 m
.45796 .87975 L
s
.44803 .9103 m
.45796 .87975 L
s
.44803 .9103 m
.45796 .87975 L
s
.44803 .13392 m
.42205 .1528 L
s
.44803 .13392 m
.47402 .1528 L
s
.44803 .13392 m
.42205 .1528 L
s
.44803 .13392 m
.45796 .10338 L
s
.44803 .13392 m
.45796 .10338 L
s
.44803 .13392 m
.45796 .10338 L
s
.44803 .13392 m
.45796 .10338 L
s
.44803 .13392 m
.45796 .10338 L
s
.44803 .17168 m
.42205 .1528 L
s
.44803 .17168 m
.47402 .1528 L
s
.44803 .17168 m
.42205 .1528 L
s
.44803 .17168 m
.45796 .20223 L
s
.44803 .17168 m
.45796 .20223 L
s
.44803 .13392 m
.42205 .1528 L
s
.44803 .13392 m
.47402 .1528 L
s
.44803 .13392 m
.42205 .1528 L
s
.44803 .13392 m
.45796 .10338 L
s
.44803 .13392 m
.45796 .10338 L
s
.44803 .13392 m
.45796 .10338 L
s
.44803 .13392 m
.45796 .10338 L
s
.44803 .13392 m
.45796 .10338 L
s
.44803 .84921 m
.42205 .83033 L
s
.44803 .84921 m
.47402 .83033 L
s
.44803 .84921 m
.42205 .83033 L
s
.44803 .84921 m
.45796 .87975 L
s
.44803 .84921 m
.45796 .87975 L
s
.44803 .84921 m
.45796 .87975 L
s
.44803 .84921 m
.45796 .87975 L
s
.44803 .84921 m
.45796 .87975 L
s
.44803 .81145 m
.42205 .83033 L
s
.44803 .81145 m
.47402 .83033 L
s
.44803 .81145 m
.42205 .83033 L
s
.44803 .81145 m
.45796 .7809 L
s
.44803 .81145 m
.45796 .7809 L
s
.44803 .84921 m
.42205 .83033 L
s
.44803 .84921 m
.47402 .83033 L
s
.44803 .84921 m
.42205 .83033 L
s
.44803 .84921 m
.45796 .87975 L
s
.44803 .84921 m
.45796 .87975 L
s
.44803 .84921 m
.45796 .87975 L
s
.44803 .84921 m
.45796 .87975 L
s
.44803 .84921 m
.45796 .87975 L
s
.82408 .59041 m
.8562 .59041 L
s
.82408 .59041 m
.79809 .57154 L
s
.82408 .59041 m
.79809 .57154 L
s
.82408 .59041 m
.81415 .62096 L
s
.82408 .33162 m
.8562 .33162 L
s
.82408 .33162 m
.79809 .31274 L
s
.82408 .33162 m
.8562 .33162 L
s
.82408 .33162 m
.8562 .33162 L
s
.82408 .33162 m
.81415 .36217 L
s
.82408 .65151 m
.8562 .65151 L
s
.82408 .65151 m
.79809 .67039 L
s
.82408 .65151 m
.8562 .65151 L
s
.82408 .65151 m
.8562 .65151 L
s
.82408 .65151 m
.81415 .62096 L
s
.8562 .49156 m
.84627 .46102 L
s
.8562 .49156 m
.84627 .52211 L
s
.8562 .43047 m
.83021 .41159 L
s
.8562 .43047 m
.83021 .41159 L
s
.8562 .43047 m
.84627 .46102 L
s
.8562 .55266 m
.83021 .57154 L
s
.8562 .55266 m
.83021 .57154 L
s
.8562 .55266 m
.84627 .52211 L
s
.8562 .39272 m
.83021 .41159 L
s
.8562 .39272 m
.83021 .41159 L
s
.8562 .39272 m
.84627 .36217 L
s
.8562 .59041 m
.83021 .57154 L
s
.8562 .59041 m
.83021 .57154 L
s
.8562 .59041 m
.86612 .62096 L
s
.8562 .59041 m
.86612 .62096 L
s
.8562 .59041 m
.84627 .62096 L
s
.8562 .59041 m
.86612 .62096 L
s
.8562 .33162 m
.88218 .31274 L
s
.8562 .33162 m
.83021 .31274 L
s
.8562 .33162 m
.84627 .30108 L
s
.8562 .33162 m
.84627 .30108 L
s
.8562 .33162 m
.88218 .31274 L
s
.8562 .33162 m
.83021 .31274 L
s
.8562 .33162 m
.84627 .36217 L
s
.8562 .65151 m
.88218 .67039 L
s
.8562 .65151 m
.83021 .67039 L
s
.8562 .65151 m
.84627 .68205 L
s
.8562 .65151 m
.84627 .68205 L
s
.8562 .65151 m
.86612 .62096 L
s
.8562 .65151 m
.86612 .62096 L
s
.8562 .65151 m
.88218 .67039 L
s
.8562 .65151 m
.83021 .67039 L
s
.8562 .65151 m
.84627 .62096 L
s
.8562 .65151 m
.86612 .62096 L
s
.88218 .31274 m
.9143 .31274 L
s
.88218 .31274 m
.87225 .2822 L
s
.88218 .31274 m
.8921 .2822 L
s
.88218 .31274 m
.8562 .33162 L
s
.88218 .31274 m
.8562 .33162 L
s
.88218 .31274 m
.8921 .2822 L
s
.88218 .31274 m
.8921 .2822 L
s
.88218 .67039 m
.9143 .67039 L
s
.88218 .67039 m
.87225 .70093 L
s
.88218 .67039 m
.8921 .70093 L
s
.88218 .67039 m
.8562 .65151 L
s
.88218 .67039 m
.8562 .65151 L
s
.88218 .67039 m
.8921 .70093 L
s
.88218 .67039 m
.8921 .70093 L
s
.9143 .31274 m
.92422 .2822 L
s
.9143 .31274 m
.88218 .31274 L
s
.9143 .31274 m
.92422 .2822 L
s
.9143 .67039 m
.92422 .70093 L
s
.9143 .67039 m
.88218 .67039 L
s
.9143 .67039 m
.92422 .70093 L
s
.79809 .47269 m
.78817 .44214 L
s
.79809 .51044 m
.78817 .54099 L
s
.79809 .41159 m
.83021 .41159 L
s
.79809 .41159 m
.83021 .41159 L
s
.79809 .41159 m
.78817 .38105 L
s
.79809 .41159 m
.78817 .44214 L
s
.79809 .41159 m
.78817 .38105 L
s
.79809 .57154 m
.83021 .57154 L
s
.79809 .57154 m
.83021 .57154 L
s
.79809 .57154 m
.78817 .54099 L
s
.79809 .57154 m
.78817 .60208 L
s
.79809 .57154 m
.78817 .60208 L
s
.83021 .41159 m
.82029 .38105 L
s
.83021 .41159 m
.82029 .44214 L
s
.83021 .41159 m
.82029 .38105 L
s
.83021 .57154 m
.79809 .57154 L
s
.83021 .57154 m
.82029 .54099 L
s
.38993 .05395 m
.42205 .05395 L
s
.38993 .05395 m
.36395 .07283 L
s
.38993 .05395 m
.42205 .05395 L
s
.38993 .05395 m
.39985 .02341 L
s
.38993 .09171 m
.36395 .07283 L
s
.38993 .09171 m
.39985 .12226 L
s
.38993 .09171 m
.39985 .12226 L
s
.38993 .89142 m
.36395 .9103 L
s
.38993 .89142 m
.39985 .86087 L
s
.38993 .89142 m
.39985 .86087 L
s
.38993 .92918 m
.42205 .92918 L
s
.38993 .92918 m
.36395 .9103 L
s
.38993 .92918 m
.42205 .92918 L
s
.38993 .92918 m
.39985 .95972 L
s
.42205 .05395 m
.38993 .05395 L
s
.42205 .05395 m
.43197 .02341 L
s
.42205 .05395 m
.43197 .02341 L
s
.42205 .92918 m
.38993 .92918 L
s
.42205 .92918 m
.43197 .95972 L
s
.42205 .92918 m
.43197 .95972 L
s
.42205 .1528 m
.43197 .12226 L
s
.42205 .1528 m
.43197 .12226 L
s
.42205 .83033 m
.43197 .86087 L
s
.42205 .83033 m
.43197 .86087 L
s
.79809 .57154 m
.83021 .57154 L
s
.79809 .57154 m
.78817 .54099 L
s
.79809 .57154 m
.78817 .60208 L
s
.79809 .57154 m
.78817 .60208 L
s
.79809 .31274 m
.83021 .31274 L
s
.79809 .31274 m
.83021 .31274 L
s
.79809 .31274 m
.78817 .34329 L
s
.79809 .67039 m
.83021 .67039 L
s
.79809 .67039 m
.83021 .67039 L
s
.79809 .67039 m
.78817 .63984 L
s
.83021 .41159 m
.82029 .38105 L
s
.83021 .41159 m
.82029 .44214 L
s
.83021 .41159 m
.82029 .38105 L
s
.83021 .57154 m
.82029 .54099 L
s
.83021 .31274 m
.82029 .2822 L
s
.83021 .31274 m
.82029 .2822 L
s
.83021 .31274 m
.8562 .33162 L
s
.83021 .31274 m
.8562 .33162 L
s
.83021 .67039 m
.82029 .70093 L
s
.83021 .67039 m
.82029 .70093 L
s
.83021 .67039 m
.8562 .65151 L
s
.83021 .67039 m
.8562 .65151 L
s
.36395 .07283 m
.38993 .05395 L
s
.36395 .07283 m
.35402 .04229 L
s
.36395 .9103 m
.38993 .92918 L
s
.36395 .9103 m
.35402 .94084 L
s
.47402 .1528 m
.50613 .1528 L
s
.47402 .1528 m
.48394 .18335 L
s
.47402 .1528 m
.48394 .12226 L
s
.47402 .1528 m
.48394 .18335 L
s
.47402 .1528 m
.48394 .12226 L
s
.47402 .83033 m
.50613 .83033 L
s
.47402 .83033 m
.48394 .79978 L
s
.47402 .83033 m
.48394 .79978 L
s
.47402 .83033 m
.48394 .86087 L
s
.47402 .83033 m
.48394 .86087 L
s
.50613 .1528 m
.51606 .18335 L
s
.50613 .1528 m
.51606 .18335 L
s
.50613 .1528 m
.51606 .12226 L
s
.50613 .1528 m
.51606 .18335 L
s
.50613 .1528 m
.51606 .12226 L
s
.50613 .83033 m
.51606 .79978 L
s
.50613 .83033 m
.51606 .79978 L
s
.50613 .83033 m
.51606 .79978 L
s
.50613 .83033 m
.51606 .86087 L
s
.50613 .83033 m
.51606 .86087 L
s
.38993 .05395 m
.42205 .05395 L
s
.38993 .05395 m
.39985 .02341 L
s
.38993 .92918 m
.42205 .92918 L
s
.38993 .92918 m
.39985 .95972 L
s
.42205 .05395 m
.43197 .02341 L
s
.42205 .05395 m
.43197 .02341 L
s
.42205 .92918 m
.43197 .95972 L
s
.42205 .92918 m
.43197 .95972 L
s
.42205 .1528 m
.43197 .12226 L
s
.42205 .1528 m
.43197 .12226 L
s
.42205 .83033 m
.43197 .86087 L
s
.42205 .83033 m
.43197 .86087 L
s
.64598 .36217 m
.6781 .36217 L
s
.64598 .36217 m
.63605 .39272 L
s
.64598 .36217 m
.6781 .36217 L
s
.64598 .36217 m
.63605 .39272 L
s
.64598 .36217 m
.63605 .33162 L
s
.64598 .36217 m
.63605 .39272 L
s
.64598 .36217 m
.6781 .36217 L
s
.64598 .62096 m
.6781 .62096 L
s
.64598 .62096 m
.63605 .59041 L
s
.64598 .62096 m
.6781 .62096 L
s
.64598 .62096 m
.63605 .59041 L
s
.64598 .62096 m
.63605 .65151 L
s
.64598 .62096 m
.63605 .59041 L
s
.64598 .62096 m
.6781 .62096 L
s
.64598 .20223 m
.63605 .17168 L
s
.64598 .20223 m
.63605 .23277 L
s
.64598 .20223 m
.6781 .20223 L
s
.64598 .20223 m
.63605 .17168 L
s
.64598 .20223 m
.6781 .20223 L
s
.64598 .30108 m
.62 .2822 L
s
.64598 .30108 m
.62 .2822 L
s
.64598 .30108 m
.63605 .33162 L
s
.64598 .30108 m
.62 .2822 L
s
.64598 .26332 m
.62 .2822 L
s
.64598 .26332 m
.63605 .23277 L
s
.64598 .26332 m
.62 .2822 L
s
.64598 .26332 m
.62 .2822 L
s
.64598 .36217 m
.6781 .36217 L
s
.64598 .36217 m
.63605 .39272 L
s
.64598 .36217 m
.6781 .36217 L
s
.64598 .36217 m
.63605 .39272 L
s
.64598 .36217 m
.63605 .33162 L
s
.64598 .36217 m
.63605 .39272 L
s
.64598 .36217 m
.6781 .36217 L
s
.64598 .62096 m
.6781 .62096 L
s
.64598 .62096 m
.63605 .59041 L
s
.64598 .62096 m
.6781 .62096 L
s
.64598 .62096 m
.63605 .59041 L
s
.64598 .62096 m
.63605 .65151 L
s
.64598 .62096 m
.63605 .59041 L
s
.64598 .62096 m
.6781 .62096 L
s
.64598 .71981 m
.6781 .71981 L
s
.64598 .71981 m
.62 .70093 L
s
.64598 .71981 m
.63605 .75036 L
s
.64598 .71981 m
.6781 .71981 L
s
.64598 .71981 m
.62 .70093 L
s
.64598 .71981 m
.63605 .68926 L
s
.64598 .71981 m
.62 .70093 L
s
.64598 .7809 m
.63605 .75036 L
s
.64598 .7809 m
.63605 .81145 L
s
.64598 .7809 m
.6781 .7809 L
s
.64598 .7809 m
.63605 .81145 L
s
.64598 .7809 m
.6781 .7809 L
s
.6781 .36217 m
.66817 .39272 L
s
.6781 .36217 m
.64598 .36217 L
s
.6781 .36217 m
.66817 .33162 L
s
.6781 .36217 m
.70408 .34329 L
s
.6781 .36217 m
.66817 .39272 L
s
.6781 .36217 m
.70408 .34329 L
s
.6781 .36217 m
.70408 .38105 L
s
.6781 .62096 m
.66817 .59041 L
s
.6781 .62096 m
.64598 .62096 L
s
.6781 .62096 m
.66817 .65151 L
s
.6781 .62096 m
.70408 .63984 L
s
.6781 .62096 m
.66817 .59041 L
s
.6781 .62096 m
.70408 .60208 L
s
.6781 .62096 m
.70408 .63984 L
s
.6781 .71981 m
.66817 .75036 L
s
.6781 .71981 m
.64598 .71981 L
s
.6781 .71981 m
.70408 .70093 L
s
.84627 .30108 m
.87225 .2822 L
s
.84627 .30108 m
.82029 .2822 L
s
.84627 .30108 m
.82029 .2822 L
s
.84627 .30108 m
.8562 .33162 L
s
.84627 .30108 m
.8562 .33162 L
s
.84627 .26332 m
.87225 .2822 L
s
.84627 .26332 m
.82029 .2822 L
s
.84627 .26332 m
.82029 .2822 L
s
.84627 .26332 m
.8562 .23277 L
s
.84627 .30108 m
.87225 .2822 L
s
.84627 .30108 m
.82029 .2822 L
s
.84627 .30108 m
.82029 .2822 L
s
.84627 .30108 m
.8562 .33162 L
s
.84627 .30108 m
.8562 .33162 L
s
.84627 .68205 m
.87225 .70093 L
s
.84627 .68205 m
.82029 .70093 L
s
.84627 .68205 m
.82029 .70093 L
s
.84627 .68205 m
.8562 .65151 L
s
.84627 .68205 m
.8562 .65151 L
s
.84627 .71981 m
.87225 .70093 L
s
.84627 .71981 m
.82029 .70093 L
s
.84627 .71981 m
.82029 .70093 L
s
.84627 .71981 m
.8562 .75036 L
s
.84627 .68205 m
.87225 .70093 L
s
.84627 .68205 m
.82029 .70093 L
s
.84627 .68205 m
.82029 .70093 L
s
.84627 .68205 m
.8562 .65151 L
s
.84627 .68205 m
.8562 .65151 L
s
.87225 .2822 m
.88218 .31274 L
s
.87225 .2822 m
.88218 .25165 L
s
.87225 .2822 m
.88218 .25165 L
s
.87225 .70093 m
.88218 .67039 L
s
.87225 .70093 m
.88218 .73148 L
s
.87225 .70093 m
.88218 .73148 L
s
.82029 .2822 m
.83021 .31274 L
s
.82029 .70093 m
.83021 .67039 L
s
.62 .2822 m
.61007 .25165 L
s
.62 .2822 m
.61007 .31274 L
s
.62 .2822 m
.61007 .25165 L
s
.62 .2822 m
.61007 .25165 L
s
.62 .2822 m
.64598 .26332 L
s
.62 .2822 m
.61007 .31274 L
s
.62 .70093 m
.61007 .73148 L
s
.62 .70093 m
.61007 .67039 L
s
.62 .70093 m
.61007 .73148 L
s
.62 .70093 m
.61007 .73148 L
s
.62 .70093 m
.64598 .71981 L
s
.62 .70093 m
.61007 .67039 L
s
.62 .70093 m
.61007 .67039 L
s
.82029 .2822 m
.83021 .31274 L
s
.82029 .70093 m
.83021 .67039 L
s
.63605 .17168 m
.61007 .1528 L
s
.63605 .17168 m
.62613 .20223 L
s
.63605 .17168 m
.64598 .20223 L
s
.63605 .17168 m
.66817 .17168 L
s
.63605 .17168 m
.64598 .20223 L
s
.63605 .23277 m
.66817 .23277 L
s
.63605 .23277 m
.61007 .25165 L
s
.63605 .23277 m
.61007 .25165 L
s
.63605 .23277 m
.61007 .2139 L
s
.63605 .23277 m
.61007 .25165 L
s
.63605 .23277 m
.62613 .20223 L
s
.63605 .23277 m
.64598 .20223 L
s
.63605 .23277 m
.64598 .26332 L
s
.63605 .23277 m
.64598 .20223 L
s
.63605 .75036 m
.66817 .75036 L
s
.63605 .75036 m
.61007 .73148 L
s
.63605 .75036 m
.61007 .73148 L
s
.63605 .75036 m
.61007 .73148 L
s
.63605 .75036 m
.61007 .76923 L
s
.63605 .75036 m
.62613 .7809 L
s
.63605 .75036 m
.64598 .71981 L
s
.63605 .75036 m
.64598 .7809 L
s
.63605 .75036 m
.64598 .7809 L
s
.63605 .81145 m
.61007 .83033 L
s
.63605 .81145 m
.62613 .7809 L
s
.63605 .81145 m
.64598 .7809 L
s
.63605 .81145 m
.66817 .81145 L
s
.63605 .81145 m
.64598 .7809 L
s
.66817 .23277 m
.6781 .20223 L
s
.66817 .23277 m
.6781 .20223 L
s
.66817 .75036 m
.6781 .71981 L
s
.66817 .75036 m
.6781 .7809 L
s
.66817 .75036 m
.6781 .7809 L
s
.57795 .25165 m
.61007 .25165 L
s
.57795 .25165 m
.61007 .25165 L
s
.57795 .25165 m
.61007 .25165 L
s
.57795 .25165 m
.55197 .23277 L
s
.57795 .25165 m
.55197 .23277 L
s
.57795 .25165 m
.56803 .2822 L
s
.57795 .73148 m
.61007 .73148 L
s
.57795 .73148 m
.61007 .73148 L
s
.57795 .73148 m
.61007 .73148 L
s
.57795 .73148 m
.55197 .75036 L
s
.57795 .73148 m
.55197 .75036 L
s
.57795 .73148 m
.56803 .70093 L
s
.57795 .31274 m
.61007 .31274 L
s
.57795 .31274 m
.55197 .33162 L
s
.57795 .31274 m
.61007 .31274 L
s
.57795 .31274 m
.55197 .33162 L
s
.57795 .31274 m
.56803 .2822 L
s
.57795 .25165 m
.61007 .25165 L
s
.57795 .25165 m
.61007 .25165 L
s
.57795 .25165 m
.61007 .25165 L
s
.57795 .25165 m
.55197 .23277 L
s
.57795 .25165 m
.55197 .23277 L
s
.57795 .25165 m
.56803 .2822 L
s
.57795 .67039 m
.61007 .67039 L
s
.57795 .67039 m
.55197 .65151 L
s
.57795 .67039 m
.61007 .67039 L
s
.57795 .67039 m
.61007 .67039 L
s
.57795 .67039 m
.55197 .65151 L
s
.57795 .67039 m
.56803 .70093 L
s
.57795 .73148 m
.61007 .73148 L
s
.57795 .73148 m
.61007 .73148 L
s
.57795 .73148 m
.61007 .73148 L
s
.57795 .73148 m
.55197 .75036 L
s
.57795 .73148 m
.55197 .75036 L
s
.57795 .73148 m
.56803 .70093 L
s
.61007 .25165 m
.58409 .23277 L
s
.61007 .25165 m
.62 .2822 L
s
.61007 .25165 m
.60015 .2822 L
s
.61007 .25165 m
.62 .2822 L
s
.61007 .73148 m
.58409 .75036 L
s
.61007 .73148 m
.62 .70093 L
s
.61007 .73148 m
.60015 .70093 L
s
.61007 .73148 m
.62 .70093 L
s
.61007 .1528 m
.60015 .18335 L
s
.61007 .1528 m
.63605 .17168 L
s
.61007 .31274 m
.62 .2822 L
s
.61007 .31274 m
.63605 .33162 L
s
.61007 .31274 m
.57795 .31274 L
s
.61007 .31274 m
.58409 .33162 L
s
.61007 .31274 m
.60015 .2822 L
s
.61007 .31274 m
.62 .2822 L
s
.61007 .25165 m
.58409 .23277 L
s
.61007 .25165 m
.62 .2822 L
s
.61007 .25165 m
.60015 .2822 L
s
.61007 .25165 m
.62 .2822 L
s
.61007 .2139 m
.58409 .23277 L
s
.61007 .2139 m
.60015 .18335 L
s
.61007 .25165 m
.58409 .23277 L
s
.61007 .25165 m
.62 .2822 L
s
.61007 .25165 m
.60015 .2822 L
s
.61007 .25165 m
.62 .2822 L
s
.61007 .67039 m
.62 .70093 L
s
.61007 .67039 m
.60015 .63984 L
s
.61007 .67039 m
.63605 .65151 L
s
.61007 .67039 m
.63605 .68926 L
s
.61007 .67039 m
.57795 .67039 L
s
.61007 .67039 m
.58409 .65151 L
s
.61007 .67039 m
.60015 .70093 L
s
.61007 .67039 m
.62 .70093 L
s
.61007 .73148 m
.58409 .75036 L
s
.61007 .73148 m
.62 .70093 L
s
.61007 .73148 m
.60015 .70093 L
s
.61007 .73148 m
.62 .70093 L
s
.61007 .73148 m
.58409 .75036 L
s
.61007 .73148 m
.62 .70093 L
s
.61007 .73148 m
.60015 .70093 L
s
.61007 .73148 m
.62 .70093 L
s
.61007 .76923 m
.58409 .75036 L
s
.61007 .76923 m
.60015 .79978 L
s
.61007 .83033 m
.60015 .79978 L
s
.61007 .83033 m
.63605 .81145 L
s
.55197 .23277 m
.58409 .23277 L
s
.55197 .23277 m
.52598 .25165 L
s
.55197 .23277 m
.52598 .25165 L
s
.55197 .23277 m
.54204 .20223 L
s
.55197 .23277 m
.54204 .26332 L
s
.55197 .75036 m
.58409 .75036 L
s
.55197 .75036 m
.52598 .73148 L
s
.55197 .75036 m
.52598 .73148 L
s
.55197 .75036 m
.54204 .7809 L
s
.55197 .75036 m
.54204 .71981 L
s
.55197 .17168 m
.52598 .1528 L
s
.55197 .17168 m
.54204 .20223 L
s
.55197 .17168 m
.52598 .1528 L
s
.55197 .33162 m
.57795 .31274 L
s
.55197 .33162 m
.58409 .33162 L
s
.55197 .33162 m
.54204 .30108 L
s
.55197 .23277 m
.58409 .23277 L
s
.55197 .23277 m
.52598 .25165 L
s
.55197 .23277 m
.52598 .25165 L
s
.55197 .23277 m
.54204 .20223 L
s
.55197 .23277 m
.54204 .26332 L
s
.55197 .65151 m
.57795 .67039 L
s
.55197 .65151 m
.58409 .65151 L
s
.55197 .65151 m
.54204 .68205 L
s
.55197 .75036 m
.58409 .75036 L
s
.55197 .75036 m
.52598 .73148 L
s
.55197 .75036 m
.52598 .73148 L
s
.55197 .75036 m
.54204 .7809 L
s
.55197 .75036 m
.54204 .71981 L
s
.55197 .81145 m
.52598 .83033 L
s
.55197 .81145 m
.54204 .7809 L
s
.55197 .81145 m
.52598 .83033 L
s
.58409 .23277 m
.57416 .20223 L
s
.58409 .75036 m
.57416 .7809 L
s
.52598 .25165 m
.51606 .22111 L
s
.52598 .25165 m
.51606 .2822 L
s
.52598 .25165 m
.51606 .2822 L
s
.52598 .73148 m
.51606 .76202 L
s
.52598 .73148 m
.51606 .70093 L
s
.52598 .73148 m
.51606 .70093 L
s
.52598 .1528 m
.51606 .18335 L
s
.52598 .1528 m
.51606 .18335 L
s
.52598 .1528 m
.51606 .12226 L
s
.52598 .1528 m
.51606 .18335 L
s
.52598 .1528 m
.51606 .12226 L
s
.52598 .25165 m
.51606 .22111 L
s
.52598 .25165 m
.51606 .2822 L
s
.52598 .25165 m
.51606 .2822 L
s
.52598 .73148 m
.51606 .76202 L
s
.52598 .73148 m
.51606 .70093 L
s
.52598 .73148 m
.51606 .70093 L
s
.52598 .83033 m
.51606 .79978 L
s
.52598 .83033 m
.51606 .79978 L
s
.52598 .83033 m
.51606 .79978 L
s
.52598 .83033 m
.51606 .86087 L
s
.52598 .83033 m
.51606 .86087 L
s
.45796 .20223 m
.49007 .20223 L
s
.45796 .20223 m
.48394 .18335 L
s
.45796 .20223 m
.48394 .18335 L
s
.45796 .7809 m
.49007 .7809 L
s
.45796 .7809 m
.48394 .79978 L
s
.45796 .7809 m
.48394 .79978 L
s
.49007 .20223 m
.51606 .18335 L
s
.49007 .20223 m
.51606 .18335 L
s
.49007 .20223 m
.51606 .22111 L
s
.49007 .20223 m
.45796 .20223 L
s
.49007 .20223 m
.51606 .18335 L
s
.49007 .7809 m
.51606 .79978 L
s
.49007 .7809 m
.51606 .76202 L
s
.49007 .7809 m
.51606 .79978 L
s
.49007 .7809 m
.45796 .7809 L
s
.49007 .7809 m
.51606 .79978 L
s
.62613 .20223 m
.60015 .18335 L
s
.62613 .20223 m
.63605 .17168 L
s
.62613 .7809 m
.60015 .79978 L
s
.62613 .7809 m
.63605 .81145 L
s
.60015 .18335 m
.57416 .20223 L
s
.60015 .79978 m
.57416 .7809 L
s
.54204 .20223 m
.57416 .20223 L
s
.54204 .20223 m
.51606 .18335 L
s
.54204 .20223 m
.51606 .18335 L
s
.54204 .20223 m
.51606 .22111 L
s
.54204 .20223 m
.51606 .18335 L
s
.54204 .7809 m
.57416 .7809 L
s
.54204 .7809 m
.51606 .79978 L
s
.54204 .7809 m
.51606 .76202 L
s
.54204 .7809 m
.51606 .79978 L
s
.54204 .7809 m
.51606 .79978 L
s
.48394 .18335 m
.51606 .18335 L
s
.48394 .18335 m
.51606 .18335 L
s
.48394 .18335 m
.45796 .20223 L
s
.48394 .18335 m
.51606 .18335 L
s
.48394 .79978 m
.51606 .79978 L
s
.48394 .79978 m
.51606 .79978 L
s
.48394 .79978 m
.45796 .7809 L
s
.48394 .79978 m
.51606 .79978 L
s
.51606 .18335 m
.48394 .18335 L
s
.51606 .18335 m
.52598 .1528 L
s
.51606 .18335 m
.48394 .18335 L
s
.51606 .18335 m
.52598 .1528 L
s
.51606 .79978 m
.48394 .79978 L
s
.51606 .79978 m
.52598 .83033 L
s
.51606 .79978 m
.48394 .79978 L
s
.51606 .79978 m
.52598 .83033 L
s
.62613 .46102 m
.60015 .44214 L
s
.62613 .46102 m
.63605 .49156 L
s
.62613 .46102 m
.63605 .43047 L
s
.62613 .46102 m
.63605 .43047 L
s
.42584 .10338 m
.45796 .10338 L
s
.42584 .10338 m
.45796 .10338 L
s
.42584 .10338 m
.45796 .10338 L
s
.42584 .10338 m
.39985 .12226 L
s
.42584 .10338 m
.45796 .10338 L
s
.42584 .10338 m
.45796 .10338 L
s
.42584 .10338 m
.39985 .12226 L
s
.42584 .87975 m
.45796 .87975 L
s
.42584 .87975 m
.45796 .87975 L
s
.42584 .87975 m
.45796 .87975 L
s
.42584 .87975 m
.39985 .86087 L
s
.42584 .87975 m
.45796 .87975 L
s
.42584 .87975 m
.45796 .87975 L
s
.42584 .87975 m
.39985 .86087 L
s
.45796 .04229 m
.43197 .02341 L
s
.45796 .04229 m
.43197 .02341 L
s
.45796 .10338 m
.43197 .12226 L
s
.45796 .10338 m
.48394 .12226 L
s
.45796 .10338 m
.42584 .10338 L
s
.45796 .10338 m
.49007 .10338 L
s
.45796 .10338 m
.49007 .10338 L
s
.45796 .10338 m
.43197 .12226 L
s
.45796 .10338 m
.48394 .12226 L
s
.45796 .87975 m
.43197 .86087 L
s
.45796 .87975 m
.48394 .86087 L
s
.45796 .87975 m
.42584 .87975 L
s
.45796 .87975 m
.49007 .87975 L
s
.45796 .87975 m
.49007 .87975 L
s
.45796 .87975 m
.43197 .86087 L
s
.45796 .87975 m
.48394 .86087 L
s
.45796 .94084 m
.43197 .95972 L
s
.45796 .94084 m
.43197 .95972 L
s
.45796 .10338 m
.43197 .12226 L
s
.45796 .10338 m
.48394 .12226 L
s
.45796 .10338 m
.42584 .10338 L
s
.45796 .10338 m
.49007 .10338 L
s
.45796 .10338 m
.49007 .10338 L
s
.45796 .10338 m
.43197 .12226 L
s
.45796 .10338 m
.48394 .12226 L
s
.45796 .10338 m
.43197 .12226 L
s
.45796 .10338 m
.48394 .12226 L
s
.45796 .10338 m
.42584 .10338 L
s
.45796 .10338 m
.49007 .10338 L
s
.45796 .10338 m
.49007 .10338 L
s
.45796 .10338 m
.43197 .12226 L
s
.45796 .10338 m
.48394 .12226 L
s
.45796 .20223 m
.48394 .18335 L
s
.45796 .7809 m
.48394 .79978 L
s
.45796 .87975 m
.43197 .86087 L
s
.45796 .87975 m
.48394 .86087 L
s
.45796 .87975 m
.42584 .87975 L
s
.45796 .87975 m
.49007 .87975 L
s
.45796 .87975 m
.49007 .87975 L
s
.45796 .87975 m
.43197 .86087 L
s
.45796 .87975 m
.48394 .86087 L
s
.45796 .87975 m
.43197 .86087 L
s
.45796 .87975 m
.48394 .86087 L
s
.45796 .87975 m
.42584 .87975 L
s
.45796 .87975 m
.49007 .87975 L
s
.45796 .87975 m
.49007 .87975 L
s
.45796 .87975 m
.43197 .86087 L
s
.45796 .87975 m
.48394 .86087 L
s
.86612 .62096 m
.8562 .65151 L
s
.86612 .62096 m
.8562 .65151 L
s
.86612 .62096 m
.8562 .65151 L
s
.86612 .62096 m
.8562 .65151 L
s
.8921 .2822 m
.92422 .2822 L
s
.8921 .2822 m
.88218 .31274 L
s
.8921 .2822 m
.88218 .25165 L
s
.8921 .2822 m
.88218 .25165 L
s
.8921 .2822 m
.92422 .2822 L
s
.8921 .70093 m
.92422 .70093 L
s
.8921 .70093 m
.88218 .67039 L
s
.8921 .70093 m
.88218 .73148 L
s
.8921 .70093 m
.88218 .73148 L
s
.8921 .70093 m
.92422 .70093 L
s
.92422 .2822 m
.8921 .2822 L
s
.92422 .2822 m
.9143 .25165 L
s
.92422 .2822 m
.8921 .2822 L
s
.92422 .70093 m
.8921 .70093 L
s
.92422 .70093 m
.9143 .73148 L
s
.92422 .70093 m
.8921 .70093 L
s
.60015 .44214 m
.61007 .47269 L
s
.60015 .44214 m
.61007 .41159 L
s
.60015 .44214 m
.61007 .41159 L
s
.60015 .44214 m
.61007 .41159 L
s
.39985 .12226 m
.43197 .12226 L
s
.39985 .12226 m
.42584 .10338 L
s
.39985 .12226 m
.43197 .12226 L
s
.39985 .86087 m
.43197 .86087 L
s
.39985 .86087 m
.42584 .87975 L
s
.39985 .86087 m
.43197 .86087 L
s
.43197 .02341 m
.39985 .02341 L
s
.43197 .95972 m
.39985 .95972 L
s
.43197 .12226 m
.45796 .10338 L
s
.43197 .12226 m
.45796 .10338 L
s
.43197 .12226 m
.39985 .12226 L
s
.43197 .86087 m
.45796 .87975 L
s
.43197 .86087 m
.45796 .87975 L
s
.43197 .86087 m
.39985 .86087 L
s
.48394 .12226 m
.51606 .12226 L
s
.48394 .12226 m
.45796 .10338 L
s
.48394 .12226 m
.45796 .10338 L
s
.48394 .12226 m
.51606 .12226 L
s
.48394 .18335 m
.51606 .18335 L
s
.48394 .79978 m
.51606 .79978 L
s
.48394 .86087 m
.51606 .86087 L
s
.48394 .86087 m
.45796 .87975 L
s
.48394 .86087 m
.45796 .87975 L
s
.48394 .86087 m
.51606 .86087 L
s
.51606 .12226 m
.52598 .1528 L
s
.51606 .12226 m
.49007 .10338 L
s
.51606 .12226 m
.49007 .10338 L
s
.51606 .12226 m
.48394 .12226 L
s
.51606 .18335 m
.52598 .1528 L
s
.51606 .79978 m
.52598 .83033 L
s
.51606 .86087 m
.52598 .83033 L
s
.51606 .86087 m
.49007 .87975 L
s
.51606 .86087 m
.49007 .87975 L
s
.51606 .86087 m
.48394 .86087 L
s
.39985 .02341 m
.43197 .02341 L
s
.39985 .95972 m
.43197 .95972 L
s
.8562 .33162 m
.88218 .31274 L
s
.8562 .33162 m
.83021 .31274 L
s
.8562 .33162 m
.84627 .36217 L
s
.8562 .33162 m
.88218 .31274 L
s
.8562 .33162 m
.83021 .31274 L
s
.8562 .33162 m
.84627 .36217 L
s
.8562 .23277 m
.88218 .25165 L
s
.8562 .23277 m
.88218 .25165 L
s
.8562 .23277 m
.88218 .2139 L
s
.8562 .65151 m
.88218 .67039 L
s
.8562 .65151 m
.83021 .67039 L
s
.8562 .65151 m
.84627 .62096 L
s
.8562 .65151 m
.86612 .62096 L
s
.8562 .65151 m
.88218 .67039 L
s
.8562 .65151 m
.83021 .67039 L
s
.8562 .65151 m
.84627 .62096 L
s
.8562 .65151 m
.86612 .62096 L
s
.8562 .75036 m
.88218 .73148 L
s
.8562 .75036 m
.88218 .73148 L
s
.8562 .75036 m
.88218 .76923 L
s
.88218 .31274 m
.8921 .2822 L
s
.88218 .31274 m
.8921 .2822 L
s
.88218 .25165 m
.8921 .2822 L
s
.88218 .25165 m
.9143 .25165 L
s
.88218 .25165 m
.8921 .2822 L
s
.88218 .67039 m
.8921 .70093 L
s
.88218 .67039 m
.8921 .70093 L
s
.88218 .73148 m
.8921 .70093 L
s
.88218 .73148 m
.9143 .73148 L
s
.88218 .73148 m
.8921 .70093 L
s
.64598 .20223 m
.6781 .20223 L
s
.64598 .20223 m
.63605 .17168 L
s
.64598 .20223 m
.6781 .20223 L
s
.64598 .26332 m
.62 .2822 L
s
.64598 .26332 m
.62 .2822 L
s
.64598 .71981 m
.6781 .71981 L
s
.64598 .71981 m
.62 .70093 L
s
.64598 .71981 m
.63605 .68926 L
s
.64598 .71981 m
.62 .70093 L
s
.64598 .7809 m
.6781 .7809 L
s
.64598 .7809 m
.63605 .81145 L
s
.64598 .7809 m
.6781 .7809 L
s
.6781 .20223 m
.66817 .17168 L
s
.6781 .20223 m
.64598 .20223 L
s
.6781 .71981 m
.70408 .70093 L
s
.6781 .7809 m
.66817 .81145 L
s
.6781 .7809 m
.64598 .7809 L
s
.62 .2822 m
.61007 .31274 L
s
.62 .70093 m
.61007 .67039 L
s
.62 .70093 m
.61007 .67039 L
s
.63605 .49156 m
.66817 .49156 L
s
.63605 .49156 m
.61007 .47269 L
s
.63605 .49156 m
.61007 .51044 L
s
.63605 .49156 m
.64598 .46102 L
s
.63605 .49156 m
.64598 .52211 L
s
.63605 .49156 m
.66817 .49156 L
s
.63605 .49156 m
.64598 .52211 L
s
.63605 .43047 m
.66817 .43047 L
s
.63605 .43047 m
.61007 .41159 L
s
.63605 .43047 m
.64598 .46102 L
s
.63605 .43047 m
.61007 .41159 L
s
.63605 .43047 m
.66204 .41159 L
s
.63605 .43047 m
.66817 .43047 L
s
.63605 .43047 m
.61007 .41159 L
s
.63605 .55266 m
.61007 .57154 L
s
.63605 .55266 m
.64598 .52211 L
s
.63605 .55266 m
.61007 .57154 L
s
.63605 .55266 m
.66204 .57154 L
s
.63605 .55266 m
.61007 .57154 L
s
.63605 .55266 m
.64598 .52211 L
s
.63605 .39272 m
.66817 .39272 L
s
.63605 .39272 m
.61007 .41159 L
s
.63605 .39272 m
.62613 .36217 L
s
.63605 .39272 m
.64598 .36217 L
s
.63605 .39272 m
.61007 .41159 L
s
.63605 .39272 m
.66204 .41159 L
s
.63605 .39272 m
.66817 .39272 L
s
.63605 .39272 m
.61007 .41159 L
s
.63605 .59041 m
.66817 .59041 L
s
.63605 .59041 m
.61007 .57154 L
s
.63605 .59041 m
.62613 .62096 L
s
.63605 .59041 m
.64598 .62096 L
s
.63605 .59041 m
.61007 .57154 L
s
.63605 .59041 m
.66204 .57154 L
s
.63605 .59041 m
.66817 .59041 L
s
.63605 .59041 m
.61007 .57154 L
s
.63605 .17168 m
.66817 .17168 L
s
.63605 .17168 m
.64598 .20223 L
s
.63605 .81145 m
.66817 .81145 L
s
.63605 .81145 m
.64598 .7809 L
s
.66817 .49156 m
.6781 .46102 L
s
.66817 .49156 m
.6781 .52211 L
s
.66817 .49156 m
.69416 .47269 L
s
.66817 .49156 m
.69416 .51044 L
s
.66817 .49156 m
.6781 .46102 L
s
.66817 .49156 m
.6781 .52211 L
s
.66817 .43047 m
.6781 .46102 L
s
.66817 .43047 m
.69416 .41159 L
s
.66817 .43047 m
.63605 .43047 L
s
.66817 .43047 m
.6781 .46102 L
s
.66817 .39272 m
.6781 .36217 L
s
.66817 .39272 m
.63605 .39272 L
s
.66817 .39272 m
.69416 .41159 L
s
.66817 .39272 m
.63605 .39272 L
s
.66817 .39272 m
.6781 .36217 L
s
.66817 .59041 m
.6781 .62096 L
s
.66817 .59041 m
.63605 .59041 L
s
.66817 .59041 m
.69416 .57154 L
s
.66817 .59041 m
.63605 .59041 L
s
.66817 .59041 m
.6781 .62096 L
s
.66817 .17168 m
.6781 .20223 L
s
.66817 .81145 m
.6781 .7809 L
s
.77824 .41159 m
.78817 .38105 L
s
.77824 .41159 m
.78817 .44214 L
s
.77824 .41159 m
.78817 .38105 L
s
.61007 .47269 m
.58409 .49156 L
s
.61007 .51044 m
.58409 .49156 L
s
.61007 .51044 m
.62 .54099 L
s
.61007 .41159 m
.60015 .38105 L
s
.61007 .41159 m
.63605 .39272 L
s
.61007 .41159 m
.63605 .43047 L
s
.61007 .41159 m
.63605 .39272 L
s
.61007 .57154 m
.60015 .60208 L
s
.61007 .57154 m
.62 .54099 L
s
.61007 .57154 m
.63605 .59041 L
s
.61007 .57154 m
.63605 .55266 L
s
.61007 .57154 m
.63605 .59041 L
s
.52598 .1528 m
.51606 .12226 L
s
.52598 .83033 m
.51606 .86087 L
s
.62613 .36217 m
.60015 .38105 L
s
.62613 .36217 m
.63605 .39272 L
s
.62613 .36217 m
.63605 .33162 L
s
.62613 .36217 m
.63605 .39272 L
s
.62613 .62096 m
.60015 .60208 L
s
.62613 .62096 m
.60015 .63984 L
s
.62613 .62096 m
.63605 .59041 L
s
.62613 .62096 m
.63605 .65151 L
s
.62613 .62096 m
.63605 .59041 L
s
.8921 .2822 m
.88218 .25165 L
s
.8921 .2822 m
.92422 .2822 L
s
.8921 .70093 m
.88218 .73148 L
s
.8921 .70093 m
.92422 .70093 L
s
.60015 .38105 m
.61007 .41159 L
s
.60015 .38105 m
.61007 .3505 L
s
.60015 .38105 m
.61007 .41159 L
s
.60015 .60208 m
.57416 .62096 L
s
.60015 .60208 m
.61007 .57154 L
s
.60015 .60208 m
.61007 .57154 L
s
.60015 .63984 m
.57416 .62096 L
s
.60015 .63984 m
.61007 .67039 L
s
.60015 .63984 m
.61007 .67039 L
s
.57416 .62096 m
.58409 .65151 L
s
.64598 .46102 m
.6781 .46102 L
s
.64598 .46102 m
.63605 .43047 L
s
.64598 .46102 m
.6781 .46102 L
s
.64598 .52211 m
.6781 .52211 L
s
.64598 .52211 m
.62 .54099 L
s
.64598 .52211 m
.63605 .55266 L
s
.64598 .52211 m
.67196 .54099 L
s
.64598 .52211 m
.6781 .52211 L
s
.64598 .36217 m
.6781 .36217 L
s
.64598 .36217 m
.63605 .39272 L
s
.64598 .36217 m
.63605 .33162 L
s
.64598 .36217 m
.63605 .39272 L
s
.64598 .36217 m
.6781 .36217 L
s
.64598 .62096 m
.6781 .62096 L
s
.64598 .62096 m
.63605 .59041 L
s
.64598 .62096 m
.63605 .65151 L
s
.64598 .62096 m
.63605 .59041 L
s
.64598 .62096 m
.6781 .62096 L
s
.64598 .20223 m
.6781 .20223 L
s
.64598 .7809 m
.6781 .7809 L
s
.6781 .46102 m
.66817 .49156 L
s
.6781 .46102 m
.66817 .43047 L
s
.6781 .46102 m
.70408 .44214 L
s
.6781 .52211 m
.66817 .49156 L
s
.6781 .52211 m
.70408 .54099 L
s
.6781 .52211 m
.64598 .52211 L
s
.6781 .36217 m
.66817 .33162 L
s
.6781 .36217 m
.70408 .34329 L
s
.6781 .36217 m
.66817 .39272 L
s
.6781 .36217 m
.70408 .34329 L
s
.6781 .36217 m
.70408 .38105 L
s
.6781 .62096 m
.66817 .65151 L
s
.6781 .62096 m
.70408 .63984 L
s
.6781 .62096 m
.66817 .59041 L
s
.6781 .62096 m
.70408 .60208 L
s
.6781 .62096 m
.70408 .63984 L
s
.81415 .36217 m
.84627 .36217 L
s
.81415 .36217 m
.78817 .38105 L
s
.81415 .36217 m
.78817 .34329 L
s
.81415 .36217 m
.78817 .38105 L
s
.81415 .62096 m
.84627 .62096 L
s
.81415 .62096 m
.78817 .60208 L
s
.81415 .62096 m
.78817 .60208 L
s
.81415 .62096 m
.78817 .63984 L
s
.84627 .46102 m
.82029 .44214 L
s
.84627 .52211 m
.82029 .54099 L
s
.84627 .36217 m
.82029 .38105 L
s
.84627 .36217 m
.82029 .38105 L
s
.78817 .38105 m
.82029 .38105 L
s
.78817 .38105 m
.82029 .38105 L
s
.78817 .38105 m
.76218 .36217 L
s
.78817 .44214 m
.82029 .44214 L
s
.78817 .54099 m
.82029 .54099 L
s
.78817 .60208 m
.76218 .62096 L
s
.82029 .38105 m
.78817 .38105 L
s
.62 .54099 m
.61007 .57154 L
s
.62 .54099 m
.61007 .57154 L
s
.62 .54099 m
.64598 .52211 L
s
.78817 .34329 m
.76218 .36217 L
s
.78817 .38105 m
.82029 .38105 L
s
.78817 .38105 m
.76218 .36217 L
s
.78817 .60208 m
.76218 .62096 L
s
.78817 .63984 m
.76218 .62096 L
s
.63605 .39272 m
.61007 .41159 L
s
.63605 .39272 m
.66204 .41159 L
s
.63605 .39272 m
.66817 .39272 L
s
.63605 .39272 m
.61007 .41159 L
s
.63605 .59041 m
.61007 .57154 L
s
.63605 .59041 m
.66204 .57154 L
s
.63605 .59041 m
.66817 .59041 L
s
.63605 .59041 m
.61007 .57154 L
s
.63605 .33162 m
.66817 .33162 L
s
.63605 .33162 m
.61007 .31274 L
s
.63605 .33162 m
.61007 .3505 L
s
.63605 .65151 m
.66817 .65151 L
s
.63605 .65151 m
.61007 .67039 L
s
.63605 .65151 m
.61007 .67039 L
s
.63605 .68926 m
.61007 .67039 L
s
.63605 .68926 m
.61007 .67039 L
s
.66817 .33162 m
.6781 .36217 L
s
.66817 .33162 m
.69416 .31274 L
s
.66817 .65151 m
.6781 .62096 L
s
.66817 .65151 m
.69416 .67039 L
s
.57795 .31274 m
.61007 .31274 L
s
.57795 .31274 m
.55197 .33162 L
s
.57795 .31274 m
.56803 .2822 L
s
.57795 .67039 m
.61007 .67039 L
s
.57795 .67039 m
.61007 .67039 L
s
.57795 .67039 m
.55197 .65151 L
s
.57795 .67039 m
.56803 .70093 L
s
.61007 .41159 m
.63605 .43047 L
s
.61007 .41159 m
.63605 .39272 L
s
.61007 .57154 m
.63605 .55266 L
s
.61007 .57154 m
.63605 .59041 L
s
.61007 .31274 m
.58409 .33162 L
s
.61007 .31274 m
.60015 .2822 L
s
.61007 .31274 m
.62 .2822 L
s
.61007 .3505 m
.58409 .33162 L
s
.61007 .67039 m
.58409 .65151 L
s
.61007 .67039 m
.60015 .70093 L
s
.61007 .67039 m
.62 .70093 L
s
.61007 .67039 m
.58409 .65151 L
s
.61007 .67039 m
.60015 .70093 L
s
.61007 .67039 m
.62 .70093 L
s
.55197 .33162 m
.58409 .33162 L
s
.55197 .33162 m
.54204 .30108 L
s
.55197 .65151 m
.58409 .65151 L
s
.55197 .65151 m
.54204 .68205 L
s
.56803 .2822 m
.60015 .2822 L
s
.56803 .2822 m
.54204 .30108 L
s
.56803 .2822 m
.54204 .26332 L
s
.56803 .70093 m
.60015 .70093 L
s
.56803 .70093 m
.54204 .68205 L
s
.56803 .70093 m
.54204 .71981 L
s
.54204 .30108 m
.51606 .2822 L
s
.54204 .30108 m
.51606 .2822 L
s
.54204 .26332 m
.51606 .2822 L
s
.54204 .26332 m
.51606 .2822 L
s
.54204 .68205 m
.51606 .70093 L
s
.54204 .68205 m
.51606 .70093 L
s
.54204 .71981 m
.51606 .70093 L
s
.54204 .71981 m
.51606 .70093 L
s
.42584 .10338 m
.45796 .10338 L
s
.42584 .10338 m
.45796 .10338 L
s
.42584 .10338 m
.39985 .12226 L
s
.42584 .87975 m
.45796 .87975 L
s
.42584 .87975 m
.45796 .87975 L
s
.42584 .87975 m
.39985 .86087 L
s
.45796 .10338 m
.49007 .10338 L
s
.45796 .10338 m
.49007 .10338 L
s
.45796 .10338 m
.43197 .12226 L
s
.45796 .10338 m
.48394 .12226 L
s
.45796 .10338 m
.49007 .10338 L
s
.45796 .10338 m
.49007 .10338 L
s
.45796 .10338 m
.43197 .12226 L
s
.45796 .10338 m
.48394 .12226 L
s
.45796 .87975 m
.49007 .87975 L
s
.45796 .87975 m
.49007 .87975 L
s
.45796 .87975 m
.43197 .86087 L
s
.45796 .87975 m
.48394 .86087 L
s
.45796 .87975 m
.49007 .87975 L
s
.45796 .87975 m
.49007 .87975 L
s
.45796 .87975 m
.43197 .86087 L
s
.45796 .87975 m
.48394 .86087 L
s
.49007 .10338 m
.51606 .12226 L
s
.49007 .10338 m
.51606 .12226 L
s
.49007 .87975 m
.51606 .86087 L
s
.49007 .87975 m
.51606 .86087 L
s
.39985 .12226 m
.43197 .12226 L
s
.39985 .86087 m
.43197 .86087 L
s
.48394 .12226 m
.51606 .12226 L
s
.48394 .86087 m
.51606 .86087 L
s
.88218 .25165 m
.9143 .25165 L
s
.88218 .25165 m
.8921 .2822 L
s
.88218 .73148 m
.9143 .73148 L
s
.88218 .73148 m
.8921 .70093 L
s
.9143 .25165 m
.92422 .2822 L
s
.9143 .73148 m
.92422 .70093 L
s
.8921 .2822 m
.92422 .2822 L
s
.8921 .70093 m
.92422 .70093 L
s
.70408 .2822 m
.7362 .2822 L
s
.70408 .2822 m
.69416 .31274 L
s
.70408 .34329 m
.6781 .36217 L
s
.70408 .34329 m
.69416 .31274 L
s
.70408 .63984 m
.6781 .62096 L
s
.70408 .63984 m
.69416 .67039 L
s
.70408 .70093 m
.7362 .70093 L
s
.70408 .70093 m
.69416 .67039 L
s
.66204 .41159 m
.69416 .41159 L
s
.66204 .41159 m
.63605 .43047 L
s
.66204 .41159 m
.63605 .39272 L
s
.66204 .57154 m
.69416 .57154 L
s
.66204 .57154 m
.63605 .55266 L
s
.66204 .57154 m
.63605 .59041 L
s
.66204 .57154 m
.67196 .54099 L
s
.69416 .47269 m
.66817 .49156 L
s
.69416 .47269 m
.70408 .44214 L
s
.69416 .51044 m
.66817 .49156 L
s
.69416 .51044 m
.70408 .54099 L
s
.69416 .41159 m
.72627 .41159 L
s
.69416 .41159 m
.66817 .43047 L
s
.69416 .41159 m
.66817 .39272 L
s
.69416 .41159 m
.70408 .38105 L
s
.69416 .41159 m
.70408 .44214 L
s
.69416 .57154 m
.66817 .59041 L
s
.69416 .57154 m
.70408 .54099 L
s
.69416 .57154 m
.70408 .60208 L
s
.72627 .41159 m
.7362 .44214 L
s
.63605 .43047 m
.66817 .43047 L
s
.63605 .43047 m
.61007 .41159 L
s
.63605 .55266 m
.61007 .57154 L
s
.63605 .55266 m
.64598 .52211 L
s
.63605 .39272 m
.66817 .39272 L
s
.63605 .39272 m
.61007 .41159 L
s
.63605 .59041 m
.66817 .59041 L
s
.63605 .59041 m
.61007 .57154 L
s
.66817 .49156 m
.6781 .46102 L
s
.66817 .49156 m
.6781 .52211 L
s
.66817 .43047 m
.6781 .46102 L
s
.66817 .39272 m
.6781 .36217 L
s
.66817 .59041 m
.6781 .62096 L
s
.67196 .54099 m
.70408 .54099 L
s
.67196 .54099 m
.64598 .52211 L
s
.70408 .34329 m
.6781 .36217 L
s
.70408 .34329 m
.69416 .31274 L
s
.70408 .38105 m
.6781 .36217 L
s
.70408 .44214 m
.7362 .44214 L
s
.70408 .44214 m
.6781 .46102 L
s
.70408 .54099 m
.7362 .54099 L
s
.70408 .54099 m
.6781 .52211 L
s
.70408 .60208 m
.6781 .62096 L
s
.70408 .63984 m
.6781 .62096 L
s
.70408 .63984 m
.69416 .67039 L
s
.64598 .52211 m
.6781 .52211 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[410]:=",
  ImageSize->{513.438, 504.813},
  ImageMargins->{{0, 0}, {0, 98.0625}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000810001n2000`400?l00000o`00003oo`3ooooo
0?ooo`<0oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo
003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo003o0?ooool0
oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo003o0?ooool0oooo0`3oool0
0?l0ooooo`3oool30?ooo`00c03ooolB000001T0oooo4P00000J0?oooa400000c@3oool00<`0oooo
00<000000?ooo`3oool03P3oool3000001D0oooo0`00000@0?ooo`<000005P3oool3000000l0oooo
00<000000?ooo`3oool0b`3oool00</0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?oo
o`3oool0000001<0oooo00<000000?ooo`000000403oool01@000000oooo0000003oool0000001@0
oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo0<X0oooo003;0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool2000000l0oooo0P0000020?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`0000000P3oool200000100oooo0P0000040?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0bP3oool00</0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
bP3oool00<X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`050000003o
ool0oooo0?ooo`000000103oool00`000000oooo0?ooo`090?ooo`800000203oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0<T0oooo003:0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01`3oool2000000L0oooo0P0000050?ooo`030000003oool0oooo00h0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`8000001`3oool2000000X0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`390?ooo`00bP3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00h0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0<T0oooo
00390?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`00
0000000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo0P0000000`3oool000000000000>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0b03oool00;D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2c
0?ooo`00]@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0;<0oooo002f0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0]03oool00;H0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`2d0?ooo`00]P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0;D0oooo002g0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0]@3oool0
09`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0=0?oooa8000003`3oool00`00
0000oooo0?ooo`070?oooa8000002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00h0oooo4@00000@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0V`3oool009/0
oooo00@000000?ooo`0000000000603oool00`000000oooo0?ooo`0<0?ooo`040000003oool00000
000000l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`800000403oool0
0`000000oooo0?ooo`070?ooo`800000203oool00`000000oooo0?ooo`0<0?ooo`8000003`3oool0
0`000000oooo0000000>0?ooo`030000003oool0oooo01L0oooo00@000000?ooo`0000000000V`3o
ool009T0oooo0P0000040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool2
000000@0oooo00<000000?ooo`3oool03@3oool2000000/0oooo00<000000?ooo`3oool01@3oool2
00000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo008000001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo0P000003
0?ooo`800000303oool00`000000oooo0?ooo`0E0?ooo`800000103oool00`000000oooo0?ooo`2H
0?ooo`00V03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2G0?ooo`00U`3oool00`000000oooo0?ooo`070?ooo`80
00005@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000000l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01`3oool2000009L0oooo002E0?ooo`800000303oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00D0oooo0P00000<0?ooo`030000003oool0oooo00d0oooo0P0000070?ooo`040000
003oool0oooo0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0=0?ooo`8000002`3oool2000000L0oooo00<000000?ooo`3oool04P3oool2000000`0
oooo00<000000?ooo`3oool0U03oool009@0oooo00<000000?ooo`3oool03@3oool2000001<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`8000003`3oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool00000
00D0oooo0P00000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo0P00002D0?ooo`00T`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0940oooo002A0?ooo`800000503oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00800000503oool00`000000oooo0?ooo`0=0?oo
o`8000000P3oool3000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo0`0000030?ooo`030000003oool0oooo00d0oooo0P00000C0?oo
o`8000000P3oool00`000000oooo0?ooo`0?0?ooo`800000503oool00`000000oooo0?ooo`2@0?oo
o`00T03oool00`000000oooo0?ooo`0E0?ooo`800000403oool2000001L0oooo0P00000?0?ooo`<0
00003P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003P3oool40000
00l0oooo00<000000?ooo`3oool05@3oool200000140oooo00<000000?ooo`3oool05@3oool20000
0900oooo002?0?ooo`030000003oool0oooo01P0oooo4@00000J0?oooa4000003`3oool00`000000
oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3ooolB000001T0oooo4P00000J0?oo
o`030000003oool0oooo08d0oooo002?0?ooo`8000005`3oool3000000l0oooo0P00000G0?ooo`<0
00003`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3o
ool0oooo0000000?0?ooo`030000003oool0oooo00h0oooo0P00000G0?ooo`800000403oool20000
01L0oooo0`00002?0?ooo`00SP3oool00`000000oooo0?ooo`02000001@0oooo00<000000?ooo`00
00003`3oool00`000000oooo00000002000001@0oooo00D000000?ooo`3oool0oooo0000000?0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P00000C0?ooo`<0000000<0oooo0000
003oool03`3oool3000001@0oooo00D000000?ooo`3oool0oooo0000002>0?ooo`00SP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000003`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`060000003oool0oooo0000003oool00000403oool010000000oooo
0?ooo`00000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0S03oool008h0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool03@3oool2000000D0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03@3oool01`000000oooo0?ooo`3oool000000?ooo`000000403oool01@00
0000oooo0?ooo`3oool0000000l0oooo0P0000050?ooo`030000003oool0oooo08`0oooo002=0?oo
o`030000003oool0oooo00D0oooo0P00000<0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool01@000000oooo0?ooo`3oool0000000<0oooo0P00000<0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00D0oooo0P00000;0?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000100oooo00@0
00000?ooo`3oool0oooo0P00000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
R`3oool008d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`8000001@3o
ool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
0?ooo`070?ooo`8000002@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo
4P00000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000000T0oooo00<000000?ooo`3o
ool0R`3oool008d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0R`3oool008`0oooo00<000000?ooo`3oool02P3oool2000000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool2000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00X0oooo0P00000?0?ooo`8000000`3oool2000000/0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`8000000`3oool2000000H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo
0P0000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0R`3oool008`0oooo00<0
00000?ooo`3oool0303oool010000000oooo0000000000080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`040000003oool00000000000h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0303oool00`000000oooo000000080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`040000003oool000000000
00h0oooo00<000000?ooo`3oool0RP3oool008`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0RP3oool008`0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`8000003`3oool2000000/0oooo
0P0000070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0RP3oool008/0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0R@3oool008/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0R@3oool008/0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`02000000l0oooo0P00000C0?ooo`8000000P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo08T0oooo002:0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo0P00000@0?ooo`030000003oool0oooo01D0oooo0P00000@0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo08P0
oooo001i0?oooa8000003`3oool00`000000oooo0?ooo`070?oooa8000002@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00h0oooo8P00000I0?oooa8000003`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo4@0000090?ooo`030000003oool0oooo00h0oooo
4@00001j0?ooo`00M`3oool2000000030?ooo`000000000000l0oooo0P00000=0?ooo`030000003o
ool0oooo00D0oooo0`00000@0?ooo`030000003oool0oooo00L0oooo0`0000070?ooo`030000003o
ool0oooo00`0oooo0P00000>0?ooo`D000003`3oool2000001D0oooo1@00000?0?ooo`8000003@3o
ool00`000000oooo0?ooo`050?ooo`<000002P3oool00`000000oooo0?ooo`0=0?ooo`<000001`3o
ool00`000000oooo0?ooo`0<0?ooo`8000003P3oool2000000030?ooo`000000000007P0oooo001f
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo000000030?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool04@3oool01`000000oooo0?ooo`3oool000000?ooo`000000403oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo07D0oooo001d0?ooo`8000001`3oool2000000l0oooo0P0000090?ooo`030000003oool0
oooo00<0oooo0P0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`8000003P3oool2
00000080oooo00<000000?ooo`3oool00P3oool2000000l0oooo0P00000?0?ooo`800000103oool0
0`000000oooo0?ooo`02000000l0oooo0P0000090?ooo`030000003oool0oooo00<0oooo0P000004
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`02
0?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`8000003P3oool2000000L0oooo0P00001e
0?ooo`00L`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0780oooo001b0?ooo`03
0000003oool0oooo00/0oooo0P00000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool2000000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo0P00000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool2000000l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1a0?ooo`00
L03oool200000100oooo0P00000>0?ooo`800000103oool00`000000oooo0?ooo`02000000T0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
0P0000020?ooo`030000003oool0oooo0080oooo0P00000?0?ooo`8000001@3oool00`000000oooo
0?ooo`070?ooo`8000003`3oool2000000L0oooo0P0000090?ooo`030000003oool0oooo00@0oooo
0P00000>0?ooo`800000103oool00`000000oooo0?ooo`02000000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo0P0000020?ooo`030000
003oool0oooo0080oooo0P00000?0?ooo`8000003`3oool200000740oooo001_0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool03@3oool01`000000oooo0?ooo`3oool000000?ooo`00
0000303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo000000030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool03@3oool01`000000oooo0?ooo`3oool000000?ooo`0000002`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1^
0?ooo`00K@3oool2000001H0oooo0P00000>0?ooo`D000003@3oool00`000000oooo0?ooo`0>0?oo
o`050000003oool0oooo0?ooo`0000003@3oool5000000l0oooo0P0000070?ooo`030000003oool0
oooo00/0oooo0P00000?0?ooo`80000000<0oooo0000000000003@3oool00`000000oooo0?ooo`06
0?ooo`8000003P3oool5000000d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00/0oooo1@00000?0?ooo`8000005@3oool2000006h0oooo001/0?oo
o`030000003oool0oooo01P0oooo4@00000@0?ooo`030000003oool0oooo00d0oooo00D000000?oo
o`3oool0oooo0000000?0?oooa8000002@3oool00`000000oooo0?ooo`0=0?oooa8000003`3oool0
0`000000oooo0?ooo`080?oooa4000003`3oool01@000000oooo0?ooo`3oool000000100oooo00<0
00000?ooo`3oool03@3ooolB000001T0oooo00<000000?ooo`3oool0J`3oool006`0oooo0P00000G
0?ooo`<000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00D00000
0?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3o
ool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`8000005`3oool2000006d0oooo001[0?ooo`030000003oool0000000800000503o
ool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`040000003oool0oooo000000l0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo008000004`3oool3000000030?ooo`000000oooo06/0
oooo001[0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool01P000000oooo
0?ooo`000000oooo000006`0oooo001[0?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool03@3oool2000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`07
0000003oool0oooo0?ooo`000000oooo0000001/0?ooo`00JP3oool01@000000oooo0?ooo`3oool0
000000<0oooo0P00000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`050?ooo`8000002`3oool2000000<0oooo00D000000?ooo`3oool0oooo0000001[0?ooo`00JP3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01`3oool2000000T0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oooa4000003`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3ooolB000000l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool0000006/0oooo001Z0?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`8000003`3oool00`000000oooo0000000>0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000>0?oo
o`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`040000003oool0
0000000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`040000003o
ool00000000000l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000
003oool0oooo0?ooo`000000J`3oool006T0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`050?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`8000000`3oool2000000/0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool2000000/0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo
0P0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`8000002`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00X0oooo0P0000030?ooo`8000001P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo06T0oooo001Y0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool010000000oooo00000000000>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1X0?ooo`00J@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P00
00050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0J03oool006T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00d0oooo0P00000;0?ooo`8000001`3oool00`000000oooo0?ooo`0>
0?ooo`040000003oool0oooo0?ooo`8000002`3oool2000000L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P00000<0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`800000303o
ool00`000000oooo0?ooo`0=0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo06P0oooo001X0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool2
000000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00d0oooo0P00000?0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`00J03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool010000000oooo0?oo
o`00000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1W0?ooo`00J03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000
3`3oool2000001<0oooo0P0000020?ooo`030000003oool0oooo00h0oooo0`00000C0?ooo`800000
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P00000D0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool00P00000D0?ooo`030000
003oool0oooo00d0oooo0P0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
I`3oool006L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool3000000l0oooo00<000000?ooo`3oool05@3o
ool200000100oooo0P00000G0?ooo`800000403oool00`000000oooo0?ooo`070?ooo`8000005`3o
ool3000000l0oooo0P00000G0?ooo`8000003`3oool200000100oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0IP3o
ool005L0oooo4@0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3ooolR
000001T0oooo4P00000I0?oooa8000002@3oool00`000000oooo0?ooo`0H0?oooa4000006P3ooolR
000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oooa800000E`3oool0
05D0oooo0`00000?0?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`030000003oool0oooo
00`0oooo0P00000?0?ooo`@000003`3oool00`000000oooo0?ooo`0E0?ooo`800000403oool20000
01L0oooo0P00000@0?ooo`030000003oool0oooo00L0oooo0P00000G0?ooo`<000003`3oool20000
01L0oooo0P00000?0?ooo`@000003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00H0oooo0P0000090?ooo`030000003oool0oooo00h0oooo0P00001F0?ooo`00E03oool01@000000
oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020000
00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`<000000`3oool00`00
0000oooo0?ooo`0=0?ooo`8000004`3oool200000080oooo00<000000?ooo`3oool03P3oool30000
01<0oooo0P0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`02000001@0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`020000
01@0oooo00<000000?ooo`3oool03@3oool200000080oooo00<000000?ooo`0000003`3oool20000
00/0oooo00<000000?ooo`3oool01@3oool200000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00800000E03oool005<0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00@000000?oo
o`3oool000004@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00@00000
0?ooo`3oool000003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000100oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0D@3oool00540oooo0P0000050?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01`3oool2000000l0oooo00D000000?ooo`3oool0oooo000000050?ooo`800000
3`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3P3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0=0?ooo`8000000`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03@3oool2000000l0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`3oool2000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D03oool00500oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool2000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`80
00000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo0P00000;0?ooo`80
00001`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0?ooo`8000002`3oool20000
00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo0P00000<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`050?ooo`800000303oool00`000000oooo0?ooo`0=0?ooo`8000001`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo0P0000070?ooo`040000003oool0oooo
0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool200000500oooo001>0?ooo`8000002@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0
000000D0oooo0P00000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2
000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool2000000l0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0C@3oool004d0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04`0oooo
001<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00X0oooo0`0000030?ooo`030000003oool0oooo00d0oooo0P00
00060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool2000000<0oooo0P00
000;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool2000000<0oooo0P00
000;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0:0?ooo`800000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02P3oool2000000@0oooo00<000000?ooo`3oool03@3oool2000000/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool3000000/0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo0P00
001<0?ooo`00BP3oool2000000h0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3o
ool0000000h0oooo1000000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303o
ool2000000l0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0>0?ooo`050000003o
ool0oooo0?ooo`0000003P3oool010000000oooo0000000000080?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0303oool010000000oooo00000000000?0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01P3oool2000000l0oooo0`00000>0?ooo`050000003oool0oooo
0?ooo`000000403oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04T0oooo00190?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0
000000l0oooo4P0000090?ooo`030000003oool0oooo00h0oooo4@00000?0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oooa8000003`3oool00`000000oooo0?oo
o`080?oooa4000003`3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`180?ooo`00B@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
00003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3o
ool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0B03oool004X0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000l0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04T0
oooo001:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000003`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`190?ooo`00BP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0B@3oool004/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?oo
o`3oool0000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`050000
003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1:0?ooo`00B`3oool00`000000oooo
0?ooo`0>0?oooa4000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`00
00003`3ooolB000000T0oooo00<000000?ooo`3oool03@3ooolB000000l0oooo00<000000?ooo`3o
ool0203ooolA000000l0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo4P00000?0?ooo`030000003oool0oooo04X0oooo001;0?ooo`030000003oool0oooo00`0
oooo0P00000>0?ooo`80000000<0oooo0000000000003@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00D0oooo0P0000000`3oool000000000000=0?ooo`030000003oool0oooo00h0
oooo00D000000?ooo`3oool0oooo0000000=0?ooo`D000003`3oool2000000L0oooo00<000000?oo
o`3oool02`3oool2000000l0oooo0P0000000`3oool000000000000=0?ooo`030000003oool0oooo
00H0oooo0P00000>0?ooo`D000003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`000000000000P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo0000000000003`3oool20000
00d0oooo00<000000?ooo`3oool0BP3oool004`0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0=0?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0B`3oool004`0oooo00<000000?ooo`3oool0203oool20000
00h0oooo0P0000070?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00<0oooo0P0000070?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool200000080oooo00<000000?ooo`3oool00P3oool20000
00l0oooo0P0000050?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`8000001`3oool20000
00T0oooo00<000000?ooo`3oool0103oool2000000h0oooo0P0000040?ooo`030000003oool0oooo
008000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool2000000L0oooo0P0000060?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool2000000L0oooo0P00000?0?ooo`8000002@3oool00`000000oooo0?ooo`1;0?oo
o`00C03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04/0oooo001=0?ooo`030000
003oool0oooo00@0oooo0P00000?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool2000000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo0P00000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo0P0000040?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`800000
3`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04`0oooo001=0?ooo`030000003o
ool0oooo0080oooo0P00000?0?ooo`8000003`3oool2000000@0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`02000000l0oooo0P0000040?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?oo
o`080?ooo`8000003P3oool200000080oooo00<000000?ooo`3oool00P3oool2000000l0oooo0P00
000?0?ooo`800000103oool00`000000oooo0?ooo`02000000l0oooo0P0000090?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`020?ooo`800000403oool200000080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`020?ooo`800000403oool2000000h0oooo0P0000040?ooo`030000003o
ool0oooo04`0oooo001=0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?oo
o`0A0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0000000C0?ooo`050000
003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`0000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00L000000?oo
o`3oool0oooo0000003oool000000100oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`050?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0=0?ooo`050000
003oool0oooo0?ooo`000000503oool00`000000oooo0000000?0?ooo`050000003oool0oooo0?oo
o`000000503oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000CP3oool0
04h0oooo0`00000?0?ooo`8000005@3oool300000100oooo0`00000E0?ooo`<00000403oool00`00
0000oooo0?ooo`070?ooo`<000001`3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool50000
00l0oooo0P00000E0?ooo`D000003`3oool2000000d0oooo00<000000?ooo`3oool01@3oool30000
00X0oooo00<000000?ooo`3oool03@3oool3000001H0oooo0`00000?0?ooo`<000005P3oool20000
00h0oooo0`00001?0?ooo`00CP3ooolB000001T0oooo4P00000I0?oooa8000002@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo8P00000I0?oooa8000003`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo4@00000J0?oooa4000006P3ooolA000004l0
oooo001>0?ooo`030000003oool0oooo00h0oooo0P00000G0?ooo`800000403oool2000001L0oooo
0P00000@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo0P00000@0?ooo`030000003oool0oooo01D0oooo
0P00000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00d0oooo0P00000G0?ooo`<000003`3oool2000001L0oooo
0`00000?0?ooo`030000003oool0oooo04d0oooo001=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00P00000C0?ooo`<0000000<0oooo0000003oool03`3oool3000001<0oooo0P00
00020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`02000000l0oooo0P00000C0?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00P00000D0?ooo`030000003oool0000000l0oooo00<0
00000?ooo`0000000P00000D0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo
0?ooo`1<0?ooo`00C@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03`3oool01P000000oooo0?ooo`000000oooo00000100oooo00@000000?ooo`3o
ool000004@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00@000000?oo
o`3oool000003`3oool00`000000oooo000000020?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04`0oooo001=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?oo
o`070000003oool0oooo0?ooo`000000oooo0000000@0?ooo`050000003oool0oooo0?ooo`000000
3`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo0P0000030?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0=0?ooo`800000
1@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04`0oooo001<0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01@3oool2000000/0oooo0P0000030?ooo`050000003o
ool0oooo0?ooo`000000403oool010000000oooo0?ooo`3oool2000000/0oooo0P0000070?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`80
00003`3oool2000000/0oooo0P0000070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`050?ooo`800000303oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000030?ooo`800000303oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0B`3oool003`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`000000403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`8000001@3oool00`000000oooo0?ooo`0=0?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`070?ooo`8000002@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0>P3oool0
03d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo
0?ooo`000000403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01P3oool010000000oooo00000000000>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool2000003d0oooo000n0?ooo`8000002`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00X0oooo0P0000030?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01@3oool2000000<0oooo0P00000<0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000103o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3o
ool2000000l0oooo0P0000030?ooo`8000002`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00X0oooo0P0000030?ooo`8000001P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02P3oool2000000@0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool2000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0?@3oool00400oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0000000>0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000
000>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`0000000000203oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool010000000oooo
00000000000>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0n0?ooo`00@@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3o
ool01`3oool2000000T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oooa80
00003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000403oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo0P0000110?ooo`00@P3oool2000000L0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?oo
o`0000000`3oool2000000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool2000000/0oooo0P0000030?oo
o`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0@@3oool004@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0=0?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`070000003oool0oooo
0?ooo`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3o
ool2000004@0oooo00150?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00H000000?ooo`3oool000000?oo
o`00000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`140?ooo`00AP3oool200000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0000000800000503oool01@000000oooo0?ooo`3oool0000000l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02000001<0oooo0`0000000`3oool00000
0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000170?ooo`00
B03oool200000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool2000001L0oooo0`00000?0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000l0
oooo00<000000?ooo`3oool03P3oool2000001L0oooo0P00000@0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo0`0000180?ooo`00B@3ooolB000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?oooa8000002@3oool00`000000oooo0?ooo`0>0?oooa4000006P3ooolA000000l0oooo
00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000l0oooo4P00000I0?oooa80
00003`3oool00`000000oooo0?ooo`080?oooa4000002@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00h0oooo4@00001:0?ooo`00B03oool4000000l0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`060?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`800000
203oool00`000000oooo0?ooo`0<0?ooo`8000003`3oool3000001L0oooo0P00000?0?ooo`<00000
3P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003P3oool4000000l0
oooo00<000000?ooo`3oool05@3oool4000000l0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`060?ooo`<000003`3oool00`000000oooo0?ooo`070?ooo`800000203oool00`000000
oooo0?ooo`0<0?ooo`8000003`3oool4000004P0oooo00160?ooo`8000000P3oool00`000000oooo
0000000?0?ooo`8000002`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P0000060?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool300000080oooo0P00000D0?ooo`030000
003oool0oooo00d0oooo0P0000020?ooo`<000002`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool3000000<0oooo00<000000?ooo`3oool0
3@3oool2000001<0oooo0P0000020?ooo`030000003oool0000000l0oooo0P00000;0?ooo`030000
003oool0oooo00H0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool03@3oool3000000<0oooo00<000000?ooo`3oool0A@3oool004D0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000100oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`140?ooo`00A03oool00`000000oooo
0?ooo`030?ooo`040000003oool0oooo0?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo0P00000?0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`0=0?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000D0oooo0P00000?0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`8000001@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`050000003oool0oooo0?ooo`00
00001@3oool2000004@0oooo00120?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00d0oooo0P0000070?ooo`040000003oool0oooo0?ooo`8000001`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool2000000<0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`8000000`3oool00`000000
oooo0?ooo`050?ooo`800000303oool00`000000oooo0?ooo`0=0?ooo`8000001`3oool010000000
oooo0?ooo`3oool2000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03@3oool2000000/0oooo0P0000070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool03@3oool2000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`8000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo0P0000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0@@3oool00440oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000D0oooo0P00000?
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00000?
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`8000002@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool01@000000oooo0?ooo`3oool0000000D0oooo0P00000?0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool200000440oooo00100?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo03h0oooo000n0?ooo`8000002`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00d0oooo0P0000020?ooo`<000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02P3oool3000000<0oooo00<000000?ooo`3oool03@3oool20000
00H0oooo00<000000?ooo`3oool02P3oool2000000@0oooo00<000000?ooo`3oool03@3oool20000
00/0oooo00<000000?ooo`3oool01@3oool200000080oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo008000001P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00d0oooo0P0000030?ooo`800000303oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00d0oooo0P0000020?ooo`030000003oool0000000`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo0`0000030?oo
o`030000003oool0oooo00d0oooo0P0000060?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0?@3oool003d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`80
00003`3oool3000000h0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo
00`0oooo1000000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool01000
0000oooo00000000000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool2
00000100oooo00<000000?ooo`3oool01`3oool2000000P0oooo00<000000?ooo`3oool0303oool2
000000l0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`060?ooo`8000003`3oool4
000000h0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000h0oooo1000
000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool2000003d0oooo000[
0?oooa8000003`3oool00`000000oooo0?ooo`080?oooa4000003`3oool01@000000oooo0?ooo`3o
ool000000100oooo00<000000?ooo`3oool03@3ooolB000000T0oooo00<000000?ooo`3oool03@3o
oolB000000l0oooo00<000000?ooo`3oool01`3ooolB000000T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0>0?oooa400000403oool00`000000oooo0?ooo`070?oooa400000403o
ool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000003`3ooolB000000T0oooo
00<000000?ooo`3oool03P3ooolA000002`0oooo000[0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo02X0oooo000Z0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000l0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo
00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000
000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000
000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000003`3oool00`000000oooo0?oo
o`0Y0?ooo`00:P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03@3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo02T0oooo000Y
0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`00
0000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?oo
o`0000003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3ooolB000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oooa4000003`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?oo
o`3oool0000000l0oooo00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool03P3o
ool01@000000oooo0?ooo`3oool0000000d0oooo0P0000000`3oool00000000000080?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool2000000030?ooo`000000000000l0oooo
0P00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool2000000030?oo
o`000000000000d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00/0
oooo0P0000000`3oool00000000000070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000000000003P3oool00`000000
oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000003P3oool2000000030?ooo`0000000000
00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool20000
00030?ooo`000000000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?oo
o`80000000<0oooo0000000000003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0:03oool002P0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0W0?oo
o`00:03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01`3oool2000000L0oooo0P0000060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01`3oool2000000L0oooo0P00000?0?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00<0oooo0P0000070?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool2000000L0oooo0P0000050?ooo`03
0000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000050?ooo`8000001`3oool20000
00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00P0oooo0P0000070?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00P0oooo0P00000>0?ooo`8000001`3oool2000000T0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`030?ooo`8000001`3oool2000000T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool09`3oool002L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool2000000@0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo0P00000?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo000000040?ooo`03
0000003oool0oooo00/0oooo0P0000060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`8000003@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool2000000l0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`800000
403oool200000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`800000
403oool2000000h0oooo0P0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0P00000?0?ooo`800000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00P3oool2000000l0oooo0P0000020?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`0000000P3oool200000100oooo0P0000040?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`800000403oool200000080oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`8000003`3oool2000000l0oooo
0P0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P00000?0?ooo`800000
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
9P3oool002L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`050000003o
ool0oooo0?ooo`000000503oool00`000000oooo0000000?0?ooo`050000003oool0oooo0?ooo`00
0000503oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000403oool00`00
0000oooo0000000C0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0>
0?ooo`050000003oool0oooo0?ooo`0000004`3oool00`000000oooo0000000@0?ooo`050000003o
ool000000?ooo`000000503oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3o
ool01@3oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`0000003`3oool01@00
0000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3o
ool000000100oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0V0?ooo`009P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo0`00000F0?ooo`<000003`3oool3000001H0oooo0P00
000>0?ooo`<00000403oool3000001D0oooo0`0000090?ooo`030000003oool0oooo00h0oooo0`00
000E0?ooo`<00000403oool3000001H0oooo0`00000?0?ooo`030000003oool0oooo00L0oooo0`00
000F0?ooo`<000003`3oool3000000l0oooo0P00000E0?ooo`<00000403oool3000001D0oooo0`00
000:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09@3oool002H0oooo4P000009
0?ooo`030000003oool0oooo01P0oooo4@00000J0?ooob8000006@3oool00`000000oooo0?ooo`07
0?oooa8000006@3ooolB000001X0oooo4@0000090?ooo`030000003oool0oooo01P0oooo8P00000I
0?oooa8000006@3oool00`000000oooo0?ooo`080?oooa4000009`3oool002H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`070?ooo`8000005`3oool3000000l0oooo0P00000G0?oo
o`8000003`3oool200000100oooo0P00000G0?ooo`8000002@3oool00`000000oooo0?ooo`0>0?oo
o`8000005`3oool200000100oooo0P00000G0?ooo`<000003`3oool00`000000oooo0?ooo`070?oo
o`<000005`3oool2000000l0oooo0`00000?0?ooo`030000003oool0oooo01D0oooo0P00000@0?oo
o`8000005`3oool2000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0U0?oo
o`009`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P00000D0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool00P00000D0?ooo`03
0000003oool0oooo00d0oooo0P0000020?ooo`030000003oool0oooo00h0oooo0`00000C0?ooo`80
00000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P00000C0?ooo`<00000403oool00`000000oooo00000002000001@0oooo00D000000?ooo`3o
ool0oooo0000000?0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000D
0?ooo`<000003`3oool01@000000oooo0?ooo`3oool0000000l0oooo0P00000C0?ooo`8000000P3o
ool00`000000oooo0?ooo`0>0?ooo`<000004`3oool200000080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo000W0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00@000000?ooo`3oool000003`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00h0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00l0oooo00@000000?ooo`3oool00000403oool00`000000oooo000000020?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`04
0000003oool0oooo000000l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?oo
o`040000003oool0oooo00000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool002L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03@3oool2000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00d0oooo0P00000?0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03P3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0000
00030?ooo`030000003oool0oooo00d0oooo0P0000050?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000003`3oool01@000000oooo0?oo
o`3oool0000000l0oooo00<000000?ooo`3oool00`3oool2000000l0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0
oooo0000000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo000X0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`800000303oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2000000`0oooo
00<000000?ooo`3oool03@3oool2000000L0oooo00<000000?ooo`3oool03P3oool010000000oooo
0?ooo`3oool2000000/0oooo0P0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`050?ooo`8000002`3oool2000000<0oooo00<000000?ooo`3o
ool03P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P00000<0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02P3oool2000000<0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo0P00000;0?ooo`8000001`3oool00`00
0000oooo0?ooo`0>0?ooo`040000003oool0oooo0?ooo`8000002`3oool2000000L0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo000X0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo0P0000050?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`8000003`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo00L0oooo0P0000090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01`3oool2000000l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo0P0000040?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`800000103oool00`000000oooo0?ooo`0=0?oo
o`8000002`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0P0000030?oo
o`8000002`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02P3oool2000000<0oooo0P0000060?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000103oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0080oooo0P0000060?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`8000000`3oool2000000/0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool2000000`0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo000Y0?ooo`03
0000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`040000003oool00000
000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
0000000000l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`0000003P3oool01@000000oooo0?ooo`3oool000000100oooo
00<000000?ooo`3oool0303oool00`000000oooo000000080?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`040000003oool00000000000h0
oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000h0oooo0P0000000`3o
ool000000?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool20000
00l0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool03P3oool01@000000
oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo4P00000?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000403oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3ooolA000000l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00D0
00000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003o
ool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0X
0?ooo`00:P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03@3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo02T0oooo000Z0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool000000100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000?0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0000000l0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`00
00003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`00
00003`3oool00`000000oooo0?ooo`0Y0?ooo`00:`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0Z0?ooo`00:`3ooolB000000l0oooo00<000000?ooo`3o
ool0203ooolA000000l0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo
00d0oooo4P0000090?ooo`030000003oool0oooo00d0oooo4P00000?0?ooo`030000003oool0oooo
00L0oooo4P0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3ooolA0000
0100oooo00<000000?ooo`3oool01`3ooolA00000100oooo00<000000?ooo`3oool03@3oool01@00
0000oooo0?ooo`3oool0000000l0oooo4P0000090?ooo`030000003oool0oooo00h0oooo4@00000/
0?ooo`00:P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000h0oooo00<000000?oo
o`3oool01P3oool2000000l0oooo0`00000>0?ooo`050000003oool0oooo0?ooo`000000403oool0
0`000000oooo0?ooo`0<0?ooo`@000003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00`0oooo00@000000?ooo`00000000003`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo0P00000@0?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`030000003o
ool0oooo00`0oooo0P00000?0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool01P3o
ool2000000l0oooo1000000>0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo
0000000>0?ooo`@000003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo
0P0000000`3oool000000?ooo`0>0?ooo`030000003oool0oooo02T0oooo000X0?ooo`8000003`3o
ool2000000<0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3o
ool200000080oooo0`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0:0?ooo`<000000`3oool00`000000oooo0?ooo`0=0?ooo`8000001P3o
ool00`000000oooo0?ooo`0:0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`8000002`3o
ool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool03@3oool2000000<0oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03@3oool200000080oooo00<000000?ooo`000000303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool3000000<0oooo00<0
00000?ooo`3oool03@3oool2000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`020?ooo`8000003P3oool2000002T0oooo000W0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool09P3oool002H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool2000000l0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00D000000?oo
o`3oool0oooo000000050?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool2000000l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`070?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool2000000l0oooo00<000000?ooo`3oool00`3oool0
10000000oooo0?ooo`3oool2000000T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`800000
3`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P0000090?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool09@3oool002@0oooo0P00000?0?ooo`8000002`3o
ool2000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`8000001`3o
ool010000000oooo0?ooo`3oool2000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3oool01@3oool2000000`0oooo
00<000000?ooo`3oool03@3oool2000000L0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`80
00000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo0P00000;0?ooo`80
00001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo0P0000070?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0=0?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00X0oooo0P00000>0?ooo`8000009@3oool002<0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
oooo0P00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000000l0
oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00d0oooo0P00000?0?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`050000003oool0
oooo0?ooo`0000001@3oool2000000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo0?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo0P0000050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool2000000l0oooo00D000000?ooo`3oool0oooo000000050?ooo`8000003`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0280oooo000R0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000100
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`00
803oool2000000l0oooo0P00000C0?ooo`8000000P3oool00`000000oooo0000000?0?ooo`800000
2`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool03@3oool300000080oooo0P00000D0?ooo`030000003oool0oooo00d0oooo
0P0000020?ooo`<000002`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool3000000<0oooo00<000000?ooo`3oool03@3oool2000001<0oooo
0P0000020?ooo`030000003oool0000000l0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo
00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P0000060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool3000000<0
oooo00<000000?ooo`3oool04P3oool2000000h0oooo0P00000Q0?ooo`007`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01D0oooo1000000?0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool01P3oool2000000T0oooo00<000000?ooo`3oool03P3oool2000000P0oooo
00<000000?ooo`3oool0303oool2000000l0oooo0`00000G0?ooo`8000003`3oool3000000h0oooo
00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000h0oooo1000000?0?ooo`03
0000003oool0oooo01D0oooo1000000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool01P3oool3000000l0oooo00<000000?ooo`3oool01`3oool2000000P0oooo00<000000?ooo`3o
ool0303oool2000000l0oooo1000000G0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool07P3oool001h0oooo4P00000I0?oooa8000003`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo4P0000090?ooo`030000003oool0oooo00h0oooo4@00000J0?oooa400000
3`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3ooolB000001T0
oooo4P00000?0?ooo`030000003oool0oooo00P0oooo4@0000090?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03P3ooolA000001X0oooo4@00000O0?ooo`007P3oool3000000l0oooo
0P00000E0?ooo`<00000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`<000005P3oool3000000l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
00003`3oool00`000000oooo0?ooo`0>0?ooo`<000005@3oool300000100oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool3000001H0oooo0P00000>0?ooo`<000007`3oool001d0oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000000@0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00D000000?ooo`000000oooo0000000D0?ooo`050000003oool0
oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`000000
4`3oool01@000000oooo0000003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool01@000000
oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0
000001h0oooo000M0?ooo`030000003oool0oooo0080oooo0P00000?0?ooo`8000003`3oool20000
00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool00000
0080oooo0P00000@0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00P3oool2000000l0oooo0P0000020?ooo`030000003oool00000
0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`800000403oool20000
00h0oooo0P0000040?ooo`030000003oool0oooo01`0oooo000M0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0L0?ooo`00703oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02@3oool2000000P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000403oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo0P00000;0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`00703oool00`00
0000oooo0?ooo`070?ooo`8000003`3oool2000000L0oooo0P0000090?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000D0oooo0P000007
0?ooo`8000002P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo4P00000?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool2000000L0oooo0P000005
0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00P0oooo0P0000070?ooo`8000003P3oool2000000T0oooo00<000000?ooo`3oool06`3o
ool001`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00/0oooo0P0000000`3oool00000000000070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000000000003@3oool0
0`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0;0?ooo`8000003`3oool2000000030?ooo`000000000000d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3o
ool2000000030?ooo`000000000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo0P0000000`3oool000000000000>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`006`3oool0
0`000000oooo0?ooo`0;0?ooo`8000003`3oool2000000030?ooo`000000000000d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P0000000`3oool000000000
000>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00/0oooo0P0000000`3oool00000000000070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`80000000<0oooo000000000000
3P3oool2000000d0oooo00<000000?ooo`3oool06P3oool001/0oooo00<000000?ooo`3oool03@3o
oolB000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`8000001`3o
ool2000000D0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00<0oooo
0P0000070?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01`3oool2000000l0oooo0P0000070?ooo`8000002@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool2000000L0oooo
0P0000060?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000050?ooo`80
00001`3oool2000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oooa40
00003`3oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool06P3oool001X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000@0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00/0oooo0P0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`0;0?ooo`8000001P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0P3oool2000000l0oooo0P0000020?ooo`030000003oool000000100oooo00<000000?ooo`3oool0
0P00000?0?ooo`800000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00P3oool2000000l0oooo0P00000?0?ooo`800000103oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool200000100oooo
0P0000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000000P3oool200000100oooo
0P0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0000000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06@3oool001X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<0
00000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000001<0oooo00D000000?ooo`000000
oooo0000000@0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0oooo0000000@0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0
oooo0140oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00D0
00000?ooo`3oool0oooo0000000D0?ooo`030000003oool0000000l0oooo00D000000?ooo`000000
oooo0000000D0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0=0?oo
o`040000003oool0oooo000000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0I
0?ooo`006@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`030000003oool0oooo00h0oooo0`00000E0?ooo`<00000403oool3
000001D0oooo0`00000@0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo0`00000?0?ooo`8000005@3oool3
00000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03@3oool3000001H0oooo0`00000?0?ooo`<000005P3oool3
000000l0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000l0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooo`006@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?oooa8000006@3o
oolB000001T0oooo4P0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
oolR000001T0oooo4P00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203o
oolA000001X0oooo4@00000J0?oooa400000403oool01@000000oooo0?ooo`3oool0000000l0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0H0?ooo`006@3oool2000000h0oooo00<0
00000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000h0oooo1000000?0?ooo`030000
003oool0oooo01D0oooo0P00000@0?ooo`8000005`3oool200000100oooo00<000000?ooo`3oool0
1`3oool2000000P0oooo00<000000?ooo`3oool0303oool2000000l0oooo0`00000@0?ooo`030000
003oool0oooo01D0oooo1000000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1P3oool2000000X0oooo00<000000?ooo`3oool03@3oool2000001L0oooo0`00000?0?ooo`800000
5`3oool2000000l0oooo0`00000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`8000006P3oool001X0oooo0`00000;0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`<000000`3o
ool00`000000oooo0?ooo`0=0?ooo`8000004`3oool200000080oooo00<000000?ooo`3oool03P3o
ool3000001<0oooo0P0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`02000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0=0?ooo`<000000P3oool2000000l0oooo0P00000C0?ooo`8000000P3oool00`000000oooo0000
000?0?ooo`8000002`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P00000D0?ooo`030000003o
ool0000000l0oooo00<000000?ooo`3oool00P00000D0?ooo`030000003oool0oooo00d0oooo0P00
00020?ooo`<00000303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool02P3oool3000001/0oooo000J0?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo00000140
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000100oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000K0?ooo`00
6P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?oo
o`8000003`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03P3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`050000003oool0
oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3@3oool2000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00d0oooo0P00000?0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000006`3oool001/0oooo00@000000?ooo`3o
ool0oooo0P0000070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00d0oooo0P00000;0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo
0?ooo`8000002`3oool2000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3oool01@3oool2000000l0oooo0P00000;
0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo0P000007
0?ooo`040000003oool0oooo0?ooo`8000001`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01@3oool2000000`0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo0P00000<0?ooo`030000003o
ool0oooo00d0oooo0P0000070?ooo`040000003oool0oooo0?ooo`8000001`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2000000<0oooo
00<000000?ooo`3oool06P3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000000l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool2000000l0oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool2000000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0
oooo0P00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool001/0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01X0oooo000K0?ooo`030000003oool0oooo00D0oooo0P0000020?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02000000H0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0=0?ooo`8000000`3oool2000000/0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool2000000`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo0`0000030?ooo`03
0000003oool0oooo00d0oooo0P0000060?ooo`030000003oool0oooo00X0oooo0P00000?0?ooo`80
00000`3oool2000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`80
00000P3oool3000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00X0oooo0P0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0:0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`80
00002`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0oooo01/0
oooo000L0?ooo`030000003oool0oooo00H0oooo0P00000@0?ooo`030000003oool0oooo00L0oooo
0P0000080?ooo`030000003oool0oooo00`0oooo0P00000?0?ooo`030000003oool0000000h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000h0oooo
00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000h0oooo1000000?0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0000000h0oooo00<000000?ooo`3oool01P3oool2000000l0oooo0`00000>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`04
0000003oool00000000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?oo
o`040000003oool00000000000l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
0?ooo`8000002P3oool00`000000oooo0?ooo`0=0?ooo`800000203oool00`000000oooo0?ooo`0K
0?ooo`00703oool00`000000oooo0?ooo`070?oooa8000002@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00h0oooo4@00000?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00D000000?oo
o`3oool0oooo0000000?0?oooa8000002@3oool00`000000oooo0?ooo`0=0?oooa8000003`3oool0
0`000000oooo0?ooo`080?oooa4000003`3oool01@000000oooo0?ooo`3oool000000100oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3ooolB000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?oooa4000002@3oool00`000000oooo0?ooo`0K0?ooo`00703oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`007@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000
000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000003`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01`0oooo000M0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000?0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?oo
o`007P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3o
ool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01d0oooo000N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000003`3ooolB000000T0oooo00<0
00000?ooo`3oool03P3ooolA000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?oo
o`3oool0000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo4P00000?0?ooo`030000003oool0oooo00P0oooo4@00000?0?ooo`050000
003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool07@3oool001d0oooo00<000000?ooo`000000203oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool010000000oooo
00000000000>0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000>0?oo
o`@000003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo0P00000?0?oo
o`030000003oool0000000h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0000000h0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0
000000h0oooo00@000000?ooo`0000000000203oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00`0oooo00@000000?ooo`00000000003`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00H0oooo0P00000?0?ooo`<000003P3oool01@000000oooo0?ooo`3oool000000100
oooo00<000000?ooo`3oool0303oool010000000oooo0000000000080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`040000003oool00000
000001d0oooo000K0?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo0`0000030?ooo`030000003oool0oooo00d0oooo0P0000060?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool03@3oool2000000<0oooo0P00000;0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01@3oool2000000<0oooo0P00000;0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`800000103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool20000
00@0oooo00<000000?ooo`3oool03@3oool2000000/0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0=0?ooo`8000000P3oool3000000/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo0P0000040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00D0oooo0P0000040?ooo`030000003oool0oooo01X0oooo000J0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`006@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool01`3oool2000000T0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo
000000050?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
0P00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00L0oooo0P0000050?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`8000003`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo0P00000?0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P0000050?ooo`05
0000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00L0oooo0P00000I0?ooo`005`3oool2000000/0oooo0P0000030?ooo`030000003oool0oooo00h0
oooo00D000000?ooo`3oool0oooo000000030?ooo`800000303oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`8000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo0P0000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool2000000/0oooo0P0000070?oo
o`030000003oool0oooo00h0oooo00@000000?ooo`3oool0oooo0P00000;0?ooo`8000001`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool2
000000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00D0oooo0P00000<0?ooo`030000003oool0oooo00d0oooo0P0000070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03@3oool2000000L0oooo00@000000?ooo`3oool0oooo0P00
00070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`050?ooo`800000303oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
3`3oool010000000oooo0?ooo`3oool2000000`0oooo00<000000?ooo`3oool05P3oool001H0oooo
00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`00
00000`3oool00`000000oooo0?ooo`0=0?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo0P00000?0?ooo`050000003oool0oooo0?ooo`0000001@3oool20000
00l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00d0oooo0P00000?0?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool0oooo0P00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`040000003o
ool0oooo000000l0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`8000005P3oool001D0oooo
00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000@0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`060000
003oool0oooo0000003oool000003`3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0
oooo01<0oooo000C0?ooo`8000004`3oool300000100oooo00<000000?ooo`0000000P00000D0?oo
o`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo008000001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo0`000003
0?ooo`030000003oool0oooo00d0oooo0P00000C0?ooo`8000000P3oool00`000000oooo0?ooo`0>
0?ooo`<000004`3oool200000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00800000503oool00`000000oooo0000000?0?ooo`030000003oool0
oooo00800000503oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool00`000000oooo0000000?
0?ooo`8000002`3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P00000D0?ooo`050000003oool0
00000?ooo`0000003`3oool3000001@0oooo00<000000?ooo`3oool04P3oool00180oooo00<00000
0?ooo`3oool05@3oool200000100oooo0P00000G0?ooo`<000003`3oool00`000000oooo0?ooo`07
0?ooo`800000203oool00`000000oooo0?ooo`0<0?ooo`8000003`3oool4000000l0oooo00<00000
0?ooo`3oool05@3oool200000100oooo0P00000G0?ooo`800000403oool00`000000oooo0?ooo`07
0?ooo`8000005`3oool3000000l0oooo0P00000G0?ooo`8000003`3oool4000000l0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`8000002@3oool00`000000oooo0?ooo`0>
0?ooo`8000005`3oool3000000l0oooo0P00000G0?ooo`8000004P3oool00140oooo00<000000?oo
o`3oool05`3ooolB000001X0oooo4@0000090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3ooolR000001T0oooo4P00000I0?oooa8000002@3oool00`000000oooo0?ooo`0H0?oo
oa4000006P3ooolR000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
oa8000006P3ooolA000001X0oooo00<000000?ooo`3oool03`3oool00140oooo0`00000E0?ooo`<0
0000403oool3000001H0oooo0`00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo0`00000?0?ooo`80
00005@3oool300000100oooo0`00000E0?ooo`<00000403oool00`000000oooo0?ooo`070?ooo`<0
00005P3oool3000000l0oooo0`00000F0?ooo`8000003P3oool300000100oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool3000001H0oooo0`00000?0?ooo`<000005P3oool300000140oooo000@0?ooo`050000
003oool0oooo0?ooo`0000004`3oool00`000000oooo0000000@0?ooo`050000003oool000000?oo
o`000000503oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool0
1@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool04@3oool01@000000oooo0?oo
o`3oool000000100oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool000000100
oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?oo
o`0000003`3oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool03@3oool0
1@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?oo
o`3oool0000001@0oooo00D000000?ooo`000000oooo0000000?0?ooo`030000003oool0000001@0
oooo00D000000?ooo`3oool0oooo0000000@0?ooo`00403oool00`000000oooo0?ooo`020?ooo`80
00003`3oool200000080oooo00<000000?ooo`3oool03P3oool00`000000oooo000000020?ooo`80
0000403oool2000000@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0080oooo0P00000?0?ooo`8000003`3oool2000000@0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`02000000l0oooo0P0000040?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`800000403oool200000080
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`800000403oool2000000h0
oooo0P0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`020?ooo`800000403oool200000080oooo00<000000?ooo`0000003`3oool00`000000
oooo0?ooo`0200000100oooo0P0000040?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03P3oool000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool01@000000oooo
0?ooo`3oool0000000@0oooo00<000000?ooo`3oool02@3oool2000000P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo0P00000?0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00T0oooo0P0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`090?ooo`8000003`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00T0oooo0P0000040?ooo`050000003oool0oooo0?ooo`0000003`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo0P0000080?ooo`030000003oool0oooo
00d0oooo000?0?ooo`030000003oool0oooo00L0oooo0P0000070?ooo`8000001@3oool00`000000
oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000L0oooo0P00000:0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?oo
o`8000003P3oool2000000L0oooo0P0000090?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00`3oool2000000L0oooo0P0000090?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`8000001`3oool2000000H0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`8000001`3oool2000000l0oooo0P0000090?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?oo
o`8000001`3oool2000000H0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0
oooo00<0oooo0P0000070?ooo`8000002P3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool000000000000>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo
0000000000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo000>0?oo
o`030000003oool0oooo00/0oooo0P0000000`3oool00000000000070?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000
000000003P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000001`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0<0?ooo`8000003P3oool2000000030?ooo`000000000000d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000000000003@3oool0
0`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003@3oool2000000030?ooo`00
0000000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`80000000<0
oooo0000000000003`3oool2000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool000000100oooo00<000000?ooo`3oool02`3oool2000000030?ooo`000000000000P0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo
0P0000000`3oool000000000000>0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00D000000?ooo`3oool0oooo000000050?ooo`8000001`3oool2000000X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oooa4000003`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3ooolB000000l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`070?ooo`8000001`3oool2000000D0oooo00D000000?ooo`3o
ool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0<0?ooo`003@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000@0oooo00<00000
0?ooo`3oool02`3oool2000000H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;
0?ooo`003@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000080oooo0P00000@0?oo
o`800000103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`0000003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`020?ooo`8000003`3oool200000080oooo00<000000?oo
o`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`003@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`05
0000003oool000000?ooo`000000503oool01@000000oooo0?ooo`3oool0000000l0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000004`3o
ool01@000000oooo0000003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool000`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool3000001H0oooo0`00000?0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo0`00000E0?ooo`<00000403oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0:0?ooo`00303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
4P0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3ooolA000001X0oooo
4@00000@0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000?0?oooa80
00002@3oool00`000000oooo0?ooo`0=0?oooa8000003`3oool00`000000oooo0?ooo`080?oooa40
00003`3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool03@3ooolB0000
01T0oooo4P00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203ooolA0000
00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`003@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo0P00000@0?ooo`030000003oool0oooo00L0
oooo0P0000080?ooo`030000003oool0oooo00`0oooo0P00000?0?ooo`<000005`3oool2000000l0
oooo0`00000>0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000>0?oo
o`@000003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0000000>0?ooo`030000003oool0oooo00H0oooo0P00000?0?oo
o`<000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool4000000l0oooo00<000000?ooo`3oool05@3oool4000000l0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`060?ooo`8000002P3oool00`000000oooo0?ooo`0=0?oo
o`800000203oool00`000000oooo0?ooo`0<0?ooo`8000003@3oool000h0oooo0P00000;0?ooo`03
0000003oool0oooo00D0oooo0P0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`02000000H0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0=0?ooo`<000000P3oool2000001@0oooo00<000000?ooo`3oool03@3oool200000080
oooo0`00000<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0:0?ooo`<000000`3oool00`000000oooo0?ooo`0=0?ooo`8000001P3oool00`000000
oooo0?ooo`0:0?ooo`8000003`3oool2000000<0oooo0P00000;0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03@3oool200000080oooo0`00000;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`<000000`3oool00`000000
oooo0?ooo`0=0?ooo`8000004`3oool200000080oooo00<000000?ooo`0000003`3oool2000000/0
oooo00<000000?ooo`3oool01@3oool200000080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo008000001P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00d0oooo000@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`004@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`0=0?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000000D0oooo0P00000?
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000002@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3o
ool01@000000oooo0?ooo`3oool0000000D0oooo0P00000?0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`8000004@3oool00180oooo0P0000070?ooo`040000
003oool0oooo0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0=0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`800000303oool00`000000
oooo0?ooo`0=0?ooo`8000001`3oool010000000oooo0?ooo`3oool2000000L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P0000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool2000000<0oooo00<000000?oo
o`3oool01@3oool2000000l0oooo0P00000;0?ooo`8000001`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo0P0000070?ooo`040000003oool0oooo0?ooo`8000001`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2
000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`8000002`3oool2
000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`8000001`3oool0
10000000oooo0?ooo`3oool2000000L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool04@3oool001@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool0000000T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`8000003`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool2000000l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`8000003`3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000?0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01`3oool2000000l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo0P00000?0?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000001@3o
ool2000001@0oooo000E0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
3@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000100oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0D0?ooo`005P3oool200000080oooo0`00000;
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`<000000`3oool00`000000oooo0?ooo`0=0?ooo`8000001P3oool00`000000oooo0?ooo`0:
0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`8000002`3oool00`000000oooo0?ooo`05
0?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P0000060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool3
00000080oooo0P00000?0?ooo`8000004`3oool200000080oooo00<000000?ooo`0000003`3oool2
000000/0oooo00<000000?ooo`3oool01@3oool200000080oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo008000001P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00d0oooo0P0000030?ooo`8000002`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`<00000303oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool3000000<0oooo00<00000
0?ooo`3oool05@3oool001P0oooo0`00000>0?ooo`030000003oool0oooo00h0oooo00D000000?oo
o`3oool0oooo0000000>0?ooo`@000003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00`0oooo00@000000?ooo`00000000003`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo0P00000@0?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`030000003o
ool0oooo00`0oooo0P00000?0?ooo`<00000403oool00`000000oooo0?ooo`0E0?ooo`@000003`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`030000003o
ool0oooo00d0oooo0P0000080?ooo`030000003oool0oooo00`0oooo0P00000?0?ooo`030000003o
ool0000000h0oooo00<000000?ooo`3oool01P3oool2000000l0oooo0`00000>0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`@00000603o
ool001T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0
oooo0?ooo`0000003`3ooolB000000T0oooo00<000000?ooo`3oool03@3ooolB000000l0oooo00<0
00000?ooo`3oool01`3ooolB000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooob8000006@3ooolB000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?oooa4000002@3oool00`000000oooo0?ooo`0>0?oooa4000003`3oool00`000000oooo0?oo
o`080?oooa400000403oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0H0?ooo`006@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool200000100oooo00<000000?ooo`3oool05@3oool200000100oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
00003`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01P0oooo000J0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`02000000l0oooo
0P00000C0?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000003`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01T0oooo000J0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`006`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3o
ool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`8000003`3o
ool2000000/0oooo0P0000070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo01X0oooo000K0?ooo`030000003oool0oooo00d0oooo4P00
000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0=0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000
003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3ooolA000000l0oooo00<000000?ooo`3oool06P3oool001/0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000h0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000h0oooo
00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00`0oooo00@000000?ooo`00
00000000203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool010000000oooo00000000000>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`000000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01P3oool010000000oooo00000000000>0?ooo`030000003oool0oooo00d0oooo00D0
00000?ooo`3oool0oooo0000000>0?ooo`040000003oool00000000000P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`80000000<0oooo0000003oool03P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo000K0?ooo`030000003oool0oooo00X0oooo
0P00000?0?ooo`8000000`3oool2000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`050?ooo`8000000`3oool2000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00X0oooo0P0000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
0P0000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0:0?ooo`8000003`3oool2000000<0oooo0P00000;0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool02P3oool2000000<0oooo0P0000060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`800000103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`800000103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`8000003P3oool2000000/0oooo
00<000000?ooo`3oool06`3oool001`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0>0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01/0oooo000L0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`070?ooo`8000002@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00d0oooo4P00000?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01`3oool2000000T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool2000000D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`070?ooo`8000002@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool001`0oooo00<000000?ooo`3oool0
1@3oool2000000l0oooo0P00000;0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`040000
003oool0oooo0?ooo`8000002`3oool2000000L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0P00000<0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000<0oooo0P00000<0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00D0oooo0P00000;0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
00000100oooo00@000000?ooo`3oool0oooo0P00000<0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P00
000<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00X0oooo0P00000>0?ooo`8000001`3oool00`000000oooo0?oo
o`0K0?ooo`007@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00D00000
0?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3o
ool200000080oooo00<000000?ooo`3oool03P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00d0oooo0P0000050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00L000000?ooo`3oool0oooo
0000003oool000000100oooo00D000000?ooo`3oool0oooo0000000?0?ooo`8000001@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0=0?ooo`8000000`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo0P00000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0L0?ooo`007@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00@000000?ooo`3oool000003`3oool00`000000oooo000000020?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`060000003oool0
oooo0000003oool00000403oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool00P00000?0?ooo`80
00004`3oool200000080oooo00<000000?ooo`3oool03P3oool3000001<0oooo0P0000020?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02000001@0
oooo00<000000?ooo`0000003`3oool00`000000oooo00000002000001@0oooo00D000000?ooo`3o
ool0oooo0000000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P00000C0?oo
o`<0000000<0oooo0000003oool03`3oool3000001@0oooo00D000000?ooo`3oool0oooo0000000?
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P00000D0?ooo`030000003oool0
000000l0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`8000003P3oool200000080oooo00<0
00000?ooo`3oool0703oool001h0oooo0P00000@0?ooo`030000003oool0oooo01D0oooo0P00000@
0?ooo`8000005`3oool2000000T0oooo00<000000?ooo`3oool03P3oool2000001L0oooo0`00000?
0?ooo`8000005`3oool3000000l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>
0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`8000005`3o
ool200000100oooo0P00000G0?ooo`<000003`3oool00`000000oooo0?ooo`070?ooo`8000005`3o
ool3000000l0oooo0`00000G0?ooo`030000003oool0oooo00d0oooo0P00000O0?ooo`003P3ooolR
000001T0oooo4P00000I0?ooo`030000003oool0oooo00L0oooo4P00000J0?oooa4000006P3ooolA
000000l0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000l0oooo4P00
000I0?oooa8000006P3ooolA000000T0oooo00<000000?ooo`3oool0603ooolA000001X0oooo8P00
000>0?ooo`00703oool5000000l0oooo0P00000E0?ooo`<00000403oool3000001D0oooo0`000009
0?ooo`030000003oool0oooo00h0oooo0`00000F0?ooo`<000003`3oool3000001H0oooo0P00000>
0?ooo`D000003@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003@3o
ool5000000l0oooo0P00000E0?ooo`<00000403oool3000001H0oooo0`00000?0?ooo`030000003o
ool0oooo00L0oooo0`00000F0?ooo`<000003`3oool3000001H0oooo0P00000>0?ooo`<000007`3o
ool001/0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0140oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0000001<0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0
oooo0000000D0?ooo`030000003oool0000000l0oooo00D000000?ooo`3oool0oooo0000000D0?oo
o`030000003oool0oooo00d0oooo00L000000?ooo`3oool0oooo0000003oool0000000/0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`030000003oool0000001@0oooo00D000000?ooo`3oool0
oooo0000000?0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000D0?oo
o`030000003oool0000000l0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0
oooo00d0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`006@3oool200000080oooo00<00000
0?ooo`3oool00P3oool2000000l0oooo0P00000?0?ooo`800000103oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo008000003`3oool2000000@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo0P00000@0?ooo`8000000P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo0P00000@0?ooo`8000003P3oool2
000000@0oooo00<000000?ooo`3oool00P0000090?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`8000000P3oool00`000000oooo0?ooo`02
0?ooo`8000003`3oool2000000l0oooo0P0000040?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00P00000@0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool200000100oooo0P0000020?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00P3oool200000100oooo0P00000>0?ooo`800000103oool0
0`000000oooo0?ooo`0L0?ooo`00603oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo
0?ooo`000000403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01`0oooo000G0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00T0oooo0P0000040?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`090?ooo`8000003`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo0P00000?0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02@3oool2000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool2000000@0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`060?ooo`8000002`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool001D0oooo0P0000050?ooo`03
0000003oool0oooo00L0oooo0P00000?0?ooo`8000001`3oool2000000T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool2000000T0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo0P0000070?ooo`80
00001P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo0P0000070?ooo`80
00003`3oool2000000T0oooo00<000000?ooo`3oool00`3oool2000000@0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P0000050?ooo`03
0000003oool0oooo00P0oooo0P00000>0?ooo`8000001`3oool2000000T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool2000000X0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P0000070?ooo`80
00001P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo0P0000070?ooo`80
00003P3oool2000000T0oooo00<000000?ooo`3oool06`3oool001@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000403oool00`000000
oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?oo
o`004P3oool2000000L0oooo00<000000?ooo`3oool02`3oool2000000l0oooo0P0000000`3oool0
00000000000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool200000003
0?ooo`000000000000d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo
00/0oooo0P0000000`3oool00000000000080?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02`3oool2000000030?ooo`000000000000l0oooo0P00000=0?ooo`030000003oool0oooo
00D0oooo0`00000@0?ooo`030000003oool0oooo00L0oooo0`0000070?ooo`030000003oool0oooo
00`0oooo0P00000>0?ooo`80000000<0oooo0000000000003@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00D0oooo0P0000000`3oool000000000000>0?ooo`030000003oool0oooo
00d0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`80000000<0oooo000000000000203oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo0P0000000`3oool000000000000>
0?ooo`8000003@3oool00`000000oooo0?ooo`0J0?ooo`004@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo4P00000?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000403oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?oooa8000003`3oool00`000000oooo0?ooo`070?oooa8000002@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo4@00000@0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oooa4000003`3oool00`000000oooo0?oo
o`0J0?ooo`004@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000403o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo
0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0J0?ooo`00403oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000l0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`0000003`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01T0oooo000@
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000@
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000?
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06@3oool00100oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000l0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`003`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0
000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0
oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000
403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0
oooo0000000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0603oool000l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
00D000000?ooo`3oool0oooo0000000?0?oooa8000002@3oool00`000000oooo0?ooo`0=0?oooa80
00003`3oool00`000000oooo0?ooo`070?oooa8000003`3oool01@000000oooo0?ooo`3oool00000
0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo4@000009
0?ooo`030000003oool0oooo00h0oooo4@00000?0?ooo`030000003oool0oooo00P0oooo4@00000@
0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01P0oooo000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000003P3oool0
0`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003P3oool4000000l0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool00000000000l0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo
0`00000>0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0000000P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00@000000?ooo`00000000003P3oool00`000000oooo0?ooo`0=0?oo
o`050000003oool0oooo0?ooo`0000003P3oool4000000l0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0<0?ooo`8000003`3oool00`000000oooo0000000>0?ooo`030000003oool0
oooo00H0oooo0P00000?0?ooo`<000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0303oool4000001P0oooo000>0?ooo`030000003oool0oooo
00D0oooo0P0000030?ooo`8000002`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02P3oool3000000<0oooo00<000000?ooo`3oool03@3oool20000
00H0oooo00<000000?ooo`3oool02P3oool2000000@0oooo00<000000?ooo`3oool03@3oool20000
00/0oooo00<000000?ooo`3oool01@3oool2000000l0oooo0P0000020?ooo`<000002`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool20000
00<0oooo0P0000060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool00000
0080oooo0P00000>0?ooo`8000001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00d0oooo0P0000030?ooo`8000002`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00d0oooo0P0000020?ooo`<00000303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02P3oool3000000<0oooo00<000000?ooo`3oool05@3oool000h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool0503oool000h0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?oo
o`8000003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool2000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00h0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00L0oooo0P00
00090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`070?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`8000003`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool2000000l0oooo00<0
00000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo000000050?ooo`800000503oool000h0oooo00@000000?ooo`3oool0oooo0P00000;0?ooo`80
00001`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool2000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`80
00000`3oool00`000000oooo0?ooo`050?ooo`800000303oool00`000000oooo0?ooo`0=0?ooo`80
00001`3oool010000000oooo0?ooo`3oool2000000l0oooo0P0000070?ooo`040000003oool0oooo
0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool2000000/0oooo0P0000030?ooo`030000003oool0oooo00h0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`800000303oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool2000000h0oooo0P0000030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03@3oool2000000/0oooo0P0000070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03@3oool2000000L0oooo00@000000?ooo`3oool0oooo
0P0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`050?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0140oooo
000=0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000000l0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00d0oooo0P00000?0?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00D000000?oo
o`3oool0oooo0000000@0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool03@3oool2
000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo0P0000050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool0
1@000000oooo0?ooo`3oool0000000D0oooo0P00000?0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`8000004@3oool000d0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000100oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000@0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`003@3oool3000001<0oooo0P00
00020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`02000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`<000000P3o
ool2000001@0oooo00<000000?ooo`3oool03@3oool200000080oooo0`00000?0?ooo`8000002`3o
ool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00P00000C0?ooo`<00000403oool00`000000oooo0000
0002000001@0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00D0oooo
00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00X0oooo0P00000>0?ooo`<0
00000`3oool00`000000oooo0?ooo`0=0?ooo`8000004`3oool200000080oooo00<000000?ooo`00
00003`3oool2000000/0oooo00<000000?ooo`3oool01@3oool200000080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo008000001P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo000<0?ooo`8000005`3oool200000100oooo
00<000000?ooo`3oool01`3oool2000000P0oooo00<000000?ooo`3oool0303oool2000000l0oooo
0`00000G0?ooo`8000003`3oool300000100oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`060?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`8000005`3oool200000100oooo
0P00000G0?ooo`<000003`3oool00`000000oooo0?ooo`070?ooo`<00000203oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00d0oooo1000000?0?ooo`030000003oool0oooo01D0oooo
1000000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool2000000X0oooo
00<000000?ooo`3oool03@3oool2000000P0oooo00<000000?ooo`3oool0303oool2000000d0oooo
000<0?ooo`030000003oool0oooo01L0oooo4P0000090?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3ooolA000001X0oooo8P00000?0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3ooolB000001T0oooo4P00000J0?oooa4000002@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo8P00000I0?oooa8000003`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00P0oooo4@0000090?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool02P3oool000`0oooo0P00000G0?ooo`800000403oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=
0?ooo`8000005`3oool2000000l0oooo0P00000@0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo0P00000G
0?ooo`800000403oool2000001L0oooo0`00000?0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo0`00000?
0?ooo`030000003oool0oooo01D0oooo0P00000@0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo000=0?oo
o`<000004`3oool200000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00800000503oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P00000C0?oo
o`<00000403oool00`000000oooo00000002000001@0oooo00D000000?ooo`3oool0oooo0000000?
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`8000004`3o
ool200000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`003@3oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3o
ool010000000oooo0?ooo`00000@0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
2`3oool000d0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03@3oool2000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo000000030?ooo`03
0000003oool0oooo00d0oooo0P0000050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`8000003`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?ooo`00
3P3oool010000000oooo0?ooo`3oool2000000/0oooo0P0000070?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`800000303oool00`000000
oooo0?ooo`0=0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01@3oool2000000/0oooo0P0000030?ooo`030000003oool0oooo00h0
oooo00D000000?ooo`3oool0oooo000000030?ooo`800000303oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo0P00000;0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00`0oooo000>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
00L0oooo0P0000090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`070?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool010000000
oooo00000000000>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000203oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`040000003oool00000000000h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool010000000oooo0000
000000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`060?ooo`040000003oool00000000000h0oooo00<000000?ooo`3oool0303oool000h0oooo
00<000000?ooo`3oool01@3oool2000000<0oooo0P00000;0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000103oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool2000000@0oooo
00<000000?ooo`3oool03@3oool2000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0:0?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00X0oooo0P0000030?ooo`8000001P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool2000000@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool2000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool2000000<0oooo
0P00000;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool2000000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01@3oool2000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000h0oooo00<0
00000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool010000000oooo00000000000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0303oool00`00
0000oooo000000080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`040000003oool00000000000h0oooo00<000000?ooo`3oool03@3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool2000000l0oooo00<0
00000?ooo`0000003P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3o
ool0000000D0oooo00<000000?ooo`3oool01`3oool2000000T0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?oooa8000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`070?ooo`8000002@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo4@00000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`8000001@3oool01@000000oooo0?ooo`3oool00000
00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`8000002@3oool00`00
0000oooo0?ooo`0=0?ooo`003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P00000<0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00D0oooo0P00000;0?ooo`8000000`3oool01@000000oooo0?ooo`3oool0
00000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000<0oooo0P00
000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00D0oooo0P00000<0?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo0000000?0?ooo`040000003oool0oooo0?ooo`800000303oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo000@0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool03@3oool2000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool01`000000oooo
0?ooo`3oool000000?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool03@3oool2000000D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000003`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool20000
0080oooo00@000000?ooo`3oool000003`3oool01@000000oooo0?ooo`3oool0000000l0oooo0P00
00050?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00H00000
0?ooo`3oool000000?ooo`00000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
403oool01P000000oooo0?ooo`000000oooo000000l0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo000@0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool00000
00800000503oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`02000001<0oooo0`0000000`3oool000000?ooo`0?0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`0000000P00000D0?ooo`050000003oool0oooo0?ooo`0000003`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000003`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00800000503oool01@000000oooo0000
003oool0000000l0oooo0`00000D0?ooo`050000003oool0oooo0?ooo`000000403oool00140oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo
0P00000G0?ooo`<000003`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`00
0000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo0P00000G0?ooo`80
0000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`8000005`3oool3000000l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`00
0000oooo0?ooo`0>0?ooo`8000005`3oool3000000l0oooo0P00000G0?ooo`<000004@3oool00140
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oooa8000006P3ooolA000000l0
oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo4P00000I0?oo
oa8000003`3oool00`000000oooo0?ooo`070?oooa8000002@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00h0oooo4@00000J0?oooa400000403oool00`000000oooo0?ooo`0=0?oo
o`050000003oool0oooo0?ooo`0000003`3ooolB000001X0oooo4@00000J0?ooo`030000003oool0
oooo00l0oooo000B0?ooo`8000001`3oool00`000000oooo0?ooo`0;0?ooo`8000003`3oool50000
01H0oooo0P00000>0?ooo`D000003@3oool01@000000oooo0?ooo`3oool000000100oooo00<00000
0?ooo`3oool02`3oool5000000l0oooo0P00000E0?ooo`D000003`3oool2000000d0oooo00<00000
0?ooo`3oool01@3oool300000100oooo00<000000?ooo`3oool01`3oool3000000L0oooo00<00000
0?ooo`3oool0303oool2000000h0oooo1@00000F0?ooo`8000003P3oool5000000h0oooo00<00000
0?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000d0oooo1@00000?0?ooo`8000005P3o
ool3000000l0oooo0`00000F0?ooo`8000004P3oool001@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00L000000?ooo`3oool0oooo0000
003oool0000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0140oooo00L000000?ooo`3oool0oooo0000003oool000000100oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000403oool0
0`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000000`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00d0oooo00L000000?ooo`3oool0oooo0000003oool0000000`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180
oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0000001@0oooo00<000000?oo
o`3oool04P3oool001D0oooo0P0000050?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`80
00000P3oool00`000000oooo0?ooo`020?ooo`800000403oool2000000h0oooo0P0000040?ooo`03
0000003oool0oooo008000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01`3oool200000080oooo00<000000?ooo`3oool00P3oool2000000l0
oooo0P00000?0?ooo`800000103oool00`000000oooo0?ooo`02000000l0oooo0P0000090?ooo`03
0000003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`80
00003P3oool200000080oooo00<000000?ooo`3oool00P3oool200000100oooo0P00000>0?ooo`80
0000103oool00`000000oooo0?ooo`02000000X0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P0000020?ooo`030000003oool0oooo0080
oooo0P00000?0?ooo`800000403oool2000000@0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0200000100oooo0P00000E0?ooo`005`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool05@3oool001P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo0P00000?0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool2000000l0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0P00000?0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0103oool2000000l0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo0P00000?0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`8000003`3oool00`000000oooo0?ooo`090?ooo`800000203o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool2000001P0oooo000I0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`8000003`3oool2
000000D0oooo00<000000?ooo`3oool01`3oool2000000L0oooo0P00000?0?ooo`8000002@3oool0
0`000000oooo0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?ooo`3oool0203oool2
000000h0oooo0P0000070?ooo`8000002@3oool00`000000oooo0?ooo`040?ooo`8000003P3oool2
000000@0oooo00<000000?ooo`3oool00P0000090?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`8000000P3oool00`000000oooo0?ooo`02
0?ooo`8000003`3oool2000000D0oooo00<000000?ooo`3oool01`3oool2000000L0oooo0P00000?
0?ooo`8000002@3oool00`000000oooo0?ooo`040?ooo`800000103oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<00000
0?ooo`3oool0203oool2000000h0oooo0P0000070?ooo`8000002P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`8000006P3oool001/0oooo00<000000?oo
o`0000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001`3oool0
0`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool01`000000oooo0?oo
o`3oool000000?ooo`0000002`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo000000030?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000070?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool0
01`0oooo1@00000?0?ooo`8000001`3oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo0000
000000003`3oool2000000d0oooo00<000000?ooo`3oool01@3oool3000000T0oooo00<000000?oo
o`3oool03P3oool3000000L0oooo00<000000?ooo`3oool0303oool2000000h0oooo0P0000000`3o
ool000000000000=0?ooo`030000003oool0oooo00H0oooo0P00000>0?ooo`D000003@3oool00`00
0000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003@3oool5000000l0oooo0P000007
0?ooo`030000003oool0oooo00/0oooo0P0000000`3oool000000000000?0?ooo`8000003@3oool0
0`000000oooo0?ooo`060?ooo`<000003`3oool00`000000oooo0?ooo`070?ooo`<000001`3oool0
0`000000oooo0?ooo`0<0?ooo`8000003P3oool2000000030?ooo`000000000000h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000000000007@3oool0
01h0oooo4P0000090?ooo`030000003oool0oooo00d0oooo4P00000?0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3ooolB000000T0oooo00<000000?ooo`3oool03P3ooolA0000
00l0oooo00<000000?ooo`3oool0203ooolA000000l0oooo00<000000?ooo`3oool03P3oool01@00
0000oooo0?ooo`3oool0000000l0oooo4P0000090?ooo`030000003oool0oooo00d0oooo4P00000?
0?ooo`030000003oool0oooo00P0oooo4@0000090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3ooolA00000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01d0oooo000N0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0M0?ooo`007@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool00000
00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool00000
0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01`0oooo000M0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000003`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0703oool001d0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`00703oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?oo
o`3oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?oo
o`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000403oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06`3oool0
01`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00D00000
0?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0=0?oooa8000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo4@0000090?ooo`03
0000003oool0oooo01/0oooo000L0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1P3oool2000000030?ooo`000000oooo00d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000>0?ooo`03
0000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`040000003oool00000
000000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0303oool010000000oooo0000000000080?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`040000003o
ool00000000000h0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000h0
oooo1000000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool001/0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
0P00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0:0?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`800000303oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool2000000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo
0P00000?0?ooo`8000000`3oool2000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`050?ooo`8000000`3oool2000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00X0oooo0P0000040?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
0P0000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`0000000P3oool2000000h0oooo
0P0000060?ooo`030000003oool0oooo01/0oooo000K0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`000000
403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo0P0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`8000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`8000001@3oool00`000000oooo0?ooo`0=0?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`070?ooo`8000002@3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2
000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool06P3oool001/0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo0P0000070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`8000002`3oool20000
00<0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`040000003oool0oooo0?ooo`8000002`3o
ool2000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo0P00000<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`050?ooo`8000003`3oool2000000/0oooo0P0000070?ooo`030000003o
ool0oooo00h0oooo00@000000?ooo`3oool0oooo0P00000;0?ooo`8000001`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2000000`0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`00
00000`3oool2000000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo0P00000>0?ooo`8000000`3oool00`000000oooo0?ooo`0J0?ooo`00
6P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0?ooo`8000003`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00L000000?ooo`3oool0oooo0000003oool0
00000100oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo000000030?ooo`030000003oool0oooo00d0oooo0P0000050?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`800000
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0
oooo0000000K0?ooo`006P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo00000180
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`060000003oool0oooo0000
003oool00000403oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0403oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000?0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo
000001/0oooo000J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000503oool20000
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
008000004`3oool3000000030?ooo`000000oooo00l0oooo0`00000C0?ooo`8000000P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P00000D0?oo
o`030000003oool0000000l0oooo00<000000?ooo`3oool00P00000?0?ooo`8000004`3oool20000
0080oooo00<000000?ooo`3oool03P3oool3000001<0oooo0P0000020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`02000001@0oooo00<000000?oo
o`0000003`3oool00`000000oooo00000002000001@0oooo00D000000?ooo`3oool0oooo0000000?
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003o
ool0oooo00X0oooo0P00000>0?ooo`<000006`3oool001T0oooo00<000000?ooo`3oool03@3oool3
000001L0oooo0P0000090?ooo`030000003oool0oooo00h0oooo0P00000G0?ooo`800000403oool2
000001L0oooo0P00000@0?ooo`030000003oool0oooo00L0oooo0P00000G0?ooo`<000003`3oool2
00000100oooo00<000000?ooo`3oool05@3oool200000100oooo0P00000G0?ooo`8000002P3oool0
0`000000oooo0?ooo`0=0?ooo`8000005`3oool3000000l0oooo0P00000G0?ooo`<000003`3oool0
0`000000oooo0?ooo`070?ooo`<00000203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00d0oooo0P00000J0?ooo`006@3ooolA000001X0oooo00<000000?ooo`3oool01`3ooolB0000
01T0oooo4P00000I0?oooa8000002@3oool00`000000oooo0?ooo`0H0?ooob8000006@3ooolB0000
01T0oooo00<000000?ooo`3oool0203ooolA000001X0oooo4@00000J0?oooa4000002@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo4@00000J0?ooo`006@3oool00`000000
oooo0?ooo`0=0?ooo`<000005`3oool2000000T0oooo00<000000?ooo`3oool03P3oool2000001L0
oooo0P00000@0?ooo`8000005`3oool200000100oooo00<000000?ooo`3oool01`3oool2000001L0
oooo0`00000?0?ooo`800000403oool00`000000oooo0?ooo`0E0?ooo`800000403oool2000001L0
oooo0P00000:0?ooo`030000003oool0oooo00d0oooo0P00000G0?ooo`<000003`3oool2000001L0
oooo0`00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0603oool001X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0000000D0?ooo`8000000P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P00000C0?ooo`<00000
00<0oooo0000003oool03`3oool3000001<0oooo0P0000020?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02000001@0oooo00<000000?ooo`000000
3`3oool00`000000oooo0?ooo`02000000l0oooo0P00000C0?ooo`8000000P3oool00`000000oooo
0?ooo`0>0?ooo`<000004`3oool200000080oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00800000503oool00`000000oooo0000000?0?ooo`030000
003oool0000000800000503oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0=0?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`06
0000003oool0oooo0000003oool00000403oool010000000oooo0?ooo`00000A0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000?0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000A0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000?0?oo
o`030000003oool000000080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?oo
o`006P3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0?ooo`8000003`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00L000000?ooo`3oool0oooo0000003o
ool000000100oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo000000030?ooo`030000003oool0oooo00d0oooo0P0000050?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`00
6`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool2000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00D0oooo0P00000;0?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000100
oooo00@000000?ooo`3oool0oooo0P00000;0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000000`0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo0P00000?0?oo
o`8000002`3oool2000000L0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`3oool2
000000/0oooo0P0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`050?ooo`800000303oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00d0oooo00D000000?ooo`3oool0oooo000000030?ooo`800000303oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0J0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0P000009
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`8000001@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`050000003o
ool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`070?ooo`8000002@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool001/0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`80000000<0oooo0000003oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01X0oooo000K0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`8000002`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool2000000<0oooo0P0000060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`800000
0`3oool2000000`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo0P0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0:0?ooo`8000003`3oool2000000<0oooo0P00000;0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool2000000<0oooo0P00000;0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`800000
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo0P00000;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
6`3oool001`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`80000000<0
oooo0000003oool03@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0
303oool00`000000oooo000000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool0
3P3oool01@000000oooo0?ooo`3oool0000000h0oooo00@000000?ooo`0000000000203oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0000000>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0000000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0<0?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00@000000?ooo`00000000003P3o
ool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0K0?ooo`00703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo4P00000?0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?oo
o`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000001@3oool2
000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo01/0oooo000L0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=
0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00X0oooo0P0000070?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool06`3oool001d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000
403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo000000030?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000403o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo000000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01`0oooo000M0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
00000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000?0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00D000000?ooo`000000oooo0000000D0?ooo`8000000P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01`0oooo000N0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00D00000
0?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool3000001L0oooo0P00000?0?ooo`030000003oool0oooo01d0oooo000N0?oooa8000002@3oool0
0`000000oooo0?ooo`0=0?oooa8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00L0oooo4P0000090?ooo`030000003oool0oooo00h0oooo4@00000?0?ooo`030000003oool0
oooo00P0oooo4@00000?0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000
000?0?oooa8000002@3oool00`000000oooo0?ooo`0=0?oooa8000003`3oool00`000000oooo0?oo
o`080?oooa4000002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo4@00
000J0?oooa4000007`3oool001l0oooo0P00000?0?ooo`8000001`3oool00`000000oooo0?ooo`0;
0?ooo`80000000<0oooo0000000000003`3oool2000000d0oooo00<000000?ooo`3oool01@3oool3
000000T0oooo00<000000?ooo`3oool03P3oool3000000L0oooo00<000000?ooo`3oool0303oool2
000000h0oooo0P0000000`3oool000000000000=0?ooo`030000003oool0oooo00H0oooo0P00000>
0?ooo`D000003@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003@3o
ool5000000l0oooo0P0000070?ooo`030000003oool0oooo00/0oooo0P0000000`3oool000000000
000?0?ooo`8000003@3oool00`000000oooo0?ooo`060?ooo`<000003`3oool00`000000oooo0?oo
o`070?ooo`<000001`3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool5000001H0oooo0P00
000>0?ooo`800000803oool00240oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo
00L000000?ooo`3oool0oooo0000003oool0000000/0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000000`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0803oool00280oooo0P00000?0?ooo`8000001@3oool0
0`000000oooo0?ooo`070?ooo`8000001`3oool2000000l0oooo0P0000090?ooo`030000003oool0
oooo00<0oooo0P0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`8000003P3oool2
000000L0oooo0P0000090?ooo`030000003oool0oooo00@0oooo0P00000>0?ooo`800000103oool0
0`000000oooo0?ooo`02000000T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo0P0000020?ooo`030000003oool0oooo0080oooo0P00000?
0?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`8000001`3oool2000000l0oooo0P000009
0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`08
0?ooo`8000003P3oool200000080oooo00<000000?ooo`3oool00P3oool200000100oooo0P00000>
0?ooo`8000008`3oool002@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02<0oooo000U0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo0P00000?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000l0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00000?0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool2000000l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo0P00000?0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000000P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`8000003`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo0P00000;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0903oool002H0oooo0P00000?0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`800000
403oool2000000h0oooo0P0000040?ooo`030000003oool0oooo008000002@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool200000080oooo
00<000000?ooo`3oool00P3oool2000000l0oooo0P00000?0?ooo`800000103oool00`000000oooo
0?ooo`02000000l0oooo0P0000090?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`800000
1@3oool00`000000oooo0?ooo`080?ooo`8000003P3oool200000080oooo00<000000?ooo`3oool0
0P3oool200000100oooo0P00000>0?ooo`800000103oool00`000000oooo0?ooo`02000000X0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
0P0000020?ooo`030000003oool0oooo0080oooo0P00000?0?ooo`8000001@3oool00`000000oooo
0?ooo`080?ooo`8000001`3oool2000000h0oooo0P00000W0?ooo`00:03oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0=0?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`070000003oool0oooo0?oo
o`000000oooo0000000@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3oool0
1@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool01@3oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`070000
003oool0oooo0?ooo`000000oooo0000000<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo000Y0?ooo`80
00003`3oool5000001H0oooo0P00000>0?ooo`D000003@3oool01@000000oooo0?ooo`3oool00000
0100oooo00<000000?ooo`3oool02`3oool5000000l0oooo0P00000E0?ooo`D000003`3oool20000
00d0oooo00<000000?ooo`3oool01@3oool300000100oooo00<000000?ooo`3oool01`3oool30000
00L0oooo00<000000?ooo`3oool0303oool2000000h0oooo1@00000F0?ooo`8000003P3oool50000
00h0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000d0oooo1@00000?
0?ooo`8000001`3oool00`000000oooo0?ooo`0<0?ooo`80000000<0oooo0000000000003P3oool2
000002X0oooo000[0?oooa8000006P3ooolA000000l0oooo00D000000?ooo`3oool0oooo0000000@
0?ooo`030000003oool0oooo00d0oooo4P00000I0?oooa8000003`3oool00`000000oooo0?ooo`07
0?oooa8000002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo4@00000J
0?oooa400000403oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000003`3o
oolB000000T0oooo00<000000?ooo`3oool03P3ooolA000002`0oooo000[0?ooo`030000003oool0
oooo00h0oooo0P00000G0?ooo`<000003`3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0
oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo0P00
000G0?ooo`800000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`8000005`3oool3000000l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000
3`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02X0oooo000Z0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`0000000P00000D0?ooo`050000003oool0oooo0?ooo`000000
3`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo008000004`3oool3000000030?oo
o`000000oooo00l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo00000002000001@0oooo
00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<000000?ooo`3o
ool0:@3oool002X0oooo00<000000?ooo`3oool03P3oool00`000000oooo000000020?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`060000
003oool0oooo0000003oool00000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool00000
00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool03@3oool2000000D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool03@3oool01`000000oooo0?ooo`3oool000000?ooo`000000403oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool03@3oool2
000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000?0?ooo`030000003o
ool0oooo02T0oooo000Y0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`800000303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`8000002`3oool2000000<0oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0
oooo000000030?ooo`800000303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0
oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo02P0oooo000Y0?ooo`03
0000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo
00L0oooo0P0000090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3ooolB0000
00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000100oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01`3o
ool2000000T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oooa4000003`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0:03oool002T0oooo00<0
00000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool010000000oooo00000000000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0303oool00`00
0000oooo000000080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`040000003oool00000000000h0oooo00<000000?ooo`3oool03@3oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool2000000l0oooo00<0
00000?ooo`0000003P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`0000003P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0:03oool002P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`800000103oool00`000000oooo0?ooo`0=
0?ooo`8000002`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo0P000003
0?ooo`8000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool02P3oool2000000<0oooo0P0000060?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`800000103oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`8000000`3oool2000000/0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool2000000`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo000X0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`040000003oool00000000000h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo00000008
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`00000000003P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool09`3oool002P0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool2000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool01`3oool2000000T0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2000000`0oooo00<0
00000?ooo`3oool03@3oool2000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00D0oooo0P00000;0?ooo`8000000`3oool00`000000oooo0?oo
o`0>0?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000`0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0=0?ooo`8000002`3oool2000000L0oooo00<000000?ooo`3oool0
3P3oool010000000oooo0?ooo`3oool2000000/0oooo0P0000070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0=0?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo
00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool03@3oool2000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo0P00000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo0000
0100oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo02H0oooo000W0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`02000001@0oooo00<000000?ooo`3oool03@3oool200000080oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo008000004`3oool30000
0100oooo00<000000?ooo`0000000P00000D0?ooo`050000003oool0oooo0?ooo`0000003`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000003`3oool2000001<0oooo0P00
00020?ooo`030000003oool0oooo00h0oooo0`00000C0?ooo`8000000P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool002H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`8000005`3oool2000000l0oooo0P00000@
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo0P00000G0?ooo`800000403oool2000001L0oooo0`00000?
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo0`00000?0?ooo`030000003oool0oooo01D0oooo0P00000@
0?ooo`8000005`3oool2000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0U
0?ooo`009P3ooolB000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
oa4000006P3ooolR000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
oa8000006@3ooolB000001X0oooo4@0000090?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3ooolR000001T0oooo4P00000I0?ooo`030000003oool0oooo00P0oooo4@00000W0?oo
o`009P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`03
0000003oool0oooo00`0oooo0P00000?0?ooo`<000005`3oool2000000l0oooo0`00000@0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool2000000T0oooo00<000000?ooo`3o
ool03P3oool2000001L0oooo0P00000@0?ooo`8000005`3oool3000000l0oooo00<000000?ooo`3o
ool01`3oool3000000P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`@0
00003`3oool00`000000oooo0?ooo`0E0?ooo`800000403oool2000001L0oooo0P00000:0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool09@3oool002L0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo008000001P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00d0oooo0`0000020?ooo`800000503oool00`000000oooo
0?ooo`0=0?ooo`8000000P3oool3000000l0oooo0P00000;0?ooo`030000003oool0oooo00D0oooo
0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`02000001<0oooo0`00000@0?ooo`030000003oool0000000800000503oool01@000000oooo
0?ooo`3oool0000000l0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
00L0oooo00<000000?ooo`3oool02P3oool2000000h0oooo0`0000030?ooo`030000003oool0oooo
00d0oooo0P00000C0?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`<000004`3oool20000
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02H0oooo000W0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0=0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000403oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0?0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool09P3oool002L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`800000
3`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool03@3oool2000000l0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`0000000`3oool0
0`000000oooo0?ooo`0=0?ooo`8000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000l0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00D0
00000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo000X0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`8000000`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo0P0000030?ooo`030000003o
ool0oooo00D0oooo0P00000<0?ooo`030000003oool0oooo00d0oooo0P0000070?ooo`040000003o
ool0oooo0?ooo`8000003`3oool2000000L0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`80
00002`3oool2000000<0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool00000
00<0oooo0P00000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`050?ooo`8000003P3oool2000000<0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0=0?ooo`8000002`3oool2000000L0oooo00<000000?ooo`3oool03P3oool01000
0000oooo0?ooo`3oool2000000/0oooo0P0000070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0
000000D0oooo0P00000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`0000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0
1`3oool2000000T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0W0?ooo`00:03o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02L0oooo000X0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`<000000`3oool00`00
0000oooo0?ooo`0=0?ooo`8000001P3oool00`000000oooo0?ooo`0:0?ooo`800000103oool00`00
0000oooo0?ooo`0=0?ooo`8000002`3oool00`000000oooo0?ooo`050?ooo`8000003`3oool20000
0080oooo0`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0:0?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`0000000P3oool2000000h0oooo0P0000060?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool03@3oool2000000<0oooo0P00000;0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool01@3oool2000000<0oooo0P00000<0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000
oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003P3oool4000000l0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool00000000000l0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo0`00000>
0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000000P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`00000000003P3oool00`000000oooo0?ooo`0=0?ooo`050000
003oool0oooo0?ooo`0000003P3oool4000000l0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0<0?ooo`8000003`3oool00`000000oooo0000000>0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000>0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`00:@3oool00`000000oooo
0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3ooolB000000T0oooo00<000000?ooo`3o
ool03@3ooolB000000l0oooo00<000000?ooo`3oool01`3ooolB000000l0oooo00D000000?ooo`3o
ool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo0000000@
0?oooa4000002@3oool00`000000oooo0?ooo`0>0?oooa4000003`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3o
ool0000000l0oooo00<000000?ooo`3oool0:03oool002T0oooo00<000000?ooo`3oool03P3oool0
1@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0=0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000
003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0
oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo02P0oooo000Z0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000?0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`04
0000003oool0oooo000000l0oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`00
0000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`00
00003`3oool00`000000oooo0?ooo`0Y0?ooo`00:P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000
003oool0oooo02T0oooo000[0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3o
ool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02X0oooo000[0?oooa8000003`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3ooolB000000l0oooo00<000000?ooo`3oool01`3ooolB000000T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oooa400000403oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000003`3ooolB000000T0oooo00<000000?oo
o`3oool03P3ooolA000002`0oooo000m0?ooo`8000003@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00D0oooo0P0000000`3oool000000000000=0?ooo`050000003oool0oooo0?oo
o`000000403oool00`000000oooo0?ooo`0;0?ooo`80000000<0oooo000000000000203oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo0P0000000`3oool000000000000?0?oo
o`8000003@3oool00`000000oooo0?ooo`050?ooo`<00000403oool00`000000oooo0?ooo`070?oo
o`<000001`3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool2000000030?ooo`0000000000
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`80000000<0oooo0000
000000003P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000003@3oool5
000000l0oooo0P0000070?ooo`030000003oool0oooo00`0oooo0P00000m0?ooo`00?`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0m0?ooo`00@03oool2
000000T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool2
000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00L0oooo0P0000070?ooo`8000001P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00L0oooo0P0000070?ooo`8000003`3oool2000000T0oooo00<000000?ooo`3oool00`3oool2
000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo0P0000050?ooo`030000003oool0oooo00P0oooo0P00000>0?ooo`8000001`3oool2
000000T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`8000001`3oool2
000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00L0oooo0P0000020?ooo`030000003oool0oooo0080oooo0P00000?0?ooo`8000001@3oool0
0`000000oooo0?ooo`080?ooo`800000@03oool00480oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`100?ooo`00@`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02`3oool2000000<0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo0P00000?0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool2000000l0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`8000001P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0
oooo0P00000?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000004<0
oooo00140?ooo`800000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00800000
3`3oool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0080oooo0P00000@0?ooo`8000000P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0080oooo0P00000@0?ooo`8000003P3oool2000000@0oooo00<000000?ooo`3oool0
0P0000090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`8000003`3oool2000000l0oooo
0P0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P00000@0?ooo`800000
103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool2000000D0oooo00<000000?ooo`3oool0203oool2000000h0oooo0P0000020?ooo`030000
003oool0oooo0080oooo0P0000150?ooo`00AP3oool01@000000oooo0?ooo`3oool000000100oooo
00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3o
ool03P3oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`0000003`3oool01@00
0000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool03@3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000002`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo000000030?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool04@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`00
0000503oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0A@3oool004L0oooo0`00000@0?oo
o`<000005@3oool3000000T0oooo00<000000?ooo`3oool03P3oool3000001H0oooo0`00000?0?oo
o`<000005P3oool2000000h0oooo1@00000=0?ooo`030000003oool0oooo00h0oooo00D000000?oo
o`3oool0oooo0000000=0?ooo`D000003`3oool2000001D0oooo0`00000@0?ooo`<000005P3oool3
000000l0oooo00<000000?ooo`3oool01`3oool3000000L0oooo00<000000?ooo`3oool0303oool2
000000h0oooo1@0000180?ooo`00B@3ooolB000001T0oooo00<000000?ooo`3oool01`3ooolB0000
01X0oooo4@00000J0?oooa4000003`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo
0?ooo`0000003`3ooolB000001T0oooo4P00000J0?oooa4000002@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00h0oooo4@00001:0?ooo`00B03oool200000100oooo0P00000G0?oo
o`8000002@3oool00`000000oooo0?ooo`0>0?ooo`8000005`3oool3000000l0oooo0P00000G0?oo
o`<000003`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`030000003oool0oooo00h0oooo0P00000G0?ooo`800000403oool2
000001L0oooo0`00000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo0`0000180?ooo`00AP3oool20000
0080oooo00<000000?ooo`3oool03P3oool3000001<0oooo0P0000020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02000001@0oooo00<000000?oo
o`0000003`3oool00`000000oooo00000002000001@0oooo00D000000?ooo`3oool0oooo0000000?
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P00000C0?ooo`<0000000<0oooo
0000003oool03`3oool3000001@0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00D000000?ooo`3oool0oooo000000170?ooo`00A@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000004@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000003`3oool00`000000
oooo000000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`060000003oool0oooo0000003oool00000403oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0A03oool004@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0=0?ooo`8000001@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0=0?ooo`070000003oool0oooo0?ooo`000000oooo0000000@0?ooo`05
0000003oool0oooo0?ooo`0000003`3oool2000000D0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0P0000140?ooo`00@P3oool2000000L0
oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`3oool2000000/0oooo0P0000070?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?oo
o`800000303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00D000000?oo
o`3oool0oooo000000030?ooo`800000303oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`8000002`3oool2
000000<0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`040000003oool0oooo0?ooo`800000
303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0440oooo00110?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`8000001@3o
ool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo
0?ooo`070?ooo`8000002@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo
4P00000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000000T0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo0P0000110?ooo`00
@03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0
oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0000000>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`060?ooo`040000003oool00000000000h0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo03h0oooo000n0?ooo`8000002`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`8000002`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool2000000@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool2000000@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo0P00000?0?ooo`8000000`3oool2000000/0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`8000000`3oool2000000H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0
oooo0P0000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03d0
oooo000m0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0000000h0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`03
0000003oool0oooo00`0oooo00@000000?ooo`0000000000203oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool010000000oooo00000000000>
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000203oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool010000000oooo00000000
000>0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo0P00000m0?ooo`00?03oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`050000003o
ool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`070?ooo`8000002@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0>P3oool004`0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2000000l0
oooo0P00000;0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0
oooo00D000000?ooo`3oool0oooo000000030?ooo`800000303oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0B`3oool004d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`00
0000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool03@3oool2000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1<0?ooo`00
C@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`1<0?ooo`00C@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00P00000?0?ooo`8000004`3oool200000080oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000800000503o
ool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0C03oool004h0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`800000403oool00`000000oooo0?oo
o`0E0?ooo`800000403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`8000005`3oool3000000l0oooo00<0
00000?ooo`3oool0C@3oool004h0oooo4P0000090?ooo`030000003oool0oooo00d0oooo4P00000?
0?ooo`030000003oool0oooo00L0oooo4P0000090?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3ooolR000001T0oooo4P00000?0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0203ooolA000000T0oooo00<000000?ooo`3oool03P3ooolA000001X0oooo4@00001?
0?ooo`00CP3oool3000000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?oo
o`040000003oool00000000000l0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
0?ooo`800000403oool00`000000oooo0?ooo`070?ooo`800000203oool00`000000oooo0?ooo`0<
0?ooo`8000003`3oool300000100oooo00<000000?ooo`3oool05@3oool4000000l0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`8000002P3oool00`000000oooo0?ooo`0=
0?ooo`800000203oool00`000000oooo0?ooo`0<0?ooo`8000003`3oool3000001L0oooo0P00000?
0?ooo`800000C`3oool004d0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`8000001P3oool0
0`000000oooo0?ooo`0:0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`8000002`3oool0
0`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool03@3oool300000080oooo0P00000?0?ooo`8000004`3oool200000080oooo00<00000
0?ooo`0000003`3oool2000000/0oooo00<000000?ooo`3oool01@3oool200000080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo008000001P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo0`0000020?ooo`800000503oool0
0`000000oooo0?ooo`0=0?ooo`8000000P3oool00`000000oooo0?ooo`1<0?ooo`00C@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1<0?ooo`00C@3oool00`000000oooo0?ooo`030?ooo`8000003`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool2000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`8000003`3o
ool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000?0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000000l0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo00d0oooo0P00000?0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0C03oool004`0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0=0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`800000303oool00`000000
oooo0?ooo`0=0?ooo`8000001`3oool010000000oooo0?ooo`3oool2000000L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P0000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool2000000<0oooo00<000000?oo
o`3oool01@3oool2000000l0oooo0P00000;0?ooo`8000001`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo0P0000070?ooo`040000003oool0oooo0?ooo`8000001`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2
000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`8000000`3oool0
0`000000oooo0?ooo`050?ooo`800000303oool00`000000oooo0?ooo`0=0?ooo`8000001`3oool0
0`000000oooo0?ooo`1;0?ooo`00C03oool00`000000oooo0?ooo`070?ooo`8000003`3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool03@3oool2000000l0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo
000000050?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool2000000l0oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool0000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`8000003`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool20000
00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1;0?ooo`00C03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
2P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04/0oooo001;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool300000080oooo0P00000D0?ooo`030000
003oool0oooo00d0oooo0P0000020?ooo`<00000303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool3000000<0oooo00<000000?ooo`3oool0
3@3oool2000000H0oooo00<000000?ooo`3oool02P3oool2000000l0oooo0P0000030?ooo`800000
2`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`<00000
2`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
2P3oool3000000<0oooo00<000000?ooo`3oool03@3oool2000000H0oooo00<000000?ooo`3oool0
2P3oool2000000@0oooo00<000000?ooo`3oool03@3oool2000000/0oooo00<000000?ooo`3oool0
B`3oool004/0oooo00<000000?ooo`3oool0303oool2000000l0oooo0`00000G0?ooo`8000003`3o
ool3000000h0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000h0oooo
1000000?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool01P3oool2000000l0oooo
0`00000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0<0?ooo`@000003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo
00@000000?ooo`00000000003`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo04X0
oooo001;0?ooo`030000003oool0oooo00h0oooo4@00000J0?oooa400000403oool00`000000oooo
0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000003`3ooolB000000T0oooo00<000000?ooo`3o
ool03@3ooolB000000l0oooo00<000000?ooo`3oool0203ooolA000000l0oooo00D000000?ooo`3o
ool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo4P0000090?ooo`030000003oool0oooo
00d0oooo4P00000?0?ooo`030000003oool0oooo04X0oooo001;0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool3000001H0oooo0`00000?0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000403oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`1:0?ooo`00BP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00d0oooo00D000000?ooo`000000oooo0000000D0?ooo`050000003oool0oooo0?ooo`0000003`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000003`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000403o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`190?ooo`00BP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`0000000P3oool200000100oooo0P0000040?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
00000100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0B@3oool004X0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0B@3oool004T0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?oo
o`000000103oool00`000000oooo0?ooo`090?ooo`800000203oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`180?ooo`00B@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000050?ooo`8000001`3o
ool2000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oooa4000003`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3ooolB000000l0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo
00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0B03oool004X0oooo0P00000>0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0
oooo000000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`80000000<0oooo00000000
00003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool0
00000000000=0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000=0?oo
o`80000000<0oooo000000000000203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00/0oooo0P0000000`3oool000000000000?0?ooo`8000003@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00D0oooo0P0000000`3oool000000000000=0?ooo`050000003oool0oooo
0?ooo`000000403oool00`000000oooo0?ooo`0;0?ooo`800000B`3oool004`0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01@3oool2000000030?ooo`000000000000h0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo04/0oooo001=0?ooo`8000002P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool2000000h0
oooo0P0000070?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0
oooo0P0000070?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01`3oool2000000L0oooo0P0000060?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool01`3oool2000000L0oooo0P00000?0?ooo`8000002@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo0P0000070?ooo`8000002@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool2000004h0
oooo001?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0CP3oool00500oooo0P00
00060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`040?ooo`8000003`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`800000103oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool2000000l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04l0oooo001B
0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00P3oool2000000l0oooo0P00000?0?ooo`800000103oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo008000003`3oool2000000@0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P00000@0?ooo`8000000P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo0P00000@0?ooo`8000003P3oool2
000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02000000l0oooo0P000004
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`02
0?ooo`800000DP3oool005@0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo0140oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`030000003oool0000001<0oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000D0?oo
o`030000003oool0000000l0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000003oool0
oooo00d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0000001<0oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0
oooo0000001D0?ooo`00E@3oool3000000l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool3000000l0oooo
0P00000E0?ooo`<00000403oool3000001D0oooo0`00000@0?ooo`030000003oool0oooo00L0oooo
0`00000F0?ooo`<000003`3oool3000001H0oooo0P00000>0?ooo`<00000403oool3000001D0oooo
0`0000090?ooo`030000003oool0oooo00h0oooo0`00001E0?ooo`00E`3ooolA000000T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooob8000006@3ooolB000001T0oooo4P00
00090?ooo`030000003oool0oooo01P0oooo4@00000J0?ooob8000006@3oool00`000000oooo0?oo
o`070?oooa800000E`3oool006L0oooo00<000000?ooo`3oool01`3oool2000000P0oooo00<00000
0?ooo`3oool0303oool2000000l0oooo1000000?0?ooo`030000003oool0oooo01D0oooo0P00000@
0?ooo`8000005`3oool200000100oooo00<000000?ooo`3oool01`3oool2000001L0oooo0`00000?
0?ooo`8000005`3oool2000000l0oooo0P00000@0?ooo`8000005`3oool2000000T0oooo00<00000
0?ooo`3oool0IP3oool006P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020000
00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`<000000`3oool00`00
0000oooo0?ooo`0=0?ooo`8000004`3oool200000080oooo00<000000?ooo`3oool03P3oool30000
01<0oooo0P0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`02000001@0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`020000
01@0oooo00<000000?ooo`3oool03@3oool200000080oooo00<000000?ooo`3oool03P3oool30000
01<0oooo0P0000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0I`3oool006P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00000?0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000A0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`00J03o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`8000003`3oool01@000000oooo0?ooo`3oool0000000D0oooo
0P00000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00d0oooo0P0000030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0=0?ooo`8000003`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1W0?ooo`00J@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0=0?ooo`8000002`3oool2000000L0oooo00<000000?ooo`3oool03P3oool010000000
oooo0?ooo`3oool2000000/0oooo0P0000070?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`800000303oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2000000`0oooo00<000000?oo
o`3oool03@3oool2000000L0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`3oool2
000000/0oooo0P0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0J03oool0
06T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo
0?ooo`0000001@3oool2000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`8000001@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool2000000l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0J03oool006T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1X
0?ooo`00J@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo0`0000030?oo
o`030000003oool0oooo00d0oooo0P0000060?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool03@3oool2000000<0oooo0P00000;0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01@3oool2000000<0oooo0P00000;0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`800000103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool2000000@0oooo00<000000?oo
o`3oool03@3oool2000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?oo
o`8000000`3oool2000000/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1Y0?oo
o`00JP3oool01@000000oooo0?ooo`3oool0000000h0oooo1000000?0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0303oool2000000l0oooo00<000000?ooo`0000003P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000003P3oool00`00
0000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003P3oool010000000oooo00000000
00080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool010000000oooo0000
0000000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0000000h0oooo00D000000?ooo`3oool0oooo0000001[0?ooo`00
JP3oool01@000000oooo0?ooo`3oool0000000l0oooo4P0000090?ooo`030000003oool0oooo00h0
oooo4@00000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
oa8000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03@3oool01@000000oooo0?ooo`3oool0000006/0oooo001Z0?ooo`050000003oool0oooo
0?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`000000J`3oool006/0oooo00<0
00000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000100oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0000001/0?ooo`00J`3oool00`000000oooo0000000?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0000006`0oooo001[0?ooo`030000003oool0000000l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`0000003`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`000000K03oool006`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`05
0000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0J`3oool006`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?oo
o`050000003oool0oooo0?ooo`0000003`3ooolB000000T0oooo00<000000?ooo`3oool03@3ooolB
000000l0oooo00<000000?ooo`3oool0203ooolA000000l0oooo00D000000?ooo`3oool0oooo0000
000@0?ooo`030000003oool0oooo00d0oooo4P0000090?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0J`3oool006d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000003P3oool00`000000oooo0?ooo`0>
0?ooo`050000003oool0oooo0?ooo`0000003P3oool4000000l0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000003P3o
ool00`000000oooo0?ooo`060?ooo`8000003`3oool3000000h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo1000000?0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1/0?ooo`00KP3oool2
000000/0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`8000000`3oool2
000000`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo0`0000030?ooo`030000003oool0oooo00d0oooo0P0000060?ooo`030000003oool0
oooo00X0oooo0P00000?0?ooo`8000000`3oool2000000/0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0=0?ooo`8000000P3oool3000000/0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo0`0000030?ooo`030000003oool0
oooo00d0oooo0P0000060?ooo`030000003oool0oooo00X0oooo0P00001_0?ooo`00L03oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
K`3oool00740oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`050000003o
ool0oooo0?ooo`0000001@3oool2000000l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00<0oooo0P00000?0?ooo`030000003oool0oooo00<0oooo
00D000000?ooo`3oool0oooo000000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000001@3oool20000
00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0700oooo001b0?ooo`8000001`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo0?oo
o`8000002`3oool2000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool03@3oool2000000<0oooo00<000000?ooo`3oool01@3oool2000000l0oooo0P00000;0?oo
o`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo0P0000070?oo
o`040000003oool0oooo0?ooo`8000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0=0?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`800000L`3oool0
07@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo
0?ooo`0000003`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01`3oool2000000l0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo0?ooo`8000003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
0P00000?0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`1c0?ooo`00
M@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool0
00004@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000403oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo07@0oooo001f
0?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`<000004`3oool200000080oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo008000001P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo0`0000020?ooo`8000003`3oool2
000001<0oooo0P0000020?ooo`030000003oool0000000l0oooo0P00000<0?ooo`030000003oool0
oooo00@0oooo0P0000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`02000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=
0?ooo`<000000P3oool2000007L0oooo001h0?ooo`800000403oool2000001L0oooo0P00000@0?oo
o`030000003oool0oooo00L0oooo0P0000080?ooo`030000003oool0oooo00`0oooo0P00000?0?oo
o`<00000403oool00`000000oooo0?ooo`0E0?ooo`@000003`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00H0oooo0P00000:0?ooo`030000003oool0oooo00d0oooo0P0000080?oo
o`030000003oool0oooo00`0oooo0P00000?0?ooo`<00000N@3oool007T0oooo4P00000I0?oooa80
00002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo8P00000I0?oooa80
00003`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo4@0000090?ooo`03
0000003oool0oooo00h0oooo4@00001j0?ooo`00RP3oool3000001D0oooo0`00000@0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00d0oooo0`00000?0?ooo`8000005@3oool300000100oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
R03oool008/0oooo00<000000?ooo`0000004`3oool01@000000oooo0?ooo`3oool000000100oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3o
ool04@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0R@3oool008/0
oooo00<000000?ooo`3oool00P00000?0?ooo`800000103oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool2000000l0oooo0P00000?0?ooo`80
0000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo08T0oooo002;0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0R@3oool008`0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`2:0?ooo`00S03oool00`000000oooo0?ooo`030?ooo`8000001`3oool2
000000T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00H0oooo00@000000?ooo`00000000003P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00L0oooo0P00000?0?ooo`8000001`3oool2000000T0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`0000000000
3P3oool00`000000oooo0?ooo`2:0?ooo`00S03oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0:0?ooo`8000000`3oool2000000H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0RP3oool008d0oooo00<000000?ooo`3oool01@3oool2
000000030?ooo`000000000000d0oooo00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02`3oool2000000l0oooo0P0000000`3oool000000000
000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo08/0oooo002=0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`070?ooo`8000002@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo4P00000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
0000000@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000000T0oooo
00<000000?ooo`3oool0R`3oool008d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo000000030?ooo`800000
303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`050?ooo`8000002`3oool2000000<0oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`040000003oool0oooo0?ooo`800000303oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo08/0oooo002>0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000<0oooo00<000000?ooo`3o
ool03@3oool2000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0000000l0oooo0P000005
0?ooo`030000003oool0oooo08`0oooo002>0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000080oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000l0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00H000000?oo
o`3oool000000?ooo`00000@0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`2<0?ooo`00SP3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo00000002000001@0oooo00D0
00000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0000000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0P00000C0?ooo`<0000000<0oooo0000003oool03`3oool3000001@0oooo00D000000?ooo`3oool0
oooo0000002>0?ooo`00S`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03@3oool2000001L0oooo0`00000?0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool03P3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3o
ool03P3oool2000001L0oooo0P00000@0?ooo`8000005`3oool3000008l0oooo002?0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool03P3ooolA000001X0oooo4@00000?0?ooo`030000
003oool0oooo00h0oooo00D000000?ooo`3oool0oooo0000000?0?oooa8000006@3ooolB000001X0
oooo00<000000?ooo`3oool0S@3oool00900oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0<0?ooo`8000003`3oool3000001L0oooo0P00000?0?ooo`<000003P3oool00`000000oooo
0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000003P3oool4000000l0oooo00<000000?ooo`3o
ool05@3oool200000140oooo00<000000?ooo`3oool05@3oool200000900oooo002A0?ooo`800000
1P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo0`0000020?ooo`800000
503oool00`000000oooo0?ooo`0=0?ooo`8000000P3oool3000000/0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo0`0000030?ooo`030000
003oool0oooo00d0oooo0P00000C0?ooo`8000000P3oool00`000000oooo0?ooo`0?0?ooo`800000
503oool00`000000oooo0?ooo`2@0?ooo`00T`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0T@3oool009@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`8000003`3oool01@000000oooo0?ooo`3oool00000
00D0oooo00<000000?ooo`3oool03@3oool2000000l0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo000000050?ooo`8000003`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0=0?ooo`800000U03oool009D0oooo0P0000030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool03@3oool2000000<0oooo00<000000?ooo`3oool01@3oool2
000000`0oooo00<000000?ooo`3oool03@3oool2000000L0oooo00@000000?ooo`3oool0oooo0P00
00070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00d0oooo0P00
000;0?ooo`8000001`3oool00`000000oooo0?ooo`0B0?ooo`800000303oool00`000000oooo0?oo
o`2D0?ooo`00U`3oool01@000000oooo0?ooo`3oool0000000D0oooo0P00000?0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`8000003`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P00000?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00L0oooo0P00002G0?ooo`00V03oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo09L0oooo002I0?ooo`<000000`3oool00`000000oooo0?ooo`0=0?ooo`8000001P3oool0
0`000000oooo0?ooo`0:0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`8000002`3oool0
0`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P0000060?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool03@3oool2000000<0oooo0P00000<0?ooo`030000003oool0oooo01D0oooo0P000004
0?ooo`030000003oool0oooo09P0oooo002K0?ooo`@000003`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00`0oooo00@000000?ooo`00000000003`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00H0oooo0P00000@0?ooo`030000003oool0oooo00L0oooo0P000008
0?ooo`030000003oool0oooo00`0oooo0P00000?0?ooo`030000003oool0000000h0oooo00<00000
0?ooo`3oool05`3oool010000000oooo00000000002K0?ooo`00W03ooolB000000T0oooo00<00000
0?ooo`3oool03@3ooolB000000l0oooo00<000000?ooo`3oool01`3ooolB000000T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oooa400000403oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo09/0oooo002g0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0]@3oool00;H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2e0?ooo`00
]P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0;@0oooo002f0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0]03oool00;D0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`2c0?ooo`00]@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0;<0oooo00390?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool200000003
0?ooo`000000000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo0P0000000`3oool000000000000>0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0b03oool00<X0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`390?ooo`00
bP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo0P0000070?ooo`800000
1@3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000L0
oooo0P00000:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0b@3oool00<X0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`390?ooo`00b`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0;0?ooo`800000
1P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0<X0oooo003;0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00P3oool2000000l0oooo0P0000020?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`0000000P3oool200000100oooo0P0000040?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0bP3oool00</0oooo00<000000?ooo`3oool03P3oool0
1@000000oooo0?ooo`3oool0000001<0oooo00<000000?ooo`000000403oool01@000000oooo0000
003oool0000001@0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo0<X0
oooo003<0?ooo`030000003oool0oooo00h0oooo0`00000E0?ooo`<00000403oool3000001H0oooo
0`00000?0?ooo`030000003oool0oooo0</0oooo003<0?oooa8000006@3ooolB000001X0oooo4@00
003=0?ooo`00o`3ooooo0?ooo`<0oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00
o`3ooooo0?ooo`<0oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?oo
o`<0oooo003o0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00o`3ooooo0?ooo`<0oooo003o
0?ooool0oooo0`3oool00?l0ooooo`3oool30?ooo`00\
\>"],
  ImageRangeCache->{{{0, 512.438}, {503.813, 0}} -> {-15.5677, -15.3057, \
0.0607594, 0.0607594}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[410]="]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Save the data in two files:\n",
  StyleBox["test.dat:  vertex positions written in a rational form (if \
possible).\ntiling.dat: vertex positions (x,y,0). (Extremely useful for \
applications!!!!)\nThe number inside Spherical Cut controls the radius of the \
tiling, in the example is set to 10.\nIf a very big radius is needed, modify \
Np as needed.", "Subsection"]
}], "Subtitle",
  Background->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(SaveDat[Union[SphericalCut[QL, 10]], \ "\<test.dat\>"]\)], "Input",
  CellLabel->"In[281]:="],

Cell[BoxData[
    \(SaveDat[N[Union[SphericalCut[QL, 10]]], \ "\<tiling.dat\>"]\)], "Input",\

  CellLabel->"In[73]:="],

Cell[CellGroupData[{

Cell["The average lattice", "Subtitle",
  Background->RGBColor[1, 0, 1]],

Cell[CellGroupData[{

Cell["Formulae for the average lattice.", "Text",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(In\ my\ \(notes : \ 
          e\_k\%\[VerticalSeparator]\) = \ \((e\_k\%y, \ \(-e\_k\%x\))\), 
    e\_j\%\(\('\)\(\[VerticalSeparator]\)\) = \ \(\((\(-e\_j\%y\), \ 
              e\_j\%x)\) . \ 
            In\ the\ paper\ the\ notation\ was\ changed\ to\ b\_jl = \ \(e\_k\
\%\[VerticalSeparator] . 
            e\_l = \(epk[k] . 
                e[l]\ and\ b\_kl = \ \
\(e\_j\%\(\('\)\(\[VerticalSeparator]\)\) . e\_l = 
              epj[j] . e[l]\)\)\)\)\)], "DisplayFormula"],

Cell[BoxData[{
    \(epk[
        k_] := {\(e[
            k]\)[\([2]\)], \(-\(e[k]\)[\([1]\)]\)}\), "\[IndentingNewLine]", 
    \(epj[j_] := {\(-\(e[j]\)[\([2]\)]\), \(e[j]\)[\([1]\)]}\)}], "Input",
  CellLabel->"In[79]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equations (10) and (12). Acta Cryst.", "Text"],

Cell[BoxData[{
    \(RR[j_, \ 
        k_, \ \[Alpha]_]\  := \ \[Sum]\+\(l = 1\)\%5 
          If[\((l != j)\) && \((l != 
                k)\), \((\ \[Alpha][\([j]\)]\ epk[k] . e[l]\/a[\([j, k]\)]\  \
+ \ \[Alpha][\([k]\)]\ epj[j] . e[l]\/a[\([j, k]\)]\  - \[Alpha][\([l]\)]\  + \
\ 1\/2)\)\ e[l], 0]\), "\[IndentingNewLine]", 
    \(A[j_, \ k_, \ \[Alpha]_]\  := \ 
      m \((e[j]\  + \ \[Sum]\+\(l = 1\)\%5 If[\((l != j)\) && \((l != k)\), 
                  epk[k] . e[l]\/a[\([j, k]\)]\ \ e[l], 0])\)\  + \ 
        n\ \((e[k]\  + \ \[Sum]\+\(l = 1\)\%5 
                  If[\((l != j)\) && \((l != k)\), 
                  epj[j] . e[l]\/a[\([j, k]\)]\ \ e[l], 0])\)\  + \ 
        RR[j, \ k, \ \[Alpha]]\)}], "Input",
  CellLabel->"In[81]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AL Returns the lattice coorresponding to (j,k,\[Alpha]) with m and \
n running between -Np to Np\
\>", "Text"],

Cell[BoxData[
    \(\(AL[j_, \ k_, \ \[Alpha]_, \ Np_]\  := \ \ Flatten[
          Table[A[j, \ k, \ \[Alpha]] /. {m \[Rule] x, 
                n \[Rule] y}, {x, \(-Np\), Np}, {y, \(-Np\), Np}], 
          1];\)\)], "Input",
  CellLabel->"In[83]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Shifts and range", "Text"],

Cell[BoxData[{
    \(\(\[Alpha]\  = \ {0.0001, 0.0002, \(-0.0004\), 
          0.0006, \(-0.0005\)};\)\), "\[IndentingNewLine]", 
    \(\(Np\  = \ 5;\)\)}], "Input",
  CellLabel->"In[84]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lattices\ of\  < t\^0 > \)], "Text"],

Cell[BoxData[{
    \(\(AL021 = AL[2, \ 1, \ \[Alpha], \ Np];\)\), "\[IndentingNewLine]", 
    \(\(AL031 = AL[3, \ 1, \ \[Alpha], \ Np];\)\), "\[IndentingNewLine]", 
    \(\(AL032 = AL[3, \ 2, \ \[Alpha], \ Np];\)\), "\[IndentingNewLine]", 
    \(\(AL041 = AL[4, \ 1, \ \[Alpha], \ Np];\)\), "\[IndentingNewLine]", 
    \(\(AL042 = AL[4, \ 2, \ \[Alpha], \ Np];\)\), "\[IndentingNewLine]", 
    \(\(AL043 = AL[4, \ 3, \ \[Alpha], \ Np];\)\), "\[IndentingNewLine]", 
    \(\(AL051 = AL[5, 1, \ \[Alpha], \ Np];\)\), "\[IndentingNewLine]", 
    \(\(AL052 = AL[5, 2, \ \[Alpha], \ Np];\)\), "\[IndentingNewLine]", 
    \(\(AL053 = AL[5, 3, \ \[Alpha], \ Np];\)\), "\[IndentingNewLine]", 
    \(\(AL054 = AL[5, 4, \ \[Alpha], \ Np];\)\)}], "Input",
  CellLabel->"In[86]:="]
}, Open  ]],

Cell[BoxData[
    \(\(AL0 = 
        Chop[N[Join[AL021, AL031, AL032, AL041, AL042, AL043, \ AL051, \ 
              AL052, \ AL053, \ AL054]]];\)\)], "Input",
  CellLabel->"In[96]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AL0, Axes \[Rule] True, Prolog \[Rule] PointSize[0.01], 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[97]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9583 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.50365 0.0117721 0.479177 0.0117721 [
[.03277 .46668 -9 -9 ]
[.03277 .46668 9 0 ]
[.26821 .46668 -9 -9 ]
[.26821 .46668 9 0 ]
[.73909 .46668 -6 -9 ]
[.73909 .46668 6 0 ]
[.97453 .46668 -6 -9 ]
[.97453 .46668 6 0 ]
[.49115 .00829 -18 -4.5 ]
[.49115 .00829 0 4.5 ]
[.49115 .24374 -18 -4.5 ]
[.49115 .24374 0 4.5 ]
[.49115 .71462 -12 -4.5 ]
[.49115 .71462 0 4.5 ]
[.49115 .95006 -12 -4.5 ]
[.49115 .95006 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .9583 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03277 .47918 m
.03277 .48543 L
s
[(-40)] .03277 .46668 0 1 Mshowa
.26821 .47918 m
.26821 .48543 L
s
[(-20)] .26821 .46668 0 1 Mshowa
.73909 .47918 m
.73909 .48543 L
s
[(20)] .73909 .46668 0 1 Mshowa
.97453 .47918 m
.97453 .48543 L
s
[(40)] .97453 .46668 0 1 Mshowa
.125 Mabswid
.09163 .47918 m
.09163 .48293 L
s
.15049 .47918 m
.15049 .48293 L
s
.20935 .47918 m
.20935 .48293 L
s
.32707 .47918 m
.32707 .48293 L
s
.38593 .47918 m
.38593 .48293 L
s
.44479 .47918 m
.44479 .48293 L
s
.56251 .47918 m
.56251 .48293 L
s
.62137 .47918 m
.62137 .48293 L
s
.68023 .47918 m
.68023 .48293 L
s
.79795 .47918 m
.79795 .48293 L
s
.85681 .47918 m
.85681 .48293 L
s
.91567 .47918 m
.91567 .48293 L
s
.25 Mabswid
0 .47918 m
1 .47918 L
s
.50365 .00829 m
.5099 .00829 L
s
[(-40)] .49115 .00829 1 0 Mshowa
.50365 .24374 m
.5099 .24374 L
s
[(-20)] .49115 .24374 1 0 Mshowa
.50365 .71462 m
.5099 .71462 L
s
[(20)] .49115 .71462 1 0 Mshowa
.50365 .95006 m
.5099 .95006 L
s
[(40)] .49115 .95006 1 0 Mshowa
.125 Mabswid
.50365 .06715 m
.5074 .06715 L
s
.50365 .12602 m
.5074 .12602 L
s
.50365 .18488 m
.5074 .18488 L
s
.50365 .3026 m
.5074 .3026 L
s
.50365 .36146 m
.5074 .36146 L
s
.50365 .42032 m
.5074 .42032 L
s
.50365 .53804 m
.5074 .53804 L
s
.50365 .5969 m
.5074 .5969 L
s
.50365 .65576 m
.5074 .65576 L
s
.50365 .77348 m
.5074 .77348 L
s
.50365 .83234 m
.5074 .83234 L
s
.50365 .8912 m
.5074 .8912 L
s
.25 Mabswid
.50365 0 m
.50365 .9583 L
s
0 0 m
1 0 L
1 .9583 L
0 .9583 L
closepath
clip
newpath
.01 w
.3488 .36667 Mdot
.37823 .35711 Mdot
.40766 .34755 Mdot
.43709 .33799 Mdot
.46652 .32842 Mdot
.49595 .31886 Mdot
.52538 .3093 Mdot
.55481 .29974 Mdot
.58424 .29017 Mdot
.61367 .28061 Mdot
.6431 .27105 Mdot
.3488 .39762 Mdot
.37823 .38805 Mdot
.40766 .37849 Mdot
.43709 .36893 Mdot
.46652 .35937 Mdot
.49595 .3498 Mdot
.52538 .34024 Mdot
.55481 .33068 Mdot
.58424 .32112 Mdot
.61367 .31156 Mdot
.6431 .30199 Mdot
.3488 .42856 Mdot
.37823 .419 Mdot
.40766 .40944 Mdot
.43709 .39987 Mdot
.46652 .39031 Mdot
.49595 .38075 Mdot
.52538 .37119 Mdot
.55481 .36162 Mdot
.58424 .35206 Mdot
.61367 .3425 Mdot
.6431 .33294 Mdot
.3488 .45951 Mdot
.37823 .44994 Mdot
.40766 .44038 Mdot
.43709 .43082 Mdot
.46652 .42126 Mdot
.49595 .41169 Mdot
.52538 .40213 Mdot
.55481 .39257 Mdot
.58424 .38301 Mdot
.61367 .37344 Mdot
.6431 .36388 Mdot
.3488 .49045 Mdot
.37823 .48089 Mdot
.40766 .47133 Mdot
.43709 .46176 Mdot
.46652 .4522 Mdot
.49595 .44264 Mdot
.52538 .43308 Mdot
.55481 .42351 Mdot
.58424 .41395 Mdot
.61367 .40439 Mdot
.6431 .39483 Mdot
.3488 .5214 Mdot
.37823 .51183 Mdot
.40766 .50227 Mdot
.43709 .49271 Mdot
.46652 .48315 Mdot
.49595 .47358 Mdot
.52538 .46402 Mdot
.55481 .45446 Mdot
.58424 .4449 Mdot
.61367 .43533 Mdot
.6431 .42577 Mdot
.3488 .55234 Mdot
.37823 .54278 Mdot
.40766 .53322 Mdot
.43709 .52365 Mdot
.46652 .51409 Mdot
.49595 .50453 Mdot
.52538 .49497 Mdot
.55481 .4854 Mdot
.58424 .47584 Mdot
.61367 .46628 Mdot
.6431 .45672 Mdot
.3488 .58329 Mdot
.37823 .57372 Mdot
.40766 .56416 Mdot
.43709 .5546 Mdot
.46652 .54504 Mdot
.49595 .53547 Mdot
.52538 .52591 Mdot
.55481 .51635 Mdot
.58424 .50679 Mdot
.61367 .49722 Mdot
.6431 .48766 Mdot
.3488 .61423 Mdot
.37823 .60467 Mdot
.40766 .59511 Mdot
.43709 .58554 Mdot
.46652 .57598 Mdot
.49595 .56642 Mdot
.52538 .55686 Mdot
.55481 .54729 Mdot
.58424 .53773 Mdot
.61367 .52817 Mdot
.6431 .51861 Mdot
.3488 .64517 Mdot
.37823 .63561 Mdot
.40766 .62605 Mdot
.43709 .61649 Mdot
.46652 .60693 Mdot
.49595 .59736 Mdot
.52538 .5878 Mdot
.55481 .57824 Mdot
.58424 .56868 Mdot
.61367 .55911 Mdot
.6431 .54955 Mdot
.3488 .67612 Mdot
.37823 .66656 Mdot
.40766 .65699 Mdot
.43709 .64743 Mdot
.46652 .63787 Mdot
.49595 .62831 Mdot
.52538 .61874 Mdot
.55481 .60918 Mdot
.58424 .59962 Mdot
.61367 .59006 Mdot
.6431 .5805 Mdot
.35538 .02282 Mdot
.38481 .06332 Mdot
.41424 .10383 Mdot
.44367 .14434 Mdot
.4731 .18485 Mdot
.50253 .22535 Mdot
.53196 .26586 Mdot
.56139 .30637 Mdot
.59082 .34687 Mdot
.62025 .38738 Mdot
.64968 .42789 Mdot
.35538 .07289 Mdot
.38481 .11339 Mdot
.41424 .1539 Mdot
.44367 .19441 Mdot
.4731 .23492 Mdot
.50253 .27542 Mdot
.53196 .31593 Mdot
.56139 .35644 Mdot
.59082 .39694 Mdot
.62025 .43745 Mdot
.64968 .47796 Mdot
.35538 .12296 Mdot
.38481 .16346 Mdot
.41424 .20397 Mdot
.44367 .24448 Mdot
.4731 .28498 Mdot
.50253 .32549 Mdot
.53196 .366 Mdot
.56139 .40651 Mdot
.59082 .44701 Mdot
.62025 .48752 Mdot
.64968 .52803 Mdot
.35538 .17303 Mdot
.38481 .21353 Mdot
.41424 .25404 Mdot
.44367 .29455 Mdot
.4731 .33505 Mdot
.50253 .37556 Mdot
.53196 .41607 Mdot
.56139 .45658 Mdot
.59082 .49708 Mdot
.62025 .53759 Mdot
.64968 .5781 Mdot
.35538 .2231 Mdot
.38481 .2636 Mdot
.41424 .30411 Mdot
.44367 .34462 Mdot
.4731 .38512 Mdot
.50253 .42563 Mdot
.53196 .46614 Mdot
.56139 .50665 Mdot
.59082 .54715 Mdot
.62025 .58766 Mdot
.64968 .62817 Mdot
.35538 .27316 Mdot
.38481 .31367 Mdot
.41424 .35418 Mdot
.44367 .39469 Mdot
.4731 .43519 Mdot
.50253 .4757 Mdot
.53196 .51621 Mdot
.56139 .55672 Mdot
.59082 .59722 Mdot
.62025 .63773 Mdot
.64968 .67824 Mdot
.35538 .32323 Mdot
.38481 .36374 Mdot
.41424 .40425 Mdot
.44367 .44476 Mdot
.4731 .48526 Mdot
.50253 .52577 Mdot
.53196 .56628 Mdot
.56139 .60678 Mdot
.59082 .64729 Mdot
.62025 .6878 Mdot
.64968 .72831 Mdot
.35538 .3733 Mdot
.38481 .41381 Mdot
.41424 .45432 Mdot
.44367 .49483 Mdot
.4731 .53533 Mdot
.50253 .57584 Mdot
.53196 .61635 Mdot
.56139 .65685 Mdot
.59082 .69736 Mdot
.62025 .73787 Mdot
.64968 .77838 Mdot
.35538 .42337 Mdot
.38481 .46388 Mdot
.41424 .50439 Mdot
.44367 .5449 Mdot
.4731 .5854 Mdot
.50253 .62591 Mdot
.53196 .66642 Mdot
.56139 .70692 Mdot
.59082 .74743 Mdot
.62025 .78794 Mdot
.64968 .82845 Mdot
.35538 .47344 Mdot
.38481 .51395 Mdot
.41424 .55446 Mdot
.44367 .59496 Mdot
.4731 .63547 Mdot
.50253 .67598 Mdot
.53196 .71649 Mdot
.56139 .75699 Mdot
.59082 .7975 Mdot
.62025 .83801 Mdot
.64968 .87852 Mdot
.35538 .52351 Mdot
.38481 .56402 Mdot
.41424 .60453 Mdot
.44367 .64503 Mdot
.4731 .68554 Mdot
.50253 .72605 Mdot
.53196 .76656 Mdot
.56139 .80706 Mdot
.59082 .84757 Mdot
.62025 .88808 Mdot
.64968 .92858 Mdot
.56282 .29713 Mdot
.58101 .32217 Mdot
.59919 .3472 Mdot
.61738 .37224 Mdot
.63557 .39727 Mdot
.65376 .42231 Mdot
.67195 .44734 Mdot
.69014 .47238 Mdot
.70833 .49741 Mdot
.72652 .52245 Mdot
.74471 .54748 Mdot
.53339 .3067 Mdot
.55158 .33173 Mdot
.56976 .35677 Mdot
.58795 .3818 Mdot
.60614 .40684 Mdot
.62433 .43187 Mdot
.64252 .45691 Mdot
.66071 .48194 Mdot
.6789 .50697 Mdot
.69709 .53201 Mdot
.71528 .55704 Mdot
.50396 .31626 Mdot
.52215 .34129 Mdot
.54033 .36633 Mdot
.55852 .39136 Mdot
.57671 .4164 Mdot
.5949 .44143 Mdot
.61309 .46647 Mdot
.63128 .4915 Mdot
.64947 .51654 Mdot
.66766 .54157 Mdot
.68585 .56661 Mdot
.47453 .32582 Mdot
.49272 .35086 Mdot
.5109 .37589 Mdot
.52909 .40093 Mdot
.54728 .42596 Mdot
.56547 .451 Mdot
.58366 .47603 Mdot
.60185 .50106 Mdot
.62004 .5261 Mdot
.63823 .55113 Mdot
.65642 .57617 Mdot
.4451 .33538 Mdot
.46329 .36042 Mdot
.48147 .38545 Mdot
.49966 .41049 Mdot
.51785 .43552 Mdot
.53604 .46056 Mdot
.55423 .48559 Mdot
.57242 .51063 Mdot
.59061 .53566 Mdot
.6088 .5607 Mdot
.62698 .58573 Mdot
.41567 .34495 Mdot
.43386 .36998 Mdot
.45204 .39502 Mdot
.47023 .42005 Mdot
.48842 .44509 Mdot
.50661 .47012 Mdot
.5248 .49515 Mdot
.54299 .52019 Mdot
.56118 .54522 Mdot
.57937 .57026 Mdot
.59755 .59529 Mdot
.38624 .35451 Mdot
.40442 .37954 Mdot
.42261 .40458 Mdot
.4408 .42961 Mdot
.45899 .45465 Mdot
.47718 .47968 Mdot
.49537 .50472 Mdot
.51356 .52975 Mdot
.53175 .55479 Mdot
.54994 .57982 Mdot
.56812 .60486 Mdot
.35681 .36407 Mdot
.37499 .38911 Mdot
.39318 .41414 Mdot
.41137 .43918 Mdot
.42956 .46421 Mdot
.44775 .48924 Mdot
.46594 .51428 Mdot
.48413 .53931 Mdot
.50232 .56435 Mdot
.52051 .58938 Mdot
.53869 .61442 Mdot
.32738 .37363 Mdot
.34556 .39867 Mdot
.36375 .4237 Mdot
.38194 .44874 Mdot
.40013 .47377 Mdot
.41832 .49881 Mdot
.43651 .52384 Mdot
.4547 .54888 Mdot
.47289 .57391 Mdot
.49108 .59895 Mdot
.50926 .62398 Mdot
.29795 .3832 Mdot
.31613 .40823 Mdot
.33432 .43327 Mdot
.35251 .4583 Mdot
.3707 .48333 Mdot
.38889 .50837 Mdot
.40708 .5334 Mdot
.42527 .55844 Mdot
.44346 .58347 Mdot
.46165 .60851 Mdot
.47983 .63354 Mdot
.26852 .39276 Mdot
.2867 .41779 Mdot
.30489 .44283 Mdot
.32308 .46786 Mdot
.34127 .4929 Mdot
.35946 .51793 Mdot
.37765 .54297 Mdot
.39584 .568 Mdot
.41403 .59304 Mdot
.43221 .61807 Mdot
.4504 .64311 Mdot
.35538 .93549 Mdot
.38481 .89498 Mdot
.41424 .85447 Mdot
.44367 .81396 Mdot
.4731 .77346 Mdot
.50253 .73295 Mdot
.53196 .69244 Mdot
.56139 .65194 Mdot
.59082 .61143 Mdot
.62025 .57092 Mdot
.64968 .53041 Mdot
.35538 .88542 Mdot
.38481 .84491 Mdot
.41424 .8044 Mdot
.44367 .7639 Mdot
.4731 .72339 Mdot
.50253 .68288 Mdot
.53196 .64237 Mdot
.56139 .60187 Mdot
.59082 .56136 Mdot
.62025 .52085 Mdot
.64968 .48034 Mdot
.35538 .83535 Mdot
.38481 .79484 Mdot
.41424 .75433 Mdot
.44367 .71383 Mdot
.4731 .67332 Mdot
.50253 .63281 Mdot
.53196 .5923 Mdot
.56139 .5518 Mdot
.59082 .51129 Mdot
.62025 .47078 Mdot
.64968 .43028 Mdot
.35538 .78528 Mdot
.38481 .74477 Mdot
.41424 .70426 Mdot
.44367 .66376 Mdot
.4731 .62325 Mdot
.50253 .58274 Mdot
.53196 .54223 Mdot
.56139 .50173 Mdot
.59082 .46122 Mdot
.62025 .42071 Mdot
.64968 .38021 Mdot
.35538 .73521 Mdot
.38481 .6947 Mdot
.41424 .65419 Mdot
.44367 .61369 Mdot
.4731 .57318 Mdot
.50253 .53267 Mdot
.53196 .49216 Mdot
.56139 .45166 Mdot
.59082 .41115 Mdot
.62025 .37064 Mdot
.64968 .33014 Mdot
.35538 .68514 Mdot
.38481 .64463 Mdot
.41424 .60412 Mdot
.44367 .56362 Mdot
.4731 .52311 Mdot
.50253 .4826 Mdot
.53196 .44209 Mdot
.56139 .40159 Mdot
.59082 .36108 Mdot
.62025 .32057 Mdot
.64968 .28007 Mdot
.35538 .63507 Mdot
.38481 .59456 Mdot
.41424 .55405 Mdot
.44367 .51355 Mdot
.4731 .47304 Mdot
.50253 .43253 Mdot
.53196 .39203 Mdot
.56139 .35152 Mdot
.59082 .31101 Mdot
.62025 .2705 Mdot
.64968 .23 Mdot
.35538 .585 Mdot
.38481 .54449 Mdot
.41424 .50398 Mdot
.44367 .46348 Mdot
.4731 .42297 Mdot
.50253 .38246 Mdot
.53196 .34196 Mdot
.56139 .30145 Mdot
.59082 .26094 Mdot
.62025 .22043 Mdot
.64968 .17993 Mdot
.35538 .53493 Mdot
.38481 .49442 Mdot
.41424 .45391 Mdot
.44367 .41341 Mdot
.4731 .3729 Mdot
.50253 .33239 Mdot
.53196 .29189 Mdot
.56139 .25138 Mdot
.59082 .21087 Mdot
.62025 .17036 Mdot
.64968 .12986 Mdot
.35538 .48486 Mdot
.38481 .44435 Mdot
.41424 .40385 Mdot
.44367 .36334 Mdot
.4731 .32283 Mdot
.50253 .28232 Mdot
.53196 .24182 Mdot
.56139 .20131 Mdot
.59082 .1608 Mdot
.62025 .12029 Mdot
.64968 .07979 Mdot
.35538 .43479 Mdot
.38481 .39428 Mdot
.41424 .35378 Mdot
.44367 .31327 Mdot
.4731 .27276 Mdot
.50253 .23225 Mdot
.53196 .19175 Mdot
.56139 .15124 Mdot
.59082 .11073 Mdot
.62025 .07023 Mdot
.64968 .02972 Mdot
.89181 .19716 Mdot
.86238 .23767 Mdot
.83295 .27817 Mdot
.80352 .31868 Mdot
.77409 .35919 Mdot
.74466 .39969 Mdot
.71523 .4402 Mdot
.6858 .48071 Mdot
.65637 .52122 Mdot
.62694 .56172 Mdot
.5975 .60223 Mdot
.84419 .21263 Mdot
.81476 .25314 Mdot
.78533 .29364 Mdot
.7559 .33415 Mdot
.72647 .37466 Mdot
.69704 .41517 Mdot
.66761 .45567 Mdot
.63818 .49618 Mdot
.60875 .53669 Mdot
.57932 .57719 Mdot
.54989 .6177 Mdot
.79657 .2281 Mdot
.76714 .26861 Mdot
.73771 .30912 Mdot
.70828 .34962 Mdot
.67885 .39013 Mdot
.64942 .43064 Mdot
.61999 .47115 Mdot
.59056 .51165 Mdot
.56113 .55216 Mdot
.5317 .59267 Mdot
.50227 .63317 Mdot
.74895 .24358 Mdot
.71952 .28408 Mdot
.69009 .32459 Mdot
.66066 .3651 Mdot
.63123 .4056 Mdot
.6018 .44611 Mdot
.57237 .48662 Mdot
.54294 .52713 Mdot
.51351 .56763 Mdot
.48408 .60814 Mdot
.45465 .64865 Mdot
.70133 .25905 Mdot
.6719 .29955 Mdot
.64247 .34006 Mdot
.61304 .38057 Mdot
.58361 .42108 Mdot
.55418 .46158 Mdot
.52475 .50209 Mdot
.49532 .5426 Mdot
.46589 .5831 Mdot
.43646 .62361 Mdot
.40703 .66412 Mdot
.65371 .27452 Mdot
.62428 .31503 Mdot
.59485 .35553 Mdot
.56542 .39604 Mdot
.53599 .43655 Mdot
.50656 .47706 Mdot
.47713 .51756 Mdot
.4477 .55807 Mdot
.41827 .59858 Mdot
.38884 .63908 Mdot
.35941 .67959 Mdot
.60609 .28999 Mdot
.57666 .3305 Mdot
.54723 .37101 Mdot
.5178 .41151 Mdot
.48837 .45202 Mdot
.45894 .49253 Mdot
.42951 .53304 Mdot
.40008 .57354 Mdot
.37065 .61405 Mdot
.34122 .65456 Mdot
.31179 .69506 Mdot
.55847 .30546 Mdot
.52904 .34597 Mdot
.49961 .38648 Mdot
.47018 .42699 Mdot
.44075 .46749 Mdot
.41132 .508 Mdot
.38189 .54851 Mdot
.35246 .58901 Mdot
.32303 .62952 Mdot
.2936 .67003 Mdot
.26417 .71054 Mdot
.51085 .32094 Mdot
.48142 .36144 Mdot
.45199 .40195 Mdot
.42256 .44246 Mdot
.39313 .48297 Mdot
.3637 .52347 Mdot
.33427 .56398 Mdot
.30484 .60449 Mdot
.27541 .64499 Mdot
.24598 .6855 Mdot
.21655 .72601 Mdot
.46324 .33641 Mdot
.43381 .37692 Mdot
.40437 .41742 Mdot
.37494 .45793 Mdot
.34551 .49844 Mdot
.31608 .53895 Mdot
.28665 .57945 Mdot
.25722 .61996 Mdot
.22779 .66047 Mdot
.19836 .70097 Mdot
.16893 .74148 Mdot
.41562 .35188 Mdot
.38619 .39239 Mdot
.35676 .4329 Mdot
.32733 .4734 Mdot
.2979 .51391 Mdot
.26847 .55442 Mdot
.23904 .59492 Mdot
.20961 .63543 Mdot
.18017 .67594 Mdot
.15074 .71645 Mdot
.12131 .75695 Mdot
.69506 .47915 Mdot
.67687 .50419 Mdot
.65868 .52922 Mdot
.64049 .55426 Mdot
.62231 .57929 Mdot
.60412 .60433 Mdot
.58593 .62936 Mdot
.56774 .6544 Mdot
.54955 .67943 Mdot
.53136 .70446 Mdot
.51317 .7295 Mdot
.67687 .45412 Mdot
.65868 .47915 Mdot
.64049 .50419 Mdot
.62231 .52922 Mdot
.60412 .55426 Mdot
.58593 .57929 Mdot
.56774 .60433 Mdot
.54955 .62936 Mdot
.53136 .6544 Mdot
.51317 .67943 Mdot
.49498 .70446 Mdot
.65868 .42908 Mdot
.64049 .45412 Mdot
.62231 .47915 Mdot
.60412 .50419 Mdot
.58593 .52922 Mdot
.56774 .55426 Mdot
.54955 .57929 Mdot
.53136 .60433 Mdot
.51317 .62936 Mdot
.49498 .6544 Mdot
.47679 .67943 Mdot
.64049 .40405 Mdot
.62231 .42908 Mdot
.60412 .45412 Mdot
.58593 .47915 Mdot
.56774 .50419 Mdot
.54955 .52922 Mdot
.53136 .55426 Mdot
.51317 .57929 Mdot
.49498 .60433 Mdot
.47679 .62936 Mdot
.45861 .6544 Mdot
.62231 .37901 Mdot
.60412 .40405 Mdot
.58593 .42908 Mdot
.56774 .45412 Mdot
.54955 .47915 Mdot
.53136 .50419 Mdot
.51317 .52922 Mdot
.49498 .55426 Mdot
.47679 .57929 Mdot
.45861 .60433 Mdot
.44042 .62936 Mdot
.60412 .35398 Mdot
.58593 .37901 Mdot
.56774 .40405 Mdot
.54955 .42908 Mdot
.53136 .45412 Mdot
.51317 .47915 Mdot
.49498 .50419 Mdot
.47679 .52922 Mdot
.45861 .55426 Mdot
.44042 .57929 Mdot
.42223 .60433 Mdot
.58593 .32894 Mdot
.56774 .35398 Mdot
.54955 .37901 Mdot
.53136 .40405 Mdot
.51317 .42908 Mdot
.49498 .45412 Mdot
.47679 .47915 Mdot
.45861 .50419 Mdot
.44042 .52922 Mdot
.42223 .55426 Mdot
.40404 .57929 Mdot
.56774 .30391 Mdot
.54955 .32894 Mdot
.53136 .35398 Mdot
.51317 .37901 Mdot
.49498 .40405 Mdot
.47679 .42908 Mdot
.45861 .45412 Mdot
.44042 .47915 Mdot
.42223 .50419 Mdot
.40404 .52922 Mdot
.38585 .55426 Mdot
.54955 .27887 Mdot
.53136 .30391 Mdot
.51317 .32894 Mdot
.49498 .35398 Mdot
.47679 .37901 Mdot
.45861 .40405 Mdot
.44042 .42908 Mdot
.42223 .45412 Mdot
.40404 .47915 Mdot
.38585 .50419 Mdot
.36766 .52922 Mdot
.53136 .25384 Mdot
.51317 .27887 Mdot
.49498 .30391 Mdot
.47679 .32894 Mdot
.45861 .35398 Mdot
.44042 .37901 Mdot
.42223 .40405 Mdot
.40404 .42908 Mdot
.38585 .45412 Mdot
.36766 .47915 Mdot
.34947 .50419 Mdot
.51317 .2288 Mdot
.49498 .25384 Mdot
.47679 .27887 Mdot
.45861 .30391 Mdot
.44042 .32894 Mdot
.42223 .35398 Mdot
.40404 .37901 Mdot
.38585 .40405 Mdot
.36766 .42908 Mdot
.34947 .45412 Mdot
.33128 .47915 Mdot
.3488 .5917 Mdot
.37823 .60126 Mdot
.40766 .61083 Mdot
.43709 .62039 Mdot
.46652 .62995 Mdot
.49595 .63951 Mdot
.52538 .64908 Mdot
.55481 .65864 Mdot
.58424 .6682 Mdot
.61367 .67776 Mdot
.6431 .68733 Mdot
.3488 .56076 Mdot
.37823 .57032 Mdot
.40766 .57988 Mdot
.43709 .58944 Mdot
.46652 .59901 Mdot
.49595 .60857 Mdot
.52538 .61813 Mdot
.55481 .62769 Mdot
.58424 .63726 Mdot
.61367 .64682 Mdot
.6431 .65638 Mdot
.3488 .52981 Mdot
.37823 .53938 Mdot
.40766 .54894 Mdot
.43709 .5585 Mdot
.46652 .56806 Mdot
.49595 .57763 Mdot
.52538 .58719 Mdot
.55481 .59675 Mdot
.58424 .60631 Mdot
.61367 .61587 Mdot
.6431 .62544 Mdot
.3488 .49887 Mdot
.37823 .50843 Mdot
.40766 .51799 Mdot
.43709 .52756 Mdot
.46652 .53712 Mdot
.49595 .54668 Mdot
.52538 .55624 Mdot
.55481 .56581 Mdot
.58424 .57537 Mdot
.61367 .58493 Mdot
.6431 .59449 Mdot
.3488 .46792 Mdot
.37823 .47749 Mdot
.40766 .48705 Mdot
.43709 .49661 Mdot
.46652 .50617 Mdot
.49595 .51574 Mdot
.52538 .5253 Mdot
.55481 .53486 Mdot
.58424 .54442 Mdot
.61367 .55399 Mdot
.6431 .56355 Mdot
.3488 .43698 Mdot
.37823 .44654 Mdot
.40766 .4561 Mdot
.43709 .46567 Mdot
.46652 .47523 Mdot
.49595 .48479 Mdot
.52538 .49435 Mdot
.55481 .50392 Mdot
.58424 .51348 Mdot
.61367 .52304 Mdot
.6431 .5326 Mdot
.3488 .40603 Mdot
.37823 .4156 Mdot
.40766 .42516 Mdot
.43709 .43472 Mdot
.46652 .44428 Mdot
.49595 .45385 Mdot
.52538 .46341 Mdot
.55481 .47297 Mdot
.58424 .48253 Mdot
.61367 .4921 Mdot
.6431 .50166 Mdot
.3488 .37509 Mdot
.37823 .38465 Mdot
.40766 .39421 Mdot
.43709 .40378 Mdot
.46652 .41334 Mdot
.49595 .4229 Mdot
.52538 .43246 Mdot
.55481 .44203 Mdot
.58424 .45159 Mdot
.61367 .46115 Mdot
.6431 .47071 Mdot
.3488 .34414 Mdot
.37823 .35371 Mdot
.40766 .36327 Mdot
.43709 .37283 Mdot
.46652 .38239 Mdot
.49595 .39196 Mdot
.52538 .40152 Mdot
.55481 .41108 Mdot
.58424 .42064 Mdot
.61367 .43021 Mdot
.6431 .43977 Mdot
.3488 .3132 Mdot
.37823 .32276 Mdot
.40766 .33232 Mdot
.43709 .34189 Mdot
.46652 .35145 Mdot
.49595 .36101 Mdot
.52538 .37057 Mdot
.55481 .38014 Mdot
.58424 .3897 Mdot
.61367 .39926 Mdot
.6431 .40882 Mdot
.3488 .28225 Mdot
.37823 .29182 Mdot
.40766 .30138 Mdot
.43709 .31094 Mdot
.46652 .3205 Mdot
.49595 .33007 Mdot
.52538 .33963 Mdot
.55481 .34919 Mdot
.58424 .35875 Mdot
.61367 .36832 Mdot
.6431 .37788 Mdot
.02381 .47919 Mdot
.07143 .49466 Mdot
.11905 .51013 Mdot
.16667 .5256 Mdot
.21429 .54108 Mdot
.2619 .55655 Mdot
.30952 .57202 Mdot
.35714 .58749 Mdot
.40476 .60297 Mdot
.45238 .61844 Mdot
.5 .63391 Mdot
.07143 .46371 Mdot
.11905 .47919 Mdot
.16667 .49466 Mdot
.21429 .51013 Mdot
.2619 .5256 Mdot
.30952 .54108 Mdot
.35714 .55655 Mdot
.40476 .57202 Mdot
.45238 .58749 Mdot
.5 .60297 Mdot
.54762 .61844 Mdot
.11905 .44824 Mdot
.16667 .46371 Mdot
.21429 .47919 Mdot
.2619 .49466 Mdot
.30952 .51013 Mdot
.35714 .5256 Mdot
.40476 .54108 Mdot
.45238 .55655 Mdot
.5 .57202 Mdot
.54762 .58749 Mdot
.59524 .60297 Mdot
.16667 .43277 Mdot
.21429 .44824 Mdot
.2619 .46371 Mdot
.30952 .47919 Mdot
.35714 .49466 Mdot
.40476 .51013 Mdot
.45238 .5256 Mdot
.5 .54108 Mdot
.54762 .55655 Mdot
.59524 .57202 Mdot
.64286 .58749 Mdot
.21429 .4173 Mdot
.2619 .43277 Mdot
.30952 .44824 Mdot
.35714 .46371 Mdot
.40476 .47919 Mdot
.45238 .49466 Mdot
.5 .51013 Mdot
.54762 .5256 Mdot
.59524 .54108 Mdot
.64286 .55655 Mdot
.69048 .57202 Mdot
.2619 .40183 Mdot
.30952 .4173 Mdot
.35714 .43277 Mdot
.40476 .44824 Mdot
.45238 .46371 Mdot
.5 .47919 Mdot
.54762 .49466 Mdot
.59524 .51013 Mdot
.64286 .5256 Mdot
.69048 .54108 Mdot
.7381 .55655 Mdot
.30952 .38635 Mdot
.35714 .40183 Mdot
.40476 .4173 Mdot
.45238 .43277 Mdot
.5 .44824 Mdot
.54762 .46371 Mdot
.59524 .47919 Mdot
.64286 .49466 Mdot
.69048 .51013 Mdot
.7381 .5256 Mdot
.78571 .54108 Mdot
.35714 .37088 Mdot
.40476 .38635 Mdot
.45238 .40183 Mdot
.5 .4173 Mdot
.54762 .43277 Mdot
.59524 .44824 Mdot
.64286 .46371 Mdot
.69048 .47919 Mdot
.7381 .49466 Mdot
.78571 .51013 Mdot
.83333 .5256 Mdot
.40476 .35541 Mdot
.45238 .37088 Mdot
.5 .38635 Mdot
.54762 .40183 Mdot
.59524 .4173 Mdot
.64286 .43277 Mdot
.69048 .44824 Mdot
.7381 .46371 Mdot
.78571 .47919 Mdot
.83333 .49466 Mdot
.88095 .51013 Mdot
.45238 .33994 Mdot
.5 .35541 Mdot
.54762 .37088 Mdot
.59524 .38635 Mdot
.64286 .40183 Mdot
.69048 .4173 Mdot
.7381 .43277 Mdot
.78571 .44824 Mdot
.83333 .46371 Mdot
.88095 .47919 Mdot
.92857 .49466 Mdot
.5 .32446 Mdot
.54762 .33994 Mdot
.59524 .35541 Mdot
.64286 .37088 Mdot
.69048 .38635 Mdot
.7381 .40183 Mdot
.78571 .4173 Mdot
.83333 .43277 Mdot
.88095 .44824 Mdot
.92857 .46371 Mdot
.97619 .47919 Mdot
.89188 .76124 Mdot
.84426 .74577 Mdot
.79664 .73029 Mdot
.74902 .71482 Mdot
.7014 .69935 Mdot
.65378 .68388 Mdot
.60616 .6684 Mdot
.55854 .65293 Mdot
.51092 .63746 Mdot
.4633 .62199 Mdot
.41568 .60652 Mdot
.86244 .72073 Mdot
.81483 .70526 Mdot
.76721 .68979 Mdot
.71959 .67431 Mdot
.67197 .65884 Mdot
.62435 .64337 Mdot
.57673 .6279 Mdot
.52911 .61243 Mdot
.48149 .59695 Mdot
.43387 .58148 Mdot
.38625 .56601 Mdot
.83301 .68022 Mdot
.7854 .66475 Mdot
.73778 .64928 Mdot
.69016 .63381 Mdot
.64254 .61834 Mdot
.59492 .60286 Mdot
.5473 .58739 Mdot
.49968 .57192 Mdot
.45206 .55645 Mdot
.40444 .54097 Mdot
.35682 .5255 Mdot
.80358 .63972 Mdot
.75597 .62424 Mdot
.70835 .60877 Mdot
.66073 .5933 Mdot
.61311 .57783 Mdot
.56549 .56236 Mdot
.51787 .54688 Mdot
.47025 .53141 Mdot
.42263 .51594 Mdot
.37501 .50047 Mdot
.32739 .48499 Mdot
.77415 .59921 Mdot
.72654 .58374 Mdot
.67892 .56827 Mdot
.6313 .55279 Mdot
.58368 .53732 Mdot
.53606 .52185 Mdot
.48844 .50638 Mdot
.44082 .4909 Mdot
.3932 .47543 Mdot
.34558 .45996 Mdot
.29796 .44449 Mdot
.74472 .5587 Mdot
.69711 .54323 Mdot
.64949 .52776 Mdot
.60187 .51229 Mdot
.55425 .49681 Mdot
.50663 .48134 Mdot
.45901 .46587 Mdot
.41139 .4504 Mdot
.36377 .43492 Mdot
.31615 .41945 Mdot
.26853 .40398 Mdot
.71529 .5182 Mdot
.66767 .50272 Mdot
.62006 .48725 Mdot
.57244 .47178 Mdot
.52482 .45631 Mdot
.4772 .44083 Mdot
.42958 .42536 Mdot
.38196 .40989 Mdot
.33434 .39442 Mdot
.28672 .37894 Mdot
.2391 .36347 Mdot
.68586 .47769 Mdot
.63824 .46222 Mdot
.59063 .44674 Mdot
.54301 .43127 Mdot
.49539 .4158 Mdot
.44777 .40033 Mdot
.40015 .38485 Mdot
.35253 .36938 Mdot
.30491 .35391 Mdot
.25729 .33844 Mdot
.20967 .32296 Mdot
.65643 .43718 Mdot
.60881 .42171 Mdot
.5612 .40624 Mdot
.51358 .39076 Mdot
.46596 .37529 Mdot
.41834 .35982 Mdot
.37072 .34435 Mdot
.3231 .32887 Mdot
.27548 .3134 Mdot
.22786 .29793 Mdot
.18024 .28246 Mdot
.627 .39667 Mdot
.57938 .3812 Mdot
.53177 .36573 Mdot
.48415 .35026 Mdot
.43653 .33478 Mdot
.38891 .31931 Mdot
.34129 .30384 Mdot
.29367 .28837 Mdot
.24605 .2729 Mdot
.19843 .25742 Mdot
.15081 .24195 Mdot
.59757 .35617 Mdot
.54995 .34069 Mdot
.50234 .32522 Mdot
.45472 .30975 Mdot
.4071 .29428 Mdot
.35948 .27881 Mdot
.31186 .26333 Mdot
.26424 .24786 Mdot
.21662 .23239 Mdot
.169 .21692 Mdot
.12138 .20144 Mdot
.56277 .66123 Mdot
.53334 .65166 Mdot
.50391 .6421 Mdot
.47448 .63254 Mdot
.44505 .62298 Mdot
.41562 .61342 Mdot
.38619 .60385 Mdot
.35676 .59429 Mdot
.32733 .58473 Mdot
.2979 .57517 Mdot
.26847 .5656 Mdot
.58096 .63619 Mdot
.55153 .62663 Mdot
.5221 .61707 Mdot
.49267 .60751 Mdot
.46324 .59794 Mdot
.43381 .58838 Mdot
.40438 .57882 Mdot
.37495 .56926 Mdot
.34552 .55969 Mdot
.31609 .55013 Mdot
.28666 .54057 Mdot
.59915 .61116 Mdot
.56972 .6016 Mdot
.54029 .59203 Mdot
.51086 .58247 Mdot
.48143 .57291 Mdot
.452 .56335 Mdot
.42257 .55378 Mdot
.39314 .54422 Mdot
.36371 .53466 Mdot
.33428 .5251 Mdot
.30485 .51553 Mdot
.61734 .58612 Mdot
.58791 .57656 Mdot
.55848 .567 Mdot
.52905 .55744 Mdot
.49962 .54787 Mdot
.47019 .53831 Mdot
.44076 .52875 Mdot
.41133 .51919 Mdot
.3819 .50962 Mdot
.35247 .50006 Mdot
.32304 .4905 Mdot
.63553 .56109 Mdot
.6061 .55153 Mdot
.57667 .54196 Mdot
.54724 .5324 Mdot
.51781 .52284 Mdot
.48838 .51328 Mdot
.45895 .50371 Mdot
.42952 .49415 Mdot
.40009 .48459 Mdot
.37066 .47503 Mdot
.34123 .46546 Mdot
.65372 .53605 Mdot
.62429 .52649 Mdot
.59486 .51693 Mdot
.56543 .50737 Mdot
.536 .4978 Mdot
.50657 .48824 Mdot
.47714 .47868 Mdot
.44771 .46912 Mdot
.41828 .45955 Mdot
.38885 .44999 Mdot
.35942 .44043 Mdot
.67191 .51102 Mdot
.64248 .50146 Mdot
.61305 .49189 Mdot
.58362 .48233 Mdot
.55419 .47277 Mdot
.52476 .46321 Mdot
.49533 .45364 Mdot
.4659 .44408 Mdot
.43647 .43452 Mdot
.40704 .42496 Mdot
.37761 .41539 Mdot
.6901 .48598 Mdot
.66067 .47642 Mdot
.63124 .46686 Mdot
.60181 .4573 Mdot
.57238 .44773 Mdot
.54295 .43817 Mdot
.51352 .42861 Mdot
.48409 .41905 Mdot
.45466 .40948 Mdot
.42523 .39992 Mdot
.3958 .39036 Mdot
.70829 .46095 Mdot
.67886 .45139 Mdot
.64943 .44182 Mdot
.62 .43226 Mdot
.59057 .4227 Mdot
.56113 .41314 Mdot
.5317 .40357 Mdot
.50227 .39401 Mdot
.47284 .38445 Mdot
.44341 .37489 Mdot
.41398 .36532 Mdot
.72647 .43591 Mdot
.69704 .42635 Mdot
.66761 .41679 Mdot
.63818 .40723 Mdot
.60875 .39766 Mdot
.57932 .3881 Mdot
.54989 .37854 Mdot
.52046 .36898 Mdot
.49103 .35941 Mdot
.4616 .34985 Mdot
.43217 .34029 Mdot
.74466 .41088 Mdot
.71523 .40132 Mdot
.6858 .39175 Mdot
.65637 .38219 Mdot
.62694 .37263 Mdot
.59751 .36307 Mdot
.56808 .3535 Mdot
.53865 .34394 Mdot
.50922 .33438 Mdot
.47979 .32482 Mdot
.45036 .31525 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[97]:=",
  ImageSize->{226.438, 216.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003R0000f0P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc>87003R1`00IPL00`071`021`801@L00`07
1`1]1`00IPL01@071`L0008700<01`L00PL00`071`1]1`00H`L5008700@01`L010L206h7001N1`@0
00D700L700031`0400L700@700<01`L0K@L006@700<01`000`L010071`041`0300L706d7001A1`80
4PL200<700@01`L010L00`071`1]1`00DPL00`071`0A1`0300L700870P051`0300L701`70P1?1`00
LPL00`071`0M1`0300L704d7001b1`0300L706d7001b1`0300L706d7001b1`0300L706d7001b1`03
00L706d7001b1`0300L706d7001b1`0300L706d7001G1`806@L00`071`1]1`00F0L00`071`0G1`80
5`L205D7001A1`807`L00`071`0G1`0300L705<7001B1`0300L701d700<01`L070L204l7001b1`03
00L701d700<01`L0C@L0078700<01`L0K@L0078700<01`L0K@L0078700<01`L0K@L0078700<01`L0
K@L005h70P0B1`0300L706d7001O1`0300L7010700<01`L03`L205`7001G1`806@L00`071`0@1`03
00L705X7001H1`0300L701L700<01`L05PL205D7001A1`807`L00`071`0G1`0300L705<7001B1`03
00L701d70P0M1`80C`L0078700<01`L07@L00`071`1=1`00LPL00`071`1]1`00LPL00`071`1]1`00
I0L200`700<01`L0K@L006D700<01`L02PL00`071`091`80HPL005h70P0B1`0300L700X700<01`L0
H0L005l700<01`L040L00`071`0?1`80G0L005L70P0I1`0300L7010700<01`L0FPL005P700<01`L0
5`L00`071`0F1`80E@L005470P0O1`0300L701L700<01`L0D`L0058700<01`L07@L00`071`0L1`80
C`L006X70P061`0300L701d700<01`L0C@L006/700<01`L010L206h7001b1`0300L700870P1Y1`00
I0L200`700<01`L00`L00`071`1;1`806PL001d70P161`0300L700X700<01`L02@L204L700<01`L0
60L001h700<01`L0?@L2018700<01`L02PL00`071`1P1`00G`L00`071`0@1`0300L700l70P1L1`00
:0L202d70P0I1`0300L7010700<01`L0=0L202@7000Y1`0300L702`700<01`L05`L00`071`0F1`80
<0L00`071`0R1`00D@L201h70P0I1`0300L705<7001B1`0300L701d70`0L1`807`L202h7000b1`80
=PL200D70P000`L01`0L1`0300L701h700<01`L0;0L003<700<01`L0;PL400<70P051`0300L704/7
0P0P1`0090L203h700<01`L00`L010071`041`0300L700870P0^1`8060L00`071`0N1`009@L00`07
1`0E1`809@L200@700@01`L010L200@700<01`L0;@L00`071`0g1`00?PL00`071`0M1`@00`L200<7
00@01`L010L00`071`091`80=PL202X7000^1`80;PL200L700@01`L00PL01P07000700@70P061`03
00L703D700<01`L0:0L002l700<01`L0;@L00`071`021`0400L7008700@01`L00PL00`0700051`03
00L700T70P0G1`80@`L004L70P0>1`8030L200@70P051`0300L700870P0<1`0300L701H700<01`L0
@@L004P700<01`L03@L00`071`0G1`0300L700<700<01`L040L200<70P0I1`80=@L003T70P0F1`80
5`L200D70P0I1`0300L700870`0H1`0300L703<7000j1`0300L701@70P0H1`801@L300H70P0<1`80
1PL302H70P0V1`00:PL202<70P000`L01`0F1`<010L200031`0700H700<01`L02`L00`071`051`03
00L700`70P0H1`0300L702@7000[1`0300L701D70P0;1`0300L701P700<01`L010L00`071`0]1`03
00L703d700141`0300L700l70P041`8050L00`071`021`802PL200<70P0U1`80<@L003D70P0P1`03
00L700<700<01`L010L200`700<01`L00`L00`071`031`8010L00`071`021`0300L702@700<01`L0
;`L003H700<01`L08`L200L700<01`L02PL00`071`071`@040L200@70P1:1`00C@L200h70`071`80
1PL200031`0000<70`031`@040L00`071`031`0300L704P7001>1`0300L700h700@01`L70P0010L0
00071`0300L000<710041`<00`L200<70P0J1`80>`L003l70P0>1`801PL200/710091`8010L200`7
00<01`L00PL01007000H1`0300L703T700101`0300L700d700<01`L01@L200/70P021`8010L20004
1`0000<700<01`L020L200H70`0U1`80;@L003470P0N1`800`L200031`0700l710021`<000<700L0
30L300L700<01`L02`L201P700<01`L0:`L0038700<01`L050L200L700<01`L00PL00`071`091`80
10L500031`0000@01PL300<7100<1`8020L00`071`141`00BPL00`071`0?1`8010L400@70`031`D0
1`L200@700<01`002`L301H70P0g1`00>`L2020700<01`L00`L700031`0700D70P021`800`L301<7
00<01`L05PL00`071`0e1`00?0L00`071`0@1`800`L200/710021`0300L000P700<01`L0200<1`80
1@L20507001@1`0300L7008700<01`L010L4008700@01`0030L010071`L300041`0700L710021`03
00L700@700<01`L0CPL005d70`051`0300L700<00PL400031`0700@700@01`L71@021`<000<700L0
5@L2048700151`803`L300870P0010L000061`@00`L500@70P041`D00PL501H700<01`L0@0L004H7
00<01`L03PL200<700<01`000P071`<000<700001@051`0400L71`8000D700001`0602@70P0c1`00
=`L201H710041`800`L400@70P031`800PL01@07000700800`L4008700<01`L010L400P70P021`80
60L00`071`0a1`00>0L00`071`0E1`<01@L00`071`021`800`L600X700<01`L0100010L0000:1`03
00L000<00`L200<700<01`L0BPL004X70P031`@040L300031`0700<01@L400031`0000@700<01`L0
2PL500<700<01`L03PL203h700111`8020L00`071`021`0300L000P70`041`@010L300870P0010L0
00061`<01@L200@71@021`<040L00`071`0l1`00@PL01007000@1`800PL400D70P041`D00PL30003
1`0700H70P041`@010L00`0700041`@0C@L004D700@01`0030L300<70P0=1`8000@700L70`0?1`D0
10L200L700<01`L00`L204H7000m1`802@L010071`L200P71@000`L0000;1`8010L600870P031`<0
10L200031`0700@700<01`L02@L404H7000n1`0300L700`710071`0300L0008700<01`L010L40087
00<01`L00`L01@0700L000<700<01`L00PL400<70P021`800PL600L70P171`00?0L20147100=1`80
00<700000`0:1`0400L71`<00PL200041`0000@700@01`L70P021`0300L000803PL200<70`0j1`00
?@L201070P000`L01`031`801@L400041`001`<01PL200031`0700<70P031`0300L000801PL40087
1@0?1`0300L700870P0j1`00?PL00`071`071`801PL00`071`031`<00`L200031`0000<700<01`00
0P061`@000<700000PL010071`L200031`0000<70P021`<00`L01007000D1`80>PL003870P0C1`<0
2`L900H70P000`L01`0200@710021`0400L000@70`000`L0000400X700@01`L70P031`@02@L00`07
1`051`80<@L003<700<01`L02`L200D70P0<1`<000@7000020L010071`L300041`001`<01@L00`07
1`041`0300L700<000<700L00P000`L000091`0300L7008700<01`004PL00`071`0_1`00@PL00`07
1`041`0300L700D70`031`0300L700870P031`801`L200871P071`<01PL200<700@01`L00`L400P7
0P141`00C`L200041`0000H70`041`<01@L300<700<01`000P061`<01@L300<710041`@020L00`07
1`121`009`L201<70P0>1`800PL500L700<01`L00`L300031`0000870`041`8000<700000P021`<0
1`L00`071`021`D00PL300031`0700l70P0C1`809PL000X700<01`L00PL201L700<01`L04@L400<7
0P081`0500L000L00P091`8010L2008700D01`L700061`0500L700L01P0=1`@00PL200031`0000/7
10021`<04PL00`071`0H1`0300L700870P051`002PL01@071`L0008700<01`L0:0L00`071`031`03
00L000802@L300@70P031`D020L400870P000`L01`031`<000@700001`L200D700<01`L00PL20003
1`0700X70P001@L01`L0008700<01`L0:PL01@071`L0008700<01`L00PL000L71@021`0400L700/7
0P0C1`802@L00`071`021`0300L700@02@L010071`L300870`021`0400L71`8010L0100700L500D7
00<01`L00PL00`071`0200031`0000@02@L010071`L200870P051`0300L7008700@01`L01@L201<7
0P0=1`D00PL010071`041`000PL400051`071`000`L010071`0<1`0300L7018700<01`L010041`05
00L71`000PL010071`0=1`@00PL300H700@01`L70P031`D02`L400031`00008000<700L03@L30003
1`0700D700D01`L700021`0300L700@700<01`L04PL00`071`0;1`0400L700<700@01`L010L000P7
00<01`000`L010071`0]1`0400L7008700<01`L01`L200@71@021`D01PL200031`0700<70P000`L0
1`021`<00`L500<700<01`L00P061`<00`L500T700@01`L00PL00`071`0X1`0300L000<700@01`L0
10L000T70P031`0400L702X700@01`L00PL010071`081`@010L00`0700041`@00PL200<700<01`L0
1@L00`0700041`<00PL200031`0000<70P021`<010L300@700<01`001@L3008700@01`L00PL00`07
1`0Y1`800`L010071`041`002PL00`071`021`8000<700004`L201<70`041`8020L600@70P061`03
00L000L02@L010071`L400041`0000L700@01`L70P021`8000<700003@L0100700021`@04@L201<7
0P051`0300L700870P051`004`L00`071`0B1`0300L7018700<01`L02@L200<70`000`L01`041`04
00L71`8010L700T70P031`800`L010071`L200P70`000`L01`0201@700<01`L04PL00`071`0B1`03
00L700l7001:1`8010L300031`0000<70`000`L01`051`0300L000870`031`D020L200<700@01`00
1`L00`071`021`0300L7008010L204H700081`804`L201<70P0C1`800PL200D71P021`<01PL200D7
0`031`D01PL300D710041`8010L500<7100B1`804`L201<70P071`000`OM0087000:1`0300L70347
00<01`L02PL00`071`041`0400L700@710071`800`L200@700@01`0020L200870P021`0300L700@7
0P031`800`L00`071`021`802@L00`071`0a1`0300L700H7000B1`804`L201<70P0;1`800PL600@7
0P041`0400L71`@000@700002@L200870`021`<00`L00`071`051`8000D700001`0200T700<01`L0
1`L201<70P0C1`804@L001<700<01`L04PL00`071`0B1`0300L700X700@01`L70`000`L01`041`03
00L700<70P021`@000<700002@L010071`L400870P061`800`L200<7100<1`801PL00`071`0B1`03
00L7018700<01`L03`L004l70`031`801@L200031`0700<70P000`L000091`0400L71`8000<700L0
0PL300D700H01`001`051`800`L200P700<01`L0@0L004l70`041`<010L400H710031`<000<700L0
0`L200<71@021`800PL200H70`041`@0B0L001d70P0C1`804`L200L700<01`L00`L400041`001`<0
1`L00`0700041`@01@L00`071`021`0300L000800PL500L700<01`L00`L601<70P0C1`8070L001h7
00<01`L04PL00`071`0>1`<000<700L03@L3008700<01`L00P031`800`L200<71@041`800`L200<7
00<01`000`000`L01`071`8010L01@071`L001@700<01`L04PL00`071`0J1`00A@L200P710051`04
00L71`<000<700L00`L00`071`021`<00PL200031`0700@710000`L01`051`0300L000@70P031`D0
2`L20407000W1`804`L200h70P021`@02@L200<70`000`L000021`<010L200031`00008000<700L0
0P0<1`D00PL2008700<01`L02PL300031`0001<70P0V1`00:0L00`071`0B1`0300L700d700D01`00
1`0300H70P061`800PL010071`L200D7100010L01`L300H70P041`D00`L400h700@01`L050L00`07
1`0T1`00D0L500L70P031`8000<700L010L3008710000`L01`051`<01PL00`071`031`0300L000<7
0`000`L01`061`80A0L004P70P081`800PL200D700<01`L00PL00`071`041`<000H7000700L200P7
0P051`<00PL200031`0000@70`091`0300L70487000b1`803@L200@70`0;1`P03@L200871@041`80
20L6008700@01`L01PL0100700031`@04@L20347000c1`0300L700`700<01`L00`L00`071`0;1`<0
00<700L00P061`@000<7000010L400031`00008700@01`L710021`0300L000803`L00`071`021`03
00L000P70P081`0300L702l700181`801@L200H700<01`L00`L0100700041`0300L0008700<01`L0
0`L3008700<01`L01@L300D700<01`L00P031`D05@L00`071`0h1`00?0L300X700<01`L010L300@7
0P051`<00PL600H70P000`L01`021`<00PL200041`0000H710031`@03PL200<70P0k1`00?@L200l7
0`000`L01`041`0300L700@70`0010L000L300L700<01`0010L200<700<01`L00P031`800PL30003
1`0000@03`L00`071`021`80>PL003d70P0=1`8000<700001PL200<70P031`0300L700@01`L400@7
0P031`<000<700L00`L010071`L2008700<01`000P071`8030L00`071`0h1`00?PL00`071`061`80
10L00`071`051`T01`L0100700L200D71@031`0300L700870P031`D010L200@700<01`L010L404H7
00141`800PL00`071`0;1`800PL300`71@031`8000<700L03@L400D700<01`L010L200@700<01`00
APL004470P021`0300L700l700@01`L70`051`801@L400041`001`<01PL300@710031`@00`L30003
1`0704`700121`0300L700D70P031`@02@L200@710031`@00`L500L70P051`8010L200031`0700<7
0P0?1`80?PL004/700<01`L00PL300l71P021`801PL00`07000300<70P0<1`D00PL2014700<01`L0
?0L004l710041`8010L200@70P021`0300L700P700@01`L71@000`L01`0<1`@00PL200870P1<1`00
=`L201L700<01`001@L010071`L400@70P021`<000<700000`000`L000041`0400L01`801PL400T7
00D01`L7000G1`80<`L003P700<01`L06`L300870`000`L01`041`0400L71`800PL00`07000300X7
1@000`L0000302H700<01`L0<@L004D70P0?1`<00`L00`07000200H710021`H010L200D7100010L0
00L305T700161`0300L700h700<01`L00PL200031`0000L70`031`<000<700L00`L200<70P000`L0
00031`D05@L20487001?1`800`L200L70`031`<00`L00`071`041`0300L000871P021`0300L700D7
00@01`070P0D1`0300L70407000k1`804`L00`071`021`0300L700L700<01`0020081`0400L71`<0
00@700003@L00`071`031`80D0L003`700<01`L07@L200@710000`L01`0300D70`031`0300L70087
0P0B1`805`L203L700191`804PL00`071`031`<00`L400870P0010L000061`<00`L400`70P0G1`03
00L703D7000a1`805`L00`071`041`800`L200`700<01`L00`L400870`000`L01`061`8010L00`07
000=1`0300L700D70P161`00<PL00`071`0M1`0300L700870`0?1`D000<70000100=1`<01PL200h7
00<01`L05@L202d7001G1`<02`L200<700<01`L00`L300041`071`802PL200L70P0V1`0300L702/7
000o1`803PL200L700<01`L020L500X700@01`L70`0;1`800`L2008700<01`L05@L203/700101`03
00L700d700<01`L04@L200031`0700T700<01`L00PL300<70`051`0300L7008700<01`L06@L00`07
1`0i1`00C@L200d710071`801PL200031`0000<70`041`<03`L20507000e1`805`L00`071`0<1`03
00L000P700<01`L01@L00`0700051`0400L71`D040L00`071`021`80BPL003H700<01`L07@L200@7
0P061`8030L00`071`021`8010L00`07000G1`0300L701D70P0a1`00@`L2018700<01`L00`L00`07
1`051`0300L700X700<01`L00`L00`071`081`800`L202H700<01`L0;`L002X70P0H1`0300L700P7
0P0I1`801@L2014700<01`L00PL00`071`0E1`80?`L002/700<01`L08PL301P70P051`<01PL200`7
0P061`803`L00`071`0E1`809PL003T70P0F1`805`L300@70P000`L01`061`0300L700/700<01`L0
1@L202L700<01`L090L003X700<01`L05@L00`071`0F1`0300L700@700<01`L05PL200<70P000`L0
1`0F1`80=@L005L70P0I1`0300L700870P0C1`0300L7008700<01`L060L00`071`0c1`00A`L200l7
00<01`L05`L00`071`031`0300L700T70P0G1`80@`L002h70P0H1`0300L702L700<01`L040L00`07
1`0F1`0300L70447000_1`0300L702`70P041`@00`L200870P000`L01`031`801@L203H70P0Z1`00
?@L2020700<01`L00PL00`071`031`0400L7008700<01`001@L00`071`041`0300L703D700<01`L0
:0L002@70P0H1`0300L702<70P041`0400L700@70P031`80;PL203T7000U1`0300L703d70P031`04
00L700@700<01`L00`L00`071`0]1`0300L701D70P0P1`00<PL203<700<01`L00P000`L01`021`80
CPL00`071`0N1`00<`L00`071`0^1`0400L700870P000`L01`031`<070L201l70P0^1`00D@L20187
0P041`8010L200031`0701`700<01`L07PL00`071`0/1`00DPL00`071`0M1`0300L701H70P1E1`00
:0L202d70P0I1`0300L701L700<01`L0D`L002T700<01`L0;0L00`071`0G1`0300L700l70P0f1`80
90L0078700<01`L040L00`071`0e1`0300L70287000M1`80?`L2018700<01`L02@L20687000N1`03
00L703h700<01`L040L00`071`0:1`0300L704@70P0J1`00I0L200`700<01`L00PL204h700<01`L0
60L006D700<01`L02PL00`071`031`0300L706L7001Z1`801PL206h7001[1`0300L700@700<01`L0
70L204l7001A1`807`L00`071`0M1`0300L704d7001B1`0300L701d700<01`L05PL205D7001G1`80
6@L00`071`0G1`0300L705<7001H1`0300L701L700<01`L03`L205`7001b1`0300L7010700<01`L0
FPL005h70P0B1`0300L700T70P1R1`00G`L00`071`0@1`0300L700X700<01`L0H0L006@70P0<1`03
00L706d7001U1`0300L700X700<01`L0K@L0078700<01`L0K@L0078700<01`L070L204l7001A1`80
7`L201h700<01`L0C@L0058700<01`L07@L00`071`0F1`80E@L005L70P0I1`0300L701L700<01`L0
D`L005P700<01`L05`L00`071`0?1`80G0L0078700<01`L040L00`071`1J1`00GPL2018700<01`L0
K@L005l700<01`L040L00`071`1]1`00LPL00`071`1]1`00LPL00`071`1]1`00LPL00`071`1]1`00
LPL00`071`0L1`80C`L005470P0O1`0300L701d700<01`L0C@L0058700<01`L07@L00`071`0F1`80
E@L005L70P0I1`8060L00`071`1C1`00F0L00`071`0G1`0300L706d7001b1`0300L706d7001b1`03
00L706d7001b1`0300L706d7001b1`0300L706d7001b1`0300L706d7001b1`0300L706d7001b1`03
00L701`70P1?1`00D@L201l700<01`L07@L00`071`1=1`00DPL00`071`0M1`0300L706d7001V1`03
00L700870P051`0300L706d7001V1`0500L71`000PL00`071`021`0300L706d7001S1`D00PL01007
1`041`80KPL006<700@01`L00`L010071`041`0300L706d7001T1`0300L000<700@01`L010L00`07
1`1]1`00I@L200<700@01`L0M0L006H700<01`L00PL207D70000\
\>"],
  ImageRangeCache->{{{0, 225.438}, {215.938, 0}} -> {-44.1564, -41.7403, \
0.386595, 0.386595}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[97]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generating the remainig regions", "Subsection"],

Cell[BoxData[{
    \(\(AL121 = 
        Table[AL021[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                AL021]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL131 = 
        Table[AL031[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                AL031]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL132 = 
        Table[AL032[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                AL032]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL141 = 
        Table[AL041[\([i]\)]\  + 
            e[4], {i, \(Dimensions[
                AL041]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL142 = 
        Table[AL042[\([i]\)]\  + 
            e[4], {i, \(Dimensions[
                AL042]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL143 = 
        Table[AL043[\([i]\)]\  + 
            e[4], {i, \(Dimensions[
                AL043]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL151 = 
        Table[AL051[\([i]\)]\  + 
            e[5], {i, \(Dimensions[
                AL051]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL152 = 
        Table[AL052[\([i]\)]\  + 
            e[5], {i, \(Dimensions[
                AL052]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL153 = 
        Table[AL053[\([i]\)]\  + 
            e[5], {i, \(Dimensions[
                AL053]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL154 = 
        Table[AL054[\([i]\)]\  + 
            e[5], {i, \(Dimensions[AL054]\)[\([1]\)]}];\)\)}], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[{
    \(\(AL221 = 
        Table[AL021[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                AL021]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL231 = 
        Table[AL031[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                AL031]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL232 = 
        Table[AL032[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                AL032]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL241 = 
        Table[AL041[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                AL041]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL242 = 
        Table[AL042[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                AL042]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL243 = 
        Table[AL043[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                AL043]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL251 = 
        Table[AL051[\([i]\)]\  + 
            e[1], {i, \(Dimensions[
                AL051]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL252 = 
        Table[AL052[\([i]\)]\  + 
            e[2], {i, \(Dimensions[
                AL052]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL253 = 
        Table[AL053[\([i]\)]\  + 
            e[3], {i, \(Dimensions[
                AL053]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL254 = 
        Table[AL054[\([i]\)]\  + 
            e[4], {i, \(Dimensions[AL054]\)[\([1]\)]}];\)\)}], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[{
    \(\(AL321 = 
        Table[AL021[\([i]\)]\  + e[2] + 
            e[1], {i, \(Dimensions[
                AL021]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL331 = 
        Table[AL031[\([i]\)]\  + e[3] + 
            e[1], {i, \(Dimensions[
                AL031]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL332 = 
        Table[AL032[\([i]\)]\  + e[3] + 
            e[2], {i, \(Dimensions[
                AL032]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL341 = 
        Table[AL041[\([i]\)]\  + e[4] + 
            e[1], {i, \(Dimensions[
                AL041]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL342 = 
        Table[AL042[\([i]\)]\  + e[4] + 
            e[2], {i, \(Dimensions[
                AL042]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL343 = 
        Table[AL043[\([i]\)]\  + e[4] + 
            e[3], {i, \(Dimensions[
                AL043]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL351 = 
        Table[AL051[\([i]\)]\  + e[5] + 
            e[1], {i, \(Dimensions[
                AL051]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL352 = 
        Table[AL052[\([i]\)]\  + e[5] + 
            e[2], {i, \(Dimensions[
                AL052]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL353 = 
        Table[AL053[\([i]\)]\  + e[5] + 
            e[3], {i, \(Dimensions[
                AL053]\)[\([1]\)]}];\)\), "\[IndentingNewLine]", 
    \(\(AL354 = 
        Table[AL054[\([i]\)]\  + e[5] + 
            e[4], {i, \(Dimensions[AL054]\)[\([1]\)]}];\)\)}], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \(\(AL = 
        Chop[N[Join[AL021, AL031, AL032, AL041, AL042, AL043, \ AL051, AL052, 
              AL053, AL054, AL121, AL131, AL132, AL141, AL142, AL143, \ 
              AL151, AL152, AL153, AL154, AL221, AL231, AL232, AL241, AL242, 
              AL243, \ AL251, AL252, AL253, AL254, AL321, AL331, AL332, 
              AL341, AL342, AL343, AL351, AL352, AL353, 
              AL354]]];\)\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \(\(ALP\  = \ 
        Chop[Join[AL021, AL032, AL041, \ AL043, \ AL121, AL132, AL141, 
            AL143, \ AL221, AL232, AL241, AL243, \ AL321, AL332, AL341, 
            AL343]];\)\)], "Input"],

Cell[BoxData[
    \(\(ALP2 = 
        Chop[Join[AL031, AL042, \ AL131, AL142, AL231, AL242, AL331, 
            AL342]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(averageLattice\  = 
      ListPlot[SphericalCut[AL, 10], Axes \[Rule] False, 
        Prolog \[Rule] PointSize[0.015], AspectRatio \[Rule] Automatic, 
        Frame \[Rule] \ False]\)], "Input",
  CellLabel->"In[129]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00456 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499981 0.0480782 0.502269 0.0480782 [
[ 0 0 0 0 ]
[ 1 1.00456 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00456 L
0 1.00456 L
closepath
clip
newpath
0 g
.015 w
.22814 .17839 Mdot
.34834 .13934 Mdot
.46853 .10028 Mdot
.58873 .06123 Mdot
.10795 .34382 Mdot
.22814 .30477 Mdot
.34834 .26572 Mdot
.46853 .22666 Mdot
.58873 .18761 Mdot
.70892 .14855 Mdot
.10795 .47021 Mdot
.22814 .43115 Mdot
.34834 .3921 Mdot
.46853 .35304 Mdot
.58873 .31399 Mdot
.70892 .27494 Mdot
.82912 .23588 Mdot
.10795 .59659 Mdot
.22814 .55753 Mdot
.34834 .51848 Mdot
.46853 .47942 Mdot
.58873 .44037 Mdot
.70892 .40132 Mdot
.82912 .36226 Mdot
.10795 .72297 Mdot
.22814 .68391 Mdot
.34834 .64486 Mdot
.46853 .60581 Mdot
.58873 .56675 Mdot
.70892 .5277 Mdot
.82912 .48864 Mdot
.94931 .44959 Mdot
.22814 .81029 Mdot
.34834 .77124 Mdot
.46853 .73219 Mdot
.58873 .69313 Mdot
.70892 .65408 Mdot
.82912 .61502 Mdot
.94931 .57597 Mdot
.34834 .89762 Mdot
.46853 .85857 Mdot
.58873 .81951 Mdot
.70892 .78046 Mdot
.82912 .74141 Mdot
.58873 .94589 Mdot
.70892 .90684 Mdot
.6156 .04004 Mdot
.7358 .20547 Mdot
.856 .37091 Mdot
.97619 .53634 Mdot
.49541 .07909 Mdot
.6156 .24453 Mdot
.7358 .40996 Mdot
.856 .5754 Mdot
.37521 .11815 Mdot
.49541 .28358 Mdot
.6156 .44902 Mdot
.7358 .61445 Mdot
.856 .77989 Mdot
.25502 .1572 Mdot
.37521 .32264 Mdot
.49541 .48807 Mdot
.6156 .65351 Mdot
.7358 .81894 Mdot
.13482 .19625 Mdot
.25502 .36169 Mdot
.37521 .52712 Mdot
.49541 .69256 Mdot
.6156 .85799 Mdot
.13482 .40074 Mdot
.25502 .56618 Mdot
.37521 .73161 Mdot
.49541 .89705 Mdot
.13482 .60523 Mdot
.25502 .77067 Mdot
.37521 .9361 Mdot
.13482 .80972 Mdot
.72409 .14363 Mdot
.79837 .24587 Mdot
.87266 .34812 Mdot
.94694 .45036 Mdot
.52961 .08044 Mdot
.60389 .18268 Mdot
.67818 .28493 Mdot
.75246 .38717 Mdot
.82675 .48941 Mdot
.90103 .59166 Mdot
.40941 .11949 Mdot
.4837 .22174 Mdot
.55798 .32398 Mdot
.63227 .42622 Mdot
.70655 .52847 Mdot
.78084 .63071 Mdot
.85512 .73296 Mdot
.28922 .15855 Mdot
.3635 .26079 Mdot
.43779 .36303 Mdot
.51207 .46528 Mdot
.58636 .56752 Mdot
.66064 .66977 Mdot
.73492 .77201 Mdot
.16902 .1976 Mdot
.24331 .29984 Mdot
.31759 .40209 Mdot
.39188 .50433 Mdot
.46616 .60658 Mdot
.54044 .70882 Mdot
.61473 .81106 Mdot
.68901 .91331 Mdot
.12311 .3389 Mdot
.19739 .44114 Mdot
.27168 .54339 Mdot
.34596 .64563 Mdot
.42025 .74787 Mdot
.49453 .85012 Mdot
.56882 .95236 Mdot
.0772 .4802 Mdot
.15148 .58244 Mdot
.22577 .68468 Mdot
.30005 .78693 Mdot
.37434 .88917 Mdot
.10557 .72374 Mdot
.17986 .82598 Mdot
.6156 .96429 Mdot
.7358 .79885 Mdot
.856 .63342 Mdot
.97619 .46798 Mdot
.49541 .92523 Mdot
.6156 .7598 Mdot
.7358 .59436 Mdot
.856 .42893 Mdot
.37521 .88618 Mdot
.49541 .72074 Mdot
.6156 .55531 Mdot
.7358 .38988 Mdot
.856 .22444 Mdot
.25502 .84713 Mdot
.37521 .68169 Mdot
.49541 .51626 Mdot
.6156 .35082 Mdot
.7358 .18539 Mdot
.13482 .80807 Mdot
.25502 .64264 Mdot
.37521 .4772 Mdot
.49541 .31177 Mdot
.6156 .14633 Mdot
.13482 .60358 Mdot
.25502 .43815 Mdot
.37521 .27271 Mdot
.49541 .10728 Mdot
.13482 .39909 Mdot
.25502 .23366 Mdot
.37521 .06823 Mdot
.13482 .19461 Mdot
.97511 .46947 Mdot
.85492 .6349 Mdot
.73472 .80034 Mdot
.61453 .96577 Mdot
.90083 .36722 Mdot
.78063 .53266 Mdot
.66044 .69809 Mdot
.54024 .86353 Mdot
.82654 .26498 Mdot
.70635 .43041 Mdot
.58615 .59585 Mdot
.46596 .76128 Mdot
.34576 .92672 Mdot
.75226 .16273 Mdot
.63206 .32817 Mdot
.51187 .4936 Mdot
.39167 .65904 Mdot
.27148 .82447 Mdot
.67797 .06049 Mdot
.55778 .22592 Mdot
.43758 .39136 Mdot
.31739 .55679 Mdot
.19719 .72223 Mdot
.48349 .12368 Mdot
.3633 .28912 Mdot
.2431 .45455 Mdot
.12291 .61998 Mdot
.28901 .18687 Mdot
.16882 .35231 Mdot
.04862 .51774 Mdot
.09453 .25006 Mdot
.91029 .60441 Mdot
.83601 .70665 Mdot
.76172 .8089 Mdot
.68744 .91114 Mdot
.91029 .39992 Mdot
.83601 .50216 Mdot
.76172 .60441 Mdot
.68744 .70665 Mdot
.61315 .8089 Mdot
.53887 .91114 Mdot
.83601 .29767 Mdot
.76172 .39992 Mdot
.68744 .50216 Mdot
.61315 .60441 Mdot
.53887 .70665 Mdot
.46458 .8089 Mdot
.3903 .91114 Mdot
.76172 .19543 Mdot
.68744 .29767 Mdot
.61315 .39992 Mdot
.53887 .50216 Mdot
.46458 .60441 Mdot
.3903 .70665 Mdot
.31601 .8089 Mdot
.68744 .09319 Mdot
.61315 .19543 Mdot
.53887 .29767 Mdot
.46458 .39992 Mdot
.3903 .50216 Mdot
.31601 .60441 Mdot
.24173 .70665 Mdot
.16745 .8089 Mdot
.53887 .09319 Mdot
.46458 .19543 Mdot
.3903 .29767 Mdot
.31601 .39992 Mdot
.24173 .50216 Mdot
.16745 .60441 Mdot
.09316 .70665 Mdot
.3903 .09319 Mdot
.31601 .19543 Mdot
.24173 .29767 Mdot
.16745 .39992 Mdot
.09316 .50216 Mdot
.16745 .19543 Mdot
.09316 .29767 Mdot
.22814 .82623 Mdot
.34834 .86528 Mdot
.46853 .90434 Mdot
.58873 .94339 Mdot
.10795 .6608 Mdot
.22814 .69985 Mdot
.34834 .7389 Mdot
.46853 .77796 Mdot
.58873 .81701 Mdot
.70892 .85606 Mdot
.10795 .53441 Mdot
.22814 .57347 Mdot
.34834 .61252 Mdot
.46853 .65158 Mdot
.58873 .69063 Mdot
.70892 .72968 Mdot
.82912 .76874 Mdot
.10795 .40803 Mdot
.22814 .44709 Mdot
.34834 .48614 Mdot
.46853 .5252 Mdot
.58873 .56425 Mdot
.70892 .6033 Mdot
.82912 .64236 Mdot
.10795 .28165 Mdot
.22814 .32071 Mdot
.34834 .35976 Mdot
.46853 .39881 Mdot
.58873 .43787 Mdot
.70892 .47692 Mdot
.82912 .51598 Mdot
.94931 .55503 Mdot
.22814 .19433 Mdot
.34834 .23338 Mdot
.46853 .27243 Mdot
.58873 .31149 Mdot
.70892 .35054 Mdot
.82912 .38959 Mdot
.94931 .42865 Mdot
.34834 .107 Mdot
.46853 .14605 Mdot
.58873 .18511 Mdot
.70892 .22416 Mdot
.82912 .26321 Mdot
.58873 .05873 Mdot
.70892 .09778 Mdot
.09611 .75507 Mdot
.29059 .81826 Mdot
.48507 .88145 Mdot
.67955 .94464 Mdot
.09611 .62869 Mdot
.29059 .69188 Mdot
.48507 .75507 Mdot
.67955 .81826 Mdot
.09611 .50231 Mdot
.29059 .5655 Mdot
.48507 .62869 Mdot
.67955 .69188 Mdot
.87403 .75507 Mdot
.09611 .37593 Mdot
.29059 .43912 Mdot
.48507 .50231 Mdot
.67955 .5655 Mdot
.87403 .62869 Mdot
.09611 .24955 Mdot
.29059 .31274 Mdot
.48507 .37593 Mdot
.67955 .43912 Mdot
.87403 .50231 Mdot
.29059 .18636 Mdot
.48507 .24955 Mdot
.67955 .31274 Mdot
.87403 .37593 Mdot
.48507 .12317 Mdot
.67955 .18636 Mdot
.87403 .24955 Mdot
.67955 .05998 Mdot
.67825 .94422 Mdot
.48377 .88103 Mdot
.28929 .81784 Mdot
.09481 .75465 Mdot
.75254 .84198 Mdot
.55806 .77879 Mdot
.36358 .71559 Mdot
.1691 .6524 Mdot
.82682 .73973 Mdot
.63234 .67654 Mdot
.43786 .61335 Mdot
.24338 .55016 Mdot
.0489 .48697 Mdot
.90111 .63749 Mdot
.70663 .5743 Mdot
.51215 .51111 Mdot
.31767 .44792 Mdot
.12318 .38473 Mdot
.97539 .53524 Mdot
.78091 .47205 Mdot
.58643 .40886 Mdot
.39195 .34567 Mdot
.19747 .28248 Mdot
.8552 .36981 Mdot
.66072 .30662 Mdot
.46623 .24343 Mdot
.27175 .18024 Mdot
.735 .20437 Mdot
.54052 .14118 Mdot
.34604 .07799 Mdot
.6148 .03894 Mdot
.52943 .92413 Mdot
.40924 .88507 Mdot
.28904 .84602 Mdot
.16885 .80696 Mdot
.72391 .86094 Mdot
.60372 .82188 Mdot
.48352 .78283 Mdot
.36333 .74377 Mdot
.24313 .70472 Mdot
.12294 .66567 Mdot
.7982 .75869 Mdot
.678 .71964 Mdot
.55781 .68058 Mdot
.43761 .64153 Mdot
.31742 .60248 Mdot
.19722 .56342 Mdot
.07703 .52437 Mdot
.87248 .65645 Mdot
.75229 .61739 Mdot
.63209 .57834 Mdot
.5119 .53929 Mdot
.3917 .50023 Mdot
.27151 .46118 Mdot
.15131 .42212 Mdot
.94677 .5542 Mdot
.82657 .51515 Mdot
.70638 .4761 Mdot
.58618 .43704 Mdot
.46599 .39799 Mdot
.34579 .35893 Mdot
.2256 .31988 Mdot
.1054 .28083 Mdot
.90086 .4129 Mdot
.78066 .37385 Mdot
.66047 .3348 Mdot
.54027 .29574 Mdot
.42008 .25669 Mdot
.29988 .21764 Mdot
.17969 .17858 Mdot
.85495 .27161 Mdot
.73475 .23255 Mdot
.61456 .1935 Mdot
.49436 .15444 Mdot
.37417 .11539 Mdot
.68884 .09125 Mdot
.56865 .0522 Mdot
.243 .09773 Mdot
.36319 .05868 Mdot
.1228 .26317 Mdot
.243 .22411 Mdot
.36319 .18506 Mdot
.48339 .14601 Mdot
.60358 .10695 Mdot
.1228 .38955 Mdot
.243 .3505 Mdot
.36319 .31144 Mdot
.48339 .27239 Mdot
.60358 .23333 Mdot
.72378 .19428 Mdot
.1228 .51593 Mdot
.243 .47688 Mdot
.36319 .43782 Mdot
.48339 .39877 Mdot
.60358 .35971 Mdot
.72378 .32066 Mdot
.84398 .28161 Mdot
.1228 .64231 Mdot
.243 .60326 Mdot
.36319 .5642 Mdot
.48339 .52515 Mdot
.60358 .4861 Mdot
.72378 .44704 Mdot
.84398 .40799 Mdot
.1228 .76869 Mdot
.243 .72964 Mdot
.36319 .69058 Mdot
.48339 .65153 Mdot
.60358 .61248 Mdot
.72378 .57342 Mdot
.84398 .53437 Mdot
.96417 .49531 Mdot
.243 .85602 Mdot
.36319 .81697 Mdot
.48339 .77791 Mdot
.60358 .73886 Mdot
.72378 .6998 Mdot
.84398 .66075 Mdot
.96417 .6217 Mdot
.36319 .94335 Mdot
.48339 .90429 Mdot
.60358 .86524 Mdot
.72378 .82618 Mdot
.84398 .78713 Mdot
.8171 .19468 Mdot
.93729 .36011 Mdot
.57671 .0683 Mdot
.6969 .23373 Mdot
.8171 .39917 Mdot
.93729 .5646 Mdot
.45651 .10735 Mdot
.57671 .27279 Mdot
.6969 .43822 Mdot
.8171 .60366 Mdot
.33632 .14641 Mdot
.45651 .31184 Mdot
.57671 .47728 Mdot
.6969 .64271 Mdot
.8171 .80815 Mdot
.21612 .18546 Mdot
.33632 .3509 Mdot
.45651 .51633 Mdot
.57671 .68176 Mdot
.6969 .8472 Mdot
.21612 .38995 Mdot
.33632 .55538 Mdot
.45651 .72082 Mdot
.57671 .88625 Mdot
.09593 .429 Mdot
.21612 .59444 Mdot
.33632 .75987 Mdot
.45651 .92531 Mdot
.09593 .63349 Mdot
.21612 .79893 Mdot
.80539 .13283 Mdot
.87967 .23508 Mdot
.61091 .06964 Mdot
.68519 .17189 Mdot
.75948 .27413 Mdot
.83376 .37638 Mdot
.90805 .47862 Mdot
.49071 .1087 Mdot
.565 .21094 Mdot
.63928 .31319 Mdot
.71357 .41543 Mdot
.78785 .51767 Mdot
.86213 .61992 Mdot
.37052 .14775 Mdot
.4448 .25 Mdot
.51908 .35224 Mdot
.59337 .45448 Mdot
.66765 .55673 Mdot
.74194 .65897 Mdot
.81622 .76122 Mdot
.25032 .1868 Mdot
.3246 .28905 Mdot
.39889 .39129 Mdot
.47317 .49354 Mdot
.54746 .59578 Mdot
.62174 .69803 Mdot
.69603 .80027 Mdot
.13012 .22586 Mdot
.20441 .3281 Mdot
.27869 .43035 Mdot
.35298 .53259 Mdot
.42726 .63484 Mdot
.50155 .73708 Mdot
.57583 .83932 Mdot
.65012 .94157 Mdot
.08421 .36716 Mdot
.1585 .4694 Mdot
.23278 .57165 Mdot
.30707 .67389 Mdot
.38135 .77613 Mdot
.45564 .87838 Mdot
.52992 .98062 Mdot
.0383 .50845 Mdot
.11259 .6107 Mdot
.18687 .71294 Mdot
.26116 .81519 Mdot
.33544 .91743 Mdot
.8171 .80965 Mdot
.93729 .64421 Mdot
.57671 .93603 Mdot
.6969 .77059 Mdot
.8171 .60516 Mdot
.93729 .43972 Mdot
.45651 .89697 Mdot
.57671 .73154 Mdot
.6969 .5661 Mdot
.8171 .40067 Mdot
.33632 .85792 Mdot
.45651 .69249 Mdot
.57671 .52705 Mdot
.6969 .36162 Mdot
.8171 .19618 Mdot
.21612 .81887 Mdot
.33632 .65343 Mdot
.45651 .488 Mdot
.57671 .32256 Mdot
.6969 .15713 Mdot
.21612 .61438 Mdot
.33632 .44894 Mdot
.45651 .28351 Mdot
.57671 .11807 Mdot
.09593 .57532 Mdot
.21612 .40989 Mdot
.33632 .24445 Mdot
.45651 .07902 Mdot
.09593 .37083 Mdot
.21612 .2054 Mdot
.89031 .70889 Mdot
.77011 .87432 Mdot
.93622 .44121 Mdot
.81602 .60664 Mdot
.69583 .77208 Mdot
.57563 .93751 Mdot
.86193 .33896 Mdot
.74174 .5044 Mdot
.62154 .66983 Mdot
.50135 .83527 Mdot
.78765 .23672 Mdot
.66745 .40215 Mdot
.54726 .56759 Mdot
.42706 .73302 Mdot
.30686 .89846 Mdot
.71336 .13447 Mdot
.59317 .29991 Mdot
.47297 .46534 Mdot
.35278 .63078 Mdot
.23258 .79621 Mdot
.51888 .19767 Mdot
.39869 .3631 Mdot
.27849 .52853 Mdot
.1583 .69397 Mdot
.4446 .09542 Mdot
.3244 .26086 Mdot
.20421 .42629 Mdot
.08401 .59173 Mdot
.25012 .15861 Mdot
.12992 .32405 Mdot
.94568 .67839 Mdot
.8714 .78064 Mdot
.94568 .4739 Mdot
.8714 .57615 Mdot
.79711 .67839 Mdot
.72283 .78064 Mdot
.64854 .88288 Mdot
.8714 .37166 Mdot
.79711 .4739 Mdot
.72283 .57615 Mdot
.64854 .67839 Mdot
.57426 .78064 Mdot
.49997 .88288 Mdot
.79711 .26942 Mdot
.72283 .37166 Mdot
.64854 .4739 Mdot
.57426 .57615 Mdot
.49997 .67839 Mdot
.42569 .78064 Mdot
.3514 .88288 Mdot
.72283 .16717 Mdot
.64854 .26942 Mdot
.57426 .37166 Mdot
.49997 .4739 Mdot
.42569 .57615 Mdot
.3514 .67839 Mdot
.27712 .78064 Mdot
.64854 .06493 Mdot
.57426 .16717 Mdot
.49997 .26942 Mdot
.42569 .37166 Mdot
.3514 .4739 Mdot
.27712 .57615 Mdot
.20283 .67839 Mdot
.12855 .78064 Mdot
.49997 .06493 Mdot
.42569 .16717 Mdot
.3514 .26942 Mdot
.27712 .37166 Mdot
.20283 .4739 Mdot
.12855 .57615 Mdot
.05426 .67839 Mdot
.3514 .06493 Mdot
.27712 .16717 Mdot
.20283 .26942 Mdot
.12855 .37166 Mdot
.05426 .4739 Mdot
.243 .90689 Mdot
.36319 .94594 Mdot
.1228 .74145 Mdot
.243 .78051 Mdot
.36319 .81956 Mdot
.48339 .85861 Mdot
.60358 .89767 Mdot
.1228 .61507 Mdot
.243 .65412 Mdot
.36319 .69318 Mdot
.48339 .73223 Mdot
.60358 .77129 Mdot
.72378 .81034 Mdot
.1228 .48869 Mdot
.243 .52774 Mdot
.36319 .5668 Mdot
.48339 .60585 Mdot
.60358 .6449 Mdot
.72378 .68396 Mdot
.84398 .72301 Mdot
.1228 .36231 Mdot
.243 .40136 Mdot
.36319 .44042 Mdot
.48339 .47947 Mdot
.60358 .51852 Mdot
.72378 .55758 Mdot
.84398 .59663 Mdot
.1228 .23593 Mdot
.243 .27498 Mdot
.36319 .31404 Mdot
.48339 .35309 Mdot
.60358 .39214 Mdot
.72378 .4312 Mdot
.84398 .47025 Mdot
.96417 .5093 Mdot
.243 .1486 Mdot
.36319 .18765 Mdot
.48339 .22671 Mdot
.60358 .26576 Mdot
.72378 .30482 Mdot
.84398 .34387 Mdot
.96417 .38292 Mdot
.36319 .06127 Mdot
.48339 .10033 Mdot
.60358 .13938 Mdot
.72378 .17844 Mdot
.84398 .21749 Mdot
.30545 .89892 Mdot
.49993 .96211 Mdot
.11097 .70935 Mdot
.30545 .77254 Mdot
.49993 .83573 Mdot
.69441 .89892 Mdot
.11097 .58297 Mdot
.30545 .64616 Mdot
.49993 .70935 Mdot
.69441 .77254 Mdot
.11097 .45658 Mdot
.30545 .51978 Mdot
.49993 .58297 Mdot
.69441 .64616 Mdot
.88889 .70935 Mdot
.11097 .3302 Mdot
.30545 .39339 Mdot
.49993 .45658 Mdot
.69441 .51978 Mdot
.88889 .58297 Mdot
.30545 .26701 Mdot
.49993 .3302 Mdot
.69441 .39339 Mdot
.88889 .45658 Mdot
.30545 .14063 Mdot
.49993 .20382 Mdot
.69441 .26701 Mdot
.88889 .3302 Mdot
.49993 .07744 Mdot
.69441 .14063 Mdot
.42434 .93755 Mdot
.22986 .87436 Mdot
.69311 .8985 Mdot
.49863 .8353 Mdot
.30415 .77211 Mdot
.10967 .70892 Mdot
.76739 .79625 Mdot
.57291 .73306 Mdot
.37843 .66987 Mdot
.18395 .60668 Mdot
.84168 .69401 Mdot
.6472 .63082 Mdot
.45272 .56763 Mdot
.25824 .50444 Mdot
.06376 .44124 Mdot
.91596 .59176 Mdot
.72148 .52857 Mdot
.527 .46538 Mdot
.33252 .40219 Mdot
.13804 .339 Mdot
.79577 .42633 Mdot
.60129 .36314 Mdot
.40681 .29995 Mdot
.21233 .23676 Mdot
.87005 .32408 Mdot
.67557 .26089 Mdot
.48109 .1977 Mdot
.28661 .13451 Mdot
.74986 .15865 Mdot
.55538 .09546 Mdot
.47001 .98065 Mdot
.34981 .94159 Mdot
.66449 .91745 Mdot
.54429 .8784 Mdot
.4241 .83935 Mdot
.3039 .80029 Mdot
.18371 .76124 Mdot
.73877 .81521 Mdot
.61858 .77616 Mdot
.49838 .7371 Mdot
.37819 .69805 Mdot
.25799 .659 Mdot
.13779 .61994 Mdot
.81306 .71297 Mdot
.69286 .67391 Mdot
.57267 .63486 Mdot
.45247 .5958 Mdot
.33228 .55675 Mdot
.21208 .5177 Mdot
.09188 .47864 Mdot
.88734 .61072 Mdot
.76715 .57167 Mdot
.64695 .53261 Mdot
.52676 .49356 Mdot
.40656 .45451 Mdot
.28636 .41545 Mdot
.16617 .3764 Mdot
.96163 .50848 Mdot
.84143 .46942 Mdot
.72124 .43037 Mdot
.60104 .39132 Mdot
.48084 .35226 Mdot
.36065 .31321 Mdot
.24045 .27415 Mdot
.12026 .2351 Mdot
.91572 .36718 Mdot
.79552 .32813 Mdot
.67532 .28907 Mdot
.55513 .25002 Mdot
.43493 .21096 Mdot
.31474 .17191 Mdot
.19454 .13286 Mdot
.86981 .22588 Mdot
.74961 .18683 Mdot
.62941 .14777 Mdot
.50922 .10872 Mdot
.38902 .06967 Mdot
.15602 .21744 Mdot
.27622 .17839 Mdot
.39642 .13934 Mdot
.51661 .10028 Mdot
.63681 .06123 Mdot
.03583 .38288 Mdot
.15602 .34382 Mdot
.27622 .30477 Mdot
.39642 .26572 Mdot
.51661 .22666 Mdot
.63681 .18761 Mdot
.757 .14855 Mdot
.03583 .50926 Mdot
.15602 .47021 Mdot
.27622 .43115 Mdot
.39642 .3921 Mdot
.51661 .35304 Mdot
.63681 .31399 Mdot
.757 .27494 Mdot
.8772 .23588 Mdot
.15602 .59659 Mdot
.27622 .55753 Mdot
.39642 .51848 Mdot
.51661 .47942 Mdot
.63681 .44037 Mdot
.757 .40132 Mdot
.8772 .36226 Mdot
.15602 .72297 Mdot
.27622 .68391 Mdot
.39642 .64486 Mdot
.51661 .60581 Mdot
.63681 .56675 Mdot
.757 .5277 Mdot
.8772 .48864 Mdot
.27622 .81029 Mdot
.39642 .77124 Mdot
.51661 .73219 Mdot
.63681 .69313 Mdot
.757 .65408 Mdot
.8772 .61502 Mdot
.39642 .89762 Mdot
.51661 .85857 Mdot
.63681 .81951 Mdot
.757 .78046 Mdot
.8772 .74141 Mdot
.63681 .94589 Mdot
.757 .90684 Mdot
.78388 .20547 Mdot
.90407 .37091 Mdot
.54349 .07909 Mdot
.66368 .24453 Mdot
.78388 .40996 Mdot
.90407 .5754 Mdot
.42329 .11815 Mdot
.54349 .28358 Mdot
.66368 .44902 Mdot
.78388 .61445 Mdot
.3031 .1572 Mdot
.42329 .32264 Mdot
.54349 .48807 Mdot
.66368 .65351 Mdot
.78388 .81894 Mdot
.1829 .19625 Mdot
.3031 .36169 Mdot
.42329 .52712 Mdot
.54349 .69256 Mdot
.66368 .85799 Mdot
.1829 .40074 Mdot
.3031 .56618 Mdot
.42329 .73161 Mdot
.54349 .89705 Mdot
.06271 .4398 Mdot
.1829 .60523 Mdot
.3031 .77067 Mdot
.42329 .9361 Mdot
.06271 .64429 Mdot
.1829 .80972 Mdot
.66466 .08711 Mdot
.73894 .18935 Mdot
.81323 .2916 Mdot
.88751 .39384 Mdot
.9618 .49609 Mdot
.47018 .02392 Mdot
.54446 .12616 Mdot
.61875 .22841 Mdot
.69303 .33065 Mdot
.76732 .4329 Mdot
.8416 .53514 Mdot
.91589 .63738 Mdot
.34998 .06297 Mdot
.42427 .16522 Mdot
.49855 .26746 Mdot
.57284 .3697 Mdot
.64712 .47195 Mdot
.72141 .57419 Mdot
.79569 .67644 Mdot
.86998 .77868 Mdot
.30407 .20427 Mdot
.37836 .30651 Mdot
.45264 .40876 Mdot
.52693 .511 Mdot
.60121 .61325 Mdot
.6755 .71549 Mdot
.74978 .81774 Mdot
.18388 .24332 Mdot
.25816 .34557 Mdot
.33245 .44781 Mdot
.40673 .55006 Mdot
.48102 .6523 Mdot
.5553 .75455 Mdot
.62959 .85679 Mdot
.13797 .38462 Mdot
.21225 .48687 Mdot
.28654 .58911 Mdot
.36082 .69136 Mdot
.43511 .7936 Mdot
.50939 .89584 Mdot
.09206 .52592 Mdot
.16634 .62816 Mdot
.24063 .73041 Mdot
.31491 .83265 Mdot
.3892 .9349 Mdot
.12043 .76946 Mdot
.19472 .87171 Mdot
.78388 .79885 Mdot
.90407 .63342 Mdot
.54349 .92523 Mdot
.66368 .7598 Mdot
.78388 .59436 Mdot
.90407 .42893 Mdot
.42329 .88618 Mdot
.54349 .72074 Mdot
.66368 .55531 Mdot
.78388 .38988 Mdot
.3031 .84713 Mdot
.42329 .68169 Mdot
.54349 .51626 Mdot
.66368 .35082 Mdot
.78388 .18539 Mdot
.1829 .80807 Mdot
.3031 .64264 Mdot
.42329 .4772 Mdot
.54349 .31177 Mdot
.66368 .14633 Mdot
.1829 .60358 Mdot
.3031 .43815 Mdot
.42329 .27271 Mdot
.54349 .10728 Mdot
.06271 .56453 Mdot
.1829 .39909 Mdot
.3031 .23366 Mdot
.42329 .06823 Mdot
.06271 .36004 Mdot
.1829 .19461 Mdot
.86977 .68063 Mdot
.74958 .84606 Mdot
.91568 .41295 Mdot
.79549 .57838 Mdot
.67529 .74382 Mdot
.5551 .90925 Mdot
.8414 .3107 Mdot
.7212 .47614 Mdot
.60101 .64157 Mdot
.48081 .80701 Mdot
.76711 .20846 Mdot
.64692 .37389 Mdot
.52672 .53933 Mdot
.40653 .70476 Mdot
.28633 .8702 Mdot
.69283 .10622 Mdot
.57263 .27165 Mdot
.45244 .43708 Mdot
.33224 .60252 Mdot
.21205 .76795 Mdot
.49835 .16941 Mdot
.37815 .33484 Mdot
.25796 .50028 Mdot
.13776 .66571 Mdot
.42406 .06716 Mdot
.30387 .2326 Mdot
.18367 .39803 Mdot
.06348 .56347 Mdot
.22958 .13035 Mdot
.10939 .29579 Mdot
.94568 .53042 Mdot
.8714 .63267 Mdot
.79711 .73491 Mdot
.72283 .83716 Mdot
.64854 .9394 Mdot
.94568 .32593 Mdot
.8714 .42818 Mdot
.79711 .53042 Mdot
.72283 .63267 Mdot
.64854 .73491 Mdot
.57426 .83716 Mdot
.49997 .9394 Mdot
.8714 .22369 Mdot
.79711 .32593 Mdot
.72283 .42818 Mdot
.64854 .53042 Mdot
.57426 .63267 Mdot
.49997 .73491 Mdot
.42569 .83716 Mdot
.3514 .9394 Mdot
.72283 .22369 Mdot
.64854 .32593 Mdot
.57426 .42818 Mdot
.49997 .53042 Mdot
.42569 .63267 Mdot
.3514 .73491 Mdot
.27712 .83716 Mdot
.64854 .12145 Mdot
.57426 .22369 Mdot
.49997 .32593 Mdot
.42569 .42818 Mdot
.3514 .53042 Mdot
.27712 .63267 Mdot
.20283 .73491 Mdot
.49997 .12145 Mdot
.42569 .22369 Mdot
.3514 .32593 Mdot
.27712 .42818 Mdot
.20283 .53042 Mdot
.12855 .63267 Mdot
.3514 .12145 Mdot
.27712 .22369 Mdot
.20283 .32593 Mdot
.12855 .42818 Mdot
.05426 .53042 Mdot
.12855 .22369 Mdot
.05426 .32593 Mdot
.15602 .78718 Mdot
.27622 .82623 Mdot
.39642 .86528 Mdot
.51661 .90434 Mdot
.63681 .94339 Mdot
.03583 .62174 Mdot
.15602 .6608 Mdot
.27622 .69985 Mdot
.39642 .7389 Mdot
.51661 .77796 Mdot
.63681 .81701 Mdot
.757 .85606 Mdot
.03583 .49536 Mdot
.15602 .53441 Mdot
.27622 .57347 Mdot
.39642 .61252 Mdot
.51661 .65158 Mdot
.63681 .69063 Mdot
.757 .72968 Mdot
.8772 .76874 Mdot
.15602 .40803 Mdot
.27622 .44709 Mdot
.39642 .48614 Mdot
.51661 .5252 Mdot
.63681 .56425 Mdot
.757 .6033 Mdot
.8772 .64236 Mdot
.15602 .28165 Mdot
.27622 .32071 Mdot
.39642 .35976 Mdot
.51661 .39881 Mdot
.63681 .43787 Mdot
.757 .47692 Mdot
.8772 .51598 Mdot
.27622 .19433 Mdot
.39642 .23338 Mdot
.51661 .27243 Mdot
.63681 .31149 Mdot
.757 .35054 Mdot
.8772 .38959 Mdot
.39642 .107 Mdot
.51661 .14605 Mdot
.63681 .18511 Mdot
.757 .22416 Mdot
.8772 .26321 Mdot
.63681 .05873 Mdot
.757 .09778 Mdot
.30545 .86399 Mdot
.49993 .92718 Mdot
.11097 .67442 Mdot
.30545 .73761 Mdot
.49993 .8008 Mdot
.69441 .86399 Mdot
.11097 .54803 Mdot
.30545 .61123 Mdot
.49993 .67442 Mdot
.69441 .73761 Mdot
.11097 .42165 Mdot
.30545 .48484 Mdot
.49993 .54803 Mdot
.69441 .61123 Mdot
.88889 .67442 Mdot
.11097 .29527 Mdot
.30545 .35846 Mdot
.49993 .42165 Mdot
.69441 .48484 Mdot
.88889 .54803 Mdot
.30545 .23208 Mdot
.49993 .29527 Mdot
.69441 .35846 Mdot
.88889 .42165 Mdot
.30545 .1057 Mdot
.49993 .16889 Mdot
.69441 .23208 Mdot
.88889 .29527 Mdot
.49993 .04251 Mdot
.69441 .1057 Mdot
.44488 .90929 Mdot
.25039 .8461 Mdot
.71364 .87024 Mdot
.51916 .80704 Mdot
.32468 .74385 Mdot
.1302 .68066 Mdot
.78792 .76799 Mdot
.59344 .7048 Mdot
.39896 .64161 Mdot
.20448 .57842 Mdot
.86221 .66575 Mdot
.66773 .60256 Mdot
.47325 .53937 Mdot
.27877 .47618 Mdot
.08429 .41298 Mdot
.93649 .5635 Mdot
.74201 .50031 Mdot
.54753 .43712 Mdot
.35305 .37393 Mdot
.15857 .31074 Mdot
.8163 .39807 Mdot
.62182 .33488 Mdot
.42734 .27169 Mdot
.23286 .2085 Mdot
.89058 .29582 Mdot
.6961 .23263 Mdot
.50162 .16944 Mdot
.30714 .10625 Mdot
.77039 .13039 Mdot
.57591 .0672 Mdot
.61073 .93492 Mdot
.49054 .89587 Mdot
.37034 .85681 Mdot
.25015 .81776 Mdot
.12995 .7787 Mdot
.80521 .87173 Mdot
.68502 .83268 Mdot
.56482 .79362 Mdot
.44463 .75457 Mdot
.32443 .71551 Mdot
.20424 .67646 Mdot
.08404 .63741 Mdot
.8795 .76949 Mdot
.7593 .73043 Mdot
.63911 .69138 Mdot
.51891 .65232 Mdot
.39872 .61327 Mdot
.27852 .57422 Mdot
.15833 .53516 Mdot
.03813 .49611 Mdot
.83359 .62819 Mdot
.71339 .58913 Mdot
.5932 .55008 Mdot
.473 .51103 Mdot
.35281 .47197 Mdot
.23261 .43292 Mdot
.11242 .39386 Mdot
.90787 .52594 Mdot
.78768 .48689 Mdot
.66748 .44784 Mdot
.54729 .40878 Mdot
.42709 .36973 Mdot
.3069 .33067 Mdot
.1867 .29162 Mdot
.86196 .38465 Mdot
.74177 .34559 Mdot
.62157 .30654 Mdot
.50138 .26748 Mdot
.38118 .22843 Mdot
.26099 .18938 Mdot
.81605 .24335 Mdot
.69586 .20429 Mdot
.57566 .16524 Mdot
.45547 .12619 Mdot
.33527 .08713 Mdot
.64995 .06299 Mdot
.52975 .02394 Mdot
.29108 .09773 Mdot
.41127 .05868 Mdot
.17088 .26317 Mdot
.29108 .22411 Mdot
.41127 .18506 Mdot
.53147 .14601 Mdot
.65166 .10695 Mdot
.05069 .4286 Mdot
.17088 .38955 Mdot
.29108 .3505 Mdot
.41127 .31144 Mdot
.53147 .27239 Mdot
.65166 .23333 Mdot
.77186 .19428 Mdot
.05069 .55498 Mdot
.17088 .51593 Mdot
.29108 .47688 Mdot
.41127 .43782 Mdot
.53147 .39877 Mdot
.65166 .35971 Mdot
.77186 .32066 Mdot
.89205 .28161 Mdot
.17088 .64231 Mdot
.29108 .60326 Mdot
.41127 .5642 Mdot
.53147 .52515 Mdot
.65166 .4861 Mdot
.77186 .44704 Mdot
.89205 .40799 Mdot
.17088 .76869 Mdot
.29108 .72964 Mdot
.41127 .69058 Mdot
.53147 .65153 Mdot
.65166 .61248 Mdot
.77186 .57342 Mdot
.89205 .53437 Mdot
.29108 .85602 Mdot
.41127 .81697 Mdot
.53147 .77791 Mdot
.65166 .73886 Mdot
.77186 .6998 Mdot
.89205 .66075 Mdot
.41127 .94335 Mdot
.53147 .90429 Mdot
.65166 .86524 Mdot
.77186 .82618 Mdot
.86518 .19468 Mdot
.62479 .0683 Mdot
.74498 .23373 Mdot
.86518 .39917 Mdot
.50459 .10735 Mdot
.62479 .27279 Mdot
.74498 .43822 Mdot
.86518 .60366 Mdot
.3844 .14641 Mdot
.50459 .31184 Mdot
.62479 .47728 Mdot
.74498 .64271 Mdot
.86518 .80815 Mdot
.2642 .18546 Mdot
.3844 .3509 Mdot
.50459 .51633 Mdot
.62479 .68176 Mdot
.74498 .8472 Mdot
.144 .22451 Mdot
.2642 .38995 Mdot
.3844 .55538 Mdot
.50459 .72082 Mdot
.62479 .88625 Mdot
.144 .429 Mdot
.2642 .59444 Mdot
.3844 .75987 Mdot
.50459 .92531 Mdot
.02381 .46806 Mdot
.144 .63349 Mdot
.2642 .79893 Mdot
.3844 .96436 Mdot
.82024 .17856 Mdot
.89453 .2808 Mdot
.62576 .11537 Mdot
.70005 .21761 Mdot
.77433 .31986 Mdot
.84862 .4221 Mdot
.9229 .52435 Mdot
.43128 .05218 Mdot
.50557 .15442 Mdot
.57985 .25667 Mdot
.65414 .35891 Mdot
.72842 .46116 Mdot
.80271 .5634 Mdot
.87699 .66564 Mdot
.31109 .09123 Mdot
.38537 .19348 Mdot
.45966 .29572 Mdot
.53394 .39796 Mdot
.60823 .50021 Mdot
.68251 .60245 Mdot
.7568 .7047 Mdot
.83108 .80694 Mdot
.26518 .23253 Mdot
.33946 .33477 Mdot
.41375 .43702 Mdot
.48803 .53926 Mdot
.56232 .64151 Mdot
.6366 .74375 Mdot
.71089 .846 Mdot
.14498 .27158 Mdot
.21927 .37383 Mdot
.29355 .47607 Mdot
.36784 .57832 Mdot
.44212 .68056 Mdot
.51641 .78281 Mdot
.59069 .88505 Mdot
.09907 .41288 Mdot
.17336 .51513 Mdot
.24764 .61737 Mdot
.32193 .71961 Mdot
.39621 .82186 Mdot
.4705 .9241 Mdot
.05316 .55418 Mdot
.12745 .65642 Mdot
.20173 .75867 Mdot
.27601 .86091 Mdot
.86518 .80965 Mdot
.62479 .93603 Mdot
.74498 .77059 Mdot
.86518 .60516 Mdot
.50459 .89697 Mdot
.62479 .73154 Mdot
.74498 .5661 Mdot
.86518 .40067 Mdot
.3844 .85792 Mdot
.50459 .69249 Mdot
.62479 .52705 Mdot
.74498 .36162 Mdot
.86518 .19618 Mdot
.2642 .81887 Mdot
.3844 .65343 Mdot
.50459 .488 Mdot
.62479 .32256 Mdot
.74498 .15713 Mdot
.144 .77981 Mdot
.2642 .61438 Mdot
.3844 .44894 Mdot
.50459 .28351 Mdot
.62479 .11807 Mdot
.144 .57532 Mdot
.2642 .40989 Mdot
.3844 .24445 Mdot
.50459 .07902 Mdot
.02381 .53627 Mdot
.144 .37083 Mdot
.2642 .2054 Mdot
.3844 .03997 Mdot
.90516 .75461 Mdot
.95107 .48693 Mdot
.83088 .65237 Mdot
.71068 .8178 Mdot
.87679 .38469 Mdot
.75659 .55012 Mdot
.6364 .71556 Mdot
.5162 .88099 Mdot
.8025 .28244 Mdot
.68231 .44788 Mdot
.56211 .61331 Mdot
.44192 .77875 Mdot
.32172 .94418 Mdot
.72822 .1802 Mdot
.60802 .34563 Mdot
.48783 .51107 Mdot
.36763 .6765 Mdot
.24744 .84194 Mdot
.65393 .07796 Mdot
.53374 .24339 Mdot
.41354 .40882 Mdot
.29335 .57426 Mdot
.17315 .73969 Mdot
.45945 .14115 Mdot
.33926 .30658 Mdot
.21906 .47202 Mdot
.09887 .63745 Mdot
.38517 .0389 Mdot
.26497 .20434 Mdot
.14478 .36977 Mdot
.02458 .53521 Mdot
.90679 .70665 Mdot
.8325 .8089 Mdot
.90679 .50216 Mdot
.8325 .60441 Mdot
.75822 .70665 Mdot
.68393 .8089 Mdot
.60965 .91114 Mdot
.90679 .29767 Mdot
.8325 .39992 Mdot
.75822 .50216 Mdot
.68393 .60441 Mdot
.60965 .70665 Mdot
.53536 .8089 Mdot
.46108 .91114 Mdot
.8325 .19543 Mdot
.75822 .29767 Mdot
.68393 .39992 Mdot
.60965 .50216 Mdot
.53536 .60441 Mdot
.46108 .70665 Mdot
.38679 .8089 Mdot
.31251 .91114 Mdot
.68393 .19543 Mdot
.60965 .29767 Mdot
.53536 .39992 Mdot
.46108 .50216 Mdot
.38679 .60441 Mdot
.31251 .70665 Mdot
.23822 .8089 Mdot
.60965 .09319 Mdot
.53536 .19543 Mdot
.46108 .29767 Mdot
.38679 .39992 Mdot
.31251 .50216 Mdot
.23822 .60441 Mdot
.16394 .70665 Mdot
.46108 .09319 Mdot
.38679 .19543 Mdot
.31251 .29767 Mdot
.23822 .39992 Mdot
.16394 .50216 Mdot
.08965 .60441 Mdot
.31251 .09319 Mdot
.23822 .19543 Mdot
.16394 .29767 Mdot
.08965 .39992 Mdot
.29108 .90689 Mdot
.41127 .94594 Mdot
.17088 .74145 Mdot
.29108 .78051 Mdot
.41127 .81956 Mdot
.53147 .85861 Mdot
.65166 .89767 Mdot
.05069 .57602 Mdot
.17088 .61507 Mdot
.29108 .65412 Mdot
.41127 .69318 Mdot
.53147 .73223 Mdot
.65166 .77129 Mdot
.77186 .81034 Mdot
.05069 .44964 Mdot
.17088 .48869 Mdot
.29108 .52774 Mdot
.41127 .5668 Mdot
.53147 .60585 Mdot
.65166 .6449 Mdot
.77186 .68396 Mdot
.89205 .72301 Mdot
.17088 .36231 Mdot
.29108 .40136 Mdot
.41127 .44042 Mdot
.53147 .47947 Mdot
.65166 .51852 Mdot
.77186 .55758 Mdot
.89205 .59663 Mdot
.17088 .23593 Mdot
.29108 .27498 Mdot
.41127 .31404 Mdot
.53147 .35309 Mdot
.65166 .39214 Mdot
.77186 .4312 Mdot
.89205 .47025 Mdot
.29108 .1486 Mdot
.41127 .18765 Mdot
.53147 .22671 Mdot
.65166 .26576 Mdot
.77186 .30482 Mdot
.89205 .34387 Mdot
.41127 .06127 Mdot
.53147 .10033 Mdot
.65166 .13938 Mdot
.77186 .17844 Mdot
.32031 .94464 Mdot
.12583 .75507 Mdot
.32031 .81826 Mdot
.51479 .88145 Mdot
.12583 .62869 Mdot
.32031 .69188 Mdot
.51479 .75507 Mdot
.70927 .81826 Mdot
.12583 .50231 Mdot
.32031 .5655 Mdot
.51479 .62869 Mdot
.70927 .69188 Mdot
.90375 .75507 Mdot
.12583 .37593 Mdot
.32031 .43912 Mdot
.51479 .50231 Mdot
.70927 .5655 Mdot
.90375 .62869 Mdot
.12583 .24955 Mdot
.32031 .31274 Mdot
.51479 .37593 Mdot
.70927 .43912 Mdot
.90375 .50231 Mdot
.32031 .18636 Mdot
.51479 .24955 Mdot
.70927 .31274 Mdot
.90375 .37593 Mdot
.32031 .05998 Mdot
.51479 .12317 Mdot
.70927 .18636 Mdot
.90375 .24955 Mdot
.38545 .96581 Mdot
.65421 .92675 Mdot
.45973 .86356 Mdot
.26525 .80037 Mdot
.7285 .82451 Mdot
.53402 .76132 Mdot
.33954 .69813 Mdot
.14506 .63494 Mdot
.80278 .72227 Mdot
.6083 .65908 Mdot
.41382 .59589 Mdot
.21934 .53269 Mdot
.02486 .4695 Mdot
.87707 .62002 Mdot
.68259 .55683 Mdot
.48811 .49364 Mdot
.29363 .43045 Mdot
.09915 .36726 Mdot
.95135 .51778 Mdot
.75687 .45459 Mdot
.56239 .3914 Mdot
.36791 .32821 Mdot
.17343 .26502 Mdot
.83116 .35234 Mdot
.63668 .28915 Mdot
.4422 .22596 Mdot
.24772 .16277 Mdot
.90544 .2501 Mdot
.71096 .18691 Mdot
.51648 .12372 Mdot
.322 .06053 Mdot
.43111 .95239 Mdot
.31092 .91333 Mdot
.62559 .8892 Mdot
.5054 .85014 Mdot
.3852 .81109 Mdot
.265 .77203 Mdot
.14481 .73298 Mdot
.82007 .826 Mdot
.69988 .78695 Mdot
.57968 .7479 Mdot
.45948 .70884 Mdot
.33929 .66979 Mdot
.21909 .63074 Mdot
.0989 .59168 Mdot
.89436 .72376 Mdot
.77416 .68471 Mdot
.65397 .64565 Mdot
.53377 .6066 Mdot
.41357 .56755 Mdot
.29338 .52849 Mdot
.17318 .48944 Mdot
.05299 .45038 Mdot
.84845 .58246 Mdot
.72825 .54341 Mdot
.60805 .50435 Mdot
.48786 .4653 Mdot
.36766 .42625 Mdot
.24747 .38719 Mdot
.12727 .34814 Mdot
.92273 .48022 Mdot
.80253 .44116 Mdot
.68234 .40211 Mdot
.56214 .36306 Mdot
.44195 .324 Mdot
.32175 .28495 Mdot
.20156 .2459 Mdot
.87682 .33892 Mdot
.75662 .29987 Mdot
.63643 .26081 Mdot
.51623 .22176 Mdot
.39604 .1827 Mdot
.27584 .14365 Mdot
.83091 .19762 Mdot
.71071 .15857 Mdot
.59052 .11951 Mdot
.47032 .08046 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[129]:=",
  ImageSize->{286.688, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004N00017`P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l77`L00?l77`L00?l77`L00?l77`L00?l7
7`L008D70`0>1`<0Q@L008@7100=1`@0Q@L008D70`0>1`<0Q@L008H700<01`L03PL00`071`241`00
K@L303l70`1/1`00K0L401h70`0M1`@0K0L006`7100M1`@07@L406`7001]1`<07PL301h70`1/1`00
KPL00`071`091`<04PL00`071`0?1`<030L00`071`1[1`00N@L402<7101j1`00FPL400T70`0:1`<0
0`L302@70`031`<02`L300T70`1J1`00F@L500D71`091`@010L00`071`0T1`0400L71`@02PL40004
1`0000@7101J1`00FPL400@720091`@000@700004`L301871`0:1`P01@L305X7001K1`801@L40003
1`0000@000@700000`L70187100A1`P00`L300051`0000L01`061`0300L705T7001S1`<00PL900@7
00<01`000`0C1`<04PL400031`07008720021`0300L00080H`L006870`051`<000@700001`L301<7
0`0C1`<01PL300041`0000D7101Q1`00H@L400H700D01`L700091`0300L700D70`0010L000041`H0
10L300041`0000P700<01`L01PL01@071`L000H7101Q1`00HPL301/720031`L00`L801d70`1Q1`00
G`L300031`0701`70`0010L000041`H010L300041`0001h700<01`000P1N1`00F0L300<7100P1`05
00L71`001PL010071`061`0500L71`0080L400@70`1G1`00E`L400@70`0<1`<03@L300870`0C1`<0
0PL300`70`0=1`<00`L405L700141`<02`L3008710051`0300L700X7100<1`@000<700000P0B1`@0
00<700000P0;1`@03PL010071`L500870`0;1`<0A0L004<7100:1`@00`L301<70`0=1`<00PL50004
1`0000H70`021`D00PL300`70`0C1`<00PL400X710141`00A0L300/70`000`L0000201D700<01`L0
3@L00`071`021`P01@L400031`0000<010L00`071`0<1`0300L701<7100010L0000;1`<0A0L004D7
00<01`L02`L00`07000400P70`0;1`<03PL300051`0000L030021`H03PL300/70`081`@00PL00`07
1`0;1`0300L704<7001F1`@01`L400X7100=1`@00PL010071`L:00@71@0=1`@02PL400P7101F1`00
E`L300P70`051`<00`L300h70`071`P01`L300h70`041`<010L300T70`1F1`00F0L00`071`081`03
00L700<710041`0300L700<000@700001`L00`071`071`800PL200T700<01`L01PL300061`0000L0
10L400D700<01`L02@L00`071`1E1`00H`L300<710061`P03PL300870`0010L0000>1`P01@L500<7
0`1S1`00HPL400@70`071`<000@700001PL300@710000`L0000600D70`071`<000@700001PL300<7
101S1`00@0L302070`051`0300L700L700D01`L700061`@010L400871`041`@020L01@071`L000P7
00<01`L00`L302070`101`00=PL300H7100Q1`0300L701X70`051`<00`L00`071`0300D70`0L1`03
00L701h710071`<0=PL003D710071`<03PL302h700<01`L01@L00`071`061`0300L700D700<01`L0
;@L300d70`061`@0=PL003H70`081`0300L700`710021`<02@L300/70`0h1`<02`L300T70`021`@0
3PL00`071`061`<0=PL003L700<01`L050L600031`00008020L400X7100?1`<050L300h7100:1`@0
20L400<71P0E1`0300L703D7001=1`@000<700L00PL300H71P041`<000<70000100>1`L000@70000
1PL300871@0?1`<000D700001`0300<71P061`<010L504d700141`<01`L300041`00008700<01`L0
10L400031`0700<720000`L01`0?1`X01@L400031`0000@040L00`07000700@71@071`0300L700<0
0PL300H70`141`00@`L400P700<01`000`0:1`<01`L300041`0001<700<01`000P000`L0000:0087
100D1`<000@700001PL300T710031`0300L700@710141`00A0L700L71P081`0300L700L700D01`L7
000G1`0400L71`P000<700L00`L00`071`0E1`0500L71`0020L00`071`061`L01`L604@700151`H0
1PL703@71P0c1`P01PL604D700161`D01`L602070`0B1`0400L701870`0P1`<000@700001`L504D7
00151`D010L3008700@01`L080L401<70`0A1`@08@L01P071`L01`<01@L404D700161`<010L400P7
0`0K1`@04PL40147100M1`<01PL400H70`151`00A`L00`071`041`<01`L401`70`0A1`D04PL301`7
10071`<01`L00`071`141`00<PL300/70`0;1`<020L301d700<01`L04@L401<700<01`L070L300P7
0`0:1`<02`L30387000a1`@02PL400X710091`0300L701<70`0K1`806`L301H700<01`L01PL500P7
100:1`@0<PL003870`081`H01`L700041`0000D70`0:1`<01@L400041`0003071`071`<02@L300D7
0`021`H01`L300041`0000L70`0b1`00<`L00`071`061`@000<700L00`L:00031`00008010L400T7
10061`L0;`L400041`0000H710081`@010L500872@041`0300L000<020L00`071`0a1`00?@L300D7
20000`L01`0500D70`091`@00`L300031`0700@0;`L4008700<01`000P031`@02@L300D710031`P0
1`L303`7000U1`<01`L300041`0000P700<01`002`021`H01@L300/70`021`@010L300d70`0A1`<0
30L300<710041`<02PL300D70`001@L0000700`00PL00`071`051`<00PL300H70`0U1`0090L400H7
20091`L000D700L700021`@000<700L010L400`700@01`L710051`0300L700/7100010L000081`<0
00<700000P0=1`0300L7008710051`0300L700P710061`0300L000<00PL00`071`0800T710000`L0
000200D7100U1`009@L300H7100010L0000:1`H020L300P70`0A1`<050L700<70`000`L000020087
0`0C1`<04@L300T70`071`H02PL800H70`0U1`009PL00`071`061`<00PL00`071`061`<000D700L7
00051`@000<700L01@L300031`07018700<01`L050L00`071`03008710021`<00`L00`071`0C1`03
00L7014700<01`L00`061`0300L000801@L010071`021`<01`L00`071`0300P700<01`L090L00307
00<01`L02@L400041`0000D71@071`@08PL300/700<01`L00PL300<700<01`L02@L3028710071`@0
1PL300031`0000802`L00`071`0^1`00?@L700H710081`<08@L4014700<01`L03@L402<70`081`<0
1@L400870`0l1`00:`L3010700<01`L00`071`8020L302<70`0R1`<090L300P700<01`L01@L300<7
00<01`L03@L302/7000Z1`@050L00`071`0?1`@090L00`071`0R1`0300L70287100A1`0300L70147
100[1`0090L300031`0000@05PL300L70`000`L0000402070`0>1`<01PL300h70`0Q1`D000@70000
1`L301H71P021`<08`L002<720000`L01`0E1`@01PL800031`0701@70`081`@00PL300D71`051`@0
0PL300@70`000`L0000200X70`0E1`P01PL401L71@000`L0000202<7000S1`@000@700006@L300L7
0`001@L0000700<04PL400T70`000`L0000200@720051`@000<700000P031`@00PL300T7100B1`<0
00D700001`0300L70`0I1`P08`L002471P021`0300L701T700<01`L01P000`L01`021`0300L000<0
2@L300L70`0010L000061`0400L71`<01@L300041`0000H70`021`<010L300<700<01`L010L30087
0`061`<020L500031`07008700<01`L01P000`L01`0J1`0300L700H08@L002071P0:1`<02@L300P7
1`061`D020L400P700<01`000`0;1`0300L700D700D01`L700081`0300L7008700<01`L010L00`07
1`081`@00`L00`071`041`@02@L400L71`091`<02@L300T71@0Q1`008@L400X710081`@02@L600L7
10091`<02`L303P70`0;1`<02PL300P71P081`@020L400T71@0Q1`008PL300/71P021`<000@70000
2PL010071`091`801`L300031`0700P70`000`L01`0A1`<040L3018700<01`L00`081`0300L00080
20L00`071`081`0400L700X71P021`<000@700002PL30287000J1`<01PL300/71@000`L000020087
00<01`L07PL400X7100C1`@00PL300H70`000`L0000201@710091`@08PL500031`0000800PL00`07
1`091`<01@L301X7000I1`@01@L400d70`021`<090L300/70`0>1`<00`L300031`0000801@L40087
0`031`<03`L300X70`0T1`<00PL300d710041`D06@L001T710061`<03PL00`071`021`0300L702@7
00<01`L02`L00`071`0<1`@010L010071`L300H70`031`0400L71`@040L00`071`0:1`0300L702@7
00<01`L00PL00`071`0=1`<01@L401T7000J1`<01`L00`071`1@1`<010L300T700<01`L01PL00`07
1`071`<01@L3058700<01`L01@L301T7000K1`0300L700@70`0;1`<0:@L300P70`0<1`@01@L00`07
1`0L1`0300L700<7100=1`<020L302T70`0:1`<01`L00`071`0H1`008@L400X7100S1`<00PL400<7
0`000`L0000200H70`041`<0:`L300<70`061`@000@700000`L400870`0S1`@02@L40287000R1`<0
2PL400H70`0I1`@00`L300871@0010L000051`@01@L00`071`0B1`@05@L010071`L400L71`041`<0
00<700000P0K1`<010L500X70`0R1`008`L00`071`021`<01@L300D710081`<03`L300@700<01`L0
0PL4008700<01`000P031`<01@L400T70`000`L0000600041`0000870`081`D010L300<70`021`H0
1@L010071`L301070`071`@01@L300D70`041`0300L70247000W1`@01PL00`071`051`<01`L400/7
0`021`0300L700T70`031`@010L00`071`031`D020L800031`0000H000<700000P071`H01@L01007
1`L400@70`0;1`0300L700<02`L400P70`061`0300L700<7100X1`007@L300P70`0?1`0300L700H7
100:1`@03`L00`071`031`<02`L400T70`0010L000021`800PL300870`081`D02PL300D700<01`L0
30L400X71@091`0300L700`70`081`<07@L001`71@081`0300L000802@L300X70`0;1`<05PL00`07
1`0;1`801PL3008700H01`L700L600031`0700<700<01`000P061`0300L000`700<01`L050L300/7
0`0:1`<02@L300031`0700L7100M1`007@L400T710081`@02`L00`071`0;1`0300L700D70`0R1`@0
1`L700L7100T1`<01PL00`071`0;1`0300L700P710081`@02PL401d7000N1`<02PL300H71P0P1`D0
20L301L70`081`H020L301P70`081`@080L600H70`0;1`<07@L001l700<01`L02PL00`071`041`@0
00<700L08@L400L7100H1`0300L700P700@01`L02PL00`071`0F1`@01`L502471@071`0300L700/7
00<01`L070L001X70`000`L0000200`70`031`<03@L301470`0010L000081`<010L3014710081`<0
20L301470`051`<020L601470`0=1`<010L300`70`021`<06@L001T72@0;1`@010L00`071`0;1`@0
40L4008700<01`L020L00`071`021`@00PL300/71@071`@01`L400`70`000`L0000200H700<01`L0
20L50107100>1`0300L70087100;1`@000<700000P0I1`006PL300031`00008030L300l71`071`<0
1`L301<70`000`L0000200`710081`<020L300/710021`<04`L300P70`051`@000@7000040L300`7
0`021`<06@L001/700@01`L70P0>1`0300L700d7100010L000061`@020L00`071`041`<020L30003
1`0700870`0=1`802PL00`071`081`0300L700/70`031`0300L000802@L300D700<01`L01PL400H7
1`0A1`0300L700`700<01`L00PL00`071`0H1`00;0L301470`021`0300L700H70`0>1`@010L700H7
0`0:1`<020L600P70`0:1`<01@L400870`031`@03`L300L700<01`L00`0A1`<0;0L002/7100B1`03
00L700/700<01`L00`051`<00`L300<7100010L000051`@02@L400L71`071`@02@L400H70`000`L0
000300<70`021`<01@L300<700<01`L02PL00`071`0?1`@0;0L002`70`0R1`@010L400@700@01`L7
1@021`0300L700@7100:1`<020L600P70`091`@01`L00`071`0500@700<01`L010041`@08`L302`7
000]1`0300L700l7100;1`<000@700001@L300T71`071`<000@700001`L00`071`081`0400L700X7
00<01`L01PL600L70`000`L0000200P70`051`<00PL300X7100A1`0300L702/7000>1`<04`L30187
0`021`D02PL4008700<01`L01@L00`071`051`<000<7000010081`0300L000<00PL300h70`0=1`<0
0PL400031`0700H710021`D01`L00`071`051`0300L700@02@L500@70`0A1`<04`L300h7000=1`@0
4PL4014710031`@02`L3014710021`D02`L300031`0000803@L400`710031`<02PL500031`000080
4`L300X710031`@040L40187100>1`003PL300h70`021`<04@L400@70P0=1`0300L700D70`091`<0
00<700000`0=1`0400L71`<03PL300d70`041`0300L700X710021`<02PL300L700<01`L02PL200<7
1@0A1`<00`L300d70`0>1`003`L00`071`0<1`@00`L00`071`0A1`<06PL400H70`000`L01`021`H0
40L00`071`0<1`@03PL00`071`0?1`D00`L00`071`0300D7100J1`<04`L010071`L400h700<01`L0
3@L001l71P0010L0000A1`0300L701X70`051`@01PL502070`0O1`D01PL400H70`0K1`0300L700l7
0`001@L0000700<07PL001h72`021`<0:PL00`071`051`<020L3024700<01`L07`L300P70`071`03
00L702L70`000`L0000600870`0M1`007@L400051`0000L00`000`L0000201/70`0E1`0300L700P7
00<01`L00`0k1`<00PL00`071`081`0300L701<70`0I1`@00PL300051`0000L0100M1`007PL30087
0`000`L01`021`<05PL300031`0000801PL300X70`0;1`D0>PL600X70`0:1`<01PL400041`0001H7
0`031`0300L000800`L301d7000O1`0300L700@01PL00`071`03014710021`<01@L400T7100:1`H0
4`L700H7100010L0000C1`D02@L400T710071`L04PL3008700<01`L00`L400@700<01`L070L002<7
0`081`@04PL300<700<01`L01@L300X70`0;1`@04`L800D72@0D1`@02PL300X70`081`0300L700<0
4@L400T70`0S1`004@L3010700<01`L020L301<700<01`L00`081`0300L000<01`L00`07000200T7
00<01`000P0B1`L01PL400041`0001470`021`0300L700H71@071`@000<700L020L300031`070187
0`0:1`0300L700l70`0@1`0040L400h70`0;1`<050L400T71@081`@02PL500P70`071`0300L70080
20L200<700<01`L010L300P7100:1`D01`L500X7100E1`<02PL300h7100@1`004@L300<70`0010L0
00031`@02PL401D70`0:1`@02@L300/710071`@07`L400P7100;1`@020L400/70`0D1`@02@L400@7
0`0010L000041`<040L0018700@01`L720041`D000@700001@L301H700<01`L00PL300D70P0;1`03
00L700/70`041`L080L300041`0000D70`0<1`802PL200D70`051`0300L701@70`041`<00PL400<7
20051`0300L700l7000G1`L01@L800H700<01`L02PL300`7100C1`<02`L00`071`021`D000<700L0
8@L00`07000300H700<01`L02@L30147100>1`<030L00`071`021`@000<700000P051`L05`L001P7
00<01`000P061`@000@700000`L300`7100=1`<04PL40147100=1`<01PL300h70`0A1`@04PL300d7
100<1`<00`L3008710051`<000<700L05`L001T710051`@00`L010071`L400d70`0>1`0300L70187
0`0B1`803@L400D7100?1`0300L701470`0C1`0300L700d70`0;1`@010L010071`L400@7100J1`00
2@L300h70`051`L01@L300h700<01`L08`L00`071`0Q1`<01PL302@700<01`L08`L00`071`0;1`<0
1@L300041`0000D70`0>1`<02@L000P7100?1`0300L700<720061`@04`L3044700<01`L01PL00`07
1`101`<04`L300D720061`0300L700`710091`002@L301D7100010L000061`@02PL300D7100010L0
000E1`<02`L400P70`0Q1`<020L300/70`0E1`<000<700000P061`<02@L400H71`0F1`<02@L000X7
00<01`L04PL6008700<01`L01PL300T710061`L02@L300P7100:1`D01`L4020710071`@02PL400T7
0`081`@00PL300D7100:1`<01`L00`071`0601@700<01`L020L001T70`021`@000<700L00`071`<0
00@700001`L300<70`0010L01`L300P71`061`<020L700P70`051`@000@700001PL3008710051`<0
20L600P70`061`H02@L300<710041`<01PL300870`061`<000<700000`041`<060L001P710031`<0
0PL400H720081`0400L71`D010L00`071`041`<000<700001@0010L000021`0300L700H710000`L0
000:1`0300L700<72@051`@000<700000`061`0300L700P71@091`0400L71`X000@700001PL00`07
1`021`@01@L00`071`041`@000<700000P051`@00`L300<7100H1`006@L300@700@01`L710071`L0
3@L400X710021`0300L000L030L301@7100010L000061`<00PL401<70`0<1`P000<700L0100:1`D0
30L400870`051`@010L00`071`031`<060L001X700@01`L70`041`<00`L3008700<01`L00`071`<0
10L300<70`051`<01@L300041`0000d700<01`L010L300P70`021`800`L00`071`061`0300L70087
0P0010L000081`<01PL00`071`0<1`<000@7000010L300D70`031`<01@L300H70`031`0300L00080
0`L300D70`031`0300L701L7000G1`<000<7000010051`0400L71`@01PL00`071`051`@01@L01007
1`L400H700<01`L01@L01@071`L001@710071`@05`L400L7100F1`0500L71`001PL00`071`031`@0
10L00`071`031`@01`L00`071`031`@010L00`071`031`H000@700005`L001H72`0:1`<03`L300X7
0`041`<08@L300P70`0H1`<020L302870`031`<02`L300h70`0;1`T05`L001L70`001PL0000700`7
00<01`L03`L00`071`0:1`0300L70087100R1`0300L700P700<01`L060L00`071`081`0300L70207
10041`0300L700/700<01`L03PL00`071`0;1`@000@700005`L001P700D01`L700021`<020L302@7
0`0j1`<0>PL302<70`091`<000<700L00PL00`071`0F1`007PL400870`021`@030L301870`000`L0
1`0D1`<03@L30187100B1`<03PL301D7100B1`<02`L400@70`000`L0000201h7000=1`<02PL30087
0`000`L0000200031`0000<02`L400@70`0:1`D000@700004@L400`7100C1`<04@L400d7100B1`P0
2PL300<7100<1`D000<700000P021`<000@700002PL300d7000<1`@02@L400<700@01`L7200=1`<0
0`L500T72@0B1`<03@L301@700<01`L04@L300h70`0A1`T02@L400@70`0=1`@00PL300<700<01`00
0`091`@03@L000d70`0:1`<020L00`071`0300l700<01`L00`L400@70`031`@000<700000`0?1`<0
2PL400031`0700D70`0H1`<01PL00`07000300/70`0>1`H000<700000P031`<00PL500D700<01`L0
3@L300<700<01`L01@L300X70`0=1`003PL00`071`0300L700<01`L02`L00`071`0;1`<01`L300<7
10041`8000<7000010021`<02@L400T71@071`@05`L400L71@0:1`@02@L300031`0000D00PL200<7
10031`<01`L300d700<01`L02`L00`071`051`@000<700L03@L00107100R1`@020L00`071`031`<0
1PL700031`0000802@L400T71@081`<060L300P7100:1`@020L400871P081`<010L00`071`051`@0
8PL50107000A1`<08`L300H70`061`0300L700870`001PL0000700<70`000`L0000200D70`031`<0
10L300X700<01`L060L00`071`081`<01@L300<70`041`T00PL00`07000200870`041`0300L700<7
0`061`<08`L40107000=1`@000<700L090L00`071`041`@02PL4008700<01`L00`L900H700@01`L7
10051`0300L7030700<01`L00`L400@700<01`L00PL:00D700<01`L010091`@01`L00`071`0S1`H0
3@L000`71@0_1`<000@700001`L300T70`000`L0000200/70`031`<0<PL300@70`0:1`D000@70000
2@L300H70`0010L0000^1`D03@L000d7100>1`<07`L00`07000300P700<01`L02@L010071`L200d7
00@01`L7100H1`<05PL400D700<01`L02PL00`0700031`0300L700T700<01`L010L4008700<01`L0
7PL300d7100=1`003PL200h7100R1`<01@L302@70`0G1`@05`L302@70`051`<08PL400h70P0>1`00
7`L302<700<01`L00`L402D700<01`L03`L300051`0000L01P0010L0000A1`0300L7028710061`03
00L702870`0N1`001PL301D70`0:1`@07@L303H720021`T0=`L301d70`0<1`0300L701@710051`00
1@L401@710091`D03PL300d700<01`L050L301l70`0010L000041`<000@7000080L301D700<01`L0
2`L300d71@0;1`<04`L500D700061`<01@L300d70`0:1`@02PL700@70`081`L03@L400<70`0;1`<0
30L01@071`L000870`000`L01`021`0300L701h7100>1`<000@700001`L300<710021`<02@L400X7
100<1`<01@L400D700071`0300L700<710041`<000@700000`L00`071`0:1`802PL400041`0000<7
10071`P030L50087100:1`@02PL300051`0000L0100010L000021`<02PL300X70`031`@03@L800H7
10041`<000<700000P0:1`<02`L300051`0000L00`031`@01PL200H7000>1`<00`L801d70`021`03
00L700<70`081`L03@L300@70`0;1`<02@L800871`000`L0000200T710091`@010L300h70`0010L0
00071`<01@L010071`L300/700<01`L02`L00`07000700@70`0>1`003@L300D70`0010L0000N1`03
00L000801PL00`071`081`0300L7008000@700002@L300H700<01`L00PL300H700<01`L02@L30004
1`0000<700<01`L00`021`<02PL300@70`031`<01@L300T70`021`0500L71`002@L00`071`051`<0
00<700L070L300041`0000D7100<1`0030L400H700D01`L700071`<02`L300P7100F1`@020L400X7
100>1`<00PL01P071`L01`H000<700L00`L00`07000200P700<01`L00PL400@700<01`L00`L400P7
100G1`@020L400X70`071`0500L71`001PL400`7000=1`<04@L400X710091`<05`L300T70`0;1`<0
3@L400870`000`L0000800051`0000L0100>1`<02`L300T70`0H1`<01`L500T7100C1`<030L000T7
10000`L01`0B1`<02`L300X700<01`L05`L00`071`091`0300L700/700<01`L03@L300031`000140
0PL300l700<01`L02`L00`071`091`0300L701P700<01`L01`L400X70`0D1`0300L000802@L000P7
1@0F1`0300L700/700<01`L05@L302<70`0@1`0400L71`<000<700000P021`@000@700000`L00`07
1`0?1`<08`L301H70P0<1`0300L701@710091`002@L400d70`061`<020L301<70`000`L0000200`7
0`0C1`@04@L300031`0700<01PL300041`071`<040L401<70`0<1`@000@7000050L300P70`051`@0
3@L300T7000:1`<030L400D710071`@04PL400031`0000802`L401871@0@1`@00PL400D710031`@0
40L40187100<1`P04`L400L710041`D03@L300T700091`@03@L300H70`081`<04`L300870`0<1`<0
4`L401472P041`L000@700004@L301<70`0=1`<000@7000050L300P70`051`@030L400T700081`D0
3PL00`071`061`0300L700P7100B1`0300L7008700<01`L030L00`071`0C1`804`L900<720021`03
00L7014700<01`L04`L00`071`0=1`0500L71`004PL300031`0700T700<01`L01@L200d710091`00
2@L300041`0001870`0:1`@020L302@70`0;1`<03PL300870`000`L0000800041`0000870`0>1`<0
2`L302@70`071`D02PL301<71P091`002PL00`0700030147100:1`@01`L401P70`081`@02PL400d7
10031`0400L71`P00`L00`071`0400d7100:1`@02@L301L710081`@02@L4018710000`L01`091`00
3@L300D70`0010L000061`<02`L300P70`0G1`@02@L300/70`0>1`<000D700001`0<00871P0>1`<0
2`L300P7100H1`<02@L300X70`061`<00PL300D70`0<1`003PL00`071`031`P01`L00`071`0;1`03
00L700P700<01`L01@L300L70`000`L0000500X700<01`L010L300@700<01`L010L300L700<01`00
1`0010L01`L500031`00008000<700L01`L300D700<01`L00PL300H700<01`L020L300051`0000L0
0`071`<01`L00`071`091`0300L700X700<01`L010L400031`0000801PL00`071`0;1`003PL300@7
0`0010L0000M1`<00PL3008710061`T000<700L02PL40087100:1`@02PL300041`0000870`0010L0
00021`<02@L400T710041`<02`L00`07000700H710041`<00PL301`70`021`<00`L300h700061`<0
10L400D700D01`L700031`<02PL400T710000`L0000200<70`071`<000<700000P0<1`D00`L300/7
0`0;1`0500L71`000PL4008700<01`L00PL00`071`091`<02PL300<7100>1`<000@700001`L300<7
10000`L0000200T7100;1`<00PL00`071`021`0400L71`@01PL300D700051`@01@L300`710091`D0
2PL300870`041`0300L700L700@01`L70P0>1`@010L00`071`0;1`0300L700X70`001@L0000700H0
00@700003@L00`071`0:1`0300L700<70`0?1`0500L71`002@L00`071`031`<00PL300P71@0:1`@0
30L300D710051`001PL300H700<01`L030L300X7100;1`0300L7008700<01`L02`L301@70P0O1`P0
0PL9024700<01`L04`L300d700<01`L00PL00`071`081`@02`L300d700<01`L01@L300D700071`03
00L701D700<01`L02PL201h7100f1`<000@7000010L300041`0003H7100N1`803@L00`071`0E1`03
00L700@7000O1`<08PL300H70`0S1`<04@L01@071`L000870`000`L01`021`0300L700l70`0T1`<0
1@L302<70`0N1`003PL300d7100Q1`@01`L00`071`0Q1`@05`L401H7100U1`0300L700<7100R1`@0
3@L300h7000=1`@03PL301h70`0010L000071`<02@L300031`0000802`L300<70`0H1`<05`L300@7
0`0:1`D000@700002@L300H70`0010L0000O1`<030L500d7000<1`D03`L00`071`0L1`@00PL00`07
1`051`@020L900X710041`0300L701P700<01`L05`L00`071`021`@02@L:00P710071`0300L000<0
80L00`071`0<1`@03@L000d70`0010L0000S1`<01PL300/70`091`<000<700000P051`<00`L300@7
0`0`1`<01@L300<70`041`D000@700002@L300X70`061`<08`L700d7000>1`0300L000<08PL400L7
00<01`L010L300@700<01`L01P021`<00PL200D710041`0300L700871@081`<060L300P710061`04
00L71`@01@L0100700L300871P031`0300L700870`051`0300L700@7100R1`D000<700L03@L00147
0`0S1`<01`L300<710061`L000<700000P091`@02@L500L7100G1`@01`L500X710081`@000<70000
1@071`@00`L300L70`0S1`@040L0018700<01`L08`L00`071`051`@010L300<70`000`L000040087
0`0:1`<02PL400P70`0H1`<020L400/70`091`<00PL600031`0000800`L300871@071`0300L702<7
0P0A1`003@L300X70`071`<000@700003PL300<71@051`0400L71`@000<700000`041`0300L700X7
0`0:1`8000@700001PL00`071`0H1`0300L700@70`000`L0000:1`@02`L00`071`021`X010L00`07
1`021`@010L300h70`021`<01PL300X70`0=1`0030L400T710061`P03@L400@70`0:1`@00PL30147
100<1`@09`L400`7100C1`P02PL300<7100=1`@000<700000P051`@02@L400d7000=1`<02PL30087
0`021`<000<700000`0<1`<01@L00`071`0:1`<00`L00`071`0A1`<03@L301<70`0B1`<03@L301@7
00<01`L00`0<1`0300L700<70`0<1`D00PL300870`0010L0000:1`<03@L000h700<01`L02PL00`07
1`0400<700@01`L7100=1`0300L7018700<01`000P0E1`0300L700d700<01`L04@L401<700<01`L0
3@L00`071`0D1`@050L00`071`0:1`D010L00`071`04008700<01`L02PL00`071`0<1`005`L30005
1`0000L00`081`<08`L403X70`0i1`@08`L300T71P021`<05PL001H720021`0300L700P700<01`L0
3`L300X70`041`<08@L300P70`0<1`0300L700T70`081`<08PL300<70`0;1`<040L00`071`091`D0
00<700000P0F1`005`L300031`0000@02PL300h710091`@01@L00`071`0O1`@01`L401L710071`@0
8`L010071`L400X7100>1`<02`L500870`0F1`0060L010071`L500T7100?1`<010L300<70`051`<0
1@L300041`0001@70`081`<060L300P70`0E1`<000@7000030L300/70`0=1`@02PL500@700<01`L0
5@L001T70`021`<010L300<70`001@L0000700<020L00`071`021`@010L00`071`031`@010L800`7
0`061`0300L700P700<01`L0100010L000061`<00PL400031`0700T700<01`L010L300`720041`<0
1PL00`071`021`@01@L00`071`051`<00PL600<70`051`<00PL301P7000H1`@00`L00`071`021`@0
10L00`07000700`71@0;1`<00`L500041`0000/7100C1`T01@L400031`0000<04PL400d71`031`@0
2PL500`710000`L0000200031`07008710061`0300L700@060L001T70`031`<00`L300L70`0010L0
000=1`<03@L00`071`0600<700<01`L00`081`L020L300D7100010L000061`<00PL400@70`091`H0
20L300<700<01`L01P0010L0000;1`@03@L300870`061`<00`L300@70`0H1`006PL010071`L70003
1`0700P70`000`L01`071`<010L00`071`031`<020L400031`0700D710091`H01`L400H70P031`03
00L700H700<01`L00PL200@710081`@000<700L01`L400L71@021`0300L700@70`041`801@L300L7
00<01`L00`081`0300L000D01@L00`071`0G1`007`L600041`0000H710091`@01PL700T70`091`<0
2`L400P70`0P1`<02@L300/70`091`<020L400870`051`@02@L400H72P0O1`002@L301@72@071`<0
2PL300D7100010L0000:1`0300L700T700<01`L02`L200X700<01`L080L00`071`091`0300L700/7
00<01`L02@L00`071`081`<000<700000P061`<02PL300D720000`L01`0C1`<02@L000P7100F1`<0
00@7000020L00`071`0:1`0300L700D70`021`0300L708@700@01`L70`071`0300L700X700<01`L0
1@L300041`0001D710091`002@L300h70`061`<000<700L01@L300`70`071`0300L701X70`0R1`<0
1PL302<70`0L1`0300L700@70`0<1`<01PL00`071`0300D70`0>1`<02@L000X700<01`L030L400D7
1@0010L000021`@02`L400h70`0B1`@04@L300d710051`@03PL30147100B1`<03@L400/710031`<0
0PL400@7100?1`0300L700P7000G1`L01@L800<70`0<1`<03@L401<70`0@1`D03@L300H70`0=1`@0
4PL30147100>1`<030L3008710000`L0000300@7100010L0000F1`005PL800H71`041`0300L700`7
00<01`L03@L301@700<01`L02@L300@71`0;1`0300L700H700<01`L02PL600D70`0;1`0300L70147
0`0?1`0300L700`700@01`L710021`<010L901H7000A1`<00`L300041`0000@710021`<01@L301D7
0`041`0300L700<70`0:1`<02`L400D71P0P1`H01@L400/70`0:1`<01@L00`071`031`<05@L300@7
0`031`<010L300870`031`<040L0010710041`0500L71`0010L400@700<01`L00`L401@710091`D0
20L400X71@061`0300L000808@L400H7100:1`D020L400X7100D1`@01@L010071`L400D700<01`L0
0PL010071`L40107000A1`<03PL300/70`0E1`<02PL400P7100;1`<02PL00`071`051`<000@70000
1PL300870`071`0300L700L70`0;1`@01`L500/70`0E1`<02PL300l70`0@1`004PL00`071`0>1`03
00L700T70`0B1`<00PL00`071`061`<000@700001PL600P70`000`L01`0A1`P01@L9018700<01`L0
0`081`D01PL300041`0000T700<01`000P0B1`<02`L00`071`0?1`0300L700l7000S1`<020L40147
10021`<01@L4008700<01`L010L400031`0700L71P0C1`L01PL400041`0001<71@091`@01`L00`07
000300L71`0A1`@02@L302<7000N1`<000<700000P051`<000@700004PL300031`0000801PL300X7
0`0;1`D050L00`07000200P70`021`0300L701471P0:1`<02PL300H7100010L0000B1`<000@70000
10L400<70`0M1`007@L400031`0000D000<700000P021`0300L7018700@01`L70`071`0300L700X7
00<01`L02`L401L700<01`L020L00`071`0F1`@030L00`071`0:1`0300L700H70`021`0300L70187
00<01`000`021`L000<700000P0M1`007PL;00870`0L1`0300L702<700<01`L0>`L00`071`0;1`<0
5@L00`071`0I1`<000<700001P021`<07@L001l700<01`L00`0010L000031`0300L703470`081`<0
@PL300P7100b1`0400L71`<000@700000`L00`071`0L1`007`L300031`07008700<01`L03`L301/7
0`051`@01@L602070`0N1`@000@700001@L300H70`0J1`<04@L01@071`L000870`0N1`003PL300d7
100F1`@06PL400H71P000`L0000501l7100O1`L000@700000PL00`071`041`@06@L501H7100=1`<0
3PL000d7100>1`<00PL30147100K1`<01`L500871@0;1`<00PL300d7100=1`<00`L300X72P0:1`<0
6PL401470`031`<030L400h7000>1`<03`L00`071`0401870`031`@02`L300L700<01`L020L300<7
100:1`@000<700000P0>1`<030L4008710091`@000@700L70`0;1`0300L700D70`0:1`@010L30107
10041`0300L700`70`0>1`003`L00`071`0B1`<04`L010071`L500X7100C1`0300L700H01`L30004
1`0000870`0?1`0300L700`70`031`H01`L300061`0000L04`L400T71@051`0300L701070`0D1`03
00L700d7000U1`0300L700@70`0@1`@02`L300041`0000D70`091`@000<700L01PL4008700<01`L0
0PL00`071`0300P71P081`<00PL00`071`031`D020L00`07000300T70`051`<00PL300X7100@1`<0
1PL00`071`0S1`00:`L401470P0=1`0300L000<010L400P71@091`@02@L400L71`071`@02@L400X7
10081`@010L400<700<01`L02PL20107100/1`00;0L301470`0;1`<000@700001@L300<70`031`@0
00@700001PL300X70`081`H020L300X70`061`<00PL300@70`021`<01@L300870`0:1`<04@L302`7
000]1`0300L700l7100010L000061`@00PL00`071`051`0400L71`@010L200031`0000801@L300`7
00<01`L020L010071`0:1`0300L700X700<01`L010L400<700<01`L00PL400<700<01`L01@L00`07
1`0400H71`0B1`0300L702/7000J1`<04@L300l71`071`<01`L300D70`081`H000<700000P0=1`<0
4`L300`70`021`H02@L300@70`081`<01@L400041`0001070`0A1`<06@L001T710000`L0000200/7
100@1`0300L000<020L00`071`051`@01PL00`071`081`D00PL300`710081`<01`L400/710000`L0
000200031`0700X700<01`L00PL400T700<01`L010L4008700<01`L03PL400`70`000`L0000201T7
000J1`P030L300<70`0=1`<04@L301<70`031`0300L700X71@071`@01`L400`70`021`<04`L30147
0`0=1`<010L300/710021`<06@L001/700<01`L0100=1`0400L71`@03PL00`071`0A1`0300L700<0
20L300D700<01`L040L300T70`081`<03@L00`071`021`0300L700@70`081`<000<700L04PL00`07
1`0;1`@01@L00`071`0;1`<00`L00`071`0H1`007`L201<71P0Q1`@01`L401L70`081`H020L301L7
10071`D080L601@700<01`L07@L001d7100:1`<01`L502071@081`<05PL400L71`071`@060L300P7
100O1`@000<700L01PL300/70`0M1`0070L500T710091`<08@L300X700<01`L05PL300P71P081`<0
6@L00`071`081`<080L300P7100:1`@07@L001d7100:1`<02PL00`071`091`<02`L300L700<01`L0
2`L300/70`071`0300L700<000H700001`021`0300L000800PL300031`0700L70`0:1`<03PL00`07
1`041`<02`L400X700<01`L020L300/70`0M1`007PL200P70`000`L01`0;1`<01`L400X7100>1`<0
0`L400X71@081`P00PL700031`0000802@L400T710041`<03@L400X71@081`<02`L00`07000200T7
00<01`L070L002L710051`<01@L400P70`0;1`<000@700002@L400@70`031`<01@L400T70`001@L0
000700@000@700000PL300P71@041`<00`L300<71@091`<000@700002`L400L710051`<010L402P7
000R1`<00`L300@710061`<02@L00`071`0;1`0300L000<020L500D700@01`L710061`<02PL01P07
1`L01`D00PL00`071`021`0300L700P70`041`@010L00`071`031`@020L4008700<01`L02`L200T7
0`041`D010L300<70`0R1`008@L400@700<01`L00`L400L700<01`L06@L300<70`031`<00PL300H7
0`071`0300L70107100C1`0300L700@70`071`<000@7000010L300870`0L1`0300L700@710051`04
00L71`@08PL002870`0;1`<090L010071`L400@700<01`L010071`0300L700<70`0D1`8050L300D7
00<01`L01@L4008700<01`L00PL400<700<01`L08`L300X70`0R1`008`L00`071`0;1`0300L702P7
0`081`<030L402T7100>1`<020L302X700<01`L02PL00`071`0Q1`006PL300H70`0g1`0300L700P7
00<01`L030L300@70`081`<01PL300T70`031`<03`L00`071`081`0300L703D70`051`<06PL001T7
10051`@04`L302<70`0;1`<020L00`071`021`@01`L400D710081`@010L00`071`071`<02PL302@7
0`0B1`@010L401X7000J1`<01PL300d70`021`@08PL400X7100>1`<00`L300870`061`<00PL300@7
0`0=1`@02@L402<710021`<03PL300D70`0J1`006`L00`071`061`0300L700/710031`<08`L300/7
0`0?1`0400L71`@00`L00`071`061`0300L700@01@L00`071`0=1`<02PL302@70`000`L0000200l7
00<01`L01@L00`071`0I1`008@L400/71P041`@02PL300X70`081`0300L000802@L00`0700020147
0`0@1`<04@L3008700<01`L01PL300031`0700L70`0;1`<02@L300031`0700870`0010L0000:1`@0
8@L002071@0:1`@000<700L010L400T71`061`D020L400X7100B1`0300L7010700<01`L03`L400X7
10091`@020L600P710061`0300L000<02@L50247000Q1`@02`L300P70`0:1`H01`L400T70`071`<0
00@700004PL300041`0000H70`021`<04@L300870`061`<020L500L71`091`<02@L300X7100Q1`00
8PL500041`0000H700<01`L020L00`071`051`<00PL00`07000500051`0000L00`0:1`0300L700D7
10021`0300L700@70`021`<010L800D710000`L0000200@70`021`<01PL00`071`0400L700<01`L0
20L700051`0000L00`000`L01`0300L700<01`L02@L00`071`031`<000<700000`0R1`008`L801P7
10051`T00PL00`071`0B1`<020L400031`0000801@L300041`0000H70`021`<00`L400031`000080
2PL301<72P021`0400L71`@060L902<7000T1`<000<70000100F1`<01`L300031`0000@05@L00`07
1`081`<00PL300H700<01`000`051`@00`L00`071`031`<00PL300/700<01`L04`L500041`0000L7
0`0F1`H000<700000P0S1`009@L010071`L501L700<01`L01`L010071`L5024700<01`L00PL00`07
1`081`<01PL300X700<01`L00PL00`071`0O1`D00`L00`071`071`0300L701@710000`L01`021`80
90L002/70`0W1`<08`L300`700<01`L01PL00`071`0:1`<090L302H70`0[1`00;0L00`071`0>1`<0
00@700001PL300T700<01`L08@L40247100U1`0300L700H70`061`<00PL300l700<01`L0:PL003`7
20051`D020L302870`0@1`<03`L302<70`071`@01@L400031`000080?0L003d70`0010L000061`@0
1`L402<700<01`L03PL4010700<01`L08@L400L710061`<00PL303`7000U1`<01`L300041`0000P7
00@01`L710051`<020L601470`0D1`<000@700000`L300870`021`<04`L301470`0010L000081`<0
10L400@700<01`L01@L300031`0000801PL302D7000T1`@01PL800X71P061`0300L000801PL50107
100C1`P010L00`071`0400031`0000804PL4010710021`0300L700@70`000`L01`031`L02@L900D7
100U1`009@L300L70`0010L000091`L010L700P70`0@1`@050L300041`0000P70`021`<04PL40147
0`081`@000@700000`L600X70`000`L0000200H70`0U1`009PL00`071`071`0500L71`0020L60003
1`0700L000D700001`0300D70`0:1`<00`L300@70`0>1`0500L71`002PL00`071`021`0300L700/7
0`041`<010L300T70`051`@000<7000020000`L01`0300041`0000L700@01`L70P081`0300L702@7
000l1`@000<700L00PL8008700<01`000`041`@02@L400@700<01`001P0_1`@000H700001`041`@0
20L400@71@021`T010L00`07000303`7000b1`<020L600<70`000`L0000500041`0000D70`0:1`<0
1@L400041`0003071`071`<02@L300D710000`L0000400041`0000<70`0010L000071`<0<PL00347
10091`D010L010071`L6008700<01`L01@L00`071`0:1`0300L700D70`021`0300L7030700<01`L0
0`081`0300L700T700<01`L01@L200031`0000@00`L010071`L4008700<01`L01@L40387000b1`<0
2`L300T71@081`<05@L00`071`0h1`0300L701@70`081`@02@L300/70`0b1`00<`L00`071`0;1`03
00L700T710071`@070L30187100B1`<070L400L7100;1`0300L700/700<01`L0<@L004d710081`<0
6`L401471@0A1`@07@L300H7101>1`00APL300D70`091`0300L701X7100B1`@04@L401h700<01`L0
1PL300H70`151`00A@L600@700<01`000P0010L0000P1`<04`L201<70`0P1`<000H700001`051`D0
A@L004D71P051`P08@L00`071`0@1`H04PL00`071`0N1`P01PL604D700161`D01PL300041`0003<7
1`0d1`<000@700001`L404H700141`@000<700L01`L300031`0700L70`071`<000@700005@L30003
1`0000X00PL301D70`0010L000061`<020L00`07000200T71@141`00@`L400L71`091`@01PL801@7
200010L01`L500031`00008050L800D710091`@00PL300D710141`00A0L300H710001@L0000700<0
1PL600@70`000`L0000400l71P0010L000061`<00PL500l70`001@L0000700<00`L600H70`001@L0
000700@01PL304@700151`0300L700H70`021`0300L000<01`L500D700@01`L71@0>1`@000<700L0
0PL00`071`061`0300L70087100>1`@00PL01@071`L000<710000`L01`051`@00PL010071`L300L7
00<01`L0@`L003L70`0E1`0300L000800PL300T70`0;1`<03`L301@70`0?1`<02`L300T70`031`<0
00<700L050L303H7000f1`@01`L300`710031`0300L700T700<01`L02`L00`071`0?1`0300L701@7
00<01`L03`L00`071`0;1`0300L700T700@01`L7100=1`<01PL403H7000g1`<01PL400d70`0]1`<0
5PL302h70`0<1`@01`L303H7000h1`0300L700H70`0>1`0300L700h70`0J1`@01@L300870`0010L0
00041`@06`L3014700<01`L030L300P700<01`L0=@L0048700<01`L07@L400@70`071`<000@70000
1PL300@710000`L0000600D70`071`<000@700001PL300<7100Q1`0300L703l7001S1`<00`L400H7
20071`0300L700@70`021`<000@700001PL00`071`051`P01@L500<70`1S1`00I0L00`071`021`@0
1`L300041`0000l700<01`L00PL01@071`L001070`0010L000061`@010L00`071`1R1`00JPL300P7
00D01`L700071`<01`L800L70`081`0500L71`0020L306T7001F1`@020L300H700<01`L00PL300d7
10061`T01PL400h70`051`0300L700<70`091`<0EPL005D71@071`@02PL400h70`001@L0000700`0
0PL600d7100:1`@020L405H700141`<02`L300031`00008020L300/70`0?1`0300L000T00PL50003
1`00008000<700L03PL300/70`091`<000@700002`L304@700131`@02PL4008710081`0300L700P7
100<1`<00PL500041`0000H70`021`D000@7000030L400X700<01`L01PL400031`0000802PL404@7
00141`<02`L30087100B1`@030L400031`0000<00`L00`071`061`0300L70087200<1`@04PL50087
0`0;1`<0A0L004D700<01`L02`L010071`L400@70`0<1`<03@L300870`0C1`<000@700003@L300d7
0`031`@00`L00`071`0;1`0300L704<7001H1`<00`L400d700<01`L03@L00`071`021`0300L701<7
00D01`L7000?1`0300L700/710041`<0E`L005T700<01`L00`L301l70`0010L000041`H010L30004
1`0002070`051`0300L705H7001P1`0300L000806`L800<71`031`P07@L300031`0705h7001Q1`@0
70L300041`0000@71P041`<000@7000070L40647001R1`<02@L3014700D01`L700061`@01PL01@07
1`L001470`0:1`<0H@L006<700<01`L010L700L70`0D1`0300L7014710051`@000@700001`L00`07
1`1P1`00H`L300<7100010L000061`@04`L301471@061`L010L40687001J1`@010L400031`0000@0
0PL00`071`021`<000@700004PL401871`041`0300L700<000<700001@051`<0FPL005T71@051`L0
00<700L01PL4008700<01`L04PL301<71P081`0300L000L010L405X7001J1`@01PL00`071`0300X7
0`031`<04PL00`071`0?1`<00`L300/70`000`L000061`<0FPL005/70P0;1`0300L700X700@01`L7
100S1`@010L00`071`0;1`0300L700T700<01`L0F@L007X70`0T1`<0NPL007/700<01`L040L30147
00<01`L0N@L006d70`0M1`@07@L406`7001/1`@07PL301`71@1/1`00K@L301l700<01`L070L406`7
001^1`0300L703h70P1]1`00Q@L300h70`251`00Q0L400d710251`00Q@L300h70`251`00QPL00`07
1`0>1`0300L708@7003o1al7003o1al7003o1al7003o1al7003o1al70000\
\>"],
  ImageRangeCache->{{{0, 285.688}, {286.938, 0}} -> {-10.4013, -10.447, \
0.072819, 0.072819}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[129]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Partial effective lattices", "Text",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(averageTypeI\  = \ 
      ListPlot[SphericalCut[ALP, 10], Axes \[Rule] False, 
        Prolog \[Rule] PointSize[0.015], AspectRatio \[Rule] Automatic, 
        Frame \[Rule] \ False]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0483268 0.5 0.0483268 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.015 w
.12046 .2061 Mdot
.21712 .10945 Mdot
.02381 .43944 Mdot
.12046 .34279 Mdot
.21712 .24614 Mdot
.31377 .14948 Mdot
.41042 .05283 Mdot
.02381 .57613 Mdot
.12046 .47948 Mdot
.21712 .38283 Mdot
.31377 .28617 Mdot
.41042 .18952 Mdot
.50708 .09287 Mdot
.12046 .61617 Mdot
.21712 .51951 Mdot
.31377 .42286 Mdot
.41042 .32621 Mdot
.50708 .22955 Mdot
.60373 .1329 Mdot
.12046 .75286 Mdot
.21712 .6562 Mdot
.31377 .55955 Mdot
.41042 .4629 Mdot
.50708 .36624 Mdot
.60373 .26959 Mdot
.70038 .17294 Mdot
.21712 .79289 Mdot
.31377 .69624 Mdot
.41042 .59959 Mdot
.50708 .50293 Mdot
.60373 .40628 Mdot
.70038 .30962 Mdot
.79704 .21297 Mdot
.31377 .83293 Mdot
.41042 .73627 Mdot
.50708 .63962 Mdot
.60373 .54297 Mdot
.70038 .44631 Mdot
.79704 .34966 Mdot
.89369 .25301 Mdot
.41042 .87296 Mdot
.50708 .77631 Mdot
.60373 .67966 Mdot
.70038 .583 Mdot
.79704 .48635 Mdot
.89369 .38969 Mdot
.50708 .913 Mdot
.60373 .81634 Mdot
.70038 .71969 Mdot
.79704 .62304 Mdot
.89369 .52638 Mdot
.60373 .95303 Mdot
.70038 .85638 Mdot
.79704 .75973 Mdot
.89369 .66307 Mdot
.43944 .02381 Mdot
.57613 .02381 Mdot
.2061 .12046 Mdot
.34279 .12046 Mdot
.47948 .12046 Mdot
.61617 .12046 Mdot
.75286 .12046 Mdot
.10945 .21712 Mdot
.24614 .21712 Mdot
.38283 .21712 Mdot
.51951 .21712 Mdot
.6562 .21712 Mdot
.79289 .21712 Mdot
.14948 .31377 Mdot
.28617 .31377 Mdot
.42286 .31377 Mdot
.55955 .31377 Mdot
.69624 .31377 Mdot
.83293 .31377 Mdot
.05283 .41042 Mdot
.18952 .41042 Mdot
.32621 .41042 Mdot
.4629 .41042 Mdot
.59959 .41042 Mdot
.73627 .41042 Mdot
.87296 .41042 Mdot
.09287 .50708 Mdot
.22955 .50708 Mdot
.36624 .50708 Mdot
.50293 .50708 Mdot
.63962 .50708 Mdot
.77631 .50708 Mdot
.913 .50708 Mdot
.1329 .60373 Mdot
.26959 .60373 Mdot
.40628 .60373 Mdot
.54297 .60373 Mdot
.67966 .60373 Mdot
.81634 .60373 Mdot
.95303 .60373 Mdot
.17294 .70038 Mdot
.30962 .70038 Mdot
.44631 .70038 Mdot
.583 .70038 Mdot
.71969 .70038 Mdot
.85638 .70038 Mdot
.21297 .79704 Mdot
.34966 .79704 Mdot
.48635 .79704 Mdot
.62304 .79704 Mdot
.75973 .79704 Mdot
.25301 .89369 Mdot
.38969 .89369 Mdot
.52638 .89369 Mdot
.66307 .89369 Mdot
.73456 .10945 Mdot
.83121 .2061 Mdot
.92786 .30276 Mdot
.54125 .05283 Mdot
.6379 .14948 Mdot
.73456 .24614 Mdot
.83121 .34279 Mdot
.92786 .43944 Mdot
.4446 .09287 Mdot
.54125 .18952 Mdot
.6379 .28617 Mdot
.73456 .38283 Mdot
.83121 .47948 Mdot
.92786 .57613 Mdot
.34794 .1329 Mdot
.4446 .22955 Mdot
.54125 .32621 Mdot
.6379 .42286 Mdot
.73456 .51951 Mdot
.83121 .61617 Mdot
.92786 .71282 Mdot
.25129 .17294 Mdot
.34794 .26959 Mdot
.4446 .36624 Mdot
.54125 .4629 Mdot
.6379 .55955 Mdot
.73456 .6562 Mdot
.83121 .75286 Mdot
.15464 .21297 Mdot
.25129 .30962 Mdot
.34794 .40628 Mdot
.4446 .50293 Mdot
.54125 .59959 Mdot
.6379 .69624 Mdot
.73456 .79289 Mdot
.15464 .34966 Mdot
.25129 .44631 Mdot
.34794 .54297 Mdot
.4446 .63962 Mdot
.54125 .73627 Mdot
.6379 .83293 Mdot
.05798 .38969 Mdot
.15464 .48635 Mdot
.25129 .583 Mdot
.34794 .67966 Mdot
.4446 .77631 Mdot
.54125 .87296 Mdot
.05798 .52638 Mdot
.15464 .62304 Mdot
.25129 .71969 Mdot
.34794 .81634 Mdot
.4446 .913 Mdot
.05798 .66307 Mdot
.15464 .75973 Mdot
.25129 .85638 Mdot
.34794 .95303 Mdot
.7939 .12046 Mdot
.89055 .21712 Mdot
.56056 .02381 Mdot
.65721 .12046 Mdot
.75386 .21712 Mdot
.85052 .31377 Mdot
.94717 .41042 Mdot
.42387 .02381 Mdot
.52052 .12046 Mdot
.61717 .21712 Mdot
.71383 .31377 Mdot
.81048 .41042 Mdot
.90713 .50708 Mdot
.38383 .12046 Mdot
.48049 .21712 Mdot
.57714 .31377 Mdot
.67379 .41042 Mdot
.77045 .50708 Mdot
.8671 .60373 Mdot
.24714 .12046 Mdot
.3438 .21712 Mdot
.44045 .31377 Mdot
.5371 .41042 Mdot
.63376 .50708 Mdot
.73041 .60373 Mdot
.82706 .70038 Mdot
.20711 .21712 Mdot
.30376 .31377 Mdot
.40041 .41042 Mdot
.49707 .50708 Mdot
.59372 .60373 Mdot
.69038 .70038 Mdot
.78703 .79704 Mdot
.16707 .31377 Mdot
.26373 .41042 Mdot
.36038 .50708 Mdot
.45703 .60373 Mdot
.55369 .70038 Mdot
.65034 .79704 Mdot
.74699 .89369 Mdot
.12704 .41042 Mdot
.22369 .50708 Mdot
.32034 .60373 Mdot
.417 .70038 Mdot
.51365 .79704 Mdot
.61031 .89369 Mdot
.087 .50708 Mdot
.18366 .60373 Mdot
.28031 .70038 Mdot
.37696 .79704 Mdot
.47362 .89369 Mdot
.04697 .60373 Mdot
.14362 .70038 Mdot
.24027 .79704 Mdot
.33693 .89369 Mdot
.05798 .33693 Mdot
.15464 .24027 Mdot
.25129 .14362 Mdot
.34794 .04697 Mdot
.05798 .47362 Mdot
.15464 .37696 Mdot
.25129 .28031 Mdot
.34794 .18366 Mdot
.4446 .087 Mdot
.05798 .61031 Mdot
.15464 .51365 Mdot
.25129 .417 Mdot
.34794 .32034 Mdot
.4446 .22369 Mdot
.54125 .12704 Mdot
.15464 .65034 Mdot
.25129 .55369 Mdot
.34794 .45703 Mdot
.4446 .36038 Mdot
.54125 .26373 Mdot
.6379 .16707 Mdot
.15464 .78703 Mdot
.25129 .69038 Mdot
.34794 .59372 Mdot
.4446 .49707 Mdot
.54125 .40041 Mdot
.6379 .30376 Mdot
.73456 .20711 Mdot
.25129 .82706 Mdot
.34794 .73041 Mdot
.4446 .63376 Mdot
.54125 .5371 Mdot
.6379 .44045 Mdot
.73456 .3438 Mdot
.83121 .24714 Mdot
.34794 .8671 Mdot
.4446 .77045 Mdot
.54125 .67379 Mdot
.6379 .57714 Mdot
.73456 .48049 Mdot
.83121 .38383 Mdot
.92786 .28718 Mdot
.4446 .90713 Mdot
.54125 .81048 Mdot
.6379 .71383 Mdot
.73456 .61717 Mdot
.83121 .52052 Mdot
.92786 .42387 Mdot
.54125 .94717 Mdot
.6379 .85052 Mdot
.73456 .75386 Mdot
.83121 .65721 Mdot
.92786 .56056 Mdot
.73456 .89055 Mdot
.83121 .7939 Mdot
.92786 .69724 Mdot
.30276 .07214 Mdot
.43944 .07214 Mdot
.57613 .07214 Mdot
.71282 .07214 Mdot
.2061 .16879 Mdot
.34279 .16879 Mdot
.47948 .16879 Mdot
.61617 .16879 Mdot
.75286 .16879 Mdot
.10945 .26544 Mdot
.24614 .26544 Mdot
.38283 .26544 Mdot
.51951 .26544 Mdot
.6562 .26544 Mdot
.79289 .26544 Mdot
.14948 .3621 Mdot
.28617 .3621 Mdot
.42286 .3621 Mdot
.55955 .3621 Mdot
.69624 .3621 Mdot
.83293 .3621 Mdot
.05283 .45875 Mdot
.18952 .45875 Mdot
.32621 .45875 Mdot
.4629 .45875 Mdot
.59959 .45875 Mdot
.73627 .45875 Mdot
.87296 .45875 Mdot
.09287 .5554 Mdot
.22955 .5554 Mdot
.36624 .5554 Mdot
.50293 .5554 Mdot
.63962 .5554 Mdot
.77631 .5554 Mdot
.913 .5554 Mdot
.1329 .65206 Mdot
.26959 .65206 Mdot
.40628 .65206 Mdot
.54297 .65206 Mdot
.67966 .65206 Mdot
.81634 .65206 Mdot
.95303 .65206 Mdot
.17294 .74871 Mdot
.30962 .74871 Mdot
.44631 .74871 Mdot
.583 .74871 Mdot
.71969 .74871 Mdot
.85638 .74871 Mdot
.21297 .84536 Mdot
.34966 .84536 Mdot
.48635 .84536 Mdot
.62304 .84536 Mdot
.75973 .84536 Mdot
.38969 .94202 Mdot
.52638 .94202 Mdot
.66307 .94202 Mdot
.60373 .04697 Mdot
.70038 .14362 Mdot
.79704 .24027 Mdot
.89369 .33693 Mdot
.50708 .087 Mdot
.60373 .18366 Mdot
.70038 .28031 Mdot
.79704 .37696 Mdot
.89369 .47362 Mdot
.41042 .12704 Mdot
.50708 .22369 Mdot
.60373 .32034 Mdot
.70038 .417 Mdot
.79704 .51365 Mdot
.89369 .61031 Mdot
.31377 .16707 Mdot
.41042 .26373 Mdot
.50708 .36038 Mdot
.60373 .45703 Mdot
.70038 .55369 Mdot
.79704 .65034 Mdot
.89369 .74699 Mdot
.21712 .20711 Mdot
.31377 .30376 Mdot
.41042 .40041 Mdot
.50708 .49707 Mdot
.60373 .59372 Mdot
.70038 .69038 Mdot
.79704 .78703 Mdot
.12046 .24714 Mdot
.21712 .3438 Mdot
.31377 .44045 Mdot
.41042 .5371 Mdot
.50708 .63376 Mdot
.60373 .73041 Mdot
.70038 .82706 Mdot
.12046 .38383 Mdot
.21712 .48049 Mdot
.31377 .57714 Mdot
.41042 .67379 Mdot
.50708 .77045 Mdot
.60373 .8671 Mdot
.02381 .42387 Mdot
.12046 .52052 Mdot
.21712 .61717 Mdot
.31377 .71383 Mdot
.41042 .81048 Mdot
.50708 .90713 Mdot
.02381 .56056 Mdot
.12046 .65721 Mdot
.21712 .75386 Mdot
.31377 .85052 Mdot
.41042 .94717 Mdot
.12046 .7939 Mdot
.21712 .89055 Mdot
.66307 .05798 Mdot
.75973 .15464 Mdot
.85638 .25129 Mdot
.95303 .34794 Mdot
.52638 .05798 Mdot
.62304 .15464 Mdot
.71969 .25129 Mdot
.81634 .34794 Mdot
.913 .4446 Mdot
.38969 .05798 Mdot
.48635 .15464 Mdot
.583 .25129 Mdot
.67966 .34794 Mdot
.77631 .4446 Mdot
.87296 .54125 Mdot
.34966 .15464 Mdot
.44631 .25129 Mdot
.54297 .34794 Mdot
.63962 .4446 Mdot
.73627 .54125 Mdot
.83293 .6379 Mdot
.21297 .15464 Mdot
.30962 .25129 Mdot
.40628 .34794 Mdot
.50293 .4446 Mdot
.59959 .54125 Mdot
.69624 .6379 Mdot
.79289 .73456 Mdot
.17294 .25129 Mdot
.26959 .34794 Mdot
.36624 .4446 Mdot
.4629 .54125 Mdot
.55955 .6379 Mdot
.6562 .73456 Mdot
.75286 .83121 Mdot
.1329 .34794 Mdot
.22955 .4446 Mdot
.32621 .54125 Mdot
.42286 .6379 Mdot
.51951 .73456 Mdot
.61617 .83121 Mdot
.71282 .92786 Mdot
.09287 .4446 Mdot
.18952 .54125 Mdot
.28617 .6379 Mdot
.38283 .73456 Mdot
.47948 .83121 Mdot
.57613 .92786 Mdot
.05283 .54125 Mdot
.14948 .6379 Mdot
.24614 .73456 Mdot
.34279 .83121 Mdot
.43944 .92786 Mdot
.10945 .73456 Mdot
.2061 .83121 Mdot
.30276 .92786 Mdot
.07214 .30276 Mdot
.16879 .2061 Mdot
.26544 .10945 Mdot
.07214 .43944 Mdot
.16879 .34279 Mdot
.26544 .24614 Mdot
.3621 .14948 Mdot
.45875 .05283 Mdot
.07214 .57613 Mdot
.16879 .47948 Mdot
.26544 .38283 Mdot
.3621 .28617 Mdot
.45875 .18952 Mdot
.5554 .09287 Mdot
.07214 .71282 Mdot
.16879 .61617 Mdot
.26544 .51951 Mdot
.3621 .42286 Mdot
.45875 .32621 Mdot
.5554 .22955 Mdot
.65206 .1329 Mdot
.16879 .75286 Mdot
.26544 .6562 Mdot
.3621 .55955 Mdot
.45875 .4629 Mdot
.5554 .36624 Mdot
.65206 .26959 Mdot
.74871 .17294 Mdot
.26544 .79289 Mdot
.3621 .69624 Mdot
.45875 .59959 Mdot
.5554 .50293 Mdot
.65206 .40628 Mdot
.74871 .30962 Mdot
.84536 .21297 Mdot
.3621 .83293 Mdot
.45875 .73627 Mdot
.5554 .63962 Mdot
.65206 .54297 Mdot
.74871 .44631 Mdot
.84536 .34966 Mdot
.45875 .87296 Mdot
.5554 .77631 Mdot
.65206 .67966 Mdot
.74871 .583 Mdot
.84536 .48635 Mdot
.94202 .38969 Mdot
.5554 .913 Mdot
.65206 .81634 Mdot
.74871 .71969 Mdot
.84536 .62304 Mdot
.94202 .52638 Mdot
.65206 .95303 Mdot
.74871 .85638 Mdot
.84536 .75973 Mdot
.94202 .66307 Mdot
.33693 .05798 Mdot
.47362 .05798 Mdot
.61031 .05798 Mdot
.24027 .15464 Mdot
.37696 .15464 Mdot
.51365 .15464 Mdot
.65034 .15464 Mdot
.78703 .15464 Mdot
.14362 .25129 Mdot
.28031 .25129 Mdot
.417 .25129 Mdot
.55369 .25129 Mdot
.69038 .25129 Mdot
.82706 .25129 Mdot
.04697 .34794 Mdot
.18366 .34794 Mdot
.32034 .34794 Mdot
.45703 .34794 Mdot
.59372 .34794 Mdot
.73041 .34794 Mdot
.8671 .34794 Mdot
.087 .4446 Mdot
.22369 .4446 Mdot
.36038 .4446 Mdot
.49707 .4446 Mdot
.63376 .4446 Mdot
.77045 .4446 Mdot
.90713 .4446 Mdot
.12704 .54125 Mdot
.26373 .54125 Mdot
.40041 .54125 Mdot
.5371 .54125 Mdot
.67379 .54125 Mdot
.81048 .54125 Mdot
.94717 .54125 Mdot
.16707 .6379 Mdot
.30376 .6379 Mdot
.44045 .6379 Mdot
.57714 .6379 Mdot
.71383 .6379 Mdot
.85052 .6379 Mdot
.20711 .73456 Mdot
.3438 .73456 Mdot
.48049 .73456 Mdot
.61717 .73456 Mdot
.75386 .73456 Mdot
.89055 .73456 Mdot
.24714 .83121 Mdot
.38383 .83121 Mdot
.52052 .83121 Mdot
.65721 .83121 Mdot
.7939 .83121 Mdot
.28718 .92786 Mdot
.42387 .92786 Mdot
.56056 .92786 Mdot
.69724 .92786 Mdot
.78288 .10945 Mdot
.87954 .2061 Mdot
.58958 .05283 Mdot
.68623 .14948 Mdot
.78288 .24614 Mdot
.87954 .34279 Mdot
.97619 .43944 Mdot
.49292 .09287 Mdot
.58958 .18952 Mdot
.68623 .28617 Mdot
.78288 .38283 Mdot
.87954 .47948 Mdot
.97619 .57613 Mdot
.39627 .1329 Mdot
.49292 .22955 Mdot
.58958 .32621 Mdot
.68623 .42286 Mdot
.78288 .51951 Mdot
.87954 .61617 Mdot
.29962 .17294 Mdot
.39627 .26959 Mdot
.49292 .36624 Mdot
.58958 .4629 Mdot
.68623 .55955 Mdot
.78288 .6562 Mdot
.87954 .75286 Mdot
.20296 .21297 Mdot
.29962 .30962 Mdot
.39627 .40628 Mdot
.49292 .50293 Mdot
.58958 .59959 Mdot
.68623 .69624 Mdot
.78288 .79289 Mdot
.10631 .25301 Mdot
.20296 .34966 Mdot
.29962 .44631 Mdot
.39627 .54297 Mdot
.49292 .63962 Mdot
.58958 .73627 Mdot
.68623 .83293 Mdot
.10631 .38969 Mdot
.20296 .48635 Mdot
.29962 .583 Mdot
.39627 .67966 Mdot
.49292 .77631 Mdot
.58958 .87296 Mdot
.10631 .52638 Mdot
.20296 .62304 Mdot
.29962 .71969 Mdot
.39627 .81634 Mdot
.49292 .913 Mdot
.10631 .66307 Mdot
.20296 .75973 Mdot
.29962 .85638 Mdot
.39627 .95303 Mdot
.69724 .07214 Mdot
.7939 .16879 Mdot
.89055 .26544 Mdot
.56056 .07214 Mdot
.65721 .16879 Mdot
.75386 .26544 Mdot
.85052 .3621 Mdot
.94717 .45875 Mdot
.42387 .07214 Mdot
.52052 .16879 Mdot
.61717 .26544 Mdot
.71383 .3621 Mdot
.81048 .45875 Mdot
.90713 .5554 Mdot
.28718 .07214 Mdot
.38383 .16879 Mdot
.48049 .26544 Mdot
.57714 .3621 Mdot
.67379 .45875 Mdot
.77045 .5554 Mdot
.8671 .65206 Mdot
.24714 .16879 Mdot
.3438 .26544 Mdot
.44045 .3621 Mdot
.5371 .45875 Mdot
.63376 .5554 Mdot
.73041 .65206 Mdot
.82706 .74871 Mdot
.20711 .26544 Mdot
.30376 .3621 Mdot
.40041 .45875 Mdot
.49707 .5554 Mdot
.59372 .65206 Mdot
.69038 .74871 Mdot
.78703 .84536 Mdot
.16707 .3621 Mdot
.26373 .45875 Mdot
.36038 .5554 Mdot
.45703 .65206 Mdot
.55369 .74871 Mdot
.65034 .84536 Mdot
.12704 .45875 Mdot
.22369 .5554 Mdot
.32034 .65206 Mdot
.417 .74871 Mdot
.51365 .84536 Mdot
.61031 .94202 Mdot
.087 .5554 Mdot
.18366 .65206 Mdot
.28031 .74871 Mdot
.37696 .84536 Mdot
.47362 .94202 Mdot
.04697 .65206 Mdot
.14362 .74871 Mdot
.24027 .84536 Mdot
.33693 .94202 Mdot
.10631 .33693 Mdot
.20296 .24027 Mdot
.29962 .14362 Mdot
.39627 .04697 Mdot
.10631 .47362 Mdot
.20296 .37696 Mdot
.29962 .28031 Mdot
.39627 .18366 Mdot
.49292 .087 Mdot
.10631 .61031 Mdot
.20296 .51365 Mdot
.29962 .417 Mdot
.39627 .32034 Mdot
.49292 .22369 Mdot
.58958 .12704 Mdot
.10631 .74699 Mdot
.20296 .65034 Mdot
.29962 .55369 Mdot
.39627 .45703 Mdot
.49292 .36038 Mdot
.58958 .26373 Mdot
.68623 .16707 Mdot
.20296 .78703 Mdot
.29962 .69038 Mdot
.39627 .59372 Mdot
.49292 .49707 Mdot
.58958 .40041 Mdot
.68623 .30376 Mdot
.78288 .20711 Mdot
.29962 .82706 Mdot
.39627 .73041 Mdot
.49292 .63376 Mdot
.58958 .5371 Mdot
.68623 .44045 Mdot
.78288 .3438 Mdot
.87954 .24714 Mdot
.39627 .8671 Mdot
.49292 .77045 Mdot
.58958 .67379 Mdot
.68623 .57714 Mdot
.78288 .48049 Mdot
.87954 .38383 Mdot
.49292 .90713 Mdot
.58958 .81048 Mdot
.68623 .71383 Mdot
.78288 .61717 Mdot
.87954 .52052 Mdot
.97619 .42387 Mdot
.58958 .94717 Mdot
.68623 .85052 Mdot
.78288 .75386 Mdot
.87954 .65721 Mdot
.97619 .56056 Mdot
.78288 .89055 Mdot
.87954 .7939 Mdot
.33693 .10631 Mdot
.47362 .10631 Mdot
.61031 .10631 Mdot
.74699 .10631 Mdot
.24027 .20296 Mdot
.37696 .20296 Mdot
.51365 .20296 Mdot
.65034 .20296 Mdot
.78703 .20296 Mdot
.14362 .29962 Mdot
.28031 .29962 Mdot
.417 .29962 Mdot
.55369 .29962 Mdot
.69038 .29962 Mdot
.82706 .29962 Mdot
.04697 .39627 Mdot
.18366 .39627 Mdot
.32034 .39627 Mdot
.45703 .39627 Mdot
.59372 .39627 Mdot
.73041 .39627 Mdot
.8671 .39627 Mdot
.087 .49292 Mdot
.22369 .49292 Mdot
.36038 .49292 Mdot
.49707 .49292 Mdot
.63376 .49292 Mdot
.77045 .49292 Mdot
.90713 .49292 Mdot
.12704 .58958 Mdot
.26373 .58958 Mdot
.40041 .58958 Mdot
.5371 .58958 Mdot
.67379 .58958 Mdot
.81048 .58958 Mdot
.94717 .58958 Mdot
.16707 .68623 Mdot
.30376 .68623 Mdot
.44045 .68623 Mdot
.57714 .68623 Mdot
.71383 .68623 Mdot
.85052 .68623 Mdot
.20711 .78288 Mdot
.3438 .78288 Mdot
.48049 .78288 Mdot
.61717 .78288 Mdot
.75386 .78288 Mdot
.89055 .78288 Mdot
.24714 .87954 Mdot
.38383 .87954 Mdot
.52052 .87954 Mdot
.65721 .87954 Mdot
.7939 .87954 Mdot
.42387 .97619 Mdot
.56056 .97619 Mdot
.65206 .04697 Mdot
.74871 .14362 Mdot
.84536 .24027 Mdot
.94202 .33693 Mdot
.5554 .087 Mdot
.65206 .18366 Mdot
.74871 .28031 Mdot
.84536 .37696 Mdot
.94202 .47362 Mdot
.45875 .12704 Mdot
.5554 .22369 Mdot
.65206 .32034 Mdot
.74871 .417 Mdot
.84536 .51365 Mdot
.94202 .61031 Mdot
.3621 .16707 Mdot
.45875 .26373 Mdot
.5554 .36038 Mdot
.65206 .45703 Mdot
.74871 .55369 Mdot
.84536 .65034 Mdot
.26544 .20711 Mdot
.3621 .30376 Mdot
.45875 .40041 Mdot
.5554 .49707 Mdot
.65206 .59372 Mdot
.74871 .69038 Mdot
.84536 .78703 Mdot
.16879 .24714 Mdot
.26544 .3438 Mdot
.3621 .44045 Mdot
.45875 .5371 Mdot
.5554 .63376 Mdot
.65206 .73041 Mdot
.74871 .82706 Mdot
.07214 .28718 Mdot
.16879 .38383 Mdot
.26544 .48049 Mdot
.3621 .57714 Mdot
.45875 .67379 Mdot
.5554 .77045 Mdot
.65206 .8671 Mdot
.07214 .42387 Mdot
.16879 .52052 Mdot
.26544 .61717 Mdot
.3621 .71383 Mdot
.45875 .81048 Mdot
.5554 .90713 Mdot
.07214 .56056 Mdot
.16879 .65721 Mdot
.26544 .75386 Mdot
.3621 .85052 Mdot
.45875 .94717 Mdot
.07214 .69724 Mdot
.16879 .7939 Mdot
.26544 .89055 Mdot
.66307 .10631 Mdot
.75973 .20296 Mdot
.85638 .29962 Mdot
.95303 .39627 Mdot
.52638 .10631 Mdot
.62304 .20296 Mdot
.71969 .29962 Mdot
.81634 .39627 Mdot
.913 .49292 Mdot
.38969 .10631 Mdot
.48635 .20296 Mdot
.583 .29962 Mdot
.67966 .39627 Mdot
.77631 .49292 Mdot
.87296 .58958 Mdot
.25301 .10631 Mdot
.34966 .20296 Mdot
.44631 .29962 Mdot
.54297 .39627 Mdot
.63962 .49292 Mdot
.73627 .58958 Mdot
.83293 .68623 Mdot
.21297 .20296 Mdot
.30962 .29962 Mdot
.40628 .39627 Mdot
.50293 .49292 Mdot
.59959 .58958 Mdot
.69624 .68623 Mdot
.79289 .78288 Mdot
.17294 .29962 Mdot
.26959 .39627 Mdot
.36624 .49292 Mdot
.4629 .58958 Mdot
.55955 .68623 Mdot
.6562 .78288 Mdot
.75286 .87954 Mdot
.1329 .39627 Mdot
.22955 .49292 Mdot
.32621 .58958 Mdot
.42286 .68623 Mdot
.51951 .78288 Mdot
.61617 .87954 Mdot
.09287 .49292 Mdot
.18952 .58958 Mdot
.28617 .68623 Mdot
.38283 .78288 Mdot
.47948 .87954 Mdot
.57613 .97619 Mdot
.05283 .58958 Mdot
.14948 .68623 Mdot
.24614 .78288 Mdot
.34279 .87954 Mdot
.43944 .97619 Mdot
.10945 .78288 Mdot
.2061 .87954 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;RLW9b40<?oo_`00?g=cLda<C820P8NZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmo
OiB;WMKBg2XX;H=kRhjYUM3KddiMD^GQY9no_m[ViUY]KD=EIB4Z<M_Vkl?Ei6F0V;2^]4U5CX61PFYo
L4mOGbL_;n;/k<oOggN?ShRZVHEhU000O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o
002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmo
Ocmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?glo
Oglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0
_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo
_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo
?oooOlS3cdDnCFmlS[g3bcU0B]C>N7j0VLG6dD52Cf]]PW5VO]_Ggd8lBVIbVOoo0_oo1mWIhEiPLko0
c3m0C1lO9FAJKk>ic=;EhC<iC1TL9DaELeioI[C3]c11=?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L007T70`0010L0000P1`<000@70000N@L007P7200O1`P0N@L007T70`0010L0000P1`<0
00@70000N@L007X700D01`L7000R1`0500L71`00NPL00?l78@L00?l78@L00?l78@L006<70`0;1`<0
>0L300/70`1S1`00HPL400X7100010L0000;1`<050L300/71`0:1`@0H`L006<70`0;1`L02PL401<7
100:1`@000@700002`L306<7001P1`<000<700L02@L400870`0;1`<000@7000030L300041`0000/7
0`021`@02PL00`0700020607001O1`@02`L400@700<01`L02`L00`07000300/710021`0300L700/7
00@01`L7100;1`@0H0L006070`0<1`<05@L300`70`0E1`<030L30607001Q1`0300L700`700<01`L0
5@L00`071`0<1`0300L701D700<01`L030L00`071`1O1`00D@L300870`0P1`<000@7000080L30004
1`0002070`0010L0001B1`00D0L400031`0000807`L801l7200O1`P0DPL005470`021`<080L30004
1`0002070`0010L0000P1`<000@70000DPL0058700<01`L00PL00`071`0P1`0500L71`008PL01@07
1`L0028700D01`L7001C1`00OPL300/70`0010L0000;1`<0O`L007d7100:1`P02PL407l7001n1`<0
2`L300041`0000/70`1o1`00O@L400X7200:1`@0O`L007h70`0;1`<000@700002`L307l7001o1`03
00L700/700D01`L7000=1`0300L707h700171`<05PL300`70`0E1`<030L301D70`0<1`<05@L304P7
000m1`<01PL400041`000147100;1`@050L400/7100D1`@02`L401871P081`<0?@L003`710071`L0
4PL300`70`0E1`<030L301D70`0<1`<04@L700L7100m1`00?@L300P700<01`L00`0C1`0300L700`7
00<01`L05@L00`071`0<1`0300L701D700<01`L030L00`071`0A1`<000<700L020L303d7000j1`<0
00<700L01PL300<700<01`L04PL300T70`0H1`<02@L301T70`081`<05@L010071`L300L700<01`00
0P0j1`00>@L400P7100G1`@020L401L710081`@060L400L7100H1`@020L403X7000j1`<02@L301P7
0`091`<01@L300/70`021`<02@L300<70`0;1`<01@L300P70`0I1`<02@L303X7000k1`0300L700T7
00<01`L060L400P700<01`L01`0:1`@00`L00`071`091`0400L71`@02PL400041`00008700<01`L0
1PL301/700<01`L02@L00`071`0i1`00HPL400X7100010L0000;1`<050L300/71`0:1`@0H`L006<7
0`0;1`<00PL00`071`0;1`0300L701@700<01`L02`L00`071`0300/70`1S1`00A`L300/70`0<1`03
00L700/700<01`L0>0L00`071`0;1`0300L700X70`0;1`<0A`L004H7100:1`@0K`L400X710171`00
A`L300/70`0010L0000;1`<0C0L300/70`0010L0000;1`<0A`L004P700<01`L02`L00`07000300X7
101;1`@02PL4008700<01`L02`L00`071`161`00?0L300D70`0B1`<01`L300051`0000L00`0L1`<0
1@L301d70`001@L0000700<01`L301870`051`<0?0L003/710041`@04`L00`071`051`@00PL00`07
000301/710041`@070L4008700<01`000`081`0300L7010710041`@0?0L003`70`051`<070L300D7
0`0L1`<01@L301d70`051`<070L300D70`0l1`00?@L00`071`051`0300L701470`081`0300L700<0
0PL00`071`0L1`0300L700D700<01`L07@L00`071`03008700<01`L01PL301<700<01`L01@L00`07
1`0k1`00>PL300T70`0?1`@01@L3008710031`<060L300T70`0I1`<00PL400870`051`@040L300T7
0`0j1`00>@L400P71@0;1`<000@7000010L400<70`021`@05`L400P7100H1`@00`L300031`000080
1PL300041`0000/710081`@0>PL003X70`091`@02PL4008700<01`L010L300@700<01`L00PL301P7
0`091`<06@L300@700@01`L70`071`0300L000<02PL500T70`0j1`00>`L00`071`091`<02`L300X7
00<01`L02@L00`071`0H1`0300L700T700<01`L06@L00`071`081`0300L700T70`0;1`<02`L00`07
1`0i1`00B0L00`071`0;1`0300L700X70`0;1`<0>0L300/70`0<1`0300L700/700<01`L0APL00687
100:1`@0=`L400X7101S1`00H`L300/70`0010L0000;1`<050L300/70`0010L0000;1`<0H`L006@7
00<01`L02`L00`07000300X7100C1`@02PL4008700<01`L02`L00`071`1R1`00M@L300/70`0D1`<0
2`L307D7000l1`<01@L301`70`051`<020L00`071`0;1`0300L700<70`051`<01PL00`071`0;1`03
00L700H70`051`<070L300D70`0l1`008@L300/70`091`@010L401/710041`@06`L400@7100L1`@0
10L401/710041`@02@L300/70`0R1`0080L400X7100:1`@010L300@70`0E1`<01@L301`70`051`<0
7@L300D70`0E1`<010L300@710081`@02PL40287000Q1`<01`L300041`0000L71`051`0300L70087
100F1`0300L700D700<01`L070L00`071`051`0300L701d700<01`L01@L00`071`0C1`@01@L00`07
1`021`@000@700001PL300041`0000L70`0R1`007PL300031`0700H710021`0300L700D720061`<0
0PL301@70`081`<06@L300P70`0I1`<020L301@70`021`<01PL700L700<01`000`081`0300L00080
7`L001d7100:1`<02`L400031`0700D710031`0300L7018710071`@060L400L7100H1`@01`L401D7
00<01`L010071`H02PL300T7100O1`007PL300/700<01`L02`L300T70`0I1`<020L300h70`081`H0
00D700001`0300L70`0?1`<020L301T70`081`@030L00`071`091`<07`L001l700<01`L06@L00`07
1`091`0300L701T700<01`L020L00`071`0<1`@02@L9008700<01`L01@L4010700<01`L020L00`07
1`0I1`0300L700P700<01`L06@L00`071`0N1`00OPL300/70`0010L0000;1`<0O`L007d7100:1`P0
2PL407l7001n1`<02`L300041`0000/70`1o1`00:`L300/70`131`0300L700/700D01`L7000=1`03
00L704870`0:1`<0;0L002X7100:1`@0Y`L400T7100/1`008@L300L70`0010L000071`<000@70000
2`L308@70`0;1`<000@700001PL300041`0000L70`0R1`0080L400@70`000`L01`0600H700<01`00
0`0:1`@000@700001PL301`70`051`<070L300D70`0L1`<01@L300031`0000802PL4008700<01`L0
10L4008700<01`L00`021`@08PL001d70`0010L000031`@010L500T70`0;1`L01@L401/710041`@0
6`L400@7100K1`@010L400870`0;1`<020L500@710031`<000@700007PL001`710021`0300L700<7
0`051`@02PL00`071`0;1`0300L700<01PL301`70`051`<070L300D70`0L1`<01@L300<700<01`L0
2`L00`071`081`<01PL300@700<01`000`0N1`007@L300T700<01`L01PL00`071`0K1`0300L700H7
00<01`L070L00`071`051`0300L701`700<01`L01@L00`071`0L1`0300L700D700<01`L070L00`07
1`061`0300L700H70`0N1`007PL301T70`091`<06@L300P70`051`<02`L300<70`081`<00`L300/7
0`051`<020L301T70`081`<06@L301l7000M1`@060L400P7100H1`D01PL400031`0000D02PL40087
10071`@00PL400X710000`L0000500L7100H1`@01`L401P7100O1`007PL301T70`091`<06@L400L7
1`0010L0000;1`<00`L300P70`031`<02`L700041`0000H71@0I1`<020L301T70`0O1`007`L00`07
1`0I1`0300L700T700<01`L06@L300P700<01`L00`021`0300L700/700<01`L00`L00`071`081`03
00L700<700<01`L02`L00`071`03008700<01`L01PL301/700<01`L020L00`071`0I1`0300L701h7
001T1`0300L700/700<01`L0>0L00`071`0;1`0300L7068700171`<02`L307070`0;1`<0A`L004H7
100:1`@000@700002`L304`70`0;1`L02PL404L7000D1`<0<0L300/71`0:1`@0B`L400X7100010L0
000;1`<0<0L301@7000C1`@0<@L00`071`0;1`0300L700<02`L304`70`0;1`<00PL00`071`0;1`03
00L702h7100D1`0050L304<700<01`L02`L00`071`1<1`0300L700/700<01`L0@@L301@7000E1`03
00L701070`061`<06`L300H70`0L1`<01@L301`70`051`<070L300D70`0L1`<01PL3018700<01`L0
4`L001@70`0@1`@01@L401X710051`D02`L300`710041`@06`L400@7100=1`<02`L400@7100K1`@0
1@L401470`0D1`004`L401470`061`<06`L300H7100:1`@03@L300D70`0L1`<01@L300`7100:1`D0
1@L301`70`061`<040L401@7000D1`<04PL00`071`061`0300L701870`061`0300L700870`0010L0
000;1`<03PL00`071`051`0300L701`700<01`L01@L00`071`0<1`<02`L300041`0000<700<01`L0
1@L301@700<01`L01PL00`071`0@1`<050L001D700<01`L04PL300870`0D1`@01`L800031`0700`7
00<01`L03@L300870`0O1`<00`L300l700<01`L02`L00`07000300041`0000H7100E1`<00PL301@7
00<01`L04`L002T710000`L0000201D70`061`@000<700000P0N1`@000<700000P0N1`@00PL401h7
2@071`<050L400031`000080:PL002X70`021`<05PL00`071`061`<00PL300X70`0;1`<010L30087
0`0O1`<00`L300@70`0;1`<02PL300870`081`0300L701@70`021`<0:PL002/700<01`L00PL00`07
1`0O1`0300L7008700<01`L020L400X710051`0300L7008700<01`L07`L00`071`031`0300L70087
100:1`@02`L00`071`021`0300L701l700<01`L00PL00`071`0Y1`00H`L300/70`0010L0000;1`<0
50L300/70`0010L0000;1`<0H`L006@700<01`L02`L00`07000300X7100C1`@02PL4008700<01`L0
2`L00`071`1R1`00M@L300/70`0D1`<02`L307D7000@1`<02PL305H700<01`L02`L00`071`0D1`03
00L700/700<01`L0D`L300/70`0@1`003`L400T7103N1`@02PL40107000@1`<02PL300041`0000/7
0`0;1`<02`L308@70`0;1`<02PL300/70`0010L0000;1`<040L000`70`021`0300L700X700<01`00
0`0010L000031`L00PL300871`0:1`D030L301D70`0<1`<05PL300/70`0F1`<030L400X7100010L0
00021`L000@7000010L6008700<01`L02`L00`07000200d7000;1`@04PL7008710001@L0000700@0
00<700000P0010L0000;1`@02`L401@7100;1`@05@L400X7100E1`@02`L500/71`000`L000020003
1`0000D00`L70147100=1`0030L301<700<01`L00`031`<00PL010071`L300870`021`0300L700/7
0`0<1`<05@L300`70`0F1`<02`L301H70`0<1`<03@L00`071`0300870`021`0300L700<010L30003
1`0701870`0=1`003@L00`071`0F1`0300L700<700<01`L01PL00`071`021`0300L7010700<01`L0
30L00`071`0E1`0300L700`700<01`L05PL00`071`0;1`0300L701H700<01`L030L00`071`0@1`03
00L7008700<01`L01@L00`071`041`0300L701D700<01`L030L002X70`021`<07`L300870`0O1`<0
0PL400/70`0010L0000;1`@00`L301l70`021`<07`L300870`0Z1`00:@L400031`0000807PL40003
1`0000807PL400031`0000<02PL800X71@021`@07PL400031`0000807PL400031`000080:PL002X7
0`021`<07`L300870`0O1`<00PL400X7200:1`D00`L301l70`021`<07`L300870`0Z1`00:`L00`07
1`021`0300L701l700<01`L00PL00`071`0O1`0300L700870`0;1`<000@700002`L300D700<01`L0
7`L00`071`021`0300L701l700<01`L00PL00`071`0Y1`00:`L300/70`131`0300L700/700D01`L7
000=1`0300L704870`0:1`<0;0L002X7100:1`@0Y`L400T7100/1`008@L300L70`0010L000071`<0
00@700002`L308@70`0;1`<000@700001PL300041`0000L70`0R1`0080L400P700<01`000`081`03
00L000<02PL408<7100:1`@00PL00`071`041`@00PL00`071`051`@08PL001070`0:1`<000@70000
2`L300/70`0;1`<0Q0L300/70`0:1`<02`L300041`0000/70`0@1`003`L400T710021`0300L700/7
00<01`L02`L00`071`0;1`0300L708@700<01`L02`L00`071`0:1`0300L700/700<01`000`0:1`@0
40L000`70`0010L0000:1`<01@L300`70`0E1`<030L301D70`0<1`<05PL300/70`0F1`<030L301D7
0`0<1`<010L300/71P0=1`002`L4008700<01`L02PL00`071`031`@02`L401@7100;1`@050L600T7
1@0D1`@02PL401D7100;1`@050L400/710051`0300L700/71@0=1`0030L301H70`0<1`<05@L300`7
0`0E1`D02PL401<71@091`D05PL300`70`0E1`<030L301D70`0=1`003@L00`071`0F1`0300L700`7
00<01`L05@L00`071`0<1`0300L700@70`0;1`L02`L301@70`0;1`<000@700002`L300H700<01`L0
30L00`071`0E1`0300L700`700<01`L05@L00`071`0<1`003PL301870`0?1`<04`L300h70`031`@0
2PL500031`0700`70`0B1`<03@L00`07000300X710031`<03`L301870`0?1`<04`L300h7000=1`@0
4@L400h7100B1`@03@L400@70`0;1`@03PL40147100>1`D02`L30087100>1`@04@L400h7100B1`@0
3PL000h70`0B1`<03`L300l70`0010L000071`<010L300D700<01`L02`L300l70`0B1`<03`L300d7
00<01`L00PL300D70`071`<000@700003PL300l70`0C1`<03PL000l700<01`L04PL00`071`0?1`03
00L700d710021`0300L700D710001PL0000700T70`091`0300L700l700<01`L04PL00`071`0?1`03
00L700L70`081`0300L700L020L00`07000300l700<01`L03`L00`071`0C1`0300L700d700061`<0
2`L303070`0;1`L02PL404/7100:1`@000@700002`L303070`0;1`<01PL000D7100:1`@0<@L00`07
1`0;1`0300L700<02`L304`70`0;1`<00PL00`071`0;1`0300L702h7100:1`@01PL000H70`0;1`<0
@`L00`071`0;1`0300L704`700<01`L02`L00`071`111`<02`L300H700071`0300L700/700<01`L0
lPL00`071`0;1`0300L700D700061`<02`L30?870`0;1`<01PL000D7100:1`@0@PL300/70`1<1`<0
2`L30447100:1`@01PL000H70`0;1`<000<700000`0R1`D00`L300/71`0:1`D08`L402<7100:1`@0
00@700002`L300<71@0R1`D000@700002`L300H700071`0300L700/700<01`001@0Q1`H00PL400X7
100010L000091`H08PL502871@0;1`L02PL400871P0Q1`H00PL00`071`0;1`0300L700D7000H1`D0
8PL500<70`0;1`<00PL00`071`091`D08`L402<7100<1`0300L700<02`L300<71@0R1`D060L001T7
00<01`0090L00`0700051`0300L700/700<01`L02PL300041`0700L70`0K1`806`L300L70P021`<0
30L00`071`0;1`0300L700<700<01`0090L00`07000I1`003PL301870`0?1`<04`L300h70`031`@0
2PL500l70`0B1`<03`L400X710031`<03`L301870`0?1`<04`L300h7000=1`@04@L400h7100B1`@0
3@L400@70`0;1`L02`L401471@0;1`L02`L30087100>1`@04@L400h7100B1`@03PL000h70`0B1`<0
3`L301<70`0>1`<01@L00`071`0;1`H02PL50187100:1`L03@L00`071`021`<03`L301870`0?1`<0
4`L300h7000?1`0300L7018700<01`L03`L00`071`0C1`0300L700h700<01`L04`L00`07000200/7
0`0D1`<02`L300031`0701<700<01`L03`L00`071`0B1`0300L700l700<01`L04`L00`071`0=1`00
40L300X70`1F1`0300L700/700<01`L050L00`071`0;1`0300L705<70`0;1`<040L000l710091`@0
gPL400X7100@1`0040L300X70`0010L0000;1`<02`L300/70`241`<02`L300X70`0;1`<000@70000
2`L30107000A1`0300L700X700<01`000`0:1`@02PL400X710231`@02PL400T7100:1`@00PL00`07
1`0;1`0300L700l7000Q1`<01`L300041`0000L70`0010L0000;1`<0Q0L300/70`0010L000061`<0
00@700001`L30287000R1`0300L700D710021`0300L700D710021`0300L700/700<01`L0Q0L00`07
1`0;1`0300L000<01`L00`07000300P700<01`L08@L001P71@0>1`<02`L300<71@0R1`D08`L402<7
100S1`D00`L300X70`0?1`D060L001L71P0?1`0300L700/700@01`L71P0Q1`H04`L300/71`0;1`<0
4`L502871P041`0300L700X700<01`L03@L601P7000H1`D08PL502871@0B1`@02PL800X7100D1`@0
8`L502871@0H1`006@L00`07000T1`0300L002@700<01`004`L400X7200:1`@05@L202D700<01`00
90L00`07000I1`0060L502871@0R1`D04`L300/71`0;1`<050L402<71@0R1`D060L001L71P0Q1`H0
8@L601@700<01`L02`L500d700<01`L04PL502871P0Q1`H060L001P71@0>1`<02`L300<71@0R1`D0
8`L402<7100S1`D00`L300X70`0?1`D060L001T700<01`003PL400X710000`L0000200031`0700L7
0`0I1`0300L002D70P0U1`806PL300P700<01`001`091`@040L00`07000I1`008@L300L70`0010L0
00071`L02PL408<7100:1`@000@700001PL300041`0000L70`0R1`0040L300X71`081`0300L000<0
20L00`071`0300/70`241`<02`L3008700<01`L010L4008700<01`L01@L400041`0000/70`0@1`00
3`L400T7100010L0000;1`<030L00`071`0;1`0300L708@700<01`L02`L00`071`091`<02`L700X7
100@1`0040L300X70`021`0300L700/700<01`L0^`L00`071`0;1`0300L700<02`L30107000A1`03
00L700X700<01`L0E0L300/70`0D1`<02`L305D700<01`L02`L00`071`0?1`003PL301870`0?1`<0
4`L300h70`0C1`H02PL50187100:1`L04PL300l70`0B1`<03`L301<70`0>1`003@L40147100>1`@0
4PL400d710041`<02`L700/7100A1`D02`L700/70`021`@03PL40147100>1`@04PL400h7000>1`<0
4PL300l70`0C1`<03PL300<7100:1`D000<700L030L301870`0=1`0300L000<02PL400<70`0?1`<0
4PL300l70`0C1`<03PL000l700<01`L04PL00`071`0?1`0300L701<700<01`L03PL00`071`031`<0
2`L3014700<01`L04PL00`071`0?1`<02`L300@700<01`L03`L00`071`0B1`0300L700l700<01`L0
4`L00`071`0=1`00A`L300/70`0<1`0300L700/700<01`L0>0L00`071`0;1`0300L700X70`0;1`<0
A`L001P71@0R1`D00PL400X7100>1`D08`L402<7100>1`@02PL400<71@0R1`D060L000H70`0;1`T0
8@L600<70`0;1`<000@700002@L602871@0R1`D02`L300041`0000/70`021`H08@L600041`0000/7
0`061`001@L400X710000`L0000302871@041`0300L700/700<01`000`0:1`D08`L402<7100:1`@0
0PL00`071`0;1`0300L700871@0R1`T02PL400H700061`<02`L3008700<01`0090L00`07000F1`<0
2`L302D70P0U1`<02`L301H700<01`0090L00`0700021`<02`L300H700071`0300L700/700<01`L0
@PL00`071`0;1`0300L704`700<01`L02`L00`071`121`0300L700/700<01`L01@L000H70`0;1`<0
lPL300/70`061`001@L400X710121`<02`L304`70`0;1`<0@@L400X710061`001PL300/70`0`1`<0
2`L700X7101;1`@02PL400041`0000/70`0`1`<02`L300H700071`0300L700/700<01`L0;PL400X7
100010L0000;1`<0C0L300/71`0:1`@0<@L00`071`0;1`0300L700D7000>1`<04PL300l70`0?1`<0
00@700001`L3008700<01`000P091`0300L700L70`0?1`<04PL300l70`091`0300L700H70`021`03
00L700<01`L300041`0000h70`0?1`<04`L300h7000=1`@04@L400h7100@1`0300L000<020L00`07
1`021`@04PL400h7100A1`@03PL4014710061`0300L700D710021`0300L700`7100>1`@04PL400h7
000>1`<04PL300l70`0C1`<03PL300@70`0;1`@03`L301870`0?1`@02`L300<70`0?1`<04PL300l7
0`0C1`<03PL000l700<01`L04PL00`071`0?1`0300L701<700<01`L03PL00`071`021`@02PL40004
1`0000/70`0D1`<02`L700X710041`0300L700l700<01`L04PL00`071`0?1`0300L701<700<01`L0
3@L000`70`0F1`<030L301D70`0<1`<01@L300/71`0:1`@04`L500T7200;1`<01@L300`70`0E1`<0
30L301D70`0=1`002`L401D7100;1`@050L400/710061`0300L700/71P091`D050L400X710000`L0
1`0<1`0300L700<7100;1`@050L400/7100D1`@03@L000`70`0010L0000:1`<01@L300`70`0E1`<0
30L301D7100;1`<05PL300/70`0F1`<030L301D70`0<1`<010L300/71P0=1`003@L00`07000300T7
10061`0300L700`700<01`L05@L00`071`0<1`0300L701D700<01`L030L00`071`0F1`0300L700/7
00<01`L05PL00`071`0<1`0300L701D700<01`L030L00`071`021`@02PL400031`0700d7000@1`<0
2PL300041`0000/70`0;1`<02`L308@70`0;1`<02PL300/70`0010L0000;1`<040L0014700<01`L0
2PL00`07000300X7100:1`@02PL408<7100:1`@02@L400X710021`0300L700/700<01`L03`L00247
0`071`<000@700001`L300041`0000/70`241`<02`L300041`0000H70`0010L000071`<08PL00287
00<01`L01@L4008700<01`L01@L4008700<01`L02`L00`071`241`0300L700/700<01`000`071`03
00L000<020L00`071`0Q1`00:`L300/70`2X1`<02PL302`7000/1`0300L700/700<01`L0@@L300/7
0`0010L0000;1`<0A0L00`071`0:1`0300L702/7000Z1`<00PL301l70`021`<07`L30087100:1`P0
2PL500<70`0O1`<00PL301l70`021`<0:PL002T710000`L0000201h710000`L0000201h710000`L0
000300/70`0010L0000;1`@00PL401h710000`L0000201h710000`L0000202X7000Z1`<00PL301l7
0`021`<07`L30087100:1`P02PL500<70`0O1`<00PL301l70`021`<0:PL002/700<01`L00PL00`07
1`0O1`0300L7008700<01`L07`L00`071`021`<02`L300041`0000/70`051`0300L701l700<01`L0
0PL00`071`0O1`0300L7008700<01`L0:@L000`70`0F1`<00`L300H70`021`<040L300`70`0E1`<0
2@L00`071`0300P700D01`L700091`<000<700L020L301H70`0<1`<040L300870`051`<010L301D7
0`0=1`002`L401D710021`@01@L400031`00008000@700002`L400/7100D1`@02`L401D7100:1`@0
5@L400/71@0;1`L000<700000P041`@00`L401@7100=1`0030L301870`0010L000031`<000@70000
0PL300871`0:1`D030L301D70`0<1`<05PL300/70`0F1`<030L400X7100010L000021`<000D70000
1`0300@71P0B1`<03@L000d700<01`L00`0:1`L00PL00`071`031`0300L000<00`L00`071`021`03
00L700<02`L300h700<01`L05@L00`071`0<1`0300L701H700<01`L02`L00`071`0F1`0300L700`7
0`0;1`<00PL00`071`021`0300L000<00PL00`071`041`D000@700002`L300031`0700d7000?1`@0
2@L400041`0000/70`0<1`0300L700/700<01`L0Q0L00`071`0;1`0300L700T70`0;1`L02PL40107
000@1`<02PL3008700<01`L02`L00`071`2k1`0300L700/700<01`L00`0;1`<040L0014700<01`L0
2PL00`071`3O1`0300L700/700<01`L03`L007D70`0;1`<050L300/70`1e1`00H`L300/71`0:1`@0
4`L400X7100010L0000;1`<0H`L00687100:1`@000@700002`L301@70`0;1`L02PL406<7000Z1`<0
0PL301l70`021`<02PL300/70`021`0300L000800PL300@700<01`L050L010071`L300<70`0010L0
1`L300/70`0:1`<00PL301l70`021`<0:PL002T710000`L0000201D70`061`@000<700000P0;1`03
00L700/700<01`L00PL400031`0000807PL4008710051`0300L700/700<01`L020L900L70`0D1`@0
00<700000P0Z1`00:PL300870`0D1`@01`L801l70`021`<07`L300<70`0O1`@000@700001PL401D7
0`021`<0:PL001@70`0D1`0300L7008700<01`L050L300P700<01`L00`0010L0000;1`<03`L00`07
1`021`0300L701l700<01`L00`L00`071`0=1`<02`L300041`00008700<01`L01PL301H700<01`L0
0PL00`071`0B1`<050L001<7100A1`<01PL301@700<01`L010L300@700<01`000`0:1`@03@L300D7
0`0L1`<01@L300`7100:1`D000<700L00PL300L700<01`L04PL300H70`0@1`@050L001@70`0@1`@0
1@L401X710051`D02`L300`710041`@06`L400@7100=1`<02`L400@7100K1`@01@L401470`0D1`00
5@L00`071`0@1`<01PL301/70`061`<03@L00`071`0<1`<01@L301`70`051`<03PL00`071`0;1`<0
1@L301`70`061`<04PL00`071`0C1`00:@L00`071`061`0300L701/700<01`L01PL00`071`0L1`03
00L700D700<01`L070L00`071`051`0300L701`700<01`L01@L00`071`0L1`0300L700H700<01`L0
9`L001@70`121`<02`L304`70`0;1`<0@PL301@7000C1`@0@@L400X7101;1`@02PL40447100D1`00
50L303070`0;1`<000@700002`L304`70`0;1`<000@700002`L303070`0D1`005@L00`071`0^1`@0
2PL4008700<01`L02`L00`071`1<1`0300L700/700<01`000`0:1`@0<@L00`071`0C1`00A`L300/7
0`1`1`<02`L304L700181`0300L700/700<01`L02PL300/70`0h1`<02`L300`700<01`L02`L00`07
1`161`007PL301T70`091`<06@L400L71`0010L0000;1`<00`L300P70`031`<02`L700041`0000H7
1@0I1`<020L301T70`0O1`007@L401P710081`@060L500H710000`L0000500X710021`@01`L40087
100:1`@000<700001@071`@060L400L7100H1`@07`L001h70`0I1`<02@L301T70`081`<00PL00`07
1`0300/70`031`<020L300<70`0;1`<00PL00`071`0300P70`0I1`<020L301T70`0O1`007`L00`07
1`0I1`0300L700T700<01`L06@L00`071`081`0300L700D700<01`L02`L00`071`031`0300L700P7
00<01`L00`L00`071`0;1`0300L700D700<01`L020L00`071`0I1`0300L700P700<01`L06@L00`07
1`0N1`007@L300P70`061`<06`L300H70`0L1`<01@L301`70`051`<070L300D70`0L1`<01PL300L7
0`0N1`0070L400041`0000<710041`D02@L300/71`051`@06`L400@7100K1`@010L401/710041`@0
0PL300/70`081`D010L400<71`0N1`007@L700@70`031`H020L400X7100010L000061`<070L300D7
0`0L1`<01@L301`70`051`<000<700000P0:1`@02@L400D70`021`@000@700007PL001h700<01`L0
0`051`0300L0008000<700000P061`<000@700002`L3008700<01`L01PL00`071`0L1`0300L700D7
00<01`L070L00`071`051`0300L701`700<01`L01@L010071`L300/70`0010L000061`<000@70000
0PL00`071`021`<00PL00`071`0M1`008PL00`071`051`@00PL00`071`051`@00PL00`071`0;1`03
00L708@700<01`L02`L00`07000300L700<01`000`081`0300L70247000[1`<02`L30:P70`0:1`<0
;0L002`700<01`L02`L00`071`111`<02`L300041`0000/70`141`0300L700X700<01`L0:`L007d7
100:1`P02PL407l7001n1`<02`L300041`0000/70`1o1`00O@L400X7200:1`@0O`L001h70`0I1`<0
2@L301T70`081`<03PL300P71P001@L0000700<01`L300l70`081`<06@L300P70`0I1`<07`L001d7
100:1`<02`L400P7100H1`@01`L400l700<01`L01PL400031`07008700<01`000`081`0300L700d7
10071`@060L400L71P0:1`<02@L401l7000N1`<02@L400X71@091`<06@L300P70`0I1`<020L301T7
0`081`<06@L300P71@091`@02PL301l7000O1`0300L000801`L300041`0000L70`0010L000071`04
00L71`<05@L00`071`081`0300L701T700<01`L020L00`071`0I1`0300L700P700<01`L04`L300<7
00<01`L01@L700H70`0010L000071`<000<700L07`L0020710081`0300L000<020L00`07000300@7
0`031`@05@L300D70`0L1`<01@L301d70`051`<050L400@70`031`D000<700L01@L4008700<01`L0
1@L40287000Q1`<02`L300T71@031`@010L301@710041`@06`L400@7100L1`@010L401D70`031`@0
10L400T70`0;1`<08PL0028700<01`L02`L00`071`091`<01@L300D700<01`L050L300D70`0L1`<0
1@L301d70`051`<05PL00`071`031`<01@L300X700<01`L02`L00`071`0Q1`00?@L00`071`051`03
00L701`700<01`L01@L00`071`0L1`0300L700D700<01`L07@L00`071`051`0300L701`700<01`L0
1@L00`071`0k1`00M@L300/70`0D1`<02`L307D7001S1`<02`L700X7100C1`@02PL400041`0000/7
0`1S1`00HPL400X7100010L0000;1`<050L300/71`0:1`@0H`L006<70`0;1`<00PL00`071`0;1`03
00L701@700<01`L02`L00`071`0300/70`1S1`00A`L300/70`0<1`0300L700/700<01`L0>0L00`07
1`0;1`0300L700X70`0;1`<0A`L004H7100:1`@0K`L400X710171`00>PL300T7100;1`<000@70000
1@L300<70`031`<060L300T70`0I1`<00`L300870`061`<000@700002`L400T70`0j1`00>@L400P7
100=1`0300L000<010L4008710021`@05`L400P7100H1`@00PL400031`0000801@L4008700<01`L0
2PL400P7100j1`00>PL300T70`0@1`<01@L300<70`031`<060L300T70`0I1`<00`L300870`061`<0
40L300T70`0j1`00>`L00`071`091`0300L7010700<01`L01@L00`071`031`0300L700<700<01`L0
60L00`071`091`0300L701T700<01`L00`L00`071`021`0300L700H700<01`L040L00`071`091`03
00L703T7000l1`<01@L301`70`051`<070L300D70`0M1`<01@L301`70`051`<0?0L003/710041`@0
4PL300H710000`L0000501/710041`@070L400031`0000D01`L3014710041`@0?0L003`70`051`<0
4@L400L71`0010L0000L1`<01@L301d71`0010L000061`@04PL300D70`0l1`00?@L00`071`051`03
00L000802`L300041`0000P700<01`L00`021`0300L701`700<01`L01@L00`071`0M1`0300L700<0
0PL00`071`061`<000@700002`L300031`0700H700<01`L0>`L004H7100:1`@00PL00`071`0;1`03
00L704`700<01`L02`L00`07000300X710171`00A`L300/70`1`1`<02`L304L700181`0300L700/7
00<01`L02PL300/70`0h1`<02`L300`700<01`L02`L00`071`161`00HPL400X7100g1`@02PL406<7
001S1`<02`L300041`0000/70`0D1`<02`L300041`0000/70`1S1`00I0L00`071`0;1`0300L000<0
2PL401<7100:1`@00PL00`071`0;1`0300L70687000j1`<02@L301P70`091`<01@L300/70`021`<0
2@L300<70`0;1`<01@L300P70`0I1`<02@L303X7000i1`@020L401L710081`@01PL00`071`0;1`03
00L700@020L400@700<01`L02`L00`071`031`@01`L401P710081`@0>PL003X70`091`<060L300T7
0`0H1`<02@L301T70`081`<06@L300T70`0j1`00>`L00`07000200L700@01`L70`0D1`0300L700T7
00<01`L060L00`071`091`0300L701T700<01`L020L00`071`0C1`<00`L00`071`051`<000<700L0
>PL003`710071`L04PL300`70`0E1`<030L301D70`0<1`<04@L700L7100m1`00?@L300H7100010L0
000A1`@02`L401@7100;1`@050L400/7100B1`H020L303d7000n1`0300L700H70`021`0300L70147
0`0<1`<05@L300`70`0E1`<030L301<700<01`000P091`0300L703`700181`0300L701H700<01`L0
30L00`071`0;1`<01`L010071`L300041`0000@700<01`L010L300h700<01`L030L00`071`0E1`03
00L704L7001m1`@02PL800X7101o1`00OPL300/70`0010L0000;1`<0O`L007d7100:1`P02PL407l7
001n1`<02`L300041`0000/70`1o1`00O`L00`071`0;1`0500L71`003@L00`071`1n1`00D@L30087
0`0P1`<000@7000080L300041`0002070`0010L0001B1`00D0L400031`0000807`L801l7200O1`P0
DPL005470`021`<080L300041`0002070`0010L0000P1`<000@70000DPL0058700<01`L00PL00`07
1`0P1`0500L71`008PL01@071`L0028700D01`L7001C1`00H0L300`70`0E1`<030L301D70`0<1`<0
H0L005l7100;1`@050L400/7100D1`@02`L40607001P1`<030L300<70`0;1`<000@7000030L30004
1`0000/70`031`<030L30607001Q1`0300L700`700@01`L7100:1`@00PL00`071`0<1`0300L000<0
2PL400@700<01`L030L00`071`1O1`00H`L300/70`0010L0000;1`<050L300/70`0010L0000;1`<0
H`L00687100:1`@00PL00`071`0;1`0300L701@700<01`L02`L00`07000300X7101S1`00H`L300/7
0`0h1`<02`L306<7001T1`0300L700/700<01`L0>0L00`071`0;1`0300L70687003o1b47003o1b47
001i1`<000@7000080L300041`0007T7001h1`P07`L807T7001i1`<000@7000080L300041`0007T7
001j1`0500L71`008PL01@071`L007X7003o1b47003o1b47003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.3463, -10.3463, 0.0720999, \
0.0720999}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(averageTypeII\  = \ 
      ListPlot[SphericalCut[ALP2, 10], Axes \[Rule] False, 
        Prolog \[Rule] PointSize[0.015], AspectRatio \[Rule] Automatic, 
        Frame \[Rule] \ False]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0481025 0.5 0.0481025 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.015 w
.42785 .04303 Mdot
.52405 .04303 Mdot
.62026 .04303 Mdot
.23544 .13923 Mdot
.33164 .13923 Mdot
.42785 .13923 Mdot
.52405 .13923 Mdot
.62026 .13923 Mdot
.71646 .13923 Mdot
.81267 .13923 Mdot
.13923 .23544 Mdot
.23544 .23544 Mdot
.33164 .23544 Mdot
.42785 .23544 Mdot
.52405 .23544 Mdot
.62026 .23544 Mdot
.71646 .23544 Mdot
.81267 .23544 Mdot
.13923 .33164 Mdot
.23544 .33164 Mdot
.33164 .33164 Mdot
.42785 .33164 Mdot
.52405 .33164 Mdot
.62026 .33164 Mdot
.71646 .33164 Mdot
.81267 .33164 Mdot
.90887 .33164 Mdot
.04303 .42785 Mdot
.13923 .42785 Mdot
.23544 .42785 Mdot
.33164 .42785 Mdot
.42785 .42785 Mdot
.52405 .42785 Mdot
.62026 .42785 Mdot
.71646 .42785 Mdot
.81267 .42785 Mdot
.90887 .42785 Mdot
.04303 .52405 Mdot
.13923 .52405 Mdot
.23544 .52405 Mdot
.33164 .52405 Mdot
.42785 .52405 Mdot
.52405 .52405 Mdot
.62026 .52405 Mdot
.71646 .52405 Mdot
.81267 .52405 Mdot
.90887 .52405 Mdot
.04303 .62026 Mdot
.13923 .62026 Mdot
.23544 .62026 Mdot
.33164 .62026 Mdot
.42785 .62026 Mdot
.52405 .62026 Mdot
.62026 .62026 Mdot
.71646 .62026 Mdot
.81267 .62026 Mdot
.90887 .62026 Mdot
.13923 .71646 Mdot
.23544 .71646 Mdot
.33164 .71646 Mdot
.42785 .71646 Mdot
.52405 .71646 Mdot
.62026 .71646 Mdot
.71646 .71646 Mdot
.81267 .71646 Mdot
.90887 .71646 Mdot
.13923 .81267 Mdot
.23544 .81267 Mdot
.33164 .81267 Mdot
.42785 .81267 Mdot
.52405 .81267 Mdot
.62026 .81267 Mdot
.71646 .81267 Mdot
.81267 .81267 Mdot
.33164 .90887 Mdot
.42785 .90887 Mdot
.52405 .90887 Mdot
.62026 .90887 Mdot
.71646 .90887 Mdot
.77211 .12585 Mdot
.84014 .19388 Mdot
.90816 .2619 Mdot
.56803 .05782 Mdot
.63605 .12585 Mdot
.70408 .19388 Mdot
.77211 .2619 Mdot
.84014 .32993 Mdot
.90816 .39796 Mdot
.97619 .46599 Mdot
.43197 .05782 Mdot
.5 .12585 Mdot
.56803 .19388 Mdot
.63605 .2619 Mdot
.70408 .32993 Mdot
.77211 .39796 Mdot
.84014 .46599 Mdot
.90816 .53401 Mdot
.36395 .12585 Mdot
.43197 .19388 Mdot
.5 .2619 Mdot
.56803 .32993 Mdot
.63605 .39796 Mdot
.70408 .46599 Mdot
.77211 .53401 Mdot
.84014 .60204 Mdot
.90816 .67007 Mdot
.22789 .12585 Mdot
.29592 .19388 Mdot
.36395 .2619 Mdot
.43197 .32993 Mdot
.5 .39796 Mdot
.56803 .46599 Mdot
.63605 .53401 Mdot
.70408 .60204 Mdot
.77211 .67007 Mdot
.84014 .7381 Mdot
.15986 .19388 Mdot
.22789 .2619 Mdot
.29592 .32993 Mdot
.36395 .39796 Mdot
.43197 .46599 Mdot
.5 .53401 Mdot
.56803 .60204 Mdot
.63605 .67007 Mdot
.70408 .7381 Mdot
.77211 .80612 Mdot
.09184 .2619 Mdot
.15986 .32993 Mdot
.22789 .39796 Mdot
.29592 .46599 Mdot
.36395 .53401 Mdot
.43197 .60204 Mdot
.5 .67007 Mdot
.56803 .7381 Mdot
.63605 .80612 Mdot
.70408 .87415 Mdot
.09184 .39796 Mdot
.15986 .46599 Mdot
.22789 .53401 Mdot
.29592 .60204 Mdot
.36395 .67007 Mdot
.43197 .7381 Mdot
.5 .80612 Mdot
.56803 .87415 Mdot
.63605 .94218 Mdot
.02381 .46599 Mdot
.09184 .53401 Mdot
.15986 .60204 Mdot
.22789 .67007 Mdot
.29592 .7381 Mdot
.36395 .80612 Mdot
.43197 .87415 Mdot
.5 .94218 Mdot
.09184 .67007 Mdot
.15986 .7381 Mdot
.22789 .80612 Mdot
.29592 .87415 Mdot
.36395 .94218 Mdot
.33164 .09113 Mdot
.42785 .09113 Mdot
.52405 .09113 Mdot
.62026 .09113 Mdot
.71646 .09113 Mdot
.13923 .18733 Mdot
.23544 .18733 Mdot
.33164 .18733 Mdot
.42785 .18733 Mdot
.52405 .18733 Mdot
.62026 .18733 Mdot
.71646 .18733 Mdot
.81267 .18733 Mdot
.13923 .28354 Mdot
.23544 .28354 Mdot
.33164 .28354 Mdot
.42785 .28354 Mdot
.52405 .28354 Mdot
.62026 .28354 Mdot
.71646 .28354 Mdot
.81267 .28354 Mdot
.90887 .28354 Mdot
.04303 .37974 Mdot
.13923 .37974 Mdot
.23544 .37974 Mdot
.33164 .37974 Mdot
.42785 .37974 Mdot
.52405 .37974 Mdot
.62026 .37974 Mdot
.71646 .37974 Mdot
.81267 .37974 Mdot
.90887 .37974 Mdot
.04303 .47595 Mdot
.13923 .47595 Mdot
.23544 .47595 Mdot
.33164 .47595 Mdot
.42785 .47595 Mdot
.52405 .47595 Mdot
.62026 .47595 Mdot
.71646 .47595 Mdot
.81267 .47595 Mdot
.90887 .47595 Mdot
.04303 .57215 Mdot
.13923 .57215 Mdot
.23544 .57215 Mdot
.33164 .57215 Mdot
.42785 .57215 Mdot
.52405 .57215 Mdot
.62026 .57215 Mdot
.71646 .57215 Mdot
.81267 .57215 Mdot
.90887 .57215 Mdot
.13923 .66836 Mdot
.23544 .66836 Mdot
.33164 .66836 Mdot
.42785 .66836 Mdot
.52405 .66836 Mdot
.62026 .66836 Mdot
.71646 .66836 Mdot
.81267 .66836 Mdot
.90887 .66836 Mdot
.13923 .76456 Mdot
.23544 .76456 Mdot
.33164 .76456 Mdot
.42785 .76456 Mdot
.52405 .76456 Mdot
.62026 .76456 Mdot
.71646 .76456 Mdot
.81267 .76456 Mdot
.23544 .86077 Mdot
.33164 .86077 Mdot
.42785 .86077 Mdot
.52405 .86077 Mdot
.62026 .86077 Mdot
.71646 .86077 Mdot
.81267 .86077 Mdot
.42785 .95697 Mdot
.52405 .95697 Mdot
.62026 .95697 Mdot
.67007 .09184 Mdot
.7381 .15986 Mdot
.80612 .22789 Mdot
.87415 .29592 Mdot
.94218 .36395 Mdot
.46599 .02381 Mdot
.53401 .09184 Mdot
.60204 .15986 Mdot
.67007 .22789 Mdot
.7381 .29592 Mdot
.80612 .36395 Mdot
.87415 .43197 Mdot
.94218 .5 Mdot
.39796 .09184 Mdot
.46599 .15986 Mdot
.53401 .22789 Mdot
.60204 .29592 Mdot
.67007 .36395 Mdot
.7381 .43197 Mdot
.80612 .5 Mdot
.87415 .56803 Mdot
.94218 .63605 Mdot
.2619 .09184 Mdot
.32993 .15986 Mdot
.39796 .22789 Mdot
.46599 .29592 Mdot
.53401 .36395 Mdot
.60204 .43197 Mdot
.67007 .5 Mdot
.7381 .56803 Mdot
.80612 .63605 Mdot
.87415 .70408 Mdot
.19388 .15986 Mdot
.2619 .22789 Mdot
.32993 .29592 Mdot
.39796 .36395 Mdot
.46599 .43197 Mdot
.53401 .5 Mdot
.60204 .56803 Mdot
.67007 .63605 Mdot
.7381 .70408 Mdot
.80612 .77211 Mdot
.12585 .22789 Mdot
.19388 .29592 Mdot
.2619 .36395 Mdot
.32993 .43197 Mdot
.39796 .5 Mdot
.46599 .56803 Mdot
.53401 .63605 Mdot
.60204 .70408 Mdot
.67007 .77211 Mdot
.7381 .84014 Mdot
.12585 .36395 Mdot
.19388 .43197 Mdot
.2619 .5 Mdot
.32993 .56803 Mdot
.39796 .63605 Mdot
.46599 .70408 Mdot
.53401 .77211 Mdot
.60204 .84014 Mdot
.67007 .90816 Mdot
.05782 .43197 Mdot
.12585 .5 Mdot
.19388 .56803 Mdot
.2619 .63605 Mdot
.32993 .70408 Mdot
.39796 .77211 Mdot
.46599 .84014 Mdot
.53401 .90816 Mdot
.05782 .56803 Mdot
.12585 .63605 Mdot
.19388 .70408 Mdot
.2619 .77211 Mdot
.32993 .84014 Mdot
.39796 .90816 Mdot
.46599 .97619 Mdot
.12585 .77211 Mdot
.19388 .84014 Mdot
.2619 .90816 Mdot
.37974 .04303 Mdot
.47595 .04303 Mdot
.57215 .04303 Mdot
.18733 .13923 Mdot
.28354 .13923 Mdot
.37974 .13923 Mdot
.47595 .13923 Mdot
.57215 .13923 Mdot
.66836 .13923 Mdot
.76456 .13923 Mdot
.18733 .23544 Mdot
.28354 .23544 Mdot
.37974 .23544 Mdot
.47595 .23544 Mdot
.57215 .23544 Mdot
.66836 .23544 Mdot
.76456 .23544 Mdot
.86077 .23544 Mdot
.09113 .33164 Mdot
.18733 .33164 Mdot
.28354 .33164 Mdot
.37974 .33164 Mdot
.47595 .33164 Mdot
.57215 .33164 Mdot
.66836 .33164 Mdot
.76456 .33164 Mdot
.86077 .33164 Mdot
.09113 .42785 Mdot
.18733 .42785 Mdot
.28354 .42785 Mdot
.37974 .42785 Mdot
.47595 .42785 Mdot
.57215 .42785 Mdot
.66836 .42785 Mdot
.76456 .42785 Mdot
.86077 .42785 Mdot
.95697 .42785 Mdot
.09113 .52405 Mdot
.18733 .52405 Mdot
.28354 .52405 Mdot
.37974 .52405 Mdot
.47595 .52405 Mdot
.57215 .52405 Mdot
.66836 .52405 Mdot
.76456 .52405 Mdot
.86077 .52405 Mdot
.95697 .52405 Mdot
.09113 .62026 Mdot
.18733 .62026 Mdot
.28354 .62026 Mdot
.37974 .62026 Mdot
.47595 .62026 Mdot
.57215 .62026 Mdot
.66836 .62026 Mdot
.76456 .62026 Mdot
.86077 .62026 Mdot
.95697 .62026 Mdot
.09113 .71646 Mdot
.18733 .71646 Mdot
.28354 .71646 Mdot
.37974 .71646 Mdot
.47595 .71646 Mdot
.57215 .71646 Mdot
.66836 .71646 Mdot
.76456 .71646 Mdot
.86077 .71646 Mdot
.18733 .81267 Mdot
.28354 .81267 Mdot
.37974 .81267 Mdot
.47595 .81267 Mdot
.57215 .81267 Mdot
.66836 .81267 Mdot
.76456 .81267 Mdot
.86077 .81267 Mdot
.28354 .90887 Mdot
.37974 .90887 Mdot
.47595 .90887 Mdot
.57215 .90887 Mdot
.66836 .90887 Mdot
.7381 .09184 Mdot
.80612 .15986 Mdot
.87415 .22789 Mdot
.53401 .02381 Mdot
.60204 .09184 Mdot
.67007 .15986 Mdot
.7381 .22789 Mdot
.80612 .29592 Mdot
.87415 .36395 Mdot
.94218 .43197 Mdot
.46599 .09184 Mdot
.53401 .15986 Mdot
.60204 .22789 Mdot
.67007 .29592 Mdot
.7381 .36395 Mdot
.80612 .43197 Mdot
.87415 .5 Mdot
.94218 .56803 Mdot
.32993 .09184 Mdot
.39796 .15986 Mdot
.46599 .22789 Mdot
.53401 .29592 Mdot
.60204 .36395 Mdot
.67007 .43197 Mdot
.7381 .5 Mdot
.80612 .56803 Mdot
.87415 .63605 Mdot
.2619 .15986 Mdot
.32993 .22789 Mdot
.39796 .29592 Mdot
.46599 .36395 Mdot
.53401 .43197 Mdot
.60204 .5 Mdot
.67007 .56803 Mdot
.7381 .63605 Mdot
.80612 .70408 Mdot
.87415 .77211 Mdot
.19388 .22789 Mdot
.2619 .29592 Mdot
.32993 .36395 Mdot
.39796 .43197 Mdot
.46599 .5 Mdot
.53401 .56803 Mdot
.60204 .63605 Mdot
.67007 .70408 Mdot
.7381 .77211 Mdot
.80612 .84014 Mdot
.12585 .29592 Mdot
.19388 .36395 Mdot
.2619 .43197 Mdot
.32993 .5 Mdot
.39796 .56803 Mdot
.46599 .63605 Mdot
.53401 .70408 Mdot
.60204 .77211 Mdot
.67007 .84014 Mdot
.7381 .90816 Mdot
.05782 .36395 Mdot
.12585 .43197 Mdot
.19388 .5 Mdot
.2619 .56803 Mdot
.32993 .63605 Mdot
.39796 .70408 Mdot
.46599 .77211 Mdot
.53401 .84014 Mdot
.60204 .90816 Mdot
.05782 .5 Mdot
.12585 .56803 Mdot
.19388 .63605 Mdot
.2619 .70408 Mdot
.32993 .77211 Mdot
.39796 .84014 Mdot
.46599 .90816 Mdot
.53401 .97619 Mdot
.05782 .63605 Mdot
.12585 .70408 Mdot
.19388 .77211 Mdot
.2619 .84014 Mdot
.32993 .90816 Mdot
.28354 .09113 Mdot
.37974 .09113 Mdot
.47595 .09113 Mdot
.57215 .09113 Mdot
.66836 .09113 Mdot
.18733 .18733 Mdot
.28354 .18733 Mdot
.37974 .18733 Mdot
.47595 .18733 Mdot
.57215 .18733 Mdot
.66836 .18733 Mdot
.76456 .18733 Mdot
.86077 .18733 Mdot
.09113 .28354 Mdot
.18733 .28354 Mdot
.28354 .28354 Mdot
.37974 .28354 Mdot
.47595 .28354 Mdot
.57215 .28354 Mdot
.66836 .28354 Mdot
.76456 .28354 Mdot
.86077 .28354 Mdot
.09113 .37974 Mdot
.18733 .37974 Mdot
.28354 .37974 Mdot
.37974 .37974 Mdot
.47595 .37974 Mdot
.57215 .37974 Mdot
.66836 .37974 Mdot
.76456 .37974 Mdot
.86077 .37974 Mdot
.95697 .37974 Mdot
.09113 .47595 Mdot
.18733 .47595 Mdot
.28354 .47595 Mdot
.37974 .47595 Mdot
.47595 .47595 Mdot
.57215 .47595 Mdot
.66836 .47595 Mdot
.76456 .47595 Mdot
.86077 .47595 Mdot
.95697 .47595 Mdot
.09113 .57215 Mdot
.18733 .57215 Mdot
.28354 .57215 Mdot
.37974 .57215 Mdot
.47595 .57215 Mdot
.57215 .57215 Mdot
.66836 .57215 Mdot
.76456 .57215 Mdot
.86077 .57215 Mdot
.95697 .57215 Mdot
.09113 .66836 Mdot
.18733 .66836 Mdot
.28354 .66836 Mdot
.37974 .66836 Mdot
.47595 .66836 Mdot
.57215 .66836 Mdot
.66836 .66836 Mdot
.76456 .66836 Mdot
.86077 .66836 Mdot
.18733 .76456 Mdot
.28354 .76456 Mdot
.37974 .76456 Mdot
.47595 .76456 Mdot
.57215 .76456 Mdot
.66836 .76456 Mdot
.76456 .76456 Mdot
.86077 .76456 Mdot
.18733 .86077 Mdot
.28354 .86077 Mdot
.37974 .86077 Mdot
.47595 .86077 Mdot
.57215 .86077 Mdot
.66836 .86077 Mdot
.76456 .86077 Mdot
.37974 .95697 Mdot
.47595 .95697 Mdot
.57215 .95697 Mdot
.63605 .05782 Mdot
.70408 .12585 Mdot
.77211 .19388 Mdot
.84014 .2619 Mdot
.90816 .32993 Mdot
.5 .05782 Mdot
.56803 .12585 Mdot
.63605 .19388 Mdot
.70408 .2619 Mdot
.77211 .32993 Mdot
.84014 .39796 Mdot
.90816 .46599 Mdot
.97619 .53401 Mdot
.36395 .05782 Mdot
.43197 .12585 Mdot
.5 .19388 Mdot
.56803 .2619 Mdot
.63605 .32993 Mdot
.70408 .39796 Mdot
.77211 .46599 Mdot
.84014 .53401 Mdot
.90816 .60204 Mdot
.29592 .12585 Mdot
.36395 .19388 Mdot
.43197 .2619 Mdot
.5 .32993 Mdot
.56803 .39796 Mdot
.63605 .46599 Mdot
.70408 .53401 Mdot
.77211 .60204 Mdot
.84014 .67007 Mdot
.90816 .7381 Mdot
.22789 .19388 Mdot
.29592 .2619 Mdot
.36395 .32993 Mdot
.43197 .39796 Mdot
.5 .46599 Mdot
.56803 .53401 Mdot
.63605 .60204 Mdot
.70408 .67007 Mdot
.77211 .7381 Mdot
.84014 .80612 Mdot
.15986 .2619 Mdot
.22789 .32993 Mdot
.29592 .39796 Mdot
.36395 .46599 Mdot
.43197 .53401 Mdot
.5 .60204 Mdot
.56803 .67007 Mdot
.63605 .7381 Mdot
.70408 .80612 Mdot
.77211 .87415 Mdot
.09184 .32993 Mdot
.15986 .39796 Mdot
.22789 .46599 Mdot
.29592 .53401 Mdot
.36395 .60204 Mdot
.43197 .67007 Mdot
.5 .7381 Mdot
.56803 .80612 Mdot
.63605 .87415 Mdot
.09184 .46599 Mdot
.15986 .53401 Mdot
.22789 .60204 Mdot
.29592 .67007 Mdot
.36395 .7381 Mdot
.43197 .80612 Mdot
.5 .87415 Mdot
.56803 .94218 Mdot
.02381 .53401 Mdot
.09184 .60204 Mdot
.15986 .67007 Mdot
.22789 .7381 Mdot
.29592 .80612 Mdot
.36395 .87415 Mdot
.43197 .94218 Mdot
.09184 .7381 Mdot
.15986 .80612 Mdot
.22789 .87415 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;RLW9b40<?oo_`00?g=cLda<C820P8NZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmo
OiB;WMKBg2XX;H=kRhjYUM3KddiMD^GQY9no_m[ViUY]KHEhU000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOlS3cdDnCFml
S[g3bcU0B]C>N7j0VLG6dD52Cf]]PW5VO]_Ggd8lBVIbVOoo0_oo1mWIhEiPLko0c3m0C1lO9FAJKk>i
c=;EhC<iC1TL9DaELl30`9T0I_ooc020P800082006IVc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L008D70`0@1`<0Q@L008@7100?1`@0Q@L008D70`0@1`<0Q@L008H700<01`L040L00`07
1`241`00o`LQ1`00K0L300/70`0:1`<02`L300/70`0;1`<0K0L006/7100:1`@02@L400X7100:1`@0
2PL406`7001/1`<02`L300X70`0;1`<02`L300/70`1/1`00K@L00`071`0;1`0300L700X700<01`L0
2`L00`071`0;1`0300L700/700<01`L0J`L00?l78@L006L70`0A1`<040L301470`0@1`<0J0L006H7
100@1`@03`L40107100?1`@0J0L006L70`0A1`<040L301470`0@1`<0J0L006P700<01`L04@L00`07
1`0@1`0300L7014700<01`L040L00`071`1W1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00
BPL300<70`0;1`<02`L300870`061`<020L500/71P081`<01PL300870`0;1`<02`L300<70`1:1`00
B@L40087100:1`@02PL400031`0000801@L400L71P0:1`L01`L400D710000`L0000200X7100:1`@0
0PL404X7001:1`<00`L300/70`0;1`<00PL300H70`081`D02`L600P70`061`<00PL300/70`0;1`<0
0`L304X7001;1`0300L700<700<01`L02`L00`071`0;1`0300L7008700<01`L01PL00`071`081`03
00L000d700@01`L02PL00`071`061`0300L7008700<01`L02`L00`071`0;1`0300L700<700<01`L0
B@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L004070`0A1`<040L301470`0@1`<0
4@L301070`0A1`<040L30447000o1`@040L400l7100@1`@03`L40107100?1`@040L400l710111`00
@0L301470`0@1`<04@L301070`0A1`<040L301470`0@1`<0@@L0044700<01`L04@L00`071`0@1`03
00L7014700<01`L040L00`071`0A1`0300L7010700<01`L04@L00`071`0@1`0300L70407000e1`<0
2PL300/70`0;1`<02`L300/70`0:1`<02`L300/70`0;1`<02`L300/70`0:1`<02`L303D7000d1`@0
2@L400X7100:1`@02PL400X710091`@02PL400X7100:1`@02PL400X710091`@02PL403D7000e1`<0
2PL300/70`0;1`<02`L300/70`0:1`<02`L300/70`0;1`<02`L300/70`0:1`<02`L303D7000f1`03
00L700X700<01`L02`L00`071`0;1`0300L700/700<01`L02`L00`071`0:1`0300L700/700<01`L0
2`L00`071`0;1`0300L700/700<01`L02`L00`071`0:1`0300L700/700<01`L0=0L00?l78@L00?l7
8@L003L70`0@1`<04@L301070`0A1`<040L301470`0@1`<04@L301070`0g1`00=PL400l7100@1`@0
3`L40107100?1`@040L400l7100@1`@03`L403L7000g1`<040L301470`0@1`<04@L301070`0A1`<0
40L301470`0@1`<0=`L003P700<01`L040L00`071`0A1`0300L7010700<01`L04@L00`071`0@1`03
00L7014700<01`L040L00`071`0A1`0300L7010700<01`L0=PL00?l78@L00?l78@L00?l78@L00?l7
8@L002L70`0;1`<02PL300/70`0;1`<02`L300/70`0:1`<02`L300/70`0;1`<02`L300/70`0:1`<0
2`L300/70`0W1`009PL400X710091`@02PL400X7100:1`@02PL400T7100:1`@02PL400X7100:1`@0
2PL400T7100:1`@02PL402L7000W1`<00`L300D70`081`D02`L300041`0000L70`061`<00PL300/7
10091`<010L300@70`0:1`@02`L300041`0000L70`071`<000@700002PL500T70`051`<00`L302L7
000X1`0400L71`@01PL00`071`061`D03@L00`07000300P700<01`L010L400<700<01`L02PL400X7
00<01`L00PL400D700<01`L020L400d700<01`000`081`0300L700D710021`0300L700X7100:1`03
00L700<710041`0300L702H7000]1`<040L301470`0@1`<04@L301070`0A1`<040L301470`0@1`<0
4@L302d7000^1`0300L7010700<01`L04@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`03
00L7010700<01`L04@L00`071`0@1`0300L7014700<01`L0;0L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L002<70`0A1`<040L301470`0@1`<04@L301070`0A1`<040L301470`0@1`<0
4@L302<7000R1`@040L400l7100@1`@03`L40107100?1`@040L400l7100@1`@03`L40107100S1`00
8`L300041`0000/71@081`<01@L300<70`0;1`<02`L300870`061`<020L500/71P081`<01PL30087
0`0;1`<02`L300<70`041`<02@L500/70`0010L0000S1`0090L00`07000300X71@081`@01PL01007
1`L400X7100:1`@00`L00`071`041`@02@L400X710000`L01`071`@01`L00`071`0400X7100:1`@0
10L00`071`021`@02PL400X710021`0300L70287000W1`<02`L300X70`0;1`<02`L300/70`0;1`<0
2PL300/70`0;1`<02`L300/70`0;1`<02PL300/70`0;1`<09`L002P700<01`L02`L00`071`0:1`03
00L700/700<01`L02`L00`071`0;1`0300L700/700<01`L02PL00`071`0;1`0300L700/700<01`L0
2`L00`071`0;1`0300L700/700<01`L02PL00`071`0;1`0300L700/700<01`L09PL00?l78@L00?l7
8@L00?l78@L001T70`0A1`<040L301470`0@1`<04@L301070`0A1`<040L301470`0@1`<04@L30147
0`0I1`0060L40107100?1`@040L400l7100@1`@03`L40107100?1`@040L400l7100@1`@040L401T7
000I1`<04@L301070`0A1`<040L301470`0@1`<04@L301070`0A1`<040L301470`0A1`<06@L001X7
00<01`L04@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L7010700<01`L04@L00`07
1`0@1`0300L7014700<01`L040L00`071`0A1`0300L7014700<01`L060L00?l78@L00?l78@L001T7
0`0;1`<02`L300X70`0;1`<02`L300/70`0;1`<02PL300/70`0;1`<02`L300/70`0;1`<02PL300/7
0`0;1`<02`L301T7000H1`@02PL400X710091`@02PL400X7100:1`@02PL400T7100:1`@02PL400X7
100:1`@02PL400T7100:1`@02PL400X7100I1`006@L300/70`0;1`<02PL300/70`0;1`<02`L300/7
0`0:1`<02`L300/70`0;1`<02`L300/70`0:1`<02`L300/70`0;1`<06@L001X700<01`L02`L00`07
1`0;1`0300L700X700<01`L02`L00`071`0;1`0300L700/700<01`L02`L00`071`0:1`0300L700/7
00<01`L02`L00`071`0;1`0300L700/700<01`L02`L00`071`0:1`0300L700/700<01`L02`L00`07
1`0;1`0300L701P7000S1`<04@L301070`0A1`<040L301470`0@1`<04@L301070`0A1`<040L30147
0`0S1`008PL40107100?1`@040L400l7100@1`@03`L40107100?1`@040L400l7100@1`@08`L002<7
0`0A1`<040L301470`0@1`<04@L301070`0A1`<040L301470`0@1`<04@L302<7000T1`0300L70147
00<01`L040L00`071`0A1`0300L7010700<01`L04@L00`071`0@1`0300L7014700<01`L040L00`07
1`0A1`0300L7010700<01`L04@L00`071`0R1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00
o`LQ1`006@L300/70`031`<01@L300P71@0;1`<000@700001`L300H70`021`<02`L400T70`041`<0
10L300X7100;1`<000@700001`L300L70`0010L0000:1`D02@L300D70`031`<02`L301T7000H1`@0
2PL4008710041`@01`L600X720061`@01@L400031`0000802PL500P710031`@00`L400T71@0:1`P0
1PL400H720091`H020L400@710021`@02PL401T7000I1`<02`L300<70`051`<020L500/70`0010L0
00071`<01PL300870`0;1`@02@L300@70`041`<02PL400/70`0010L000071`<01`L300041`0000X7
1@091`<01@L300<70`0;1`<06@L001X700<01`L02`L00`071`031`0300L700D700<01`L020L00`07
000=1`0500L71`002@L00`071`061`0300L7008700<01`L02`L200/700<01`L010L00`071`041`03
00L700X70P0=1`0500L71`002@L00`071`071`0500L71`0030L00`07000;1`0300L700D700<01`L0
0`L00`071`0;1`0300L701P7003o1b47003o1b47003o1b47003o1b47003o1b47003o1b47000?1`<0
4@L301470`0@1`<04@L301070`0A1`<040L301470`0@1`<04@L301070`0A1`<040L30107000>1`@0
40L40107100?1`@040L400l7100@1`@03`L40107100?1`@040L400l7100@1`@03`L40107000?1`<0
4@L301470`0@1`<04@L301070`0A1`<040L301470`0@1`<04@L301070`0A1`<040L30107000@1`03
00L7014700<01`L04@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L7010700<01`L0
4@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L7010700<01`L03`L000/70`0;1`<0
2`L300/70`0:1`<02`L300/70`0;1`<02`L300X70`0;1`<02`L300/70`0;1`<02`L300X70`0;1`<0
2`L300/70`0;1`<02`L000X7100:1`@02PL400X710091`@02PL400X7100:1`@02PL400T7100:1`@0
2PL400X7100:1`@02PL400T7100:1`@02PL400X7100:1`@02`L000/70`0;1`<02`L300/70`0:1`<0
2`L300/70`0;1`<02`L300X70`0;1`<02`L300/70`0;1`<02`L300X70`0;1`<02`L300/70`0;1`<0
2`L000`700<01`L02`L00`071`0;1`0300L700/700<01`L02PL00`071`0;1`0300L700/700<01`L0
2`L00`071`0;1`0300L700X700<01`L02`L00`071`0;1`0300L700/700<01`L02`L00`071`0;1`03
00L700X700<01`L02`L00`071`0;1`0300L700/700<01`L02`L00`071`0:1`00o`LQ1`006@L30147
0`0@1`<04@L301070`0A1`<040L301470`0@1`<04@L301070`0A1`<04@L301T7000H1`@040L400l7
100@1`@03`L40107100?1`@040L400l7100@1`@03`L40107100@1`@06@L001T70`0A1`<040L30147
0`0@1`<04@L301070`0A1`<040L301470`0@1`<04@L301470`0I1`006PL00`071`0A1`0300L70107
00<01`L04@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L7010700<01`L04@L00`07
1`0@1`0300L7014700<01`L04@L00`071`0H1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00
2`L300/70`0;1`<02`L300X70`0;1`<02`L300/70`0;1`<02PL300/70`0;1`<02`L300/70`0;1`<0
2PL300/70`0;1`<02`L300/70`0;1`002PL400041`0000H710071`L02PL600L710051`<00PL400X7
100:1`@00PL300D710081`D02PL700L710061`<000<700000P0:1`@02PL400<70`031`@02@L500X7
100010L000061`@01PL300031`0000802`L000/71`071`<01PL400041`0000/71@081`<010L400<7
0`0:1`@02`L300031`0000801PL300L71P0;1`H020L300D710021`<02PL400/70`021`@010L300P7
1P0;1`L01`L300D710021`<02`L000`700<01`L00`081`0300L700H70`021`0300L700/710091`03
00L700@70`041`0300L700X70`0<1`0400L71`<01`L00`071`071`@03@L00`07000200T700<01`L0
1@L300<700<01`L02PL300`700<01`L00PL300D700<01`L020L400d700<01`L00`081`0300L700D7
0`031`0300L700X7000@1`0300L7014700<01`L04@L00`071`0@1`0300L7014700<01`L040L00`07
1`0A1`0300L7010700<01`L04@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L70107
00<01`L03`L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L000H70`0@1`<04@L30107
0`0A1`<040L301470`0@1`<04@L301070`0A1`<040L301470`0A1`<040L300H700051`@03`L40107
100?1`@040L400l7100@1`@03`L40107100?1`@040L400l7100@1`@040L400l710061`001PL30107
0`0A1`<040L301470`0@1`<04@L301070`0A1`<040L301470`0@1`<04@L301470`0@1`<01PL000L7
00@01`L70`0;1`<02`L300@700<01`L010L300T7100;1`<00PL00`071`061`<01`L010071`L300/7
0`0:1`<01@L00`071`031`<02`L300/70`021`0300L700H70`081`0300L700<02PL400X70`061`03
00L700870`0;1`<02`L300<700<01`L01@L000X7100:1`@02PL400X710091`@02PL400X7100:1`@0
2PL400T7100:1`@02PL400X7100:1`@02PL400T7100:1`@02PL400X7100:1`@02`L000/70`0;1`<0
2`L300/70`0:1`<02`L300/70`0;1`<02`L300X70`0;1`<02`L300/70`0;1`<02`L300X70`0;1`<0
2`L300/70`0;1`<02`L000`700<01`L02`L00`071`0;1`0300L700/700<01`L02PL00`071`0;1`03
00L700/700<01`L02`L00`071`0;1`0300L700X700<01`L02`L00`071`0;1`0300L700/700<01`L0
2`L00`071`0;1`0300L700X700<01`L02`L00`071`0;1`0300L700/700<01`L02`L00`071`0:1`00
o`LQ1`00o`LQ1`00o`LQ1`003`L301470`0A1`<040L301470`0@1`<04@L301070`0A1`<040L30147
0`0@1`<04@L301070`0@1`003PL40107100@1`@03`L40107100?1`@040L400l7100@1`@03`L40107
100?1`@040L400l7100@1`003`L301470`0A1`<040L301470`0@1`<04@L301070`0A1`<040L30147
0`0@1`<04@L301070`0@1`0040L00`071`0A1`0300L7014700<01`L040L00`071`0A1`0300L70107
00<01`L04@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L7010700<01`L04@L00`07
1`0@1`0300L700l7003o1b47003o1b47003o1b47000;1`<02`L300/70`0;1`<02PL300/70`0;1`<0
2`L300/70`0:1`<02`L300/70`0;1`<02`L300/70`0:1`<02`L300/70`0;1`<02`L300/7000:1`@0
2PL400X7100:1`@02@L400X7100:1`@02PL400X710091`@02PL400X7100:1`@02PL400X710091`@0
2PL400X7100:1`@02PL400/700061`<00PL300/70`0;1`<00`L300D70`081`D02`L300041`0000L7
0`061`<00PL300/710091`<010L300@70`0:1`@02`L300041`0000L70`071`<000@700002PL500T7
0`051`<00`L300/70`0;1`<00PL300H700051`@00`L00`071`091`@030L010071`L400H700<01`L0
1PL500d700<01`000`081`0300L700@710031`0300L700X7100:1`0300L7008710051`0300L700P7
100=1`0300L000<020L00`071`051`@00PL00`071`0:1`@02PL00`071`031`@010L00`071`091`@0
30L00`071`0400H700061`<040L301470`0@1`<04@L301070`0A1`<040L301470`0@1`<04@L30107
0`0A1`<04@L301070`061`001`L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L70107
00<01`L04@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L7010700<01`L04@L00`07
1`0A1`0300L7010700<01`L01@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L000l7
0`0A1`<04@L301070`0A1`<040L301470`0@1`<04@L301070`0A1`<040L301470`0@1`<040L000/7
1`071`<01PL400041`0000/71@081`<010L400<70`0:1`@02`L300031`0000801PL300L71P0;1`H0
20L300D710021`<02PL400/70`021`@010L300P71P0;1`L01`L300D710021`<02`L000X7100010L0
00061`@01`L700X71P071`@01@L30087100:1`@02PL400870`051`@020L500X71`071`@01PL30003
1`0000802PL400X710031`<00`L400T71@0:1`@000@700001PL400H70`000`L0000200/7000;1`<0
0PL00`071`061`<020L00`071`0300/710091`<01PL00`071`021`<02`L300/70`031`0300L700D7
0`091`@02`L300031`0700P70`071`0400L71`<02`L300/70`041`0300L700<70`0:1`@02`L30087
00<01`L01PL300L700@01`L70`0;1`0030L00`071`0;1`0300L700/700<01`L02`L00`071`0:1`03
00L700/700<01`L02`L00`071`0;1`0300L700/700<01`L02PL00`071`0;1`0300L700/700<01`L0
2`L00`071`0;1`0300L700/700<01`L02PL00`071`0;1`0300L700/700<01`L02`L00`071`0;1`03
00L700X7003o1b47003o1b47003o1b47003o1b47003o1b47000I1`<04@L301070`0A1`<040L30147
0`0@1`<04@L301070`0A1`<040L301470`0A1`<06@L001P7100@1`@03`L40107100?1`@040L400l7
100@1`@03`L40107100?1`@040L40107100I1`006@L301470`0@1`<04@L301070`0A1`<040L30147
0`0@1`<04@L301070`0A1`<04@L301T7000J1`0300L7014700<01`L040L00`071`0A1`0300L70107
00<01`L04@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L7010700<01`L04@L00`07
1`0A1`0300L701P7003o1b47000;1`<02`L300/70`0;1`<02PL300/70`0;1`<02`L300/70`0:1`<0
2`L300/70`0;1`<02`L300/70`0:1`<02`L300/70`0;1`<02`L300/7000:1`@02PL400X7100:1`@0
2@L400X7100:1`@02PL400X710091`@02PL400X7100:1`@02PL400X710091`@02PL400X7100:1`@0
2PL400/7000;1`<02`L300/70`0;1`<02PL300/70`0;1`<02`L300/70`0:1`<02`L300/70`0;1`<0
2`L300/70`0:1`<02`L300/70`0;1`<02`L300/7000<1`0300L700/700<01`L02`L00`071`0;1`03
00L700X700<01`L02`L00`071`0;1`0300L700/700<01`L02`L00`071`0:1`0300L700/700<01`L0
2`L00`071`0;1`0300L700/700<01`L02`L00`071`0:1`0300L700/700<01`L02`L00`071`0;1`03
00L700/700<01`L02PL00?l78@L000l70`0A1`<04@L301070`0A1`<040L301470`0@1`<04@L30107
0`0A1`<040L301470`0@1`<040L000h7100@1`@040L400l7100@1`@03`L40107100?1`@040L400l7
100@1`@03`L40107100?1`@040L000l70`0A1`<04@L301070`0A1`<040L301470`0@1`<04@L30107
0`0A1`<040L301470`0@1`<040L0010700<01`L04@L00`071`0A1`0300L7010700<01`L04@L00`07
1`0@1`0300L7014700<01`L040L00`071`0A1`0300L7010700<01`L04@L00`071`0@1`0300L70147
00<01`L040L00`071`0?1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`006@L300/70`031`<0
1@L300P71@0;1`<000@700001`L300H70`021`<02`L400T70`041`<010L300X7100;1`<000@70000
1`L300L70`0010L0000:1`D02@L300D70`031`<02`L301T7000H1`@02PL4008710041`@01`L600X7
20061`@01@L400031`0000802PL500P710031`@00`L400T71@0:1`P01PL400H720091`H020L400@7
10021`@02PL401T7000I1`<02`L300<70`051`<020L500/70`0010L000071`<01PL300870`0;1`@0
2@L300@70`041`<02PL400/70`0010L000071`<01`L300041`0000X71@091`<01@L300<70`0;1`<0
6@L001X700<01`L02`L00`071`031`0300L700D700<01`L020L00`07000=1`0500L71`002@L00`07
1`061`0300L7008700<01`L02`L200/700<01`L010L00`071`041`0300L700X70P0=1`0500L71`00
2@L00`071`071`0500L71`0030L00`07000;1`0300L700D700<01`L00`L00`071`0;1`0300L701P7
003o1b47003o1b47003o1b47003o1b47003o1b47003o1b47000S1`<04@L301070`0A1`<040L30147
0`0@1`<04@L301070`0A1`<040L301470`0S1`008PL40107100?1`@040L400l7100@1`@03`L40107
100?1`@040L400l7100@1`@08`L002<70`0A1`<040L301470`0@1`<04@L301070`0A1`<040L30147
0`0@1`<04@L302<7000T1`0300L7014700<01`L040L00`071`0A1`0300L7010700<01`L04@L00`07
1`0@1`0300L7014700<01`L040L00`071`0A1`0300L7010700<01`L04@L00`071`0R1`006@L300/7
0`0;1`<02PL300/70`0;1`<02`L300/70`0:1`<02`L300/70`0;1`<02`L300/70`0:1`<02`L300/7
0`0;1`<06@L001P7100:1`@02PL400T7100:1`@02PL400X7100:1`@02@L400X7100:1`@02PL400X7
100:1`@02@L400X7100:1`@02PL401T7000I1`<02`L300/70`0:1`<02`L300/70`0;1`<02`L300X7
0`0;1`<02`L300/70`0;1`<02`L300X70`0;1`<02`L300/70`0I1`006PL00`071`0;1`0300L700/7
00<01`L02PL00`071`0;1`0300L700/700<01`L02`L00`071`0;1`0300L700X700<01`L02`L00`07
1`0;1`0300L700/700<01`L02`L00`071`0;1`0300L700X700<01`L02`L00`071`0;1`0300L700/7
00<01`L060L00?l78@L00?l78@L001T70`0A1`<040L301470`0@1`<04@L301070`0A1`<040L30147
0`0@1`<04@L301470`0I1`0060L40107100?1`@040L400l7100@1`@03`L40107100?1`@040L400l7
100@1`@040L401T7000I1`<04@L301070`0A1`<040L301470`0@1`<04@L301070`0A1`<040L30147
0`0A1`<06@L001X700<01`L04@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L70107
00<01`L04@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L7014700<01`L060L00?l7
8@L00?l78@L00?l78@L00?l78@L002L70`0;1`<02PL300/70`0;1`<02`L300/70`0:1`<02`L300/7
0`0;1`<02`L300/70`0:1`<02`L300/70`0W1`009PL400X710091`@02PL400X7100:1`@02PL400T7
100:1`@02PL400X7100:1`@02PL400T7100:1`@02PL402L7000S1`<000@700002`L500P70`051`<0
0`L300/70`0;1`<00PL300H70`081`D02`L600P70`061`<00PL300/70`0;1`<00`L300@70`091`D0
2`L300041`0002<7000R1`@00PL00`071`0;1`@02@L00`071`031`@010L00`071`091`@030L00`07
1`0400L700<01`L01PL500d71@091`0300L700@710031`0300L700T7100<1`0400L71`@01@L00`07
1`071`D03@L00`07000302<7000S1`<04@L301070`0A1`<040L301470`0@1`<04@L301070`0A1`<0
40L301470`0S1`0090L00`071`0A1`0300L7010700<01`L04@L00`071`0@1`0300L7014700<01`L0
40L00`071`0A1`0300L7010700<01`L04@L00`071`0@1`0300L7014700<01`L08PL00?l78@L00?l7
8@L00?l78@L00?l78@L00?l78@L002d70`0@1`<04@L301070`0A1`<040L301470`0@1`<04@L30107
0`0A1`<0;@L002`7100?1`@040L400l7100@1`@03`L40107100?1`@040L400l7100@1`@0;@L002L7
0`031`<01@L300P71@0;1`<000@700001`L300H70`021`<02`L400T70`041`<010L300X7100;1`<0
00@700001`L300L70`0010L0000:1`D02@L300D70`031`<09`L002H710041`0300L700<710091`@0
2PL4008700<01`L01@L400L700<01`L0100:1`@02@L400D700<01`L00PL400X7100:1`@00PL00`07
1`051`@020L00`07000300T71@091`@01PL010071`L402L7000W1`<02`L300X70`0;1`<02`L300/7
0`0;1`<02PL300/70`0;1`<02`L300/70`0;1`<02PL300/70`0;1`<09`L002P700<01`L02`L00`07
1`0:1`0300L700/700<01`L02`L00`071`0;1`0300L700/700<01`L02PL00`071`0;1`0300L700/7
00<01`L02`L00`071`0;1`0300L700/700<01`L02PL00`071`0;1`0300L700/700<01`L09PL00?l7
8@L00?l78@L00?l78@L00?l78@L003L70`0@1`<04@L301070`0A1`<040L301470`0@1`<04@L30107
0`0g1`00=PL400l7100@1`@03`L40107100?1`@040L400l7100@1`@03`L403L7000g1`<040L30147
0`0@1`<04@L301070`0A1`<040L301470`0@1`<0=`L003P700<01`L040L00`071`0A1`0300L70107
00<01`L04@L00`071`0@1`0300L7014700<01`L040L00`071`0A1`0300L7010700<01`L0=PL00?l7
8@L00?l78@L003D70`0:1`<02`L300/70`0;1`<02`L300X70`0;1`<02`L300/70`0;1`<02`L300X7
0`0;1`<0=@L003@710091`@02PL400X7100:1`@02PL400T7100:1`@02PL400X7100:1`@02PL400T7
100:1`@0=@L003D70`0:1`<02`L300/70`0;1`<02`L300X70`0;1`<02`L300/70`0;1`<02`L300X7
0`0;1`<0=@L003H700<01`L02PL00`071`0;1`0300L700/700<01`L02`L00`071`0;1`0300L700X7
00<01`L02`L00`071`0;1`0300L700/700<01`L02`L00`071`0;1`0300L700X700<01`L02`L00`07
1`0d1`00@0L301470`0@1`<04@L301070`0A1`<040L301470`0@1`<0@@L003l7100@1`@03`L40107
100?1`@040L400l7100@1`@03`L4044700101`<04@L301070`0A1`<040L301470`0@1`<04@L30107
0`111`00@@L00`071`0A1`0300L7010700<01`L04@L00`071`0@1`0300L7014700<01`L040L00`07
1`0A1`0300L7010700<01`L0@0L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L004X7
0`031`<02`L300/70`021`<01PL300P71@0;1`H020L300H70`021`<02`L300/70`031`<0BPL004T7
10021`@02PL400X710000`L0000200D710071`H02PL700L710051`@000<700000P0:1`@02PL40087
101:1`00BPL300<70`0;1`<02`L300870`061`<020L500/71P081`<01PL300870`0;1`<02`L300<7
0`1:1`00B`L00`071`031`0300L700/700<01`L02`L00`071`021`0300L700H700<01`L020L00`07
000=1`0400L700X700<01`L01PL00`071`021`0300L700/700<01`L02`L00`071`031`0300L704T7
003o1b47003o1b47003o1b47003o1b47003o1b47003o1b47001W1`<04@L301070`0A1`<040L306P7
001V1`@040L400l7100@1`@03`L406P7001W1`<04@L301070`0A1`<040L306P7001X1`0300L70147
00<01`L040L00`071`0A1`0300L7010700<01`L0I`L006`70`0;1`<02PL300/70`0;1`<02`L306`7
001[1`@02PL400T7100:1`@02PL400X7101/1`00K0L300/70`0:1`<02`L300/70`0;1`<0K0L006d7
00<01`L02`L00`071`0:1`0300L700/700<01`L02`L00`071`0;1`0300L706/7003o1b4700251`<0
40L308D700241`@03`L408D700251`<040L308D700261`0300L7010700<01`L0Q0L00?l78@L00?l7
8@L00?l78@L00?l78@L00?l78@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.3946, -10.3946, 0.0724361, \
0.0724361}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Comparing with the Penrose tiling", "Text",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[octatiling, averageLattice]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0478596 0.5 0.0478596 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .46616 m
.05765 .5 L
s
.02381 .46616 m
.07167 .46616 L
s
.02381 .53384 m
.05765 .5 L
s
.02381 .53384 m
.07167 .53384 L
s
.05765 .3366 m
.05765 .38446 L
s
.05765 .3366 m
.05765 .38446 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .38446 m
.05765 .3366 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .3366 m
.05765 .38446 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .5 m
.10551 .5 L
s
.05765 .5 m
.10551 .5 L
s
.05765 .61554 m
.05765 .6634 L
s
.05765 .61554 m
.10551 .61554 L
s
.05765 .61554 m
.10551 .61554 L
s
.05765 .6634 m
.10551 .6634 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .4183 m
.07167 .46616 L
s
.07167 .4183 m
.10551 .38446 L
s
.07167 .4183 m
.10551 .38446 L
s
.07167 .4183 m
.10551 .45214 L
s
.07167 .4183 m
.10551 .38446 L
s
.07167 .4183 m
.10551 .45214 L
s
.07167 .46616 m
.10551 .5 L
s
.07167 .46616 m
.10551 .5 L
s
.07167 .53384 m
.07167 .5817 L
s
.07167 .53384 m
.10551 .5 L
s
.07167 .53384 m
.10551 .5 L
s
.07167 .5817 m
.10551 .61554 L
s
.07167 .5817 m
.10551 .54786 L
s
.07167 .5817 m
.10551 .61554 L
s
.07167 .69724 m
.10551 .73109 L
s
.07167 .69724 m
.10551 .6634 L
s
.07167 .69724 m
.10551 .73109 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .45214 m
.10551 .5 L
s
.10551 .45214 m
.10551 .5 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .5 m
.10551 .45214 L
s
.10551 .5 m
.10551 .54786 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .61554 m
.10551 .6634 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .73109 m
.13935 .69724 L
s
.10551 .73109 m
.13935 .69724 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .45214 m
.10551 .5 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .5 m
.10551 .54786 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .54786 m
.13935 .5817 L
s
.10551 .54786 m
.13935 .5817 L
s
.10551 .54786 m
.13935 .5817 L
s
.10551 .61554 m
.10551 .6634 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .6634 m
.13935 .69724 L
s
.10551 .6634 m
.13935 .69724 L
s
.10551 .73109 m
.13935 .69724 L
s
.10551 .73109 m
.13935 .69724 L
s
.13935 .18721 m
.17319 .22105 L
s
.13935 .18721 m
.18721 .18721 L
s
.13935 .2549 m
.13935 .30276 L
s
.13935 .2549 m
.13935 .30276 L
s
.13935 .2549 m
.17319 .22105 L
s
.13935 .2549 m
.18721 .2549 L
s
.13935 .30276 m
.13935 .35062 L
s
.13935 .30276 m
.13935 .35062 L
s
.13935 .30276 m
.18721 .30276 L
s
.13935 .35062 m
.13935 .30276 L
s
.13935 .35062 m
.17319 .38446 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .35062 m
.13935 .30276 L
s
.13935 .35062 m
.17319 .38446 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .4183 m
.13935 .46616 L
s
.13935 .4183 m
.13935 .46616 L
s
.13935 .4183 m
.17319 .38446 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .46616 m
.13935 .4183 L
s
.13935 .46616 m
.17319 .5 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.17319 .5 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .5817 m
.13935 .53384 L
s
.13935 .5817 m
.13935 .53384 L
s
.13935 .5817 m
.17319 .61554 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .64938 m
.13935 .69724 L
s
.13935 .64938 m
.13935 .69724 L
s
.13935 .64938 m
.17319 .61554 L
s
.13935 .64938 m
.18721 .64938 L
s
.13935 .69724 m
.13935 .7451 L
s
.13935 .69724 m
.13935 .64938 L
s
.13935 .69724 m
.18721 .69724 L
s
.13935 .7451 m
.13935 .69724 L
s
.13935 .7451 m
.17319 .77895 L
s
.13935 .7451 m
.18721 .7451 L
s
.13935 .81279 m
.17319 .77895 L
s
.13935 .81279 m
.18721 .81279 L
s
.13935 .46616 m
.13935 .4183 L
s
.13935 .46616 m
.17319 .5 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.17319 .5 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .5817 m
.13935 .53384 L
s
.13935 .5817 m
.17319 .61554 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .30276 m
.18721 .30276 L
s
.13935 .4183 m
.17319 .38446 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.17319 .5 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .5817 m
.17319 .61554 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .64938 m
.13935 .69724 L
s
.13935 .64938 m
.17319 .61554 L
s
.13935 .64938 m
.18721 .64938 L
s
.13935 .69724 m
.18721 .69724 L
s
.17319 .22105 m
.22105 .22105 L
s
.17319 .38446 m
.22105 .38446 L
s
.17319 .38446 m
.22105 .38446 L
s
.17319 .5 m
.22105 .5 L
s
.17319 .61554 m
.22105 .61554 L
s
.17319 .77895 m
.22105 .77895 L
s
.18721 .13935 m
.18721 .18721 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .13935 m
.18721 .18721 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .18721 m
.22105 .22105 L
s
.18721 .2549 m
.18721 .30276 L
s
.18721 .2549 m
.22105 .22105 L
s
.18721 .30276 m
.18721 .35062 L
s
.18721 .30276 m
.18721 .35062 L
s
.18721 .30276 m
.22105 .26891 L
s
.18721 .30276 m
.22105 .3366 L
s
.18721 .30276 m
.22105 .3366 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .4183 m
.18721 .46616 L
s
.18721 .4183 m
.18721 .46616 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .45214 L
s
.18721 .46616 m
.18721 .4183 L
s
.18721 .46616 m
.22105 .5 L
s
.18721 .53384 m
.18721 .5817 L
s
.18721 .53384 m
.18721 .5817 L
s
.18721 .53384 m
.22105 .5 L
s
.18721 .5817 m
.18721 .53384 L
s
.18721 .5817 m
.22105 .54786 L
s
.18721 .5817 m
.22105 .61554 L
s
.18721 .64938 m
.18721 .69724 L
s
.18721 .64938 m
.22105 .61554 L
s
.18721 .69724 m
.18721 .7451 L
s
.18721 .69724 m
.22105 .6634 L
s
.18721 .69724 m
.22105 .73109 L
s
.18721 .7451 m
.22105 .77895 L
s
.18721 .81279 m
.18721 .86065 L
s
.18721 .81279 m
.22105 .77895 L
s
.18721 .86065 m
.22105 .82681 L
s
.18721 .4183 m
.18721 .46616 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .45214 L
s
.18721 .46616 m
.22105 .5 L
s
.18721 .53384 m
.18721 .5817 L
s
.18721 .53384 m
.22105 .5 L
s
.18721 .5817 m
.22105 .54786 L
s
.18721 .5817 m
.22105 .61554 L
s
.22105 .17319 m
.22105 .22105 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .17319 m
.22105 .22105 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .22105 m
.22105 .26891 L
s
.22105 .22105 m
.2549 .18721 L
s
.22105 .22105 m
.26891 .22105 L
s
.22105 .26891 m
.2549 .30276 L
s
.22105 .26891 m
.26891 .26891 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.2549 .30276 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.2549 .30276 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .38446 m
.2549 .4183 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .38446 m
.2549 .4183 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .45214 m
.22105 .5 L
s
.22105 .45214 m
.2549 .4183 L
s
.22105 .5 m
.22105 .54786 L
s
.22105 .5 m
.2549 .46616 L
s
.22105 .5 m
.2549 .53384 L
s
.22105 .5 m
.26891 .5 L
s
.22105 .54786 m
.2549 .5817 L
s
.22105 .61554 m
.22105 .6634 L
s
.22105 .61554 m
.2549 .5817 L
s
.22105 .61554 m
.26891 .61554 L
s
.22105 .6634 m
.2549 .69724 L
s
.22105 .6634 m
.26891 .6634 L
s
.22105 .73109 m
.22105 .77895 L
s
.22105 .73109 m
.2549 .69724 L
s
.22105 .73109 m
.26891 .73109 L
s
.22105 .77895 m
.22105 .82681 L
s
.22105 .77895 m
.2549 .81279 L
s
.22105 .77895 m
.26891 .77895 L
s
.22105 .82681 m
.2549 .86065 L
s
.2549 .13935 m
.2549 .18721 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .13935 m
.2549 .18721 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .18721 m
.30276 .18721 L
s
.2549 .30276 m
.30276 .30276 L
s
.2549 .4183 m
.2549 .46616 L
s
.2549 .4183 m
.30276 .4183 L
s
.2549 .46616 m
.30276 .46616 L
s
.2549 .53384 m
.2549 .5817 L
s
.2549 .53384 m
.30276 .53384 L
s
.2549 .5817 m
.30276 .5817 L
s
.2549 .69724 m
.30276 .69724 L
s
.2549 .81279 m
.2549 .86065 L
s
.2549 .81279 m
.30276 .81279 L
s
.2549 .86065 m
.30276 .86065 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .22105 m
.26891 .26891 L
s
.26891 .22105 m
.30276 .18721 L
s
.26891 .22105 m
.30276 .2549 L
s
.26891 .26891 m
.30276 .30276 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.30276 .30276 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.30276 .30276 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .4183 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .4183 L
s
.26891 .5 m
.30276 .46616 L
s
.26891 .5 m
.30276 .53384 L
s
.26891 .61554 m
.26891 .6634 L
s
.26891 .61554 m
.30276 .5817 L
s
.26891 .61554 m
.30276 .64938 L
s
.26891 .6634 m
.30276 .69724 L
s
.26891 .73109 m
.26891 .77895 L
s
.26891 .73109 m
.30276 .69724 L
s
.26891 .77895 m
.30276 .7451 L
s
.26891 .77895 m
.30276 .81279 L
s
.26891 .89449 m
.30276 .86065 L
s
.26891 .89449 m
.30276 .92833 L
s
.26891 .89449 m
.30276 .92833 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .13935 m
.30276 .18721 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.30276 .18721 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .18721 m
.3366 .22105 L
s
.30276 .18721 m
.3366 .22105 L
s
.30276 .18721 m
.35062 .18721 L
s
.30276 .18721 m
.35062 .18721 L
s
.30276 .2549 m
.30276 .30276 L
s
.30276 .2549 m
.3366 .22105 L
s
.30276 .2549 m
.3366 .22105 L
s
.30276 .30276 m
.30276 .35062 L
s
.30276 .30276 m
.30276 .35062 L
s
.30276 .30276 m
.3366 .26891 L
s
.30276 .30276 m
.3366 .3366 L
s
.30276 .30276 m
.3366 .3366 L
s
.30276 .30276 m
.35062 .30276 L
s
.30276 .30276 m
.35062 .30276 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .4183 m
.30276 .46616 L
s
.30276 .4183 m
.3366 .38446 L
s
.30276 .4183 m
.3366 .45214 L
s
.30276 .4183 m
.3366 .38446 L
s
.30276 .4183 m
.3366 .38446 L
s
.30276 .4183 m
.3366 .45214 L
s
.30276 .4183 m
.35062 .4183 L
s
.30276 .4183 m
.35062 .4183 L
s
.30276 .46616 m
.3366 .5 L
s
.30276 .46616 m
.3366 .5 L
s
.30276 .53384 m
.30276 .5817 L
s
.30276 .53384 m
.3366 .5 L
s
.30276 .53384 m
.3366 .5 L
s
.30276 .5817 m
.3366 .54786 L
s
.30276 .5817 m
.3366 .61554 L
s
.30276 .5817 m
.3366 .61554 L
s
.30276 .5817 m
.35062 .5817 L
s
.30276 .5817 m
.35062 .5817 L
s
.30276 .64938 m
.30276 .69724 L
s
.30276 .64938 m
.3366 .61554 L
s
.30276 .64938 m
.3366 .61554 L
s
.30276 .69724 m
.30276 .7451 L
s
.30276 .69724 m
.3366 .6634 L
s
.30276 .69724 m
.3366 .73109 L
s
.30276 .69724 m
.35062 .69724 L
s
.30276 .69724 m
.35062 .69724 L
s
.30276 .7451 m
.3366 .77895 L
s
.30276 .81279 m
.30276 .86065 L
s
.30276 .81279 m
.3366 .77895 L
s
.30276 .81279 m
.35062 .81279 L
s
.30276 .81279 m
.35062 .81279 L
s
.30276 .86065 m
.3366 .89449 L
s
.30276 .86065 m
.3366 .89449 L
s
.30276 .86065 m
.35062 .86065 L
s
.30276 .86065 m
.35062 .86065 L
s
.30276 .92833 m
.3366 .89449 L
s
.30276 .92833 m
.3366 .89449 L
s
.30276 .92833 m
.3366 .89449 L
s
.30276 .92833 m
.3366 .89449 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .10551 m
.3366 .05765 L
s
.3366 .10551 m
.38446 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .10551 m
.38446 .10551 L
s
.3366 .22105 m
.3366 .26891 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .26891 m
.3366 .22105 L
s
.3366 .26891 m
.38446 .26891 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .38446 m
.3366 .3366 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .45214 m
.3366 .5 L
s
.3366 .45214 m
.3366 .5 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .5 m
.3366 .54786 L
s
.3366 .5 m
.3366 .45214 L
s
.3366 .5 m
.38446 .5 L
s
.3366 .54786 m
.3366 .5 L
s
.3366 .54786 m
.38446 .54786 L
s
.3366 .61554 m
.3366 .6634 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .6634 m
.3366 .61554 L
s
.3366 .6634 m
.38446 .6634 L
s
.3366 .89449 m
.3366 .94235 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .94235 m
.3366 .89449 L
s
.3366 .94235 m
.38446 .94235 L
s
.3366 .10551 m
.38446 .10551 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .45214 m
.3366 .5 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .5 m
.38446 .5 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .73109 m
.3366 .77895 L
s
.3366 .73109 m
.38446 .73109 L
s
.3366 .73109 m
.38446 .73109 L
s
.3366 .77895 m
.38446 .77895 L
s
.3366 .77895 m
.38446 .77895 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.38446 .10551 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.38446 .10551 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .18721 m
.35062 .13935 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .30276 m
.38446 .26891 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .5817 m
.38446 .54786 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .69724 m
.38446 .6634 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .81279 m
.35062 .86065 L
s
.35062 .81279 m
.35062 .86065 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .86065 m
.35062 .81279 L
s
.35062 .86065 m
.38446 .82681 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.38446 .10551 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .30276 m
.38446 .26891 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .5817 m
.38446 .54786 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .69724 m
.38446 .6634 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .81279 m
.35062 .86065 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .86065 m
.38446 .82681 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.38446 .05765 m
.38446 .10551 L
s
.38446 .05765 m
.38446 .10551 L
s
.38446 .10551 m
.4183 .07167 L
s
.38446 .10551 m
.4183 .13935 L
s
.38446 .10551 m
.4183 .13935 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .22105 m
.38446 .26891 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .2549 L
s
.38446 .26891 m
.38446 .22105 L
s
.38446 .26891 m
.4183 .30276 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.4183 .30276 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.4183 .30276 L
s
.38446 .38446 m
.38446 .3366 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .4183 L
s
.38446 .38446 m
.38446 .3366 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .4183 L
s
.38446 .45214 m
.38446 .5 L
s
.38446 .45214 m
.4183 .4183 L
s
.38446 .5 m
.38446 .54786 L
s
.38446 .5 m
.38446 .45214 L
s
.38446 .5 m
.4183 .46616 L
s
.38446 .5 m
.4183 .53384 L
s
.38446 .54786 m
.4183 .5817 L
s
.38446 .61554 m
.38446 .6634 L
s
.38446 .61554 m
.4183 .5817 L
s
.38446 .61554 m
.4183 .64938 L
s
.38446 .6634 m
.38446 .61554 L
s
.38446 .6634 m
.4183 .69724 L
s
.38446 .73109 m
.38446 .77895 L
s
.38446 .73109 m
.38446 .77895 L
s
.38446 .73109 m
.4183 .69724 L
s
.38446 .77895 m
.38446 .82681 L
s
.38446 .77895 m
.38446 .73109 L
s
.38446 .77895 m
.4183 .7451 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .82681 m
.38446 .77895 L
s
.38446 .82681 m
.4183 .86065 L
s
.38446 .82681 m
.4183 .86065 L
s
.38446 .89449 m
.38446 .94235 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.38446 .94235 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .94235 m
.38446 .89449 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .2549 L
s
.38446 .3366 m
.4183 .30276 L
s
.38446 .45214 m
.4183 .4183 L
s
.38446 .61554 m
.4183 .5817 L
s
.38446 .61554 m
.4183 .64938 L
s
.38446 .73109 m
.38446 .77895 L
s
.38446 .73109 m
.4183 .69724 L
s
.38446 .77895 m
.4183 .7451 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.4183 .92833 L
s
.4183 .07167 m
.45214 .10551 L
s
.4183 .07167 m
.46616 .07167 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.45214 .10551 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.45214 .10551 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .18721 m
.45214 .22105 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .18721 m
.45214 .22105 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .2549 m
.4183 .30276 L
s
.4183 .2549 m
.45214 .22105 L
s
.4183 .2549 m
.46616 .2549 L
s
.4183 .30276 m
.4183 .35062 L
s
.4183 .30276 m
.4183 .35062 L
s
.4183 .30276 m
.45214 .3366 L
s
.4183 .30276 m
.45214 .3366 L
s
.4183 .30276 m
.46616 .30276 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .4183 m
.4183 .46616 L
s
.4183 .4183 m
.45214 .38446 L
s
.4183 .4183 m
.45214 .38446 L
s
.4183 .4183 m
.46616 .4183 L
s
.4183 .46616 m
.45214 .5 L
s
.4183 .46616 m
.46616 .46616 L
s
.4183 .53384 m
.4183 .5817 L
s
.4183 .53384 m
.45214 .5 L
s
.4183 .53384 m
.46616 .53384 L
s
.4183 .5817 m
.45214 .61554 L
s
.4183 .5817 m
.46616 .5817 L
s
.4183 .64938 m
.4183 .69724 L
s
.4183 .64938 m
.45214 .61554 L
s
.4183 .69724 m
.4183 .7451 L
s
.4183 .69724 m
.45214 .6634 L
s
.4183 .69724 m
.46616 .69724 L
s
.4183 .7451 m
.45214 .77895 L
s
.4183 .7451 m
.46616 .7451 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.45214 .77895 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.45214 .77895 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.46616 .92833 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.46616 .92833 L
s
.45214 .10551 m
.5 .10551 L
s
.45214 .22105 m
.5 .22105 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .38446 m
.5 .38446 L
s
.45214 .38446 m
.5 .38446 L
s
.45214 .5 m
.5 .5 L
s
.45214 .61554 m
.45214 .6634 L
s
.45214 .61554 m
.5 .61554 L
s
.45214 .6634 m
.5 .6634 L
s
.45214 .77895 m
.5 .77895 L
s
.45214 .89449 m
.5 .89449 L
s
.45214 .89449 m
.5 .89449 L
s
.45214 .89449 m
.5 .89449 L
s
.45214 .89449 m
.5 .89449 L
s
.46616 .02381 m
.46616 .07167 L
s
.46616 .02381 m
.5 .05765 L
s
.46616 .07167 m
.5 .10551 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.5 .10551 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.5 .10551 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.5 .10551 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .18721 m
.5 .22105 L
s
.46616 .18721 m
.5 .22105 L
s
.46616 .2549 m
.46616 .30276 L
s
.46616 .2549 m
.5 .22105 L
s
.46616 .30276 m
.5 .26891 L
s
.46616 .30276 m
.5 .3366 L
s
.46616 .30276 m
.5 .3366 L
s
.46616 .4183 m
.46616 .46616 L
s
.46616 .4183 m
.5 .38446 L
s
.46616 .4183 m
.5 .45214 L
s
.46616 .46616 m
.5 .5 L
s
.46616 .53384 m
.46616 .5817 L
s
.46616 .53384 m
.5 .5 L
s
.46616 .5817 m
.5 .54786 L
s
.46616 .5817 m
.5 .61554 L
s
.46616 .69724 m
.46616 .7451 L
s
.46616 .69724 m
.5 .6634 L
s
.46616 .69724 m
.5 .73109 L
s
.46616 .7451 m
.5 .77895 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.5 .77895 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.5 .77895 L
s
.46616 .86065 m
.5 .82681 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .86065 m
.5 .82681 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .92833 m
.46616 .97619 L
s
.46616 .92833 m
.5 .89449 L
s
.46616 .92833 m
.5 .89449 L
s
.46616 .97619 m
.5 .94235 L
s
.5 .05765 m
.5 .10551 L
s
.5 .05765 m
.53384 .02381 L
s
.5 .10551 m
.53384 .07167 L
s
.5 .10551 m
.53384 .13935 L
s
.5 .10551 m
.53384 .13935 L
s
.5 .10551 m
.54786 .10551 L
s
.5 .17319 m
.5 .22105 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .17319 m
.5 .22105 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .22105 m
.5 .26891 L
s
.5 .22105 m
.53384 .18721 L
s
.5 .22105 m
.53384 .2549 L
s
.5 .22105 m
.54786 .22105 L
s
.5 .26891 m
.53384 .30276 L
s
.5 .3366 m
.5 .38446 L
s
.5 .3366 m
.53384 .30276 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .3366 m
.5 .38446 L
s
.5 .3366 m
.53384 .30276 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .38446 m
.53384 .4183 L
s
.5 .38446 m
.54786 .38446 L
s
.5 .38446 m
.54786 .38446 L
s
.5 .45214 m
.5 .5 L
s
.5 .45214 m
.53384 .4183 L
s
.5 .5 m
.5 .54786 L
s
.5 .5 m
.53384 .46616 L
s
.5 .5 m
.53384 .53384 L
s
.5 .5 m
.54786 .5 L
s
.5 .54786 m
.53384 .5817 L
s
.5 .61554 m
.5 .6634 L
s
.5 .61554 m
.53384 .5817 L
s
.5 .61554 m
.54786 .61554 L
s
.5 .6634 m
.53384 .69724 L
s
.5 .6634 m
.54786 .6634 L
s
.5 .73109 m
.5 .77895 L
s
.5 .73109 m
.53384 .69724 L
s
.5 .77895 m
.5 .82681 L
s
.5 .77895 m
.53384 .7451 L
s
.5 .77895 m
.53384 .81279 L
s
.5 .77895 m
.54786 .77895 L
s
.5 .82681 m
.53384 .86065 L
s
.5 .89449 m
.5 .94235 L
s
.5 .89449 m
.53384 .86065 L
s
.5 .89449 m
.53384 .92833 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .89449 m
.5 .94235 L
s
.5 .89449 m
.53384 .86065 L
s
.5 .89449 m
.53384 .92833 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .94235 m
.53384 .97619 L
s
.53384 .02381 m
.53384 .07167 L
s
.53384 .07167 m
.5817 .07167 L
s
.53384 .13935 m
.53384 .18721 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.53384 .18721 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .18721 m
.5817 .18721 L
s
.53384 .18721 m
.5817 .18721 L
s
.53384 .2549 m
.53384 .30276 L
s
.53384 .2549 m
.5817 .2549 L
s
.53384 .30276 m
.5817 .30276 L
s
.53384 .4183 m
.53384 .46616 L
s
.53384 .4183 m
.5817 .4183 L
s
.53384 .46616 m
.5817 .46616 L
s
.53384 .53384 m
.53384 .5817 L
s
.53384 .53384 m
.5817 .53384 L
s
.53384 .5817 m
.5817 .5817 L
s
.53384 .69724 m
.53384 .7451 L
s
.53384 .69724 m
.5817 .69724 L
s
.53384 .7451 m
.5817 .7451 L
s
.53384 .81279 m
.53384 .86065 L
s
.53384 .81279 m
.5817 .81279 L
s
.53384 .86065 m
.5817 .86065 L
s
.53384 .92833 m
.53384 .97619 L
s
.53384 .92833 m
.5817 .92833 L
s
.53384 .92833 m
.5817 .92833 L
s
.54786 .10551 m
.5817 .07167 L
s
.54786 .10551 m
.5817 .13935 L
s
.54786 .10551 m
.5817 .13935 L
s
.54786 .10551 m
.5817 .13935 L
s
.54786 .22105 m
.5817 .18721 L
s
.54786 .22105 m
.5817 .18721 L
s
.54786 .22105 m
.5817 .2549 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.5817 .30276 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.5817 .30276 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .4183 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .4183 L
s
.54786 .5 m
.5817 .46616 L
s
.54786 .5 m
.5817 .53384 L
s
.54786 .61554 m
.54786 .6634 L
s
.54786 .61554 m
.5817 .5817 L
s
.54786 .61554 m
.5817 .64938 L
s
.54786 .6634 m
.5817 .69724 L
s
.54786 .77895 m
.5817 .7451 L
s
.54786 .77895 m
.5817 .81279 L
s
.54786 .89449 m
.5817 .86065 L
s
.54786 .89449 m
.5817 .92833 L
s
.54786 .89449 m
.5817 .92833 L
s
.54786 .89449 m
.5817 .86065 L
s
.54786 .89449 m
.5817 .92833 L
s
.54786 .89449 m
.5817 .92833 L
s
.5817 .07167 m
.61554 .10551 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.61554 .10551 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.61554 .10551 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.61554 .10551 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .18721 m
.61554 .22105 L
s
.5817 .18721 m
.61554 .22105 L
s
.5817 .2549 m
.5817 .30276 L
s
.5817 .2549 m
.61554 .22105 L
s
.5817 .30276 m
.5817 .35062 L
s
.5817 .30276 m
.5817 .35062 L
s
.5817 .30276 m
.61554 .26891 L
s
.5817 .30276 m
.61554 .3366 L
s
.5817 .30276 m
.61554 .3366 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .4183 m
.5817 .46616 L
s
.5817 .4183 m
.61554 .38446 L
s
.5817 .4183 m
.61554 .38446 L
s
.5817 .4183 m
.61554 .45214 L
s
.5817 .46616 m
.61554 .5 L
s
.5817 .53384 m
.5817 .5817 L
s
.5817 .53384 m
.61554 .5 L
s
.5817 .5817 m
.61554 .54786 L
s
.5817 .5817 m
.61554 .61554 L
s
.5817 .64938 m
.5817 .69724 L
s
.5817 .64938 m
.61554 .61554 L
s
.5817 .69724 m
.5817 .7451 L
s
.5817 .69724 m
.61554 .6634 L
s
.5817 .69724 m
.61554 .73109 L
s
.5817 .7451 m
.61554 .77895 L
s
.5817 .81279 m
.5817 .86065 L
s
.5817 .81279 m
.61554 .77895 L
s
.5817 .86065 m
.61554 .82681 L
s
.5817 .86065 m
.61554 .89449 L
s
.5817 .86065 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.61554 .05765 m
.61554 .10551 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .10551 m
.61554 .05765 L
s
.61554 .10551 m
.61554 .05765 L
s
.61554 .10551 m
.64938 .13935 L
s
.61554 .10551 m
.64938 .13935 L
s
.61554 .10551 m
.6634 .10551 L
s
.61554 .10551 m
.6634 .10551 L
s
.61554 .10551 m
.6634 .10551 L
s
.61554 .17319 m
.61554 .22105 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .17319 m
.61554 .22105 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .22105 m
.61554 .26891 L
s
.61554 .22105 m
.64938 .18721 L
s
.61554 .22105 m
.6634 .22105 L
s
.61554 .22105 m
.6634 .22105 L
s
.61554 .26891 m
.64938 .30276 L
s
.61554 .26891 m
.6634 .26891 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.64938 .30276 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.64938 .30276 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .38446 m
.64938 .4183 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.64938 .4183 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .45214 m
.61554 .5 L
s
.61554 .45214 m
.64938 .4183 L
s
.61554 .45214 m
.6634 .45214 L
s
.61554 .45214 m
.6634 .45214 L
s
.61554 .5 m
.61554 .54786 L
s
.61554 .5 m
.6634 .5 L
s
.61554 .5 m
.6634 .5 L
s
.61554 .54786 m
.64938 .5817 L
s
.61554 .54786 m
.6634 .54786 L
s
.61554 .61554 m
.61554 .6634 L
s
.61554 .61554 m
.64938 .5817 L
s
.61554 .61554 m
.6634 .61554 L
s
.61554 .61554 m
.6634 .61554 L
s
.61554 .6634 m
.64938 .69724 L
s
.61554 .6634 m
.6634 .6634 L
s
.61554 .73109 m
.61554 .77895 L
s
.61554 .73109 m
.64938 .69724 L
s
.61554 .73109 m
.6634 .73109 L
s
.61554 .73109 m
.6634 .73109 L
s
.61554 .77895 m
.61554 .82681 L
s
.61554 .77895 m
.64938 .81279 L
s
.61554 .77895 m
.6634 .77895 L
s
.61554 .77895 m
.6634 .77895 L
s
.61554 .82681 m
.64938 .86065 L
s
.61554 .89449 m
.61554 .94235 L
s
.61554 .89449 m
.64938 .86065 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .89449 m
.61554 .94235 L
s
.61554 .89449 m
.64938 .86065 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .94235 m
.6634 .94235 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.64938 .13935 m
.64938 .18721 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.64938 .18721 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .18721 m
.69724 .18721 L
s
.64938 .30276 m
.69724 .30276 L
s
.64938 .4183 m
.69724 .4183 L
s
.64938 .5817 m
.69724 .5817 L
s
.64938 .69724 m
.69724 .69724 L
s
.64938 .81279 m
.64938 .86065 L
s
.64938 .81279 m
.69724 .81279 L
s
.64938 .86065 m
.69724 .86065 L
s
.6634 .22105 m
.6634 .26891 L
s
.6634 .22105 m
.69724 .18721 L
s
.6634 .22105 m
.69724 .2549 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.69724 .30276 L
s
.6634 .38446 m
.6634 .3366 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .4183 L
s
.6634 .38446 m
.6634 .3366 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .4183 L
s
.6634 .45214 m
.6634 .5 L
s
.6634 .45214 m
.6634 .5 L
s
.6634 .45214 m
.69724 .4183 L
s
.6634 .5 m
.6634 .45214 L
s
.6634 .5 m
.6634 .54786 L
s
.6634 .5 m
.69724 .46616 L
s
.6634 .5 m
.69724 .53384 L
s
.6634 .61554 m
.6634 .6634 L
s
.6634 .61554 m
.69724 .5817 L
s
.6634 .61554 m
.69724 .64938 L
s
.6634 .73109 m
.6634 .77895 L
s
.6634 .73109 m
.6634 .77895 L
s
.6634 .73109 m
.69724 .69724 L
s
.6634 .77895 m
.6634 .73109 L
s
.6634 .77895 m
.69724 .7451 L
s
.6634 .77895 m
.69724 .81279 L
s
.6634 .89449 m
.6634 .94235 L
s
.6634 .89449 m
.69724 .86065 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .10551 m
.6634 .05765 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .22105 m
.6634 .26891 L
s
.6634 .22105 m
.69724 .18721 L
s
.6634 .22105 m
.69724 .2549 L
s
.6634 .26891 m
.69724 .30276 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.69724 .30276 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .4183 L
s
.6634 .45214 m
.6634 .5 L
s
.6634 .45214 m
.69724 .4183 L
s
.6634 .5 m
.6634 .54786 L
s
.6634 .5 m
.69724 .46616 L
s
.6634 .5 m
.69724 .53384 L
s
.6634 .54786 m
.69724 .5817 L
s
.6634 .61554 m
.6634 .6634 L
s
.6634 .61554 m
.69724 .5817 L
s
.6634 .61554 m
.69724 .64938 L
s
.6634 .6634 m
.69724 .69724 L
s
.6634 .73109 m
.6634 .77895 L
s
.6634 .73109 m
.69724 .69724 L
s
.6634 .77895 m
.69724 .7451 L
s
.6634 .77895 m
.69724 .81279 L
s
.6634 .89449 m
.6634 .94235 L
s
.6634 .89449 m
.69724 .86065 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .13935 m
.69724 .18721 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.69724 .18721 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .18721 m
.69724 .13935 L
s
.69724 .18721 m
.73109 .22105 L
s
.69724 .18721 m
.7451 .18721 L
s
.69724 .2549 m
.69724 .30276 L
s
.69724 .2549 m
.73109 .22105 L
s
.69724 .30276 m
.69724 .35062 L
s
.69724 .30276 m
.69724 .35062 L
s
.69724 .30276 m
.73109 .26891 L
s
.69724 .30276 m
.73109 .3366 L
s
.69724 .30276 m
.7451 .30276 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .4183 m
.69724 .46616 L
s
.69724 .4183 m
.73109 .38446 L
s
.69724 .4183 m
.73109 .38446 L
s
.69724 .4183 m
.7451 .4183 L
s
.69724 .46616 m
.73109 .5 L
s
.69724 .46616 m
.7451 .46616 L
s
.69724 .53384 m
.69724 .5817 L
s
.69724 .53384 m
.73109 .5 L
s
.69724 .53384 m
.7451 .53384 L
s
.69724 .5817 m
.73109 .61554 L
s
.69724 .5817 m
.7451 .5817 L
s
.69724 .64938 m
.69724 .69724 L
s
.69724 .64938 m
.73109 .61554 L
s
.69724 .69724 m
.69724 .7451 L
s
.69724 .69724 m
.73109 .6634 L
s
.69724 .69724 m
.73109 .73109 L
s
.69724 .69724 m
.7451 .69724 L
s
.69724 .7451 m
.73109 .77895 L
s
.69724 .81279 m
.69724 .86065 L
s
.69724 .81279 m
.73109 .77895 L
s
.69724 .81279 m
.7451 .81279 L
s
.69724 .86065 m
.73109 .89449 L
s
.69724 .86065 m
.7451 .86065 L
s
.69724 .92833 m
.73109 .89449 L
s
.69724 .92833 m
.73109 .89449 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.7451 .13935 L
s
.73109 .22105 m
.73109 .26891 L
s
.73109 .22105 m
.77895 .22105 L
s
.73109 .26891 m
.77895 .26891 L
s
.73109 .3366 m
.73109 .38446 L
s
.73109 .3366 m
.73109 .38446 L
s
.73109 .3366 m
.77895 .3366 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .5 m
.77895 .5 L
s
.73109 .61554 m
.73109 .6634 L
s
.73109 .61554 m
.77895 .61554 L
s
.73109 .6634 m
.77895 .6634 L
s
.73109 .73109 m
.73109 .77895 L
s
.73109 .73109 m
.77895 .73109 L
s
.73109 .77895 m
.77895 .77895 L
s
.7451 .13935 m
.7451 .18721 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .13935 m
.7451 .18721 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .18721 m
.77895 .22105 L
s
.7451 .30276 m
.77895 .26891 L
s
.7451 .30276 m
.77895 .3366 L
s
.7451 .4183 m
.7451 .46616 L
s
.7451 .4183 m
.77895 .38446 L
s
.7451 .4183 m
.77895 .38446 L
s
.7451 .4183 m
.77895 .45214 L
s
.7451 .46616 m
.77895 .5 L
s
.7451 .53384 m
.7451 .5817 L
s
.7451 .53384 m
.77895 .5 L
s
.7451 .5817 m
.77895 .54786 L
s
.7451 .5817 m
.77895 .61554 L
s
.7451 .69724 m
.77895 .6634 L
s
.7451 .69724 m
.77895 .73109 L
s
.7451 .81279 m
.7451 .86065 L
s
.7451 .81279 m
.77895 .77895 L
s
.7451 .86065 m
.77895 .82681 L
s
.77895 .17319 m
.77895 .22105 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .17319 m
.77895 .22105 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .22105 m
.77895 .26891 L
s
.77895 .22105 m
.81279 .18721 L
s
.77895 .22105 m
.81279 .2549 L
s
.77895 .22105 m
.82681 .22105 L
s
.77895 .26891 m
.81279 .30276 L
s
.77895 .3366 m
.77895 .38446 L
s
.77895 .3366 m
.77895 .38446 L
s
.77895 .3366 m
.81279 .30276 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.82681 .38446 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.82681 .38446 L
s
.77895 .45214 m
.77895 .5 L
s
.77895 .45214 m
.81279 .4183 L
s
.77895 .45214 m
.81279 .4183 L
s
.77895 .5 m
.77895 .54786 L
s
.77895 .5 m
.81279 .46616 L
s
.77895 .5 m
.81279 .53384 L
s
.77895 .5 m
.82681 .5 L
s
.77895 .54786 m
.81279 .5817 L
s
.77895 .61554 m
.77895 .6634 L
s
.77895 .61554 m
.81279 .5817 L
s
.77895 .61554 m
.81279 .64938 L
s
.77895 .61554 m
.82681 .61554 L
s
.77895 .6634 m
.81279 .69724 L
s
.77895 .73109 m
.77895 .77895 L
s
.77895 .73109 m
.81279 .69724 L
s
.77895 .77895 m
.77895 .82681 L
s
.77895 .77895 m
.81279 .7451 L
s
.77895 .77895 m
.81279 .81279 L
s
.77895 .77895 m
.82681 .77895 L
s
.77895 .82681 m
.81279 .86065 L
s
.81279 .4183 m
.81279 .46616 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .46616 m
.81279 .4183 L
s
.81279 .46616 m
.86065 .46616 L
s
.81279 .46616 m
.86065 .46616 L
s
.81279 .13935 m
.81279 .18721 L
s
.81279 .13935 m
.81279 .18721 L
s
.81279 .18721 m
.86065 .18721 L
s
.81279 .2549 m
.81279 .30276 L
s
.81279 .2549 m
.86065 .2549 L
s
.81279 .30276 m
.81279 .35062 L
s
.81279 .30276 m
.81279 .35062 L
s
.81279 .30276 m
.86065 .30276 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .53384 m
.81279 .5817 L
s
.81279 .53384 m
.86065 .53384 L
s
.81279 .53384 m
.86065 .53384 L
s
.81279 .5817 m
.86065 .5817 L
s
.81279 .5817 m
.86065 .5817 L
s
.81279 .64938 m
.81279 .69724 L
s
.81279 .64938 m
.86065 .64938 L
s
.81279 .64938 m
.86065 .64938 L
s
.81279 .69724 m
.81279 .7451 L
s
.81279 .69724 m
.86065 .69724 L
s
.81279 .69724 m
.86065 .69724 L
s
.81279 .7451 m
.86065 .7451 L
s
.81279 .81279 m
.81279 .86065 L
s
.81279 .81279 m
.86065 .81279 L
s
.82681 .22105 m
.86065 .18721 L
s
.82681 .22105 m
.86065 .2549 L
s
.82681 .38446 m
.86065 .4183 L
s
.82681 .38446 m
.86065 .4183 L
s
.82681 .38446 m
.86065 .35062 L
s
.82681 .38446 m
.86065 .35062 L
s
.82681 .38446 m
.86065 .4183 L
s
.82681 .5 m
.86065 .53384 L
s
.82681 .5 m
.86065 .46616 L
s
.82681 .5 m
.86065 .46616 L
s
.82681 .5 m
.86065 .53384 L
s
.82681 .61554 m
.86065 .5817 L
s
.82681 .61554 m
.86065 .64938 L
s
.82681 .61554 m
.86065 .5817 L
s
.82681 .61554 m
.86065 .64938 L
s
.82681 .77895 m
.86065 .7451 L
s
.82681 .77895 m
.86065 .81279 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .53384 m
.86065 .5817 L
s
.86065 .53384 m
.86065 .5817 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .5817 m
.86065 .53384 L
s
.86065 .5817 m
.89449 .54786 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .64938 m
.86065 .69724 L
s
.86065 .64938 m
.86065 .69724 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .69724 m
.86065 .64938 L
s
.86065 .69724 m
.86065 .7451 L
s
.86065 .69724 m
.89449 .6634 L
s
.86065 .69724 m
.89449 .73109 L
s
.86065 .69724 m
.89449 .73109 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .46616 m
.86065 .4183 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .2549 m
.86065 .30276 L
s
.86065 .30276 m
.86065 .35062 L
s
.86065 .30276 m
.86065 .35062 L
s
.86065 .30276 m
.89449 .3366 L
s
.86065 .30276 m
.89449 .26891 L
s
.86065 .30276 m
.89449 .3366 L
s
.86065 .30276 m
.89449 .3366 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .53384 m
.86065 .5817 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .5817 m
.89449 .54786 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .64938 m
.86065 .69724 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .69724 m
.86065 .7451 L
s
.86065 .69724 m
.89449 .6634 L
s
.86065 .69724 m
.89449 .73109 L
s
.86065 .69724 m
.89449 .73109 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .38446 m
.89449 .3366 L
s
.89449 .38446 m
.89449 .3366 L
s
.89449 .38446 m
.92833 .4183 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .45214 m
.89449 .5 L
s
.89449 .45214 m
.89449 .5 L
s
.89449 .45214 m
.92833 .4183 L
s
.89449 .5 m
.89449 .54786 L
s
.89449 .5 m
.89449 .45214 L
s
.89449 .5 m
.92833 .46616 L
s
.89449 .5 m
.92833 .53384 L
s
.89449 .5 m
.94235 .5 L
s
.89449 .54786 m
.89449 .5 L
s
.89449 .54786 m
.92833 .5817 L
s
.89449 .61554 m
.89449 .6634 L
s
.89449 .61554 m
.92833 .5817 L
s
.89449 .61554 m
.94235 .61554 L
s
.89449 .6634 m
.89449 .61554 L
s
.89449 .6634 m
.92833 .69724 L
s
.89449 .6634 m
.94235 .6634 L
s
.89449 .73109 m
.92833 .69724 L
s
.89449 .26891 m
.92833 .30276 L
s
.89449 .26891 m
.92833 .30276 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .38446 m
.92833 .4183 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.92833 .4183 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .45214 m
.89449 .5 L
s
.89449 .45214 m
.92833 .4183 L
s
.89449 .5 m
.92833 .46616 L
s
.89449 .5 m
.92833 .53384 L
s
.89449 .5 m
.94235 .5 L
s
.89449 .61554 m
.92833 .5817 L
s
.89449 .61554 m
.94235 .61554 L
s
.89449 .73109 m
.92833 .69724 L
s
.92833 .4183 m
.92833 .46616 L
s
.92833 .46616 m
.97619 .46616 L
s
.92833 .53384 m
.92833 .5817 L
s
.92833 .53384 m
.97619 .53384 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .38446 m
.94235 .3366 L
s
.94235 .5 m
.97619 .46616 L
s
.94235 .5 m
.97619 .53384 L
s
.94235 .61554 m
.94235 .6634 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .3366 m
.94235 .38446 L
s
.008 w
.12413 .20894 Mdot
.21985 .11322 Mdot
.02841 .44003 Mdot
.12413 .34431 Mdot
.21985 .24859 Mdot
.31557 .15287 Mdot
.41129 .05715 Mdot
.02841 .5754 Mdot
.12413 .47968 Mdot
.21985 .38396 Mdot
.31557 .28824 Mdot
.41129 .19252 Mdot
.50701 .0968 Mdot
.12413 .61505 Mdot
.21985 .51933 Mdot
.31557 .42361 Mdot
.41129 .32789 Mdot
.50701 .23217 Mdot
.60273 .13645 Mdot
.12413 .75041 Mdot
.21985 .65469 Mdot
.31557 .55897 Mdot
.41129 .46326 Mdot
.50701 .36754 Mdot
.60273 .27182 Mdot
.69845 .1761 Mdot
.21985 .79006 Mdot
.31557 .69434 Mdot
.41129 .59862 Mdot
.50701 .5029 Mdot
.60273 .40718 Mdot
.69845 .31146 Mdot
.79417 .21575 Mdot
.31557 .82971 Mdot
.41129 .73399 Mdot
.50701 .63827 Mdot
.60273 .54255 Mdot
.69845 .44683 Mdot
.79417 .35111 Mdot
.88989 .25539 Mdot
.41129 .86936 Mdot
.50701 .77364 Mdot
.60273 .67792 Mdot
.69845 .5822 Mdot
.79417 .48648 Mdot
.88989 .39076 Mdot
.50701 .909 Mdot
.60273 .81329 Mdot
.69845 .71757 Mdot
.79417 .62185 Mdot
.88989 .52613 Mdot
.60273 .94865 Mdot
.69845 .85293 Mdot
.79417 .75721 Mdot
.88989 .6615 Mdot
.42821 .04533 Mdot
.52393 .04533 Mdot
.61965 .04533 Mdot
.23677 .14105 Mdot
.33249 .14105 Mdot
.42821 .14105 Mdot
.52393 .14105 Mdot
.61965 .14105 Mdot
.71537 .14105 Mdot
.81109 .14105 Mdot
.14105 .23677 Mdot
.23677 .23677 Mdot
.33249 .23677 Mdot
.42821 .23677 Mdot
.52393 .23677 Mdot
.61965 .23677 Mdot
.71537 .23677 Mdot
.81109 .23677 Mdot
.14105 .33249 Mdot
.23677 .33249 Mdot
.33249 .33249 Mdot
.42821 .33249 Mdot
.52393 .33249 Mdot
.61965 .33249 Mdot
.71537 .33249 Mdot
.81109 .33249 Mdot
.90681 .33249 Mdot
.04533 .42821 Mdot
.14105 .42821 Mdot
.23677 .42821 Mdot
.33249 .42821 Mdot
.42821 .42821 Mdot
.52393 .42821 Mdot
.61965 .42821 Mdot
.71537 .42821 Mdot
.81109 .42821 Mdot
.90681 .42821 Mdot
.04533 .52393 Mdot
.14105 .52393 Mdot
.23677 .52393 Mdot
.33249 .52393 Mdot
.42821 .52393 Mdot
.52393 .52393 Mdot
.61965 .52393 Mdot
.71537 .52393 Mdot
.81109 .52393 Mdot
.90681 .52393 Mdot
.04533 .61965 Mdot
.14105 .61965 Mdot
.23677 .61965 Mdot
.33249 .61965 Mdot
.42821 .61965 Mdot
.52393 .61965 Mdot
.61965 .61965 Mdot
.71537 .61965 Mdot
.81109 .61965 Mdot
.90681 .61965 Mdot
.14105 .71537 Mdot
.23677 .71537 Mdot
.33249 .71537 Mdot
.42821 .71537 Mdot
.52393 .71537 Mdot
.61965 .71537 Mdot
.71537 .71537 Mdot
.81109 .71537 Mdot
.90681 .71537 Mdot
.14105 .81109 Mdot
.23677 .81109 Mdot
.33249 .81109 Mdot
.42821 .81109 Mdot
.52393 .81109 Mdot
.61965 .81109 Mdot
.71537 .81109 Mdot
.81109 .81109 Mdot
.33249 .90681 Mdot
.42821 .90681 Mdot
.52393 .90681 Mdot
.61965 .90681 Mdot
.71537 .90681 Mdot
.73229 .11322 Mdot
.82801 .20894 Mdot
.92373 .30466 Mdot
.54085 .05715 Mdot
.63657 .15287 Mdot
.73229 .24859 Mdot
.82801 .34431 Mdot
.92373 .44003 Mdot
.44513 .0968 Mdot
.54085 .19252 Mdot
.63657 .28824 Mdot
.73229 .38396 Mdot
.82801 .47968 Mdot
.92373 .5754 Mdot
.34941 .13645 Mdot
.44513 .23217 Mdot
.54085 .32789 Mdot
.63657 .42361 Mdot
.73229 .51933 Mdot
.82801 .61505 Mdot
.92373 .71076 Mdot
.25369 .1761 Mdot
.34941 .27182 Mdot
.44513 .36754 Mdot
.54085 .46326 Mdot
.63657 .55897 Mdot
.73229 .65469 Mdot
.82801 .75041 Mdot
.15797 .21575 Mdot
.25369 .31146 Mdot
.34941 .40718 Mdot
.44513 .5029 Mdot
.54085 .59862 Mdot
.63657 .69434 Mdot
.73229 .79006 Mdot
.15797 .35111 Mdot
.25369 .44683 Mdot
.34941 .54255 Mdot
.44513 .63827 Mdot
.54085 .73399 Mdot
.63657 .82971 Mdot
.06226 .39076 Mdot
.15797 .48648 Mdot
.25369 .5822 Mdot
.34941 .67792 Mdot
.44513 .77364 Mdot
.54085 .86936 Mdot
.06226 .52613 Mdot
.15797 .62185 Mdot
.25369 .71757 Mdot
.34941 .81329 Mdot
.44513 .909 Mdot
.06226 .6615 Mdot
.15797 .75721 Mdot
.25369 .85293 Mdot
.34941 .94865 Mdot
.44003 .02841 Mdot
.5754 .02841 Mdot
.20894 .12413 Mdot
.34431 .12413 Mdot
.47968 .12413 Mdot
.61505 .12413 Mdot
.75041 .12413 Mdot
.11322 .21985 Mdot
.24859 .21985 Mdot
.38396 .21985 Mdot
.51933 .21985 Mdot
.65469 .21985 Mdot
.79006 .21985 Mdot
.15287 .31557 Mdot
.28824 .31557 Mdot
.42361 .31557 Mdot
.55897 .31557 Mdot
.69434 .31557 Mdot
.82971 .31557 Mdot
.05715 .41129 Mdot
.19252 .41129 Mdot
.32789 .41129 Mdot
.46326 .41129 Mdot
.59862 .41129 Mdot
.73399 .41129 Mdot
.86936 .41129 Mdot
.0968 .50701 Mdot
.23217 .50701 Mdot
.36754 .50701 Mdot
.5029 .50701 Mdot
.63827 .50701 Mdot
.77364 .50701 Mdot
.909 .50701 Mdot
.13645 .60273 Mdot
.27182 .60273 Mdot
.40718 .60273 Mdot
.54255 .60273 Mdot
.67792 .60273 Mdot
.81329 .60273 Mdot
.94865 .60273 Mdot
.1761 .69845 Mdot
.31146 .69845 Mdot
.44683 .69845 Mdot
.5822 .69845 Mdot
.71757 .69845 Mdot
.85293 .69845 Mdot
.21575 .79417 Mdot
.35111 .79417 Mdot
.48648 .79417 Mdot
.62185 .79417 Mdot
.75721 .79417 Mdot
.25539 .88989 Mdot
.39076 .88989 Mdot
.52613 .88989 Mdot
.6615 .88989 Mdot
.77073 .12774 Mdot
.83842 .19542 Mdot
.9061 .26311 Mdot
.56768 .06006 Mdot
.63537 .12774 Mdot
.70305 .19542 Mdot
.77073 .26311 Mdot
.83842 .33079 Mdot
.9061 .39847 Mdot
.97379 .46616 Mdot
.43232 .06006 Mdot
.5 .12774 Mdot
.56768 .19542 Mdot
.63537 .26311 Mdot
.70305 .33079 Mdot
.77073 .39847 Mdot
.83842 .46616 Mdot
.9061 .53384 Mdot
.36463 .12774 Mdot
.43232 .19542 Mdot
.5 .26311 Mdot
.56768 .33079 Mdot
.63537 .39847 Mdot
.70305 .46616 Mdot
.77073 .53384 Mdot
.83842 .60153 Mdot
.9061 .66921 Mdot
.22927 .12774 Mdot
.29695 .19542 Mdot
.36463 .26311 Mdot
.43232 .33079 Mdot
.5 .39847 Mdot
.56768 .46616 Mdot
.63537 .53384 Mdot
.70305 .60153 Mdot
.77073 .66921 Mdot
.83842 .73689 Mdot
.16158 .19542 Mdot
.22927 .26311 Mdot
.29695 .33079 Mdot
.36463 .39847 Mdot
.43232 .46616 Mdot
.5 .53384 Mdot
.56768 .60153 Mdot
.63537 .66921 Mdot
.70305 .73689 Mdot
.77073 .80458 Mdot
.0939 .26311 Mdot
.16158 .33079 Mdot
.22927 .39847 Mdot
.29695 .46616 Mdot
.36463 .53384 Mdot
.43232 .60153 Mdot
.5 .66921 Mdot
.56768 .73689 Mdot
.63537 .80458 Mdot
.70305 .87226 Mdot
.0939 .39847 Mdot
.16158 .46616 Mdot
.22927 .53384 Mdot
.29695 .60153 Mdot
.36463 .66921 Mdot
.43232 .73689 Mdot
.5 .80458 Mdot
.56768 .87226 Mdot
.63537 .93994 Mdot
.02621 .46616 Mdot
.0939 .53384 Mdot
.16158 .60153 Mdot
.22927 .66921 Mdot
.29695 .73689 Mdot
.36463 .80458 Mdot
.43232 .87226 Mdot
.5 .93994 Mdot
.0939 .66921 Mdot
.16158 .73689 Mdot
.22927 .80458 Mdot
.29695 .87226 Mdot
.36463 .93994 Mdot
.79106 .12413 Mdot
.88678 .21985 Mdot
.55997 .02841 Mdot
.65569 .12413 Mdot
.75141 .21985 Mdot
.84713 .31557 Mdot
.94285 .41129 Mdot
.4246 .02841 Mdot
.52032 .12413 Mdot
.61604 .21985 Mdot
.71176 .31557 Mdot
.80748 .41129 Mdot
.9032 .50701 Mdot
.38495 .12413 Mdot
.48067 .21985 Mdot
.57639 .31557 Mdot
.67211 .41129 Mdot
.76783 .50701 Mdot
.86355 .60273 Mdot
.24959 .12413 Mdot
.34531 .21985 Mdot
.44103 .31557 Mdot
.53674 .41129 Mdot
.63246 .50701 Mdot
.72818 .60273 Mdot
.8239 .69845 Mdot
.20994 .21985 Mdot
.30566 .31557 Mdot
.40138 .41129 Mdot
.4971 .50701 Mdot
.59282 .60273 Mdot
.68854 .69845 Mdot
.78425 .79417 Mdot
.17029 .31557 Mdot
.26601 .41129 Mdot
.36173 .50701 Mdot
.45745 .60273 Mdot
.55317 .69845 Mdot
.64889 .79417 Mdot
.74461 .88989 Mdot
.13064 .41129 Mdot
.22636 .50701 Mdot
.32208 .60273 Mdot
.4178 .69845 Mdot
.51352 .79417 Mdot
.60924 .88989 Mdot
.091 .50701 Mdot
.18671 .60273 Mdot
.28243 .69845 Mdot
.37815 .79417 Mdot
.47387 .88989 Mdot
.05135 .60273 Mdot
.14707 .69845 Mdot
.24279 .79417 Mdot
.3385 .88989 Mdot
.06226 .3385 Mdot
.15797 .24279 Mdot
.25369 .14707 Mdot
.34941 .05135 Mdot
.06226 .47387 Mdot
.15797 .37815 Mdot
.25369 .28243 Mdot
.34941 .18671 Mdot
.44513 .091 Mdot
.06226 .60924 Mdot
.15797 .51352 Mdot
.25369 .4178 Mdot
.34941 .32208 Mdot
.44513 .22636 Mdot
.54085 .13064 Mdot
.15797 .64889 Mdot
.25369 .55317 Mdot
.34941 .45745 Mdot
.44513 .36173 Mdot
.54085 .26601 Mdot
.63657 .17029 Mdot
.15797 .78425 Mdot
.25369 .68854 Mdot
.34941 .59282 Mdot
.44513 .4971 Mdot
.54085 .40138 Mdot
.63657 .30566 Mdot
.73229 .20994 Mdot
.25369 .8239 Mdot
.34941 .72818 Mdot
.44513 .63246 Mdot
.54085 .53674 Mdot
.63657 .44103 Mdot
.73229 .34531 Mdot
.82801 .24959 Mdot
.34941 .86355 Mdot
.44513 .76783 Mdot
.54085 .67211 Mdot
.63657 .57639 Mdot
.73229 .48067 Mdot
.82801 .38495 Mdot
.92373 .28924 Mdot
.44513 .9032 Mdot
.54085 .80748 Mdot
.63657 .71176 Mdot
.73229 .61604 Mdot
.82801 .52032 Mdot
.92373 .4246 Mdot
.54085 .94285 Mdot
.63657 .84713 Mdot
.73229 .75141 Mdot
.82801 .65569 Mdot
.92373 .55997 Mdot
.73229 .88678 Mdot
.82801 .79106 Mdot
.92373 .69534 Mdot
.33249 .09319 Mdot
.42821 .09319 Mdot
.52393 .09319 Mdot
.61965 .09319 Mdot
.71537 .09319 Mdot
.14105 .18891 Mdot
.23677 .18891 Mdot
.33249 .18891 Mdot
.42821 .18891 Mdot
.52393 .18891 Mdot
.61965 .18891 Mdot
.71537 .18891 Mdot
.81109 .18891 Mdot
.14105 .28463 Mdot
.23677 .28463 Mdot
.33249 .28463 Mdot
.42821 .28463 Mdot
.52393 .28463 Mdot
.61965 .28463 Mdot
.71537 .28463 Mdot
.81109 .28463 Mdot
.90681 .28463 Mdot
.04533 .38035 Mdot
.14105 .38035 Mdot
.23677 .38035 Mdot
.33249 .38035 Mdot
.42821 .38035 Mdot
.52393 .38035 Mdot
.61965 .38035 Mdot
.71537 .38035 Mdot
.81109 .38035 Mdot
.90681 .38035 Mdot
.04533 .47607 Mdot
.14105 .47607 Mdot
.23677 .47607 Mdot
.33249 .47607 Mdot
.42821 .47607 Mdot
.52393 .47607 Mdot
.61965 .47607 Mdot
.71537 .47607 Mdot
.81109 .47607 Mdot
.90681 .47607 Mdot
.04533 .57179 Mdot
.14105 .57179 Mdot
.23677 .57179 Mdot
.33249 .57179 Mdot
.42821 .57179 Mdot
.52393 .57179 Mdot
.61965 .57179 Mdot
.71537 .57179 Mdot
.81109 .57179 Mdot
.90681 .57179 Mdot
.14105 .66751 Mdot
.23677 .66751 Mdot
.33249 .66751 Mdot
.42821 .66751 Mdot
.52393 .66751 Mdot
.61965 .66751 Mdot
.71537 .66751 Mdot
.81109 .66751 Mdot
.90681 .66751 Mdot
.14105 .76323 Mdot
.23677 .76323 Mdot
.33249 .76323 Mdot
.42821 .76323 Mdot
.52393 .76323 Mdot
.61965 .76323 Mdot
.71537 .76323 Mdot
.81109 .76323 Mdot
.23677 .85895 Mdot
.33249 .85895 Mdot
.42821 .85895 Mdot
.52393 .85895 Mdot
.61965 .85895 Mdot
.71537 .85895 Mdot
.81109 .85895 Mdot
.42821 .95467 Mdot
.52393 .95467 Mdot
.61965 .95467 Mdot
.60273 .05135 Mdot
.69845 .14707 Mdot
.79417 .24279 Mdot
.88989 .3385 Mdot
.50701 .091 Mdot
.60273 .18671 Mdot
.69845 .28243 Mdot
.79417 .37815 Mdot
.88989 .47387 Mdot
.41129 .13064 Mdot
.50701 .22636 Mdot
.60273 .32208 Mdot
.69845 .4178 Mdot
.79417 .51352 Mdot
.88989 .60924 Mdot
.31557 .17029 Mdot
.41129 .26601 Mdot
.50701 .36173 Mdot
.60273 .45745 Mdot
.69845 .55317 Mdot
.79417 .64889 Mdot
.88989 .74461 Mdot
.21985 .20994 Mdot
.31557 .30566 Mdot
.41129 .40138 Mdot
.50701 .4971 Mdot
.60273 .59282 Mdot
.69845 .68854 Mdot
.79417 .78425 Mdot
.12413 .24959 Mdot
.21985 .34531 Mdot
.31557 .44103 Mdot
.41129 .53674 Mdot
.50701 .63246 Mdot
.60273 .72818 Mdot
.69845 .8239 Mdot
.12413 .38495 Mdot
.21985 .48067 Mdot
.31557 .57639 Mdot
.41129 .67211 Mdot
.50701 .76783 Mdot
.60273 .86355 Mdot
.02841 .4246 Mdot
.12413 .52032 Mdot
.21985 .61604 Mdot
.31557 .71176 Mdot
.41129 .80748 Mdot
.50701 .9032 Mdot
.02841 .55997 Mdot
.12413 .65569 Mdot
.21985 .75141 Mdot
.31557 .84713 Mdot
.41129 .94285 Mdot
.12413 .79106 Mdot
.21985 .88678 Mdot
.30466 .07627 Mdot
.44003 .07627 Mdot
.5754 .07627 Mdot
.71076 .07627 Mdot
.20894 .17199 Mdot
.34431 .17199 Mdot
.47968 .17199 Mdot
.61505 .17199 Mdot
.75041 .17199 Mdot
.11322 .26771 Mdot
.24859 .26771 Mdot
.38396 .26771 Mdot
.51933 .26771 Mdot
.65469 .26771 Mdot
.79006 .26771 Mdot
.15287 .36343 Mdot
.28824 .36343 Mdot
.42361 .36343 Mdot
.55897 .36343 Mdot
.69434 .36343 Mdot
.82971 .36343 Mdot
.05715 .45915 Mdot
.19252 .45915 Mdot
.32789 .45915 Mdot
.46326 .45915 Mdot
.59862 .45915 Mdot
.73399 .45915 Mdot
.86936 .45915 Mdot
.0968 .55487 Mdot
.23217 .55487 Mdot
.36754 .55487 Mdot
.5029 .55487 Mdot
.63827 .55487 Mdot
.77364 .55487 Mdot
.909 .55487 Mdot
.13645 .65059 Mdot
.27182 .65059 Mdot
.40718 .65059 Mdot
.54255 .65059 Mdot
.67792 .65059 Mdot
.81329 .65059 Mdot
.94865 .65059 Mdot
.1761 .74631 Mdot
.31146 .74631 Mdot
.44683 .74631 Mdot
.5822 .74631 Mdot
.71757 .74631 Mdot
.85293 .74631 Mdot
.21575 .84203 Mdot
.35111 .84203 Mdot
.48648 .84203 Mdot
.62185 .84203 Mdot
.75721 .84203 Mdot
.39076 .93774 Mdot
.52613 .93774 Mdot
.6615 .93774 Mdot
.66921 .0939 Mdot
.73689 .16158 Mdot
.80458 .22927 Mdot
.87226 .29695 Mdot
.93994 .36463 Mdot
.46616 .02621 Mdot
.53384 .0939 Mdot
.60153 .16158 Mdot
.66921 .22927 Mdot
.73689 .29695 Mdot
.80458 .36463 Mdot
.87226 .43232 Mdot
.93994 .5 Mdot
.39847 .0939 Mdot
.46616 .16158 Mdot
.53384 .22927 Mdot
.60153 .29695 Mdot
.66921 .36463 Mdot
.73689 .43232 Mdot
.80458 .5 Mdot
.87226 .56768 Mdot
.93994 .63537 Mdot
.26311 .0939 Mdot
.33079 .16158 Mdot
.39847 .22927 Mdot
.46616 .29695 Mdot
.53384 .36463 Mdot
.60153 .43232 Mdot
.66921 .5 Mdot
.73689 .56768 Mdot
.80458 .63537 Mdot
.87226 .70305 Mdot
.19542 .16158 Mdot
.26311 .22927 Mdot
.33079 .29695 Mdot
.39847 .36463 Mdot
.46616 .43232 Mdot
.53384 .5 Mdot
.60153 .56768 Mdot
.66921 .63537 Mdot
.73689 .70305 Mdot
.80458 .77073 Mdot
.12774 .22927 Mdot
.19542 .29695 Mdot
.26311 .36463 Mdot
.33079 .43232 Mdot
.39847 .5 Mdot
.46616 .56768 Mdot
.53384 .63537 Mdot
.60153 .70305 Mdot
.66921 .77073 Mdot
.73689 .83842 Mdot
.12774 .36463 Mdot
.19542 .43232 Mdot
.26311 .5 Mdot
.33079 .56768 Mdot
.39847 .63537 Mdot
.46616 .70305 Mdot
.53384 .77073 Mdot
.60153 .83842 Mdot
.66921 .9061 Mdot
.06006 .43232 Mdot
.12774 .5 Mdot
.19542 .56768 Mdot
.26311 .63537 Mdot
.33079 .70305 Mdot
.39847 .77073 Mdot
.46616 .83842 Mdot
.53384 .9061 Mdot
.06006 .56768 Mdot
.12774 .63537 Mdot
.19542 .70305 Mdot
.26311 .77073 Mdot
.33079 .83842 Mdot
.39847 .9061 Mdot
.46616 .97379 Mdot
.12774 .77073 Mdot
.19542 .83842 Mdot
.26311 .9061 Mdot
.6615 .06226 Mdot
.75721 .15797 Mdot
.85293 .25369 Mdot
.94865 .34941 Mdot
.52613 .06226 Mdot
.62185 .15797 Mdot
.71757 .25369 Mdot
.81329 .34941 Mdot
.909 .44513 Mdot
.39076 .06226 Mdot
.48648 .15797 Mdot
.5822 .25369 Mdot
.67792 .34941 Mdot
.77364 .44513 Mdot
.86936 .54085 Mdot
.35111 .15797 Mdot
.44683 .25369 Mdot
.54255 .34941 Mdot
.63827 .44513 Mdot
.73399 .54085 Mdot
.82971 .63657 Mdot
.21575 .15797 Mdot
.31146 .25369 Mdot
.40718 .34941 Mdot
.5029 .44513 Mdot
.59862 .54085 Mdot
.69434 .63657 Mdot
.79006 .73229 Mdot
.1761 .25369 Mdot
.27182 .34941 Mdot
.36754 .44513 Mdot
.46326 .54085 Mdot
.55897 .63657 Mdot
.65469 .73229 Mdot
.75041 .82801 Mdot
.13645 .34941 Mdot
.23217 .44513 Mdot
.32789 .54085 Mdot
.42361 .63657 Mdot
.51933 .73229 Mdot
.61505 .82801 Mdot
.71076 .92373 Mdot
.0968 .44513 Mdot
.19252 .54085 Mdot
.28824 .63657 Mdot
.38396 .73229 Mdot
.47968 .82801 Mdot
.5754 .92373 Mdot
.05715 .54085 Mdot
.15287 .63657 Mdot
.24859 .73229 Mdot
.34431 .82801 Mdot
.44003 .92373 Mdot
.11322 .73229 Mdot
.20894 .82801 Mdot
.30466 .92373 Mdot
.07627 .30466 Mdot
.17199 .20894 Mdot
.26771 .11322 Mdot
.07627 .44003 Mdot
.17199 .34431 Mdot
.26771 .24859 Mdot
.36343 .15287 Mdot
.45915 .05715 Mdot
.07627 .5754 Mdot
.17199 .47968 Mdot
.26771 .38396 Mdot
.36343 .28824 Mdot
.45915 .19252 Mdot
.55487 .0968 Mdot
.07627 .71076 Mdot
.17199 .61505 Mdot
.26771 .51933 Mdot
.36343 .42361 Mdot
.45915 .32789 Mdot
.55487 .23217 Mdot
.65059 .13645 Mdot
.17199 .75041 Mdot
.26771 .65469 Mdot
.36343 .55897 Mdot
.45915 .46326 Mdot
.55487 .36754 Mdot
.65059 .27182 Mdot
.74631 .1761 Mdot
.26771 .79006 Mdot
.36343 .69434 Mdot
.45915 .59862 Mdot
.55487 .5029 Mdot
.65059 .40718 Mdot
.74631 .31146 Mdot
.84203 .21575 Mdot
.36343 .82971 Mdot
.45915 .73399 Mdot
.55487 .63827 Mdot
.65059 .54255 Mdot
.74631 .44683 Mdot
.84203 .35111 Mdot
.45915 .86936 Mdot
.55487 .77364 Mdot
.65059 .67792 Mdot
.74631 .5822 Mdot
.84203 .48648 Mdot
.93774 .39076 Mdot
.55487 .909 Mdot
.65059 .81329 Mdot
.74631 .71757 Mdot
.84203 .62185 Mdot
.93774 .52613 Mdot
.65059 .94865 Mdot
.74631 .85293 Mdot
.84203 .75721 Mdot
.93774 .6615 Mdot
.38035 .04533 Mdot
.47607 .04533 Mdot
.57179 .04533 Mdot
.18891 .14105 Mdot
.28463 .14105 Mdot
.38035 .14105 Mdot
.47607 .14105 Mdot
.57179 .14105 Mdot
.66751 .14105 Mdot
.76323 .14105 Mdot
.18891 .23677 Mdot
.28463 .23677 Mdot
.38035 .23677 Mdot
.47607 .23677 Mdot
.57179 .23677 Mdot
.66751 .23677 Mdot
.76323 .23677 Mdot
.85895 .23677 Mdot
.09319 .33249 Mdot
.18891 .33249 Mdot
.28463 .33249 Mdot
.38035 .33249 Mdot
.47607 .33249 Mdot
.57179 .33249 Mdot
.66751 .33249 Mdot
.76323 .33249 Mdot
.85895 .33249 Mdot
.09319 .42821 Mdot
.18891 .42821 Mdot
.28463 .42821 Mdot
.38035 .42821 Mdot
.47607 .42821 Mdot
.57179 .42821 Mdot
.66751 .42821 Mdot
.76323 .42821 Mdot
.85895 .42821 Mdot
.95467 .42821 Mdot
.09319 .52393 Mdot
.18891 .52393 Mdot
.28463 .52393 Mdot
.38035 .52393 Mdot
.47607 .52393 Mdot
.57179 .52393 Mdot
.66751 .52393 Mdot
.76323 .52393 Mdot
.85895 .52393 Mdot
.95467 .52393 Mdot
.09319 .61965 Mdot
.18891 .61965 Mdot
.28463 .61965 Mdot
.38035 .61965 Mdot
.47607 .61965 Mdot
.57179 .61965 Mdot
.66751 .61965 Mdot
.76323 .61965 Mdot
.85895 .61965 Mdot
.95467 .61965 Mdot
.09319 .71537 Mdot
.18891 .71537 Mdot
.28463 .71537 Mdot
.38035 .71537 Mdot
.47607 .71537 Mdot
.57179 .71537 Mdot
.66751 .71537 Mdot
.76323 .71537 Mdot
.85895 .71537 Mdot
.18891 .81109 Mdot
.28463 .81109 Mdot
.38035 .81109 Mdot
.47607 .81109 Mdot
.57179 .81109 Mdot
.66751 .81109 Mdot
.76323 .81109 Mdot
.85895 .81109 Mdot
.28463 .90681 Mdot
.38035 .90681 Mdot
.47607 .90681 Mdot
.57179 .90681 Mdot
.66751 .90681 Mdot
.78015 .11322 Mdot
.87587 .20894 Mdot
.58871 .05715 Mdot
.68443 .15287 Mdot
.78015 .24859 Mdot
.87587 .34431 Mdot
.97159 .44003 Mdot
.49299 .0968 Mdot
.58871 .19252 Mdot
.68443 .28824 Mdot
.78015 .38396 Mdot
.87587 .47968 Mdot
.97159 .5754 Mdot
.39727 .13645 Mdot
.49299 .23217 Mdot
.58871 .32789 Mdot
.68443 .42361 Mdot
.78015 .51933 Mdot
.87587 .61505 Mdot
.30155 .1761 Mdot
.39727 .27182 Mdot
.49299 .36754 Mdot
.58871 .46326 Mdot
.68443 .55897 Mdot
.78015 .65469 Mdot
.87587 .75041 Mdot
.20583 .21575 Mdot
.30155 .31146 Mdot
.39727 .40718 Mdot
.49299 .5029 Mdot
.58871 .59862 Mdot
.68443 .69434 Mdot
.78015 .79006 Mdot
.11011 .25539 Mdot
.20583 .35111 Mdot
.30155 .44683 Mdot
.39727 .54255 Mdot
.49299 .63827 Mdot
.58871 .73399 Mdot
.68443 .82971 Mdot
.11011 .39076 Mdot
.20583 .48648 Mdot
.30155 .5822 Mdot
.39727 .67792 Mdot
.49299 .77364 Mdot
.58871 .86936 Mdot
.11011 .52613 Mdot
.20583 .62185 Mdot
.30155 .71757 Mdot
.39727 .81329 Mdot
.49299 .909 Mdot
.11011 .6615 Mdot
.20583 .75721 Mdot
.30155 .85293 Mdot
.39727 .94865 Mdot
.3385 .06226 Mdot
.47387 .06226 Mdot
.60924 .06226 Mdot
.24279 .15797 Mdot
.37815 .15797 Mdot
.51352 .15797 Mdot
.64889 .15797 Mdot
.78425 .15797 Mdot
.14707 .25369 Mdot
.28243 .25369 Mdot
.4178 .25369 Mdot
.55317 .25369 Mdot
.68854 .25369 Mdot
.8239 .25369 Mdot
.05135 .34941 Mdot
.18671 .34941 Mdot
.32208 .34941 Mdot
.45745 .34941 Mdot
.59282 .34941 Mdot
.72818 .34941 Mdot
.86355 .34941 Mdot
.091 .44513 Mdot
.22636 .44513 Mdot
.36173 .44513 Mdot
.4971 .44513 Mdot
.63246 .44513 Mdot
.76783 .44513 Mdot
.9032 .44513 Mdot
.13064 .54085 Mdot
.26601 .54085 Mdot
.40138 .54085 Mdot
.53674 .54085 Mdot
.67211 .54085 Mdot
.80748 .54085 Mdot
.94285 .54085 Mdot
.17029 .63657 Mdot
.30566 .63657 Mdot
.44103 .63657 Mdot
.57639 .63657 Mdot
.71176 .63657 Mdot
.84713 .63657 Mdot
.20994 .73229 Mdot
.34531 .73229 Mdot
.48067 .73229 Mdot
.61604 .73229 Mdot
.75141 .73229 Mdot
.88678 .73229 Mdot
.24959 .82801 Mdot
.38495 .82801 Mdot
.52032 .82801 Mdot
.65569 .82801 Mdot
.79106 .82801 Mdot
.28924 .92373 Mdot
.4246 .92373 Mdot
.55997 .92373 Mdot
.69534 .92373 Mdot
.73689 .0939 Mdot
.80458 .16158 Mdot
.87226 .22927 Mdot
.53384 .02621 Mdot
.60153 .0939 Mdot
.66921 .16158 Mdot
.73689 .22927 Mdot
.80458 .29695 Mdot
.87226 .36463 Mdot
.93994 .43232 Mdot
.46616 .0939 Mdot
.53384 .16158 Mdot
.60153 .22927 Mdot
.66921 .29695 Mdot
.73689 .36463 Mdot
.80458 .43232 Mdot
.87226 .5 Mdot
.93994 .56768 Mdot
.33079 .0939 Mdot
.39847 .16158 Mdot
.46616 .22927 Mdot
.53384 .29695 Mdot
.60153 .36463 Mdot
.66921 .43232 Mdot
.73689 .5 Mdot
.80458 .56768 Mdot
.87226 .63537 Mdot
.26311 .16158 Mdot
.33079 .22927 Mdot
.39847 .29695 Mdot
.46616 .36463 Mdot
.53384 .43232 Mdot
.60153 .5 Mdot
.66921 .56768 Mdot
.73689 .63537 Mdot
.80458 .70305 Mdot
.87226 .77073 Mdot
.19542 .22927 Mdot
.26311 .29695 Mdot
.33079 .36463 Mdot
.39847 .43232 Mdot
.46616 .5 Mdot
.53384 .56768 Mdot
.60153 .63537 Mdot
.66921 .70305 Mdot
.73689 .77073 Mdot
.80458 .83842 Mdot
.12774 .29695 Mdot
.19542 .36463 Mdot
.26311 .43232 Mdot
.33079 .5 Mdot
.39847 .56768 Mdot
.46616 .63537 Mdot
.53384 .70305 Mdot
.60153 .77073 Mdot
.66921 .83842 Mdot
.73689 .9061 Mdot
.06006 .36463 Mdot
.12774 .43232 Mdot
.19542 .5 Mdot
.26311 .56768 Mdot
.33079 .63537 Mdot
.39847 .70305 Mdot
.46616 .77073 Mdot
.53384 .83842 Mdot
.60153 .9061 Mdot
.06006 .5 Mdot
.12774 .56768 Mdot
.19542 .63537 Mdot
.26311 .70305 Mdot
.33079 .77073 Mdot
.39847 .83842 Mdot
.46616 .9061 Mdot
.53384 .97379 Mdot
.06006 .63537 Mdot
.12774 .70305 Mdot
.19542 .77073 Mdot
.26311 .83842 Mdot
.33079 .9061 Mdot
.69534 .07627 Mdot
.79106 .17199 Mdot
.88678 .26771 Mdot
.55997 .07627 Mdot
.65569 .17199 Mdot
.75141 .26771 Mdot
.84713 .36343 Mdot
.94285 .45915 Mdot
.4246 .07627 Mdot
.52032 .17199 Mdot
.61604 .26771 Mdot
.71176 .36343 Mdot
.80748 .45915 Mdot
.9032 .55487 Mdot
.28924 .07627 Mdot
.38495 .17199 Mdot
.48067 .26771 Mdot
.57639 .36343 Mdot
.67211 .45915 Mdot
.76783 .55487 Mdot
.86355 .65059 Mdot
.24959 .17199 Mdot
.34531 .26771 Mdot
.44103 .36343 Mdot
.53674 .45915 Mdot
.63246 .55487 Mdot
.72818 .65059 Mdot
.8239 .74631 Mdot
.20994 .26771 Mdot
.30566 .36343 Mdot
.40138 .45915 Mdot
.4971 .55487 Mdot
.59282 .65059 Mdot
.68854 .74631 Mdot
.78425 .84203 Mdot
.17029 .36343 Mdot
.26601 .45915 Mdot
.36173 .55487 Mdot
.45745 .65059 Mdot
.55317 .74631 Mdot
.64889 .84203 Mdot
.13064 .45915 Mdot
.22636 .55487 Mdot
.32208 .65059 Mdot
.4178 .74631 Mdot
.51352 .84203 Mdot
.60924 .93774 Mdot
.091 .55487 Mdot
.18671 .65059 Mdot
.28243 .74631 Mdot
.37815 .84203 Mdot
.47387 .93774 Mdot
.05135 .65059 Mdot
.14707 .74631 Mdot
.24279 .84203 Mdot
.3385 .93774 Mdot
.11011 .3385 Mdot
.20583 .24279 Mdot
.30155 .14707 Mdot
.39727 .05135 Mdot
.11011 .47387 Mdot
.20583 .37815 Mdot
.30155 .28243 Mdot
.39727 .18671 Mdot
.49299 .091 Mdot
.11011 .60924 Mdot
.20583 .51352 Mdot
.30155 .4178 Mdot
.39727 .32208 Mdot
.49299 .22636 Mdot
.58871 .13064 Mdot
.11011 .74461 Mdot
.20583 .64889 Mdot
.30155 .55317 Mdot
.39727 .45745 Mdot
.49299 .36173 Mdot
.58871 .26601 Mdot
.68443 .17029 Mdot
.20583 .78425 Mdot
.30155 .68854 Mdot
.39727 .59282 Mdot
.49299 .4971 Mdot
.58871 .40138 Mdot
.68443 .30566 Mdot
.78015 .20994 Mdot
.30155 .8239 Mdot
.39727 .72818 Mdot
.49299 .63246 Mdot
.58871 .53674 Mdot
.68443 .44103 Mdot
.78015 .34531 Mdot
.87587 .24959 Mdot
.39727 .86355 Mdot
.49299 .76783 Mdot
.58871 .67211 Mdot
.68443 .57639 Mdot
.78015 .48067 Mdot
.87587 .38495 Mdot
.49299 .9032 Mdot
.58871 .80748 Mdot
.68443 .71176 Mdot
.78015 .61604 Mdot
.87587 .52032 Mdot
.97159 .4246 Mdot
.58871 .94285 Mdot
.68443 .84713 Mdot
.78015 .75141 Mdot
.87587 .65569 Mdot
.97159 .55997 Mdot
.78015 .88678 Mdot
.87587 .79106 Mdot
.28463 .09319 Mdot
.38035 .09319 Mdot
.47607 .09319 Mdot
.57179 .09319 Mdot
.66751 .09319 Mdot
.18891 .18891 Mdot
.28463 .18891 Mdot
.38035 .18891 Mdot
.47607 .18891 Mdot
.57179 .18891 Mdot
.66751 .18891 Mdot
.76323 .18891 Mdot
.85895 .18891 Mdot
.09319 .28463 Mdot
.18891 .28463 Mdot
.28463 .28463 Mdot
.38035 .28463 Mdot
.47607 .28463 Mdot
.57179 .28463 Mdot
.66751 .28463 Mdot
.76323 .28463 Mdot
.85895 .28463 Mdot
.09319 .38035 Mdot
.18891 .38035 Mdot
.28463 .38035 Mdot
.38035 .38035 Mdot
.47607 .38035 Mdot
.57179 .38035 Mdot
.66751 .38035 Mdot
.76323 .38035 Mdot
.85895 .38035 Mdot
.95467 .38035 Mdot
.09319 .47607 Mdot
.18891 .47607 Mdot
.28463 .47607 Mdot
.38035 .47607 Mdot
.47607 .47607 Mdot
.57179 .47607 Mdot
.66751 .47607 Mdot
.76323 .47607 Mdot
.85895 .47607 Mdot
.95467 .47607 Mdot
.09319 .57179 Mdot
.18891 .57179 Mdot
.28463 .57179 Mdot
.38035 .57179 Mdot
.47607 .57179 Mdot
.57179 .57179 Mdot
.66751 .57179 Mdot
.76323 .57179 Mdot
.85895 .57179 Mdot
.95467 .57179 Mdot
.09319 .66751 Mdot
.18891 .66751 Mdot
.28463 .66751 Mdot
.38035 .66751 Mdot
.47607 .66751 Mdot
.57179 .66751 Mdot
.66751 .66751 Mdot
.76323 .66751 Mdot
.85895 .66751 Mdot
.18891 .76323 Mdot
.28463 .76323 Mdot
.38035 .76323 Mdot
.47607 .76323 Mdot
.57179 .76323 Mdot
.66751 .76323 Mdot
.76323 .76323 Mdot
.85895 .76323 Mdot
.18891 .85895 Mdot
.28463 .85895 Mdot
.38035 .85895 Mdot
.47607 .85895 Mdot
.57179 .85895 Mdot
.66751 .85895 Mdot
.76323 .85895 Mdot
.38035 .95467 Mdot
.47607 .95467 Mdot
.57179 .95467 Mdot
.65059 .05135 Mdot
.74631 .14707 Mdot
.84203 .24279 Mdot
.93774 .3385 Mdot
.55487 .091 Mdot
.65059 .18671 Mdot
.74631 .28243 Mdot
.84203 .37815 Mdot
.93774 .47387 Mdot
.45915 .13064 Mdot
.55487 .22636 Mdot
.65059 .32208 Mdot
.74631 .4178 Mdot
.84203 .51352 Mdot
.93774 .60924 Mdot
.36343 .17029 Mdot
.45915 .26601 Mdot
.55487 .36173 Mdot
.65059 .45745 Mdot
.74631 .55317 Mdot
.84203 .64889 Mdot
.26771 .20994 Mdot
.36343 .30566 Mdot
.45915 .40138 Mdot
.55487 .4971 Mdot
.65059 .59282 Mdot
.74631 .68854 Mdot
.84203 .78425 Mdot
.17199 .24959 Mdot
.26771 .34531 Mdot
.36343 .44103 Mdot
.45915 .53674 Mdot
.55487 .63246 Mdot
.65059 .72818 Mdot
.74631 .8239 Mdot
.07627 .28924 Mdot
.17199 .38495 Mdot
.26771 .48067 Mdot
.36343 .57639 Mdot
.45915 .67211 Mdot
.55487 .76783 Mdot
.65059 .86355 Mdot
.07627 .4246 Mdot
.17199 .52032 Mdot
.26771 .61604 Mdot
.36343 .71176 Mdot
.45915 .80748 Mdot
.55487 .9032 Mdot
.07627 .55997 Mdot
.17199 .65569 Mdot
.26771 .75141 Mdot
.36343 .84713 Mdot
.45915 .94285 Mdot
.07627 .69534 Mdot
.17199 .79106 Mdot
.26771 .88678 Mdot
.3385 .11011 Mdot
.47387 .11011 Mdot
.60924 .11011 Mdot
.74461 .11011 Mdot
.24279 .20583 Mdot
.37815 .20583 Mdot
.51352 .20583 Mdot
.64889 .20583 Mdot
.78425 .20583 Mdot
.14707 .30155 Mdot
.28243 .30155 Mdot
.4178 .30155 Mdot
.55317 .30155 Mdot
.68854 .30155 Mdot
.8239 .30155 Mdot
.05135 .39727 Mdot
.18671 .39727 Mdot
.32208 .39727 Mdot
.45745 .39727 Mdot
.59282 .39727 Mdot
.72818 .39727 Mdot
.86355 .39727 Mdot
.091 .49299 Mdot
.22636 .49299 Mdot
.36173 .49299 Mdot
.4971 .49299 Mdot
.63246 .49299 Mdot
.76783 .49299 Mdot
.9032 .49299 Mdot
.13064 .58871 Mdot
.26601 .58871 Mdot
.40138 .58871 Mdot
.53674 .58871 Mdot
.67211 .58871 Mdot
.80748 .58871 Mdot
.94285 .58871 Mdot
.17029 .68443 Mdot
.30566 .68443 Mdot
.44103 .68443 Mdot
.57639 .68443 Mdot
.71176 .68443 Mdot
.84713 .68443 Mdot
.20994 .78015 Mdot
.34531 .78015 Mdot
.48067 .78015 Mdot
.61604 .78015 Mdot
.75141 .78015 Mdot
.88678 .78015 Mdot
.24959 .87587 Mdot
.38495 .87587 Mdot
.52032 .87587 Mdot
.65569 .87587 Mdot
.79106 .87587 Mdot
.4246 .97159 Mdot
.55997 .97159 Mdot
.63537 .06006 Mdot
.70305 .12774 Mdot
.77073 .19542 Mdot
.83842 .26311 Mdot
.9061 .33079 Mdot
.5 .06006 Mdot
.56768 .12774 Mdot
.63537 .19542 Mdot
.70305 .26311 Mdot
.77073 .33079 Mdot
.83842 .39847 Mdot
.9061 .46616 Mdot
.97379 .53384 Mdot
.36463 .06006 Mdot
.43232 .12774 Mdot
.5 .19542 Mdot
.56768 .26311 Mdot
.63537 .33079 Mdot
.70305 .39847 Mdot
.77073 .46616 Mdot
.83842 .53384 Mdot
.9061 .60153 Mdot
.29695 .12774 Mdot
.36463 .19542 Mdot
.43232 .26311 Mdot
.5 .33079 Mdot
.56768 .39847 Mdot
.63537 .46616 Mdot
.70305 .53384 Mdot
.77073 .60153 Mdot
.83842 .66921 Mdot
.9061 .73689 Mdot
.22927 .19542 Mdot
.29695 .26311 Mdot
.36463 .33079 Mdot
.43232 .39847 Mdot
.5 .46616 Mdot
.56768 .53384 Mdot
.63537 .60153 Mdot
.70305 .66921 Mdot
.77073 .73689 Mdot
.83842 .80458 Mdot
.16158 .26311 Mdot
.22927 .33079 Mdot
.29695 .39847 Mdot
.36463 .46616 Mdot
.43232 .53384 Mdot
.5 .60153 Mdot
.56768 .66921 Mdot
.63537 .73689 Mdot
.70305 .80458 Mdot
.77073 .87226 Mdot
.0939 .33079 Mdot
.16158 .39847 Mdot
.22927 .46616 Mdot
.29695 .53384 Mdot
.36463 .60153 Mdot
.43232 .66921 Mdot
.5 .73689 Mdot
.56768 .80458 Mdot
.63537 .87226 Mdot
.0939 .46616 Mdot
.16158 .53384 Mdot
.22927 .60153 Mdot
.29695 .66921 Mdot
.36463 .73689 Mdot
.43232 .80458 Mdot
.5 .87226 Mdot
.56768 .93994 Mdot
.02621 .53384 Mdot
.0939 .60153 Mdot
.16158 .66921 Mdot
.22927 .73689 Mdot
.29695 .80458 Mdot
.36463 .87226 Mdot
.43232 .93994 Mdot
.0939 .73689 Mdot
.16158 .80458 Mdot
.22927 .87226 Mdot
.6615 .11011 Mdot
.75721 .20583 Mdot
.85293 .30155 Mdot
.94865 .39727 Mdot
.52613 .11011 Mdot
.62185 .20583 Mdot
.71757 .30155 Mdot
.81329 .39727 Mdot
.909 .49299 Mdot
.39076 .11011 Mdot
.48648 .20583 Mdot
.5822 .30155 Mdot
.67792 .39727 Mdot
.77364 .49299 Mdot
.86936 .58871 Mdot
.25539 .11011 Mdot
.35111 .20583 Mdot
.44683 .30155 Mdot
.54255 .39727 Mdot
.63827 .49299 Mdot
.73399 .58871 Mdot
.82971 .68443 Mdot
.21575 .20583 Mdot
.31146 .30155 Mdot
.40718 .39727 Mdot
.5029 .49299 Mdot
.59862 .58871 Mdot
.69434 .68443 Mdot
.79006 .78015 Mdot
.1761 .30155 Mdot
.27182 .39727 Mdot
.36754 .49299 Mdot
.46326 .58871 Mdot
.55897 .68443 Mdot
.65469 .78015 Mdot
.75041 .87587 Mdot
.13645 .39727 Mdot
.23217 .49299 Mdot
.32789 .58871 Mdot
.42361 .68443 Mdot
.51933 .78015 Mdot
.61505 .87587 Mdot
.0968 .49299 Mdot
.19252 .58871 Mdot
.28824 .68443 Mdot
.38396 .78015 Mdot
.47968 .87587 Mdot
.5754 .97159 Mdot
.05715 .58871 Mdot
.15287 .68443 Mdot
.24859 .78015 Mdot
.34431 .87587 Mdot
.44003 .97159 Mdot
.11322 .78015 Mdot
.20894 .87587 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;RLW9b40<?oo_`00?g=cLda<C820P8NZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmo
OiB;WMKBg2XX;H=kRhjYUM3KddiMD^GQY9no_m[ViUY]KD=EIB4Z<M_Vkl?Ei6F0V;2^]4U5CX61PFYo
L4mOGbL_;n;/k<oOggN?ShRZVHEhU000O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o
002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmo
Ocmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?glo
Oglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0
_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo
_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo
?oooOlS3cdDnCFmlS[g3bcU0B]C>N7j0VLG6dD52Cf]]PW5VO]_Ggd8lBVIbVOoo0_oo1mWIhEiPLko0
c3m0C1lO9FAJKk>ic=;EhC<iC1TL9DaELeioI[C3]c11=?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L008D700<01`L04@L00`071`241`00N@L200870P061`804@L200H70P021`80
NPL007X700D01`L700061`<03`L00`0700071`0500L71`00NPL008D700@01`L03@L010071`261`00
Q@L01@071`L000/700D01`L700261`00Q@L00`071`021`0300L700L700<01`L00PL00`071`241`00
K0L200`70P091`0300L7008000<700L01PL0100700021`0300L700L70P0<1`80K@L006d700<01`L0
2`L00`071`071`0500L71`000PL00`071`031`0500L71`000PL00`071`081`0300L700/700<01`L0
J`L006<70P0<1`804PL00`071`051`0500L71`001`L00`071`0@1`8030L206@7001T1`0300L700/7
00<01`L040L00`071`061`0300L000P700<01`L04@L00`071`0;1`0300L70687001P1`l01PL200@7
0P061`<020L200T70`061`8010L200H73`1Q1`00H0L200L700<01`L00PL300D700<01`L00`L00`07
1`051`8000<700001PL00`071`041`8000@700L01`L00`071`031`0300L700870`051`0300L700@7
0P1Q1`00H0L200`700<01`0050L010071`061`0300L700D700<01`005@L200d700<01`L0G`L00607
00<01`L02`L00`071`0D1`0300L700L700<01`L01`L00`071`0D1`0300L700/700<01`L0G`L005H7
00<01`L01`L00`071`0;1`0300L700L73P091`0300L700L73P091`0300L700/700<01`L01`L00`07
1`1E1`00DPL200041`0000P700<01`L02`L00`071`061`0400L000870P071`0300L700H700<01`L0
1PL00`071`051`800PL200031`0700L700<01`L02`L00`071`051`8000<700L00P1C1`00D`L20087
0P071`0300L700/700<01`L01@L01@071`L000<700<01`L01PL00`071`051`0300L700D700<01`L0
1`L00`071`02008700<01`L01@L00`071`0;1`0300L700D70P021`0300L005<7001C1`0300L700<7
00<01`L010L00`071`0;1`0300L700@700<01`L00`L00`071`0:1`0300L700@700<01`L010L00`07
1`0:1`0300L700<700<01`L010L00`071`0;1`0300L700@700<01`L00`L00`071`1B1`00DPL00`07
1`051`0300L700<700<01`L02`L00`071`031`0300L700D700<01`L02PL00`071`031`0300L700<7
00<01`L02PL00`071`051`0300L700<700<01`L02`L00`071`031`0300L700D700<01`L0D@L00587
00<01`L01PL00`071`021`0300L700/700<01`L00PL00`071`061`0300L700802@L01@07000700<0
0PL00`071`071`800PL00`071`061`0300L7008700<01`L02`L00`071`021`0300L700H700<01`L0
D@L004X70P051`802@L00`07000200/70`021`801`L200051`071`0010L2000>1`001`0700L01`07
00L200031`0000D700@01`070P071`800PL300/70`000`L01`081`8010L204`7001;1`0300L70087
00<01`002PL01007000<1`800PL200P700<01`L00`051`0400L700870P000`L0000200<700@01`L0
10L300<700<01`L01PL01P071`0700/7100;1`8010L00`071`1:1`00C`L00`071`0<1`0300L000d7
00<01`003PL200`700D01`07000=1`0300L700`700<01`003@L00`07000>1`0300L704h7001>1`03
00L700h70P0=1`8040L00`071`0;1`<03@L00`071`0>1`803@L2010700<01`L0C@L004d700<01`L0
40L?01877@0B1`l04PL00`071`1<1`00B0L200@700<01`L03PL300/700@01`003`L00`071`041`80
1@L00`0700051`801PL00`071`0=1`8000<700L02PL3010700<01`L00PL204T7000n1`802@L00`07
1`0200031`0700d700@01`L02PL01@071`L000h700<01`L01PL00`071`021`0500L71`001@L00`07
1`051`0300L700`70P021`0300L700T700<01`003PL0100700031`0300L700H70P0o1`00?`L00`07
1`0;1`0400L700`700<01`L02`L00`071`031`0300L700X700<01`L02`L00`071`031`0300L700/7
00<01`L02PL00`071`031`0300L700/700<01`L02PL01@071`L000d700<01`L0?@L0054700<01`L0
1`L200`70P071`0300L700P700<01`L02PL200L700<01`L02`L00`071`071`801`L00`071`0;1`03
00L700P700<01`L0D0L003/70P0:1`802@L00`071`051`0300L700D70P041`0300L700870P041`80
1`L00`071`0:1`802@L200`700<01`L01@L00`071`021`8010L200@70P061`801`L00`071`071`80
2PL203`7000l1`0300L700870P051`0300L700P70`031`0300L700L700@01`L70`041`0300L700@7
00<01`L00`L200/700<01`000`L200D70P0;1`801@L00`071`041`0300L700870`041`0300L700H7
00@01`L70`0;1`0300L700870P051`0300L703X700121`0300L700l70P021`0300L700/700@01`L0
2`L200<700<01`001PL2008700<01`L01@L00`071`051`0300L700801`L200<70P0<1`0300L000d7
00D01`L7000B1`0300L70407001E1`0300L000/70`0;1`800`L200031`0700T700<01`004@L01007
1`091`0500L01`000PL200/70`0;1`0300L005H7000e1`0300L70147700=1`0300L700<73P0C1`h0
1PL00`071`0:1a`04`L00`071`0d1`00=@L200`70P031`801`L200<700<01`L01@L200@70P061`80
2@L200031`0000T70P000`L0000;1`8000<700002@L200031`0000T70P061`800`L200P700@01`L7
0P071`800`L200`70P0f1`00=@L300`700<01`L00`081`0300L7008020L00`071`021`0300L000H7
00<01`L01PL00`0700021`0300L700L700D01`07000<1`8000<700L02@L01@0700L000T700<01`L0
0`L00`0700041`0300L700D70P041`0300L700D70`031`0300L700T700<01`00=PL003D700@01`L0
3@L010071`0<1`0300L700/700@01`L03@L010071`0<1`0400L700d700@01`L030L010071`0=1`04
00L700d700<01`L02PL200031`0700`700@01`L0=PL003D700D01`L7000;1`0500L71`0030L00`07
1`0200T700<01`L00P0;1`0500L71`0030L01@071`L000/700D01`L7000<1`0500L71`002`L20087
00<01`L01PL200<700<01`L02PL01@071`L000/700D01`L7000f1`00=@L00`071`021`0300L70080
1@L3008700<01`L02PL01@071`L000T70P021`8000<700001PL00`071`021`0300L700X700<01`L0
0PL200H70`041`0300L700X700<01`L00PL00`071`031`800PL0100700L200T700D01`L7000<1`03
00L700<01@L2008700<01`L00PL00`071`0d1`00=@L0100700021`0400L700@700@01`L00PL300X7
00<01`L01@L200@70P041`0300L000@70P051`0300L700X70P041`0300L700D700<01`L00PL200`7
00<01`L00`L200@700<01`001@L00`071`021`801`L00`071`071`8000<700L00PL00`0700051`03
00L000870P000`L01`0e1`00=@L010071`031`0300L700<700<01`L010L00`07000:1`0300L700H7
00<01`L00PL00`071`041`0300L700<70P051`0300L700X70P051`0300L700<700<01`L010L00`07
1`0:1`0300L700@700<01`L00`L00`071`041`0300L700<700<01`L01@L00`071`081`0300L000H7
00<01`L00`L00`071`021`0300L003H7000e1`0300L700D700D01`L700071`0300L700X700<01`L0
2`L00`071`051`0500L71`001`L00`071`0:1`0300L700D700D01`L700071`0300L700X700<01`L0
1@L01@071`L000L700<01`L02`L00`071`0:1`0300L700D700D01`L700071`0300L703@7000e1`03
00L700<70P0010L01`061`<030L00`071`0200L70`021`8010L300P700<01`L02PL010071`L200<7
00<01`000`L200<700<01`L02PL00`071`061`<010L200870`061`800`L00`071`0:1`<01PL01007
00L200D700<01`L0=0L003D700<01`L010L010071`081`8030L01@071`L000P70P031`0300L700<7
00<01`L01`L00`071`0:1`0300L7008700<01`L00PL00`071`031`0500L71`0030L00`071`071`03
00L700@700H01`L01`071`0500L71`0030L00`0700071`0500L71`001@L00`071`0d1`00=@L00`07
1`071`0300L700H70P0;1`803@L00`071`071`0300L700L700<01`L02PL00`071`071`0300L700L7
00<01`L02PL00`071`071`0300L700L700<01`L02PL200`70P081`0300L700L700<01`L0=0L003D7
00<01`L01`L00`071`071`0300L700X700<01`L02`L00`071`071`0300L700L700<01`L02PL00`07
1`071`0300L700L700<01`L02PL00`071`071`0300L700L700<01`L02`L00`071`0:1`8020L00`07
1`071`0300L703@7000e1`0300L700L700<01`L01`L00`071`0:1`0300L700/700<01`L01`L00`07
1`071`0300L700X700<01`L01`L00`071`071`0300L700X700<01`L01`L00`071`071`0300L700/7
00<01`L02PL00`071`071`0300L700L700<01`L0=0L002L740081`0400L71`8010LL00L70`021`80
1@L>00870P051`0300L700<70P021`h01@L200870`071a`010L200<700<01`L01PL@02P7000X1`03
00L700/700<01`L01PL00`071`021`0500L71`002@L01P071`0700L700<01`L00PL200L70P031`03
00L700<000@700L01`L200051`071`001@L00`071`041`0400L01`8020L200041`0000<700H01`L0
1`061`0300L000<700<01`L01@L00`0700031`0300L700H700<01`L00PL01@071`L000P70P0<1`03
00L702L7000Y1`0400L71`8020L00`071`051`0400L000@700<01`L02PL2008700<01`L02`L01007
00041`0300L700D700@01`L70`071`0400L700H70P071`0500L71`001PL300<70P061`0300L70087
0P000`L01`0<1`0300L7008030L00`071`021`8000<700L01PL00`071`061`800`L00`071`0X1`00
:PL01@071`L000T700<01`L010L010071`031`0300L700X700<01`000`L00`071`0;1`0300L000@7
00<01`L010L00`071`031`802`L00`071`041`0300L700@700<01`L02PL00`071`031`0300L700@7
00<01`L00`L200d700<01`L00PL200`700<01`L00PL00`0700061`0300L700P700@01`L0:`L002/7
00<01`L02`L00`071`031`0300L700<700<01`L02PL00`071`051`0300L700/700<01`L00`L00`07
1`031`0300L700D700<01`L02PL00`071`031`0300L700<700<01`L02PL00`071`051`0300L700<7
00<01`L00`L00`071`0;1`0300L700D700<01`L02PL00`071`031`0300L700<700<01`L02`L00`07
1`0Z1`00;0L00`071`0;1`0300L700<010L300/700<01`L01PL00`071`061`800`L01P07000700@7
00<01`L01PL00`071`0;1`800`L00`071`0300d700<01`L01PL00`071`021`<00PL010071`L200P7
00<01`L01PL00`071`091`<010L3008700<01`L02`L00`071`0[1`008`L200P700<01`L00P091`03
00L700800`L010071`051`800`L00`071`081`0300L700H700<01`L00PL01@0700L000<700<01`L0
20L00`071`0;1`0500L71`000`L00`071`0;1`0300L700P700T01`L700L01`001@L00`071`051`03
00L700P700@01`L70P061`0300L000<70`000`L01`081`800PL00`071`061`8090L002@700<01`L0
1`L010071`0:1`0400L7008700<01`L020L010071`0<1`0300L700/700@01`L00PL00`071`0:1`03
00L700/700@01`L00PL00`071`0;1`0300L700X700@01`L00PL00`071`0;1`0300L700X700D01`L7
00091`0300L7008000<700L02PL00`07000:1`0300L70287000/1`8000<700L02@L200061`0700L0
3@L00`071`0<1`0300L700/700D01`07000>1`0300L700/700D01`07000=1`0300L700`700D01`07
000=1`0300L700`700<01`L02`L01P0700L01`802PL01007000]1`007`L200`700@01`L02PL20004
1`0000D70P061`0300L700h700<01`L00P091`<040L00`071`061`800`L300<70P081`0300L700h7
0`091`800PL00`071`0>1`0300L700@70P051`<000@700002@L01@071`L000X70P0Q1`0080L00`07
1`0>1ad04PL?01877@0B1`l04PLM010700<01`L07`L0030700<01`L02`L200d70P0@1`803@L200l7
0P0;1`H030L200l70P0=1`8040L200d70P0=1`0300L702l7000T1`802@L00`071`051`8010L00`07
000:1`8000@700L03PL300d700<01`000P0<1`8010L200H700D01`0700061`801@L00`071`0:1`<0
00<700L030L300h700<01`000P0;1`0300L000@70P071`0300L700L70P0U1`009@L00`071`061`03
00L700L700D01`L700021`0300L700T700<01`000PL00`071`0:1`0400L000d700<01`L00P0;1`<0
1@L00`071`031`8000<700000P061`0300L700870`0<1`0400L700d700@01`0030L01P071`0700/7
00@01`L010L00`071`061`0300L700L700<01`L08`L002L70P041`0300L700D70P041`0500L71`00
0`L200P700@01`L70P091`0300L000802`L300<700<01`L01@L200051`071`001`L2000;1`0700L0
1`0700L00P081`0400L01`801`L010071`L300/70P021`0300L700L70P031`0300L700H70P031`05
00L71`0010L200L700@01`L70P0Y1`00:0L01@071`L000T700D01`L700041`0300L7008700<01`L0
1PL010071`L200P700@01`L70P0<1`8010L00`071`051`0300L000/70P041`0300L7008700<01`00
2PL010071`061`0300L7008700<01`002`L200<700<01`L01`L01@071`L000T700D01`L700041`03
00L7008700<01`L01PL01@071`L002T7000[1`<02`L300<700<01`L02`L00`071`021`0300L700D7
00<01`L00`L00`071`0;1`0300L700<700<01`L01@L00`071`0:1`0300L700<700<01`L00`L00`07
1`0:1`0300L700D700<01`L00`L00`071`0;1`0300L700<700<01`L01@L00`071`021`0300L700/7
00@01`L70`0;1`<0;0L002X700@01`L02PL010071`021`8030L200D700<01`L00`L00`071`041`03
00L700/700<01`L010L00`071`031`0300L700X700<01`L010L00`071`041`0300L700X700<01`L0
0`L00`071`041`0300L700/700<01`L010L00`071`031`0300L700<70P0<1`800`L00`07000;1`03
00L002/7000S1`8010L00`071`041`801@L00`071`051`0300L700/700<01`L010L01@071`L000L7
00<01`L02`L00`071`051`0500L71`0030L00`071`051`0300L700D700<01`L02PL01@071`L000L7
00<01`L02`L00`071`051`0500L71`001PL200`70P061`0300L700<70P061`0300L700870P0T1`00
7PL200@700@01`L70`061`800`L00`071`061`0300L700/700<01`L00P031`0300L000801PL00`07
1`0;1`0300L700H70`051`801@L00`071`061`0300L700H700<01`L00`L200D70`081`0300L700/7
00<01`L00`L200041`0700<70P021`0300L700/700<01`L01PL00`071`0200031`0700@70`041`03
00L7008080L001l700<01`L01@L?00T700<01`L02`L01@071`L000@700@01`L01PL00`071`0;1`03
00L700L73P091`0300L700L73`081`0300L700/700<01`L010L010071`051`0400L700d700<01`L0
1`L?00L700<01`L07PL002L700<01`L02`L00`071`071`0300L700/700<01`L01PL00`071`071`03
00L700/700<01`L01`L00`071`0:1`0300L700L700<01`L01`L00`071`0:1`0300L700L700<01`L0
2`L00`071`071`0300L700H700<01`L02`L00`071`071`0300L700/700<01`L09PL001X70P0;1`03
00L700<70P061`0300L700L700@01`002PL00`071`041`<02@L00`071`051`8010L00`071`041`80
00@700L70P061`<020L200T70`061`800PL0100700061`0300L700870P071`0300L700L70`061`03
00L700P70P000`L01`081`0300L700@70P051`0300L700T70P0K1`006`L010071`L200H700<01`L0
10L00`071`041`0300L700<70P021`0400L700<70P051`0300L700D70P091`0400L000D700@01`L7
0P071`0300L000<700<01`L01@L200<70P041`0300L700870P031`0300L000L700@01`L00PL00`07
1`041`8010L00`071`021`8000<700L020L00`0700061`0300L700<70P041`0300L000870P051`03
00L700D700<01`L00`L00`071`031`801@L00`071`0I1`007PL00`0700061`0300L700/700<01`L0
10L00`071`0?00P700<01`L01`L?00870P051`0300L700X700<01`L00PL00`071`021`0300L700<7
00D01`L7000<1`0300L700<70P021`l02@L00`071`061`l00`L00`071`031`0300L700/700<01`L0
10L00`07000O1`007@L00`0700071`0300L700/700<01`L01PL00`07000=1`0300L700D700<01`L0
1PL00`071`021`0300L700H700<01`000PL00`071`031`0300L700X700<01`L01PL00`0700081`03
00L700X700<01`L010L01@0700L000T700D01`L700081`0300L700D700<01`L02`L00`0700081`03
00L700/700<01`L01@L00`07000N1`0070L01@071`L000H700<01`L02`L00`071`051`0500L71`00
3@L00`071`041`0300L700D700<01`L02`L01@071`L000L700<01`L02PL00`071`051`0500L71`00
1`L00`071`0:1`0300L700D700D01`L7000=1`0300L700D700<01`L010L00`071`0;1`0500L71`00
1`L00`071`0;1`0300L700@700D01`L7000M1`006`L00`071`031`0300L700<700<01`L02`L00`07
1`041`0300L700<700<01`L00`L200H700<01`L00PL200H700<01`L02`L00`071`031`0300L700@7
00<01`L02PL00`071`041`0300L700<700<01`L010L00`071`0:1`0300L700@700<01`L00`L00`07
1`0;1`0300L700<70P051`0300L700@70P051`0300L700<700<01`L010L00`071`0;1`0300L700<7
00<01`L00`L00`071`0J1`006@L300H700<01`L00PL200`70P031`801`L200@700<01`L01@L200<7
00<01`L00PL200031`0000T70P000`L000041`0300L700<700@01`002@L00`071`0400L700@01`00
0PL00`071`071`8000<700L00`L200@70P000`L01`081`800PL00`071`031`0400L71`8020L01007
1`L200L700<01`L00PL200/70`041`0300L700@70P0K1`005@L200051`071`001`L010071`L200`7
0P021`0300L700P70P0<1`0500L71`000PL200@700<01`L01@L200@700<01`L00`L200<700@01`L0
2@L01@071`L000X70`021`0300L700P700<01`000`L00`071`051`0300L700<01`L010071`L200<7
00@01`L70P0;1`0300L000P70P031`0300L700X70P031`0300L700H70`000`L0000F1`005PL200`7
00@01`L03@L010071`0=1`0300L700X700@01`L00PL200`70P0<1`0400L700`700@01`L03@L01007
1`0<1`0400L700d700<01`L02PL2008700@01`L030L00`071`0;1`0400L700d700@01`L030L00`07
000F1`005PL00`071`0;1`8000<700L030L01007000>1`0300L7008020L01@0700L000D70P061`03
00L700P70P031`0300L000`70`0?1`<030L00`0700031`802PL00`071`041`801@L01@0700L000L7
0P031`0300L700`70P000`L01`0<1`0400L000d700<01`L05@L001D700<01`L03@L300d70P000`L0
1`0>1`0400L700T70`071`0300L700<700<01`L02PL00`071`021`8030L201470P0<1`801@L00`07
1`091`0300L700@700<01`L010L300T700@01`L040L300d70P000`L01`0=1`0300L701@7000D1`03
00L701073`0C1a`04PL?01<73`0B1a`04`L?018700<01`L04`L001D70P0?1`800PL00`071`051`03
00L700804@L00`071`061`0400L71`<000<700002PL01007000>1`<01PL00`071`031`0300L700l7
00<01`L010L00`071`031`<03PL200031`0700P70`0010L000041`0300L700D700<01`L03`L20087
00<01`L01PL01007000?1`805PL001H700<01`L030L00`07000=1`0300L000l700<01`L02PL01`07
00L01`002`L00`07000=1`0500L01`0030L00`071`0=1`0300L700X700D01`07000>1`802`L01`07
00L01`0030L00`071`0=1`0300L000d700<01`003PL201H7000G1`0300L700X700@01`L03@L01007
1`0=1`0400L000T700@01`000PL00`071`0;1`0300L700/700@01`L00PL00`071`0:1`0300L700/7
00<01`L02PL010071`021`0300L700/700<01`L02`L0100700021`0300L700L70P000`L01`0<1`04
00L700d700@01`L030L00`071`0F1`0060L00`071`081`0500L71`000`L200<70P031`0500L71`00
2`L01@071`L000P70P021`<000<700L030L00`071`091`0400L71`800PL300X700<01`L02@L00`07
1`071`8000<700L00`031`0300L700T700<01`L02`L00`07000200870P091`0400L700/700D01`L7
00031`800`L200<700D01`L7000:1`0300L701L7000I1`0300L700L700D01`L700041`0300L70087
00D01`L700041`0300L700L700<01`L02`L2008700<01`000PL00`071`0;1`0300L700L700<01`L0
0PL2008700<01`002`L00`071`071`0300L700T700<01`000PL200@700<01`L01`L00`071`0;1`04
00L71`800`L00`071`0;1`0300L700L700<01`L00PL00`071`021`0300L7008700D01`L700031`03
00L700L700<01`L060L001X700<01`L01@L00`071`021`0300L700/700<01`L00`L00`071`051`03
00L700/700<01`L00PL00`071`031`0300L700@70P051`0300L700@70P051`0300L7008700<01`L0
2`L00`071`051`0300L700/700<01`L00PL00`071`031`801PL00`071`031`801PL00`071`031`03
00L7008700<01`L02`L00`071`051`0300L700<700<01`L02`L00`071`021`0300L700D700<01`L0
6@L001/700<01`L00`L00`071`031`0300L700/700<01`L010L00`071`031`0300L700/700<01`L0
0`L00`071`041`0300L700@700<01`L010L00`071`031`800PL200031`0700@700<01`L00PL200L7
00<01`L00`L00`071`051`8010L00`071`031`0400L000<700<01`L00`L00`071`051`0300L700<7
00<01`L010L00`071`031`0300L700/700<01`L00`L00`071`041`0300L700/700<01`L00`L00`07
1`031`0300L701X7000J1`<00`L00`071`041`0300L700<70P061`0300L700D700@01`L70P0<1`03
00L700870`071`0300L700L70P021`0500L71`001@L00`0700021`800PL00`071`021`0300L700H7
0`000`L01`081`0500L71`000PL2008700@01`L010L01@071`L000870P091`0300L700D70`041`03
00L700X70P031`0300L700D700<01`L010L200D700<01`L010L010071`L301/7000J1`8000@700L0
1`L200D700<01`L010L200L700@01`070`091`0300L700800PL200L70P091`0300L7008000<700L0
1`L00`07000200<700<01`L01@L200@70`041`801`L00`071`021`8000<700L01`L0100700031`03
00L700D70P081`0400L01`800PL00`071`071`8000D7000700071`801`L010071`L300L700@01`07
0P0K1`0040L@00L70P0<1`8020L?00@700D01`L700081a002@L010071`051ad01PL00`0700091a00
20L00`071`021`0400L71`l02@L00`071`0:1`801PLA0147000@1`0300L000/70P071`0300L700/7
00<01`L01`L00`071`0;1`0300L700H700<01`L01`L00`071`0;1`0300L700L700<01`L01PL00`07
1`0;1`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L00`071`061`0300L700/7
00<01`L01`L00`071`0;1`0300L700D70P0<1`804@L0010700<01`L02`L00`071`021`800PL00`07
1`061`800`L00`071`061`8030L200P700<01`L01`L00`071`0;1`0300L700L700<01`L01PL00`07
1`0;1`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L00`071`061`8030L200P7
00@01`L70P081`0300L7008010L00`071`0;1`0300L700l7000>1`<03@L00`071`031`0400L000T7
00<01`L00P091`0300L700/70P071`0300L700870P031`0300L700/700<01`L00`L2008700<01`L0
1PL300/700<01`L02@L300P700<01`L00P051`0300L700/700<01`L00P051`0300L700D70`0<1`80
1`L200@700<01`L01PL2008700<01`L00PL00`071`0;1`<03`L000l70P0=1`0300L700H73`041`80
0`L00`071`0;1`801`L00`071`031`0500L71`003@L00`071`041`0400L700P700<01`002`L00`07
1`0:1`8020L01@071`L000D700<01`L02`L01@071`L000D700<01`L01PL00`071`0;1`0400L71`80
10L@00L700<01`L02`L00`07000?1`0040L00`071`0;1`0300L700D700<01`0010L00`071`061`03
00L7008700D01`L7000=1`0300L700D700<01`0020L00`071`0;1`0300L700H700<01`001`L00`07
1`0;1`0300L700/700<01`L01@L00`0700081`0300L700/700<01`L01PL00`0700071`0300L700/7
00<01`L00PL01@071`L000T700L01`L700L000L700<01`L02`L00`071`0?1`0040L00`071`0;1`03
00L700@700D01`L7000=1`0300L700D700<01`L02`L00`071`041`0500L71`001`L00`071`0;1`03
00L700D700D01`L700061`0300L700/700<01`L02`L00`071`041`0500L71`001`L00`071`0;1`03
00L700D700D01`L700061`0300L700/700<01`L01@L00`071`0;1`0500L71`001PL00`071`0;1`03
00L700l7000@1`0300L700/700<01`L00`L00`071`031`<00`L200H700<01`L010L00`071`0;1`03
00L700870P031`<01PL00`071`0;1`0300L700@700<01`L00P000`L01`0500X70P0010L0000;1`@0
0PL300<700<01`L010L00`071`0;1`0300L700@70`031`8010L00`071`0;1`0300L700@700<01`L0
10L200<70`051`0300L700<700<01`L02`L00`071`0?1`0040L200`700<01`L00PL300D70P041`03
00L700<70`051`0300L700P70P000`L01`031`8010L00`0700031`<03@L00`071`0200031`0700<7
00L01`L01`0700800`L200H700D01`0700061`800`L01P070007008700<01`L00PL0100700021`03
00L700/70`031`0400L700@700<01`L00PL300/700<01`L00`L300H700<01`L00PL00`071`031`<0
10L00`071`0:1`804@L001070P0<1`0300L7008700<01`001PL00`071`091`0300L000@700<01`L0
2@L00`0700041`0300L700H700@01`L70P0=1`0400L71`8020L00`071`0300@700<01`L00`L20004
1`0000L700@01`L70`021`0300L700H700<01`000PL00`071`0;1`0300L0008700<01`L01PL00`07
1`021`0300L000/700<01`L00PL010071`0:1`0300L700D70P041`0300L700/700<01`L03`L00107
00<01`L02`L01@071`L000X700<01`L02`L01@071`L000d700D01`L7000:1`0500L71`003@L01@07
1`L000X700<01`L00P0;1`0500L01`002`L01@0700L000X700D01`L7000=1`0500L71`002PL01@07
1`L000d700D01`L7000=1`0300L700P700D01`L7000=1`0300L700l7000@1`0300L700/700@01`L0
30L00`071`0;1`0400L700d700@01`L030L010071`0=1`0400L700`700@01`L03@L00`071`0;1`04
00L700`700@01`L03@L010071`0<1`0400L700d700@01`L03@L00`071`0:1`0400L700d700<01`L0
3`L000`70P021`0300L700L70P021`0300L000H70P031`8000<700L010L200<70P0010L01`031`80
20L0100700L200/70`0;1`<000<700L020L200<700<01`001PL200D700<01`L00`L200H700<01`00
0`L200T700<01`000P0;1`<02`L200041`0700P70P031`0400L01`800`L200D700@01`000PL200L7
00<01`000PL200T700<01`L00P0=1`003@L010071`0:1`0300L7008020L00`071`021`0400L700D7
00<01`L00PL00`071`0200@700<01`L01@L300<700<01`L02PL200`70`0;1`0300L700870P071`03
00L700<700<01`L010L00`071`041`801@L00`071`081`8000<700L02PL200d700<01`L00`081`04
00L71`800`L00`071`021`0300L7008700D01`L700031`0300L700H70P031`0300L700L700D01`L7
000=1`0040L?00@70P0;1ah04PL?01877@0B1`l04PLN00/70P041`l04@L001470P0:1`<010L00`07
1`091`8030L00`07000=1`0300L700h700<01`L02`L00`07000@1`0300L700/700<01`003@L00`07
1`0>1`0300L000d700<01`L03PL00`071`0;1`0300L000d700<01`L02PL00`071`0200031`0700T7
0P0B1`004PL00`071`071`0300L700803PL00`071`0;1`0500L71`003@L00`071`0<1`0300L700/7
00D01`L7000>1`0300L700/700D01`L7000=1`0300L700`700D01`L7000=1`0300L700`700<01`L0
2`L01@071`L000d700<01`L030L2008700<01`L020L00`071`0@1`003PL200X70P051`0300L70087
0P051`801@L200H700<01`L00PL200X70P000`L01`021`801@L300X70P000`L01`041`0300L70080
1@L200031`0700870P081`0400L0008700<01`L01PL200<700@01`001@L2008700<01`L00`L01007
000:1`801PL200<700@01`002PL200@700<01`L00`L200H70P051`8010L00`071`031`802PL200l7
000?1`0300L700P70P061`0300L7008700<01`L00`L200H700<01`L00`L00`071`041`802PL01007
1`031`0300L700@700<01`L02PL200L700<01`L00P051`801@L200H700D01`L700031`0300L700@7
0`041`0300L000@70`000`L01`061`0300L000/700<01`L01@L010071`031`0300L700L700<01`00
1@L00`071`031`0300L700D700<01`L010L01@071`L000L700<01`L02@L00`071`0=1`006@L00`07
1`061`0300L700L700<01`L02`L00`071`071`0300L700X700<01`L01`L00`071`0;1`0300L700L7
00@01`L01PL00`071`041`0300L700<700<01`L01`L00`071`041`0300L700<700<01`L01@L00`07
00091`0300L700/700<01`L01`L00`071`0:1`0300L700L700<01`L02`L00`071`071`0300L700H7
00<01`L060L001P700<01`L020L00`071`051`0300L700/700<01`L02@L00`071`0:1`0300L700D7
00<01`L01PL200<700<01`L01PL200031`0700H700<01`L02PL00`071`091`0300L700X700<01`L0
1@L0100700081`0400L71`8020L00`071`051`0300L700X700<01`L02@L00`071`0;1`0300L700D7
00<01`L020L00`071`0G1`003`L200H700<01`L02PL200@700<01`L02@L300d700<01`L00PL200H7
00<01`L00`L010071`L200D700@01`L02PL200031`0700@700<01`L01PL2008700<01`L02`L00`07
1`0200P700<01`L00`L00`07000200T700D01`L700041`800`L00`071`031`0300L700@70P041`03
00L700/70`0;1`0400L71`<030L00`071`031`804@L0010700<01`L00`L00`071`0<1`0500L71`00
3@L00`071`0=1`0300L7008700<01`L01@L01@071`L000D700<01`L01@L00`071`0:1`0400L700<7
00<01`L020L00`07000?1`0400L700T700D01`L700031`0300L700T700<01`L01PL00`071`021`05
00L71`0020L01@071`L000l70P0<1`0500L71`003PL00`071`031`0300L700l7000E1`0300L700h7
00<01`003@L00`071`0?1`802`L300d700<01`L03`L00`07000<1`0300L700l700<01`L02PL00`07
000A1`0300L700/70`0;1`804@L00`071`0;1`0300L0010700<01`L050L001@700<01`L040L?01<7
700C1`h04`L>01<77@0B1`l04PL00`071`0C1`001`L200/70`0?1`803@L201470P0<1`8000<70000
2PL01007000>1`8030L201470P0<1`803PL200031`0700P70P021`8030L201470P0=1`803`L300/7
0P081`0020L010071`L200H700<01`000`L200T700@01`0030L300/70P021`0300L000L70P031`05
00L01`000`L200H700<01`000`L200P700@01`070P091`0300L000802`L300031`0700P70P0010L0
1`081`8010L200D70P041`0500L01`000`L200L700<01`000PL200/70`0;1`<000<700L020L200<7
0`061`8010L00`071`061`003@L00`071`02008700@01`L00`L00`071`061`8000<7000030L400/7
00<01`000PL300H700D01`L700021`0300L700870P071`0300L700<700@01`L70P021`0400L70087
00<01`L01`L200031`0000`700@01`002PL00`0700021`0300L7008010L00`071`021`0300L700D7
0P041`0400L700@700<01`L00PL200051`071`000PL00`071`081`8000<700L02`L200031`0000T7
00@01`L00PL00`071`0200<700<01`L02`L0014700@01`L00`L00`071`081`0500L01`003@L00`07
1`0200X70P031`0300L000X700D01`L700041`0300L700H700<01`L01`L300<700<01`L02PL20087
00<01`L020L200<700<01`L02PL01@071`L0008700<01`L01@L200T700<01`L00P031`0300L700P7
00<01`000`L00`071`081`8000@700L03@L00`071`0200T70P031`0500L71`004@L000L70P0;1`<0
0PL200L700<01`L00PL00`071`0;1`0300L700870P071`0300L700<700<01`L02PL00`071`021`80
30L200L700<01`L00`L00`071`0:1`0300L700870P071`0300L700<700<01`L02PL00`071`021`80
1`L00`071`0;1`0300L700<700<01`L02PL00`071`021`801`L00`071`031`0300L700/700<01`L0
0PL00`071`051`0400L71`<02`L200P700081`0300L700T700<01`0010L00`071`031`0300L700<7
00<01`L02`L00`071`041`0300L700<700<01`L010L00`071`0:1`0300L700800PL00`071`071`80
0PL00`071`031`0300L700@700<01`L02PL00`071`041`0300L700<700<01`L010L00`071`0:1`03
00L700@700<01`L00`L00`071`0200T700@01`000`L00`071`0:1`0300L700@700<01`L00`L00`07
1`041`0300L700/700<01`L00`L00`071`031`0300L700<70P0<1`0300L700H7000D1`0300L70087
10031`0300L700@700<01`L02`L00`071`051`0300L700@010L200/70P031`0500L71`0020L30087
00D01`L700071`0300L700X700<01`L01@L500L700<01`L02PL00`071`051`0600L71`0710081`05
00L71`000PL200`70P041`@00PL00`071`051`0300L700/700<01`L010L010071`L400@700<01`L0
4`L001@700<01`L00`L01P07000700L700<01`L02`L00`071`061`0600L000L01@L00`071`0:1`03
00L700H700<01`L01PL200<700<01`0020L00`071`0:1`0300L700H70`081`0300L700X700<01`L0
1PL00`0700031`0300L000L700<01`L01PL00`071`0:1`801@L01@0700L000P700<01`L02`L00`07
1`051`0700L01`0700041`0300L701<7000D1`0300L700L700<01`L01PL00`071`0;1`0300L700L7
00<01`L01`L00`071`0:1`0300L700L73`091`0300L700X700<01`L01`L00`071`071`0300L700X7
00<01`L01`L?00T700<01`L02PL00`071`071`0300L700L700<01`L02`L00`071`061`0300L700L7
00<01`L04`L001@700<01`L01`L00`071`061`0300L700/700<01`L01`L00`071`071`0300L700X7
00<01`L01`L00`071`0200T700<01`L00P051`0300L700X700<01`L01`L00`071`071`0300L700X7
00<01`L00`L2008700<01`L01`L2008700<01`L01`L00`071`0:1`0300L700L700<01`L01`L00`07
1`0;1`0300L700H700<01`L01`L00`071`0C1`003`L200<700<01`L01`L00`071`031`8000<700L0
30L300L700<01`L01`L0100700091`0300L700@70P000`L01`021`0300L700L700@01`L70P041`03
00L700T70P091`0300L700L70P0;1`0300L700870`021`0300L700P700D01`L01`0200H700<01`L0
1`L200031`0700P700<01`L01@L300d70`061`0300L700L700<01`L00P0A1`0040L01@071`L000T7
00<01`L010L00`07000=1`0300L000L700<01`L01`L010071`091`0300L700D700<01`003@L00`07
1`021`0600L000L02PL300T700<01`L01`L300X700@01`000PL01@071`L000d700@01`L01PL00`07
1`081`0300L000T700<01`L01PL200d700<01`001PL00`071`071`0500L71`004@L000H73`051`80
0PL00`071`061`l02@L0100700061`h02@L00`071`051`8010L00`071`051`0300L000d020L200T7
3P021`0300L700@700<01`L00PL200L700<01`L01`L>00H70P000`L01`081`l020L00`071`0200D7
3`071`001`L00`071`0;1`0300L700<700@01`L01`L00`0700051`0300L700D700<01`L01PL01007
1`051`0300L700X700<01`0020L00`071`061`0300L7008700<01`L01PL00`0700021`0300L700L7
00<01`L01PL00`071`061`0300L700P700D01`0700081`0300L700<700<01`L01@L00`071`061`04
00L000/700<01`L010L00`0700081`0300L700H700<01`L00PL00`0700071`0500L71`0010L00`07
1`0;1`0300L700H700081`0300L700H70P031`0300L700D70P051`0500L71`003@L00`071`051`03
00L700D700<01`L02PL01@071`L000L700<01`L02`L00`071`051`0500L71`0030L00`071`051`03
00L700D700<01`L02PL01@071`L000L700<01`L02`L00`071`051`0500L71`0030L00`071`051`03
00L700D700<01`L02`L01@071`L000@70`071`0400L71`8020L00`071`071`002@L00`071`0200@7
00<01`L00PL00`071`0200870P041`0300L7008000<700L02@L200031`0700D700@01`L70P000`L0
1`091`<01@L00`071`021`<02`L300H700<01`L00PL200`70P051`0300L700<70P0<1`8010L00`07
1`041`<02`L200D700<01`L00`L300X700@01`000`L00`071`041`0400L000X70`031`0300L70087
0P021`800PL00`071`031`0400L71`800PL00`071`081`002PL010071`0:1`0400L7008700<01`L0
0PL200<700@01`L010L200@700@01`L010L200@70P061`8010L00`071`051`0300L700870P0<1`80
1@L00`071`041`8030L00`071`031`0300L700<70P0;1`0300L000D700<01`L00`L00`07000;1`80
10L00`071`051`800`L200H700<01`000`L200@700D01`L700031`8010L010071`031`8010L01`07
1`L01`002`L00`07000;1`002`L00`071`0;1`0300L7008700<01`L00PL200L700<01`L00PL00`07
1`061`0300L7008700<01`L00PL00`071`061`0300L7008700<01`L01PL00`071`021`0300L700/7
00<01`L00PL00`071`061`0300L700/700<01`L00PL00`071`021`0300L700/700<01`L01PL00`07
1`021`0300L700/700<01`L00PL00`071`061`0300L700<700<01`L01@L00`071`021`800`L00`07
1`071`0500L71`0020L00`071`021`0300L7008700<01`L02`L00`071`0:1`0030L00`071`0;1`05
00L71`000`L00`071`071`8030L200<700D01`L7000=1`0300L700P700D01`L7000=1`0500L71`00
2PL00`071`0;1`0500L71`000`L00`071`0;1`0300L700P700D01`L7000=1`0500L71`002PL00`07
1`0;1`0500L71`000`L200`70P091`0500L71`000`L00`071`0;1`0300L700/7000=1`0300L700/7
00@01`L00PL00`071`091`8030L2008700@01`L03@L00`071`0:1`0400L700d700@01`L030L00`07
1`0;1`0400L7008700<01`L02`L00`071`0:1`0400L700d700@01`L030L00`071`0;1`0400L70087
00<01`002`L00`07000:1`0400L7008700<01`L02`L00`071`0<1`003PL00`071`081`@000@700L0
3PL00`071`0;1`0300L000@02`L00`071`0<1`0300L000H70`041`0300L000h700<01`L02`L500d7
00<01`L030L00`0700031`@01PL00`07000>1`0300L700T71@000`L01`0<1`0300L700`700@01`07
100:1`0300L700d7000?1`0300L700P700<01`000`0@1`0300L700/710000`L01`091`0300L700h7
0P071`8010L200l70P0;1`H030L200l70P041`0300L000H70P0@1`0300L700T700<01`000P0=1`03
00L700h70`0010L01`091`0300L700h7000@1`l01@L200/77@0@1a400PL200`78@0<1`800PLA0107
7@0;1`801@L?0147000?1`0300L000/70`051`0300L700P700<01`L01@L00`071`031`<02PL01007
1`0@1`803@L2008700<01`L02`L00`071`031`0300L700@71@071`0300L700870P0=1`0400L000d7
0`0?1`0400L700X70`061`0300L700@700<01`L02@L00`071`021`<030L20107000>1`0300L700P7
100010L01`0>1`0300L700/700<01`00100;1`0300L700`700<01`001PL300@700<01`003PL00`07
1`0;1`D03@L00`071`0<1`0300L000<710061`0300L000h700<01`L02@L500031`0700`700<01`L0
30L0100700L400X700<01`L03@L000d700<01`L02PL300051`071`0030L00`071`0;1`0500L700L0
0`0<1`0300L700X700@01`L01`L200@700@01`L030L00`071`0;1`0300L7008000<700L030L00`07
1`0:1`0400L700@700<01`001PL010071`0<1`0300L700/700@01`000PL00`071`0;1`0300L700X7
00@01`L00PL00`07000;1`0300L700`7000<1`0300L700/700D01`L700031`0300L700L70P0<1`80
0`L01@071`L000d700<01`L020L01@071`L000d700D01`L7000:1`0300L700/700D01`L700031`03
00L700/700<01`L020L01@071`L000d700D01`L7000:1`0300L700/700D01`L700031`8030L200T7
00D01`L700031`0300L700/700<01`L02`L000/700<01`L02`L00`071`021`0400L71`<01`L20087
0P081`800PL200@700<01`L01@L200<700<01`L01`L00`071`021`0300L700/700<01`L00PL00`07
1`071`0300L700X700<01`L00PL00`071`021`0300L700X700<01`L01`L00`071`021`0300L700/7
00<01`L00PL00`071`071`0400L71`801`L00`071`021`800`L00`071`061`800`L00`071`051`<0
0`L00`071`021`0300L700/700<01`L02PL000X700@01`002PL0100700021`0300L700870P021`80
0PL00`071`031`0400L71`800PL00`071`031`0400L71`<01`L010071`L200L700@01`L70`0;1`<0
1@L00`071`031`<02`L200D700<01`L00`L200/70`051`0300L700<70`0;1`8010L00`071`051`80
10L00`071`041`<00`L200@700<01`L00P041`0300L7008700@01`0010L00`071`021`0300L70080
00<700L02@L200031`0700X700091`0500L71`000`L200@700D01`L700021`8010L01`071`L01`00
2`L00`0700061`0300L7008700<01`002`L200D700<01`L00`L200`70P061`0300L700<700<01`L0
2PL200D700<01`L010L00`071`0:1`8010L00`071`041`0300L000/70P051`0300L700<700<01`00
2PL010071`031`0300L700@700@01`L02PL00`0700031`0400L71`<00`L010071`041`8010L01007
1`0:1`0020L00`071`071`0500L71`001`L200D700D01`L7000=1`0300L700D700<01`L01@L00`07
1`0:1`0500L71`001`L00`071`0;1`0300L700D700D01`L7000<1`0300L700D700<01`L01@L00`07
1`0:1`0500L71`001`L00`071`0;1`0300L700D700D01`L7000<1`0300L700D700<01`L01@L00`07
1`0;1`0500L71`001@L200L700<01`L00PL00`071`061`0300L700L700061`803@L00`071`021`80
0PL00`071`051`0300L000@70P071`0300L700H700@01`001@L00`071`091`8000<700L01`L00`07
1`051`8010L00`071`061`0400L01`802@L00`071`051`8020L00`071`071`8000@700L020L00`07
1`021`801`L00`071`061`0400L000/700<01`L00`L200031`0700L700<01`L01@L200@700<01`00
1`L00`071`0200@700<01`L02PL200P700061`l01PL010071`081`l02@L010071`061`h02@L00`07
1`061`0300L7008700<01`L010L200031`0000`02@L00`071`071`h000<700001PL00`071`031`03
00L700D700<01`L01`L>00L700<01`002@L?00P700D01`L700051`l01`L000l70P031`0300L700L7
00<01`L00`L200031`0700`70`071`0300L700L700@01`002@L00`071`041`8000<700L030L01007
1`L2008700<01`002`L200T700<01`L01`L300X700D01`L01`0200<700<01`L02`L0100700061`03
00L700L70P000`L01`081`0300L700D70`0=1`<01PL00`071`071`0300L700804@L0010700D01`L7
00091`0300L700@700<01`003@L00`0700071`0300L700L700@01`L02@L00`071`051`0300L00087
0P091`0300L700<010L00`071`0:1`0300L700L700<01`L01`L200/700<01`L00`L2008700<01`L0
1`L2008700@01`L01PL00`071`081`0300L000T700<01`L01PL200d700<01`001PL00`071`071`05
00L71`004@L001@700<01`L01`L00`071`061`0300L700/700<01`L01`L00`071`071`0300L700X7
00<01`L01`L01@071`L000T700D01`L700051`0300L700X700<01`L01`L00`071`071`0300L700X7
00<01`L010L010071`0:1`0400L700T700<01`L02PL00`071`071`0300L700L700<01`L02`L00`07
1`061`0300L700L700<01`L04`L001@700<01`L01`L00`071`061`0300L700/700<01`L01`L00`07
1`071`0300L700X700<01`L01`L?00T700<01`L02PL00`071`071`0300L700L700<01`L02PL00`07
1`071`l02@L00`071`0:1`0300L700L700<01`L01`L00`071`0;1`0300L700H700<01`L01`L00`07
1`0C1`0050L00`071`021`D000<700L01PL00`071`0;1`0300L700H700<01`000`041`802`L200P7
00<01`L01@L300<700<01`0020L00`071`0:1`0300L700H70`081`0300L700X700<01`L01PL00`07
00021`@01`L00`071`051`8030L200@710000`L01`071`0300L700/700<01`L01@L00`07000400@7
00<01`L04`L001@700<01`L00`L00`0700031`0300L700@700<01`L02`L00`071`051`0700L71`07
00051`0300L700X700<01`L01@L00`071`071`800PL01@071`L000L700<01`L02PL00`071`051`03
00L000801`L00`071`0:1`0300L700D700D01`L700021`0300L000P700<01`L01@L00`071`0:1`80
1@L3008700<01`L01@L00`071`0;1`0300L700@700@01`L70P000`L01`031`0300L701<700071`80
2`L300@700<01`L00`L00`071`031`0300L700/700<01`L010L00`071`031`0300L700@700<01`L0
2PL00`071`02008700<01`L01`L2008700<01`L00`L00`071`041`0300L700X700<01`L010L00`07
1`031`0300L700@700<01`L02PL00`071`041`0300L700<700<01`L00P091`0400L000<700<01`L0
2PL00`071`041`0300L700<700<01`L010L00`071`0;1`0300L700<700<01`L00`L00`071`021`<0
2`L200P700081`0300L700T700<01`000PL200L700<01`L00PL00`071`0;1`0300L700870P071`03
00L700<700<01`L02PL010071`L300/70`071`0300L700<700<01`L02PL00`071`021`801`L00`07
1`031`0300L700X700<01`L00PL200L700@01`L02PL00`0700031`0300L700X700<01`L00PL200L7
00<01`L00`L00`071`0;1`0300L7008700<01`L01@L00`071`021`8030L00`071`061`0040L20087
00D01`L7000:1`<000<700L030L00`07000200X70P031`<02PL01@071`L000<70P081`0300L700H7
10031`0300L700X70P021`0300L700P70P021`8030L01P071`L01`801`L200P70P021`800`L00`07
1`071`8000<700L00PL00`071`081`@000<700L030L00`07000200T70P031`0300L700804@L000`7
0P031`0400L7008700<01`L00P081`8000<7000030L200031`0700T70P001`L01`L01`001@L200<7
00@01`L010L200L700<01`L00PL200@700@01`L00PL0100700091`8000<700002`L2008700<01`L0
1`L200051`071`000`L010071`L200@700<01`L010L300@700@01`L00`L200D700<01`000PL01007
000:1`@02`L3008700<01`L01PL2008700@01`L00`L00`071`0200d700071`8010L00`071`041`<0
10L00`071`071`0400L000`70`0<1`0600L700L020L01`071`L01`001PL00`071`041`0300L700@7
00<01`L01PL00`0700021`0300L700L700D01`07000<1`8000<700L02@L01@0700L000T700<01`L0
0`L00`071`041`0300L700@700<01`0010L00`071`051`0300L000<700<01`L02@L00`07000<1`80
00<700L02@L010071`L300L700@01`L70P081`0020L00`071`091`<03`L200d70P0A1`8030L20003
1`0000X700@01`003PL200`70P0A1`8030L200h70P000`L01`081`800PL200`70P0A1`803@L20107
0P0<1`0300L700H7000D1`0300L701073`0B1ad00`L00`071`0=1`h04`L>010700<01`L07@0B1`l0
4PL00`071`0C1`005@L00`071`0>1`0300L000d700<01`L03`L200/70`0=1`0300L700l700<01`00
30L00`071`0?1`0300L700X700<01`004@L00`071`0;1`<030L00`071`0?1`0300L700/700<01`00
40L00`071`0D1`003`L200D700<01`L02`L200<700<01`L02PL200l700@01`L70P071`0500L71`00
10L200L700<01`L02@L2008700D01`L700091`8000<700L03PL0100700091`0500L71`000PL200/7
00<01`L01@L200@700D01`L700071`800`L00`071`0=1`8030L00`071`0200h700<01`L00PL20147
000@1`0300L700@700<01`L02PL200@700<01`L02PL200d700<01`L00`L00`071`041`0300L700<7
00<01`L00PL00`071`021`800PL00`071`071`<000<700L010L00`071`071`0400L700d700D01`L7
00081`0300L700<700<01`L00P091`0300L700801@L01@071`L000D700<01`L01@L00`071`021`03
00L700/700<01`002`L00`071`021`8030L00`071`041`0300L700l7000H1`0300L700P700<01`L0
1@L00`071`0;1`0300L700T700<01`L02PL00`071`051`0300L700L700D01`L700091`0300L000L7
00<01`L02PL00`071`091`0300L700X700<01`L01@L010071`081`0300L7008700<01`L01PL00`07
1`051`0300L700X700<01`L02@L00`071`0;1`0300L700D700<01`L020L00`071`0G1`006@L00`07
1`071`0300L700H700<01`L02`L00`071`071`0300L700/700<01`L01PL00`071`0;1`0300L700L7
00@01`001@L00`071`041`801@L00`071`071`0300L700<70P061`0300L700<70P000`L01`081`03
00L700/700<01`L01PL00`071`0;1`0300L700L700<01`L02`L00`071`061`0300L700L700<01`L0
60L000h70P0:1`801PL010071`L200D70P051`801@L00`071`031`<02@L2008700<01`L00P051`80
2`L300L700<01`000P041`<010L300H700<01`L00P031`0300L700D70P041`<01@L200031`0700H7
0`0:1`801PL2008700<01`L00P091`<01@L00`071`021`801PL200D70P031`0300L700@70P0:1`80
3`L000l700<01`L02@L00`071`031`0300L700<700<01`L010L00`071`041`0300L700@700<01`L0
0`L00`071`091`0300L000@700<01`L010L200/700<01`001@L01@071`L000H700<01`0010L00`07
1`061`0400L7008700<01`L01`L01@071`L0008700<01`L010L010071`051`0400L700X70P071`05
00L71`000PL00`071`081`8010L00`071`041`0300L700@70P061`0300L7008700<01`L00`L200/7
00<01`L03@L001470P091`0300L000803PL00`071`0;1`0500L71`003@L00`071`0<1`0300L700/7
00D01`L7000>1`0300L700/700D01`L7000=1`0300L700`700D01`L7000=1`0300L700`700<01`L0
2`L01@071`L000d700<01`L030L2008700<01`L01`L20187000B1`0300L700P700<01`0040L00`07
1`0;1`0300L000d700<01`L03PL00`071`0;1`0300L0010700<01`L02`L00`07000=1`0300L700h7
00<01`003@L00`071`0>1`0300L700/700<01`003@L00`071`0>1`0300L000/700<01`L040L00107
3`041`802`LN01873`0B1ad04PL?01877P0;1`8010L?0147000<1`800PL00`071`071`800PL200@7
00<01`L00P071`800`L200L70P031`8020L200870P0;1`<02`L400X70P041`801PL200D700<01`L0
0`L200H70P041`802PL400/70P0<1`800PL300L70P031`801`L200@700<01`L010L200@700@01`L7
0P021`802@L00`071`0200d7000=1`0400L700X700H01`L01`071`0400L71`8000<700L01@L01007
1`L200041`0700@700<01`L01PL00`0700021`0300L700T70`0<1`8000<700L02@L01`071`L01`00
1`L00`071`031`0300L700@700<01`L010L00`0700041`0300L700L700D01`07000;1`<030L01@07
00L000T700P01`L700L01`8010L00`071`031`0400L000<700<01`L01@L00`0700031`0300L700L7
00D01`L7000=1`0040L00`071`0;1`0400L700/70P0<1`800PL00`071`0;1`0400L700`700@01`L0
3@L010071`0<1`0400L700d700<01`L02`L010071`0<1`0400L700d700@01`L030L010071`0=1`06
00L700L02`L00`07000:1`0400L700d700<01`L03`L0010700<01`L02`L01@071`L000X700<01`L0
2`L01@071`L000d700D01`L7000:1`0500L71`003@L01@071`L000X700D01`L7000=1`0300L700/7
00D01`L7000:1`0500L71`003@L01@071`L000X700D01`L7000=1`0500L71`003@L00`071`081`05
00L71`003@L00`071`0?1`0040L200`700H01`L700L200H700<01`L020L200031`0700<700<01`L0
20L200031`07008700<01`L01`L00`071`0300d700<01`L00`091`0300L000800`L200D70P0010L0
00061`800`L300031`0700P70`021`0300L700/70`021`0300L700L700@01`L70`0;1`0300L70087
00@01`002PL00`071`041`8000<700L00PL00`071`0:1`804@L001070P0<1`0300L7008700<01`00
1@L200<70P061`801@L00`071`091`0300L000@70P031`8000<700L00`L200d700L01`L700L000<7
0P021`H010L00`071`031`8000@700001`L010071`L400031`07008010L010071`021`0300L700/7
00<01`000`L0100700031`8010L00`07000;1`0300L700<700<01`001@L200<70P061`8010L00`07
1`0;1`0300L700l7000@1`0300L700/700<01`L00`L00`071`031`0300L000@700<01`L010L00`07
1`041`0300L700/700<01`L00`L00`071`021`801PL00`071`0;1`0300L700@700L01`L700L00087
00@01`002`L01@0700L000/700@01`000PL00`0700031`0300L700@700<01`L02`L00`071`041`03
00L000<70P041`0300L700/700<01`L010L00`071`051`0300L700870P051`0300L700<700<01`L0
2`L00`071`0?1`0040L00`071`0;1`0300L700@700D01`L7000=1`0300L700D700<01`L02`L00`07
1`041`0500L71`001`L00`071`0;1`0300L700D700D01`L700061`0300L700/700<01`L02`L00`07
1`041`0500L71`001`L00`071`0;1`0300L700D700D01`L700061`0300L700/700<01`L01@L00`07
1`0;1`0500L71`001PL00`071`0;1`0300L700l7000@1`0300L700/700<01`L01@L00`0700031`80
20L010071`L200<700<01`L02`L00`071`051`0300L000P700<01`L02`L00`071`061`0300L000L7
00<01`L02`L00`071`0;1`0300L700D700<01`0020L00`071`0;1`0300L700H700<01`001`L00`07
1`0;1`0400L71`800`L00`071`061`800`L00`0700071`0300L700/700<01`L03`L000h70`0=1`03
00L700D740051`0500L71`003@L200L700<01`L00PL200<700<01`L02`L00`071`031`800PL00`07
1`061`<02`L00`071`091`<020L00`071`0200D700<01`L02`L00`071`0200D700<01`L01@L200d7
00<01`L00PL010071`LA00L700<01`L02`L300l7000?1`803@L00`071`021`800PL00`071`061`80
0`L00`071`061`8030L300L700<01`L00`L01@071`L000d700<01`L010L010071`081`0300L000/7
00<01`L02PL200P700D01`L700051`0300L700/700D01`L700051`0300L700H70P0<1`8020L01007
1`L200P70P000`L000041`0300L700/700<01`003`L0010700<01`L02`L00`071`031`0400L700T7
00D01`L700091`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L00`071`061`03
00L700/700<01`L02`L00`071`061`0300L700L700<01`L02`L00`071`071`0300L700H70P0<1`80
20L00`071`021`0300L700H700D01`L700041`0300L700/700<01`L03`L001070`0;1`801`L00`07
1`0;1`0300L700L700<01`L02`L00`071`061`0300L700L700<01`L02`L00`071`071`0300L700H7
00<01`L02`L00`071`0;1`0300L700H700<01`L01`L00`071`0;1`0300L700L700<01`L01PL00`07
1`0;1`0300L700L700<01`L02`L00`071`041`<02`L30147000@1a001`L00`071`0;1`0300L700L7
3`081`0300L700L73`091`0300L700H77@081`0300L700L73`091`0300L700H73`091`0300L700/7
00<01`L01@L@0147000J1`8000@700L01`L200@70P061`801`L00`07000400T700<01`L00P0010L0
00071`8020L200870P000`L01`071`0300L000800`L00`071`051`8010L300@70P071`0400L71`<0
00<700L01`L0100700021`801`L200P70`000`L000021`0300L700L71@000`L01`061`801PL200<7
0`071`0400L01`806`L001/70P031`0300L700@70P051`0300L700@70P061`0400L71`8000<700L0
2@L010071`021`801`L200T700<01`L00P021`0300L700870P0010L01`L2008700@01`L70P041`09
00L71`0700L000@700@01`L70P031`0400L71`8000<700L00P041`0500L71`000`L00`071`061`80
1`L00`0700021`0300L000/700<01`000`L00`071`051`0300L700D700<01`L00PL200H700L01`L7
00L001/7000K1`0300L700<700<01`L00`L00`071`0;1`0300L700@700<01`L00`L00`071`0;1`03
00L700<700<01`L010L00`071`0;1`0300L700<700<01`L00PL00`0700051`0300L700<700<01`L0
1@L00`071`031`0300L700H700<01`L00PL00`071`031`0400L700<700<01`L00`L00`071`0;1`03
00L700@700<01`L00`L00`071`0;1`0300L700<700<01`L010L00`071`0;1`0300L700<700<01`L0
0`L00`071`0J1`006PL00`071`051`0300L7008700<01`L02`L00`071`031`0300L700D700<01`L0
2`L00`071`021`0300L700<700<01`L010L200D700<01`L010L200D700<01`L00PL00`071`0;1`03
00L700D700<01`L02`L00`071`021`0300L700<70P061`0300L700<70P061`0300L700<700<01`L0
0PL00`071`0;1`0300L700D700<01`L00`L00`071`0;1`0300L7008700<01`L01@L00`071`0I1`00
6@L00`071`061`0300L7008700<01`L02`L00`071`021`0300L700L700<01`L02PL00`071`021`03
00L7008700<01`L01PL00`071`021`0300L700H70P041`0300L7008700<01`L02PL00`071`071`03
00L700X700<01`L00PL00`071`021`0300L000L700<01`L00`L00`071`051`0300L7008700<01`L0
0PL00`071`0:1`0300L700L700<01`L00PL00`071`0;1`0300L7008700<01`L01PL00`071`0H1`00
60L00`071`081`0500L71`000`L200<70P031`0500L71`002`L00`071`0:1`800PL300031`0700`7
00<01`L02@L010071`L200870`0:1`0300L700T700<01`L01`L200031`0700<00`L00`071`091`03
00L700/700<01`000P021`8030L00`071`091`0500L71`000`L200<70P031`0500L71`002PL00`07
1`0G1`005`L00`071`0:1`0400L700@700<01`L00PL01@071`L0008700<01`L02`L0100700091`05
00L000L00P0=1`0300L700/700<01`L00P001@L01`L000T700<01`L02`L00`071`071`0500L700L0
0P021`0300L700/700<01`L02`L0100700021`8020L200031`0700`700@01`L010L00`071`021`05
00L71`000PL00`071`0:1`0300L701H7000F1`0300L700`700<01`003@L00`07000?1`0300L000X7
00@01`070`0;1`<03@L01@0700L000`700<01`L03@L00`071`0:1`0500L01`003@L300X70P001PL0
1`0700/70P0?1`0300L000d700<01`003PL00`071`0E1`005@L200l70P0=1`804@L00`071`0:1`<0
0PL00`071`081`0400L700h70`0<1`0300L700l700<01`L02PL300l700<01`002PL00`071`0300`7
00<01`L03`L200d70P0?1`805PL001@700<01`0040L?01<7700B1`l04`L?0187700C1`l04@L201D7
000E1`0300L700`710021`0300L700D700<01`L0100?1`0400L000D700@01`L70`000`L01`031`80
1@L00`071`091`8010L200L700<01`L00PL201470P051`0300L700@70P041`802`L00`071`031`80
10L00`07000200@700@01`L70P021`0300L700d710021`0300L700H700<01`000`0>1`0300L701@7
000F1`0300L700`700<01`003@L01007000>1`0500L71`0020L01@0700L000H700<01`L010L00`07
1`091`0700L71`07000<1`<03`L00`07000<1`0300L000@700<01`L020L00`071`051`0300L700<7
00D01`0700081`0500L71`003`L00`07000=1`0400L000d700<01`L05@L001D70`0<1`0400L700d7
00@01`L03@L00`071`0:1`0400L700870P0<1`8030L010071`0<1`0400L700d700@01`L030L01007
1`0<1`802`L3008700@01`L030L00`071`0;1`0400L700d700@01`L030L301H7000F1`0400L01`80
1`L010071`L200`70P021`0300L700L70`0;1`800`L01@071`L000<70P081`0400L71`801@L200<7
00@01`002@L00`071`0200X70`021`0300L700L70P000`L01`021`0300L700@70P021`<01PL200<7
0P031`0400L71`802`L300P70P021`802`L300<700<01`L01@L4008700<01`L050L001T70`061`03
00L700870P0<1`800`L200L70P031`801`L200870P041`800PL00`071`071`800PL00`071`021`03
00L700<700@01`L02@L010071`L300L700@01`L00PL00`071`081`0300L000@70P051`0300L000X7
00@01`L010L200@700<01`L01@L200<70P071`0300L700<700<01`L02PL200@700<01`L01@L00`07
1`0I1`006`L00`071`031`0300L700<700<01`L02`L00`071`041`0300L700<700<01`L010L00`07
1`041`0300L700<700<01`L010L00`071`0;1`0300L700<700<01`L010L00`071`0:1`0300L700@7
00<01`L00`L00`071`041`0300L700X700<01`L010L00`071`031`0300L700/700<01`L010L00`07
1`031`0300L700D700<01`L00`L00`071`031`0300L700@700<01`L02`L00`071`031`0300L700<7
00<01`L06PL001`700D01`L700061`0300L700/700<01`L01@L01@071`L000d700<01`L010L00`07
1`051`0300L700/700D01`L700071`0300L700X700<01`L01@L01@071`L000L700<01`L02PL00`07
1`051`0500L71`003@L00`071`051`0300L700@700<01`L02`L01@071`L000L700<01`L02`L00`07
1`041`0500L71`007@L001d700<01`001`L00`071`0;1`0300L700H700<01`003@L00`071`051`03
00L700H700@01`L70P081`0400L01`801@L00`071`0:1`0300L700H700<01`0020L00`071`0:1`03
00L700<70P0010L01`081`800`L00`071`061`0300L700D700<01`L02`L00`0700081`0300L700/7
00<01`L01@L00`07000N1`007PL300H700<01`L02`L00`071`031`800PL?00P700<01`L01`L?00<7
00<01`L00`L00`071`0:1`0400L71`8010L00`071`021`800`L00`071`0:1`0300L700@700<01`L0
3`091`0300L700H73`021`801@L00`071`0;1`0300L700<70P000`L01`0N1`0080L00`071`041`03
00L700/700<01`L010L010071`071`0300L700<700<01`L01PL00`071`071`0400L700X700<01`L0
10L200031`0700T70`041`0300L7008700<01`L00`L010071`L300X700@01`001PL200X700<01`00
2@L00`071`061`0300L700@700<01`L010L01@071`L000D700<01`L02`L00`071`041`0300L701l7
000J1`802`L00`071`031`801PL00`071`071`0400L000X700<01`L010L300T700<01`L01@L200@7
00<01`L01@L00`0700021`801`L200P70P091`0300L000H70P021`0400L700H700<01`L00PL200L7
00<01`L01`L300H700<01`L020L200031`0700P700<01`L010L200D700<01`L02@L201/7000K1`03
00L700T700<01`L010L00`071`041`0300L700L700@01`L02PL00`071`051`802@L00`071`061`03
00L7008700<01`L01`L01@071`L000P700<01`L01`L00`071`071`0300L700L700@01`L02@L00`07
1`031`0300L700D700<01`L01`L00`0700061`0300L700T700<01`002@L00`071`051`0300L700<7
00<01`L02PL00`071`0I1`007PL200L73`091`0300L700/700<01`L00P041`0400L000H700<01`L0
2`L00`071`061`l02@L00`071`071`l020L00`071`0;1`0300L700<70P021`0300L700870P021`03
00L700/700<01`L01`L?00H70P0P1`007`L010071`L200<700<01`001@L300<700<01`L01PL00`07
1`0;1`0500L71`000`L01@0700L000H700<01`L02`L00`071`061`<01PL00`071`031`0300L700H7
00<01`L01PL00`071`041`0300L700<700<01`0020L00`071`0;1`0300L700@700D01`0700041`04
00L700d700<01`L01PL010071`L300H70P031`800`L00`071`0N1`0090L00`071`021`0300L700D7
00<01`L00`L00`071`041`8030L200H700D01`L700071`0300L700/700<01`L01@L01@071`L000`7
00<01`L01@L00`071`051`0300L700X700D01`L700071`0300L700/700<01`L01@L01@071`L000H7
0P0<1`801PL00`071`041`0300L700@700<01`L00`L00`071`0R1`00:PL01007000:1`0400L000<7
00<01`L02`L00`071`031`0300L700<700<01`L010L00`071`0;1`0300L700@700<01`L00`L00`07
1`0:1`0300L700@700<01`L010L00`071`0:1`0300L700<700<01`L010L00`071`0;1`0300L700@7
00<01`L00`L00`071`031`8030L200870P000`L01`091`8000<700L0:PL002/700<01`002`L00`07
00031`0300L700/700<01`L00PL00`071`051`0300L700<700<01`L02`L00`071`031`0300L700D7
00<01`L02PL00`071`031`0300L700<700<01`L02PL00`071`051`0300L700<700<01`L02`L00`07
1`031`0300L700D700<01`L00PL00`071`0;1`0300L700870P0<1`80;0L002L70P031`0300L700H7
0P031`0300L7008700@01`L70P081`0400L71`8020L00`071`0300/70`041`0300L700@70`0;1`<0
10L00`071`021`<02`L300H700<01`L00PL300/70P031`0300L700H70P031`0300L700H70P031`03
00L7008700@01`L70P081`0300L70080:@L002P700<01`L00PL00`071`061`0300L7008700D01`L7
00041`0300L700H700@01`L70P091`0300L7008030L200<700<01`L01PL0100700L200P700<01`00
0P001PL00007008700<01`L01@L200051`071`001`L01`071`L01`002`L2008700<01`L020L01@07
1`L000T700D01`L700031`0300L700<700<01`L01@L00`071`021`0300L702L7000T1`8020L00`07
1`061`800`L010071`0:1`8000D700L7000<1`@03@L00`071`0200/700<01`0010L200D70P000`L0
1`0200D70P051`802`L2008700<01`L02`L400`700<01`L00`0;1`0400L700<70P081`0300L700H7
0P0U1`009@L00`071`071`0300L700H700<01`L00PL00`07000;1`0500L01`003PL300d700D01`07
000<1`801@L00`071`031`8000@700001`L00`071`021`803@L200031`0700`700<01`003PL01@07
00L000/700<01`001@L00`071`051`0300L700P700<01`L08`L0030700<01`L02`L200d70P0@1`80
3@L2010700<01`L02PL500`70P0?1`803@L201070P0=1`803@L00`071`0_1`007`L201077@0B1`l0
4PLM01873`0B1ad03`L20247000P1`0300L700T70P021`0300L700L70`0010L000061`0300L700@7
00<01`L03PL01@071`L000T70`0@1`0300L700L700@01`L70`041`0300L700H700<01`L03PL300X7
00@01`L040L00`071`051`0300L700<70`021`802@L00`071`0200/700<01`L07`L002d700<01`00
2`L01`0700L01`003@L00`071`0<1`0300L700/700D01`07000>1`0300L700/700D01`07000=1`03
00L700`700D01`07000=1`0300L700`700<01`L02`L01@0700L0008700<01`L020L010071`0]1`00
8`L200T700@01`002PL0100700021`0300L700L70P021`0300L700X700<01`L02`L010071`021`03
00L700X700<01`L02`L010071`021`0300L700/700<01`L02PL010071`021`0300L700/700<01`L0
2PL00`071`0200T700<01`L00P000`L01`091`8000<700L020L202@7000T1`0300L700H700D01`L7
00091`0300L000800`L0100700061`0500L71`002PL00`071`051`8010L300031`07008700<01`L0
20L00`071`0:1`800`L00`071`0200d700<01`L020L010071`L300031`0700<70P071`0300L700P7
00<01`L00PL00`071`031`8000<700L00PL300031`0700T700@01`L02@L00`071`0R1`00;0L00`07
1`0;1`0400L71`8010L00`07000:1`0300L700L700<01`L01`L01@071`L0008700<01`0010L00`07
1`071`0300L700X70P031`0400L71`8030L00`071`071`0300L7008700<01`000PL00`071`021`03
00L700H700<01`L01`L00`071`091`8010L00`0700021`0300L700/700<01`L0:`L002/700<01`L0
2`L00`071`031`0300L700<700<01`L02PL00`071`051`0300L700/700<01`L00`L00`071`031`03
00L700D700<01`L02PL00`071`031`0300L700<700<01`L02PL00`071`051`0300L700<700<01`L0
0`L00`071`0;1`0300L700D700<01`L02PL00`071`031`0300L700<700<01`L02`L00`071`0Z1`00
:PL00`071`0200T700<01`L010L0100700031`0300L700X70`031`0300L700/70`041`0300L700@7
00<01`L00`L200/700<01`L00`L200H700<01`L02@L200D700<01`L010L00`071`021`<03@L01007
1`L300`700@01`L70P000`L01`051`0300L700L70P021`0300L702T7000Y1`0300L7008700<01`L0
1PL00`071`051`0400L700@700<01`L02PL2008700<01`L02`L010071`041`0300L700@70P031`03
00L000H70P021`0300L700D700<01`L01@L00`071`0200L70P031`801PL00`071`031`0300L000d7
00D01`L7000<1`0300L700<700<01`001`L00`071`071`0500L71`00:PL002L70P0<1`8020L01007
1`L200<700<01`L01PL2008700<01`001PL200D700<01`L010L300L70P0010L000081`0400L01`80
1@L00`071`031`8000D700L700071`<000@700L01PL300H700<01`L00PL200L700<01`000PL200P7
00@01`L70P031`0300L700H70P0;1`80:@L002L740081`0300L7008700<01`L00PLL00P70P021`80
1@L>00<700<01`L00`L00`071`041`0300L700h01@L2008700<01`001`LL00D700D01`L700091`l0
:0L003D700<01`L01`L00`071`071`0300L700X700<01`L02`L00`071`071`0500L71`001@L00`07
1`0:1`0300L700L700<01`L01`L00`071`0:1`0300L700@700@01`L02@L200`700<01`L02PL00`07
1`071`0300L700L700<01`L0=0L003D700<01`L01`L00`071`071`0300L700X700<01`L02`L00`07
1`071`0300L700L700<01`L02PL00`071`071`0300L700L700<01`L02PL00`071`071`0300L700L7
00<01`L02`L00`071`0:1`0300L700L700<01`L01`L00`071`0d1`00=@L00`071`071`0300L700H7
0P0;1`803@L00`071`071`0300L700L700<01`L02PL00`071`071`0300L700L700<01`L02PL00`07
1`071`0300L700L700<01`L02PL200`70P081`0300L700L700<01`L0=0L003D700<01`L00`L20087
00<01`L01@L300`700<01`L00P071`<00PL200@70P091`0300L700X700@01`L70P041`0300L70087
0P031`0300L700X700<01`L01PL200D70P021`<01PL200<700<01`L02PL300L700<01`L00P051`03
00L703@7000e1`0300L700@700D01`0700071`8030L01@071`L000P70P031`0300L700870`081`03
00L700X700<01`L00PL01`071`L01`0010L01@071`L000`700<01`L01PL300D700H01`L01`071`05
00L71`0030L00`0700061`0300L0008700<01`L00`L00`071`0d1`00=@L00`071`051`0500L71`00
1`L00`071`0:1`0300L700/700<01`L01@L01@071`L000L700<01`L02PL00`071`051`0500L71`00
1`L00`071`0:1`0300L700D700D01`L700071`0300L700/700<01`L02PL00`071`051`0500L71`00
1`L00`071`0d1`00=@L0100700031`0300L700<700<01`L010L300X700<01`L01@L200@700<01`L0
10L00`071`031`801@L00`071`0:1`801@L00`071`031`0300L700<70P0<1`0300L700<70P051`03
00L700@700<01`L00PL200L700<01`L01`L200031`0700D700<01`L00`L010071`L200031`0703D7
000e1`0400L7008700@01`0010L0100700021`0300L000X700<01`L01PL00`071`021`8010L300D7
00<01`L00`L00`071`0:1`800`L200H70P051`0300L700X700<01`L00`L200<70P000`L01`031`80
1@L00`071`051`0300L700P700<01`000PL200031`0700<70P000`L01`021`0300L003H7000e1`03
00L7008700D01`L700051`0300L0008700<01`L02PL00`071`0200T70P0010L000021`0300L700@7
00<01`L00PL00`071`0:1`0300L700870P071`8010L00`071`0:1`0300L7008700<01`L010L00`07
1`03008700<01`L01PL200<700<01`L02PL010071`L200H700@01`L010L00`071`0d1`00=@L01@07
1`L000/700D01`L7000<1`0500L71`002@L01@071`L000/700D01`L7000<1`0500L71`002`L01@07
1`L000`700D01`L7000;1`800PL00`071`071`0500L71`0030L01@071`L000/700D01`L7000f1`00
=@L010071`0=1`0400L000/70P0=1`0400L700d700@01`L030L010071`0=1`0400L700`700@01`L0
3@L010071`0<1`8030L200031`0700`700@01`L0=PL003D700<01`003`L00`07000<1`0300L700/7
00<01`003`L00`07000<1`0300L000l700<01`0030L00`07000?1`0300L000d700<01`L02PL300l7
00<01`00=PL003D70P0<1`800`L200L70P031`0300L700D70P041`801PL200T70P000`L000091`80
00<700002`L200031`0000T70P000`L000091`801PL200<70P081`0400L71`801`L200<70P0<1`80
=PL003D70P0=1`0300L7008770081`0400L71`801@L>00<700<01`L02PL00`071`0>00D70P041`03
00L700D770051`0300L700/700<01`L0=0L005D700<01`0030L200`700<01`L00PL00`07000<1`03
00L700l700<01`L02PL00`0700051`0300L700T700<01`002`L00`07001F1`00@@L201470P021`03
00L700/700@01`002`L200<70`061`800PL00`071`041`801`L00`071`0200H70`031`802`L20003
1`0700`700<01`L00P0A1`80@PL003/70P051`0300L700870P0:1`0300L000<700<01`L01PL200<7
00<01`000`L200H70P041`801`L010071`L300@700<01`L00PL300@700<01`L01@L00`071`031`03
00L700<70P051`800`L200P700<01`L00PL200X70P051`0300L700870P0l1`00?0L00`071`091`03
00L700L700<01`L01@L00`071`061`0300L7008700<01`L00`L00`071`021`801`L00`071`0:1`80
2@L200`700<01`L01@L00`071`031`0300L700870P051`0300L700@70P071`0300L700P700<01`L0
2@L00`071`0j1`00D@L00`071`071`8030L200L700<01`L020L00`071`0:1`801`L00`071`0;1`03
00L700L70P071`0300L700/700<01`L020L00`071`1@1`00D0L00`071`0:1`0300L700/700<01`L0
0`L00`071`0:1`0300L700/700<01`L00`L00`071`0;1`0300L700X700<01`L00`L00`071`0;1`03
00L700X700<01`L0C`L003h70P0<1`8000<700L03@L00`071`0;1`0500L71`003PL00`071`0;1`05
00L71`003@L00`071`0<1`0500L71`003@L00`071`0<1`0400L000`70P0o1`00?`L00`071`061`80
0`L201070`0;1`0400L000l700<01`L010L200D700<01`001@L200H700<01`L03@L200031`0700X7
0`0@1`0300L000870P091`0300L703d700191`0500L71`004PL?00031`0700l77@0A1a004PL00`07
1`021`0300L704L7001>1`0300L700h70P0=1`8040L00`071`0;1`<03@L00`071`0>1`803@L20107
00<01`L0C@L004l700<01`L030L00`07000=1`0300L000h70P0;1`8000@7000030L200h700<01`00
3@L00`07000>1`0300L704h7001:1`8010L300X7100;1`<00PL200L70P021`0300L000@70P000`L0
00021`8000<700L00P021`8000<700001@L200870P071`800PL300/7100:1`<00`L204`7001;1`03
00L700<70P091`0300L7008030L200<700<01`L01PL0100700L200D700D01`L01`0300061`0000L0
0PL010071`041`8000D700L700071`800PL00`07000;1`<000<700L02@L00`071`031`0300L704X7
001A1`0300L700L700<01`L00PL00`071`0;1`0300L7008700<01`L01`L010071`091`0800L700L0
1`021`0300L700P700<01`002@L00`071`021`0300L700/700<01`L00PL00`071`071`0300L70507
001B1`0300L700D700<01`L00`L00`071`0;1`0300L700<700<01`L01@L00`071`0:1`0300L700<7
00<01`L00`L00`071`0:1`0300L700D700<01`L00`L00`071`0;1`0300L700<700<01`L01@L00`07
1`1A1`00D`L00`071`031`0300L700@700<01`L02`L00`071`041`0300L700<700<01`L02PL00`07
1`041`0300L700@700<01`L02PL00`071`031`0300L700@700<01`L02`L00`071`041`0300L700<7
00<01`L0DPL005870`0010L000071`0300L700/700<01`L01@L00`071`0200870P081`0300L700D7
00<01`L01@L00`071`061`800PL2008700<01`L01@L00`071`0;1`0300L700D70P021`<0D`L005<7
00D01`0700081`0300L700/700<01`L01PL0100700031`0300L700D700<01`L01PL00`071`061`03
00L700H700L01`L700L000P700<01`L02`L00`071`061`0300L0008700<01`L0D@L005H700<01`L0
1`L00`071`0;1`0300L700L73P091`0300L700L73P091`0300L700/700<01`L01`L00`071`1E1`00
H0L00`071`0;1`0300L701@700<01`L01`L00`071`071`0300L701@700<01`L02`L00`071`1O1`00
H0L200`70`0D1`0400L000H700<01`L010L200031`0701<70`0<1`80H@L006070P061`8010L00`07
000:1`8020L010071`051`801`L00`0700081`802`L200@70P071`0300L705l7001P1`l01PL200D7
00<01`L010L300T700<01`L01`L300L700<01`L00PL200H73`1Q1`00H`L200`70P031`0300L700/7
0P081`0300L000P700<01`003@L00`071`0200`70P1T1`00I0L00`071`0;1`0300L7010700<01`L0
1@L01@071`L000L700<01`L04@L00`071`0;1`0300L70687001/1`8030L200T700<01`L00P021`03
00L700<700<01`L00P021`0300L700L70P0<1`80K@L006d700<01`L02`L00`071`071`0700L71`07
00071`0400L7008700<01`L020L00`071`0;1`0300L706/700251`0300L7008700<01`L01`L00`07
1`021`0300L708@700251`0500L71`002`L01@071`L008H700251`0400L700d700@01`L0QPL007T7
0P021`801PL00`07000?1`0300L000H70P021`80NPL007X700D01`L700061`804@L200L700D01`L7
001j1`00Q@L2018700<01`L0Q0L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.4473, -10.4473, 0.0728037, \
0.0728037}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[octatiling, averageTypeI]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0478596 0.5 0.0478596 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .46616 m
.05765 .5 L
s
.02381 .46616 m
.07167 .46616 L
s
.02381 .53384 m
.05765 .5 L
s
.02381 .53384 m
.07167 .53384 L
s
.05765 .3366 m
.05765 .38446 L
s
.05765 .3366 m
.05765 .38446 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .38446 m
.05765 .3366 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .3366 m
.05765 .38446 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .5 m
.10551 .5 L
s
.05765 .5 m
.10551 .5 L
s
.05765 .61554 m
.05765 .6634 L
s
.05765 .61554 m
.10551 .61554 L
s
.05765 .61554 m
.10551 .61554 L
s
.05765 .6634 m
.10551 .6634 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .4183 m
.07167 .46616 L
s
.07167 .4183 m
.10551 .38446 L
s
.07167 .4183 m
.10551 .38446 L
s
.07167 .4183 m
.10551 .45214 L
s
.07167 .4183 m
.10551 .38446 L
s
.07167 .4183 m
.10551 .45214 L
s
.07167 .46616 m
.10551 .5 L
s
.07167 .46616 m
.10551 .5 L
s
.07167 .53384 m
.07167 .5817 L
s
.07167 .53384 m
.10551 .5 L
s
.07167 .53384 m
.10551 .5 L
s
.07167 .5817 m
.10551 .61554 L
s
.07167 .5817 m
.10551 .54786 L
s
.07167 .5817 m
.10551 .61554 L
s
.07167 .69724 m
.10551 .73109 L
s
.07167 .69724 m
.10551 .6634 L
s
.07167 .69724 m
.10551 .73109 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .45214 m
.10551 .5 L
s
.10551 .45214 m
.10551 .5 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .5 m
.10551 .45214 L
s
.10551 .5 m
.10551 .54786 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .61554 m
.10551 .6634 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .73109 m
.13935 .69724 L
s
.10551 .73109 m
.13935 .69724 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .45214 m
.10551 .5 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .5 m
.10551 .54786 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .54786 m
.13935 .5817 L
s
.10551 .54786 m
.13935 .5817 L
s
.10551 .54786 m
.13935 .5817 L
s
.10551 .61554 m
.10551 .6634 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .6634 m
.13935 .69724 L
s
.10551 .6634 m
.13935 .69724 L
s
.10551 .73109 m
.13935 .69724 L
s
.10551 .73109 m
.13935 .69724 L
s
.13935 .18721 m
.17319 .22105 L
s
.13935 .18721 m
.18721 .18721 L
s
.13935 .2549 m
.13935 .30276 L
s
.13935 .2549 m
.13935 .30276 L
s
.13935 .2549 m
.17319 .22105 L
s
.13935 .2549 m
.18721 .2549 L
s
.13935 .30276 m
.13935 .35062 L
s
.13935 .30276 m
.13935 .35062 L
s
.13935 .30276 m
.18721 .30276 L
s
.13935 .35062 m
.13935 .30276 L
s
.13935 .35062 m
.17319 .38446 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .35062 m
.13935 .30276 L
s
.13935 .35062 m
.17319 .38446 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .4183 m
.13935 .46616 L
s
.13935 .4183 m
.13935 .46616 L
s
.13935 .4183 m
.17319 .38446 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .46616 m
.13935 .4183 L
s
.13935 .46616 m
.17319 .5 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.17319 .5 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .5817 m
.13935 .53384 L
s
.13935 .5817 m
.13935 .53384 L
s
.13935 .5817 m
.17319 .61554 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .64938 m
.13935 .69724 L
s
.13935 .64938 m
.13935 .69724 L
s
.13935 .64938 m
.17319 .61554 L
s
.13935 .64938 m
.18721 .64938 L
s
.13935 .69724 m
.13935 .7451 L
s
.13935 .69724 m
.13935 .64938 L
s
.13935 .69724 m
.18721 .69724 L
s
.13935 .7451 m
.13935 .69724 L
s
.13935 .7451 m
.17319 .77895 L
s
.13935 .7451 m
.18721 .7451 L
s
.13935 .81279 m
.17319 .77895 L
s
.13935 .81279 m
.18721 .81279 L
s
.13935 .46616 m
.13935 .4183 L
s
.13935 .46616 m
.17319 .5 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.17319 .5 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .5817 m
.13935 .53384 L
s
.13935 .5817 m
.17319 .61554 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .30276 m
.18721 .30276 L
s
.13935 .4183 m
.17319 .38446 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.17319 .5 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .5817 m
.17319 .61554 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .64938 m
.13935 .69724 L
s
.13935 .64938 m
.17319 .61554 L
s
.13935 .64938 m
.18721 .64938 L
s
.13935 .69724 m
.18721 .69724 L
s
.17319 .22105 m
.22105 .22105 L
s
.17319 .38446 m
.22105 .38446 L
s
.17319 .38446 m
.22105 .38446 L
s
.17319 .5 m
.22105 .5 L
s
.17319 .61554 m
.22105 .61554 L
s
.17319 .77895 m
.22105 .77895 L
s
.18721 .13935 m
.18721 .18721 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .13935 m
.18721 .18721 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .18721 m
.22105 .22105 L
s
.18721 .2549 m
.18721 .30276 L
s
.18721 .2549 m
.22105 .22105 L
s
.18721 .30276 m
.18721 .35062 L
s
.18721 .30276 m
.18721 .35062 L
s
.18721 .30276 m
.22105 .26891 L
s
.18721 .30276 m
.22105 .3366 L
s
.18721 .30276 m
.22105 .3366 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .4183 m
.18721 .46616 L
s
.18721 .4183 m
.18721 .46616 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .45214 L
s
.18721 .46616 m
.18721 .4183 L
s
.18721 .46616 m
.22105 .5 L
s
.18721 .53384 m
.18721 .5817 L
s
.18721 .53384 m
.18721 .5817 L
s
.18721 .53384 m
.22105 .5 L
s
.18721 .5817 m
.18721 .53384 L
s
.18721 .5817 m
.22105 .54786 L
s
.18721 .5817 m
.22105 .61554 L
s
.18721 .64938 m
.18721 .69724 L
s
.18721 .64938 m
.22105 .61554 L
s
.18721 .69724 m
.18721 .7451 L
s
.18721 .69724 m
.22105 .6634 L
s
.18721 .69724 m
.22105 .73109 L
s
.18721 .7451 m
.22105 .77895 L
s
.18721 .81279 m
.18721 .86065 L
s
.18721 .81279 m
.22105 .77895 L
s
.18721 .86065 m
.22105 .82681 L
s
.18721 .4183 m
.18721 .46616 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .45214 L
s
.18721 .46616 m
.22105 .5 L
s
.18721 .53384 m
.18721 .5817 L
s
.18721 .53384 m
.22105 .5 L
s
.18721 .5817 m
.22105 .54786 L
s
.18721 .5817 m
.22105 .61554 L
s
.22105 .17319 m
.22105 .22105 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .17319 m
.22105 .22105 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .22105 m
.22105 .26891 L
s
.22105 .22105 m
.2549 .18721 L
s
.22105 .22105 m
.26891 .22105 L
s
.22105 .26891 m
.2549 .30276 L
s
.22105 .26891 m
.26891 .26891 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.2549 .30276 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.2549 .30276 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .38446 m
.2549 .4183 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .38446 m
.2549 .4183 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .45214 m
.22105 .5 L
s
.22105 .45214 m
.2549 .4183 L
s
.22105 .5 m
.22105 .54786 L
s
.22105 .5 m
.2549 .46616 L
s
.22105 .5 m
.2549 .53384 L
s
.22105 .5 m
.26891 .5 L
s
.22105 .54786 m
.2549 .5817 L
s
.22105 .61554 m
.22105 .6634 L
s
.22105 .61554 m
.2549 .5817 L
s
.22105 .61554 m
.26891 .61554 L
s
.22105 .6634 m
.2549 .69724 L
s
.22105 .6634 m
.26891 .6634 L
s
.22105 .73109 m
.22105 .77895 L
s
.22105 .73109 m
.2549 .69724 L
s
.22105 .73109 m
.26891 .73109 L
s
.22105 .77895 m
.22105 .82681 L
s
.22105 .77895 m
.2549 .81279 L
s
.22105 .77895 m
.26891 .77895 L
s
.22105 .82681 m
.2549 .86065 L
s
.2549 .13935 m
.2549 .18721 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .13935 m
.2549 .18721 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .18721 m
.30276 .18721 L
s
.2549 .30276 m
.30276 .30276 L
s
.2549 .4183 m
.2549 .46616 L
s
.2549 .4183 m
.30276 .4183 L
s
.2549 .46616 m
.30276 .46616 L
s
.2549 .53384 m
.2549 .5817 L
s
.2549 .53384 m
.30276 .53384 L
s
.2549 .5817 m
.30276 .5817 L
s
.2549 .69724 m
.30276 .69724 L
s
.2549 .81279 m
.2549 .86065 L
s
.2549 .81279 m
.30276 .81279 L
s
.2549 .86065 m
.30276 .86065 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .22105 m
.26891 .26891 L
s
.26891 .22105 m
.30276 .18721 L
s
.26891 .22105 m
.30276 .2549 L
s
.26891 .26891 m
.30276 .30276 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.30276 .30276 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.30276 .30276 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .4183 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .4183 L
s
.26891 .5 m
.30276 .46616 L
s
.26891 .5 m
.30276 .53384 L
s
.26891 .61554 m
.26891 .6634 L
s
.26891 .61554 m
.30276 .5817 L
s
.26891 .61554 m
.30276 .64938 L
s
.26891 .6634 m
.30276 .69724 L
s
.26891 .73109 m
.26891 .77895 L
s
.26891 .73109 m
.30276 .69724 L
s
.26891 .77895 m
.30276 .7451 L
s
.26891 .77895 m
.30276 .81279 L
s
.26891 .89449 m
.30276 .86065 L
s
.26891 .89449 m
.30276 .92833 L
s
.26891 .89449 m
.30276 .92833 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .13935 m
.30276 .18721 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.30276 .18721 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .18721 m
.3366 .22105 L
s
.30276 .18721 m
.3366 .22105 L
s
.30276 .18721 m
.35062 .18721 L
s
.30276 .18721 m
.35062 .18721 L
s
.30276 .2549 m
.30276 .30276 L
s
.30276 .2549 m
.3366 .22105 L
s
.30276 .2549 m
.3366 .22105 L
s
.30276 .30276 m
.30276 .35062 L
s
.30276 .30276 m
.30276 .35062 L
s
.30276 .30276 m
.3366 .26891 L
s
.30276 .30276 m
.3366 .3366 L
s
.30276 .30276 m
.3366 .3366 L
s
.30276 .30276 m
.35062 .30276 L
s
.30276 .30276 m
.35062 .30276 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .4183 m
.30276 .46616 L
s
.30276 .4183 m
.3366 .38446 L
s
.30276 .4183 m
.3366 .45214 L
s
.30276 .4183 m
.3366 .38446 L
s
.30276 .4183 m
.3366 .38446 L
s
.30276 .4183 m
.3366 .45214 L
s
.30276 .4183 m
.35062 .4183 L
s
.30276 .4183 m
.35062 .4183 L
s
.30276 .46616 m
.3366 .5 L
s
.30276 .46616 m
.3366 .5 L
s
.30276 .53384 m
.30276 .5817 L
s
.30276 .53384 m
.3366 .5 L
s
.30276 .53384 m
.3366 .5 L
s
.30276 .5817 m
.3366 .54786 L
s
.30276 .5817 m
.3366 .61554 L
s
.30276 .5817 m
.3366 .61554 L
s
.30276 .5817 m
.35062 .5817 L
s
.30276 .5817 m
.35062 .5817 L
s
.30276 .64938 m
.30276 .69724 L
s
.30276 .64938 m
.3366 .61554 L
s
.30276 .64938 m
.3366 .61554 L
s
.30276 .69724 m
.30276 .7451 L
s
.30276 .69724 m
.3366 .6634 L
s
.30276 .69724 m
.3366 .73109 L
s
.30276 .69724 m
.35062 .69724 L
s
.30276 .69724 m
.35062 .69724 L
s
.30276 .7451 m
.3366 .77895 L
s
.30276 .81279 m
.30276 .86065 L
s
.30276 .81279 m
.3366 .77895 L
s
.30276 .81279 m
.35062 .81279 L
s
.30276 .81279 m
.35062 .81279 L
s
.30276 .86065 m
.3366 .89449 L
s
.30276 .86065 m
.3366 .89449 L
s
.30276 .86065 m
.35062 .86065 L
s
.30276 .86065 m
.35062 .86065 L
s
.30276 .92833 m
.3366 .89449 L
s
.30276 .92833 m
.3366 .89449 L
s
.30276 .92833 m
.3366 .89449 L
s
.30276 .92833 m
.3366 .89449 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .10551 m
.3366 .05765 L
s
.3366 .10551 m
.38446 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .10551 m
.38446 .10551 L
s
.3366 .22105 m
.3366 .26891 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .26891 m
.3366 .22105 L
s
.3366 .26891 m
.38446 .26891 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .38446 m
.3366 .3366 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .45214 m
.3366 .5 L
s
.3366 .45214 m
.3366 .5 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .5 m
.3366 .54786 L
s
.3366 .5 m
.3366 .45214 L
s
.3366 .5 m
.38446 .5 L
s
.3366 .54786 m
.3366 .5 L
s
.3366 .54786 m
.38446 .54786 L
s
.3366 .61554 m
.3366 .6634 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .6634 m
.3366 .61554 L
s
.3366 .6634 m
.38446 .6634 L
s
.3366 .89449 m
.3366 .94235 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .94235 m
.3366 .89449 L
s
.3366 .94235 m
.38446 .94235 L
s
.3366 .10551 m
.38446 .10551 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .45214 m
.3366 .5 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .5 m
.38446 .5 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .73109 m
.3366 .77895 L
s
.3366 .73109 m
.38446 .73109 L
s
.3366 .73109 m
.38446 .73109 L
s
.3366 .77895 m
.38446 .77895 L
s
.3366 .77895 m
.38446 .77895 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.38446 .10551 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.38446 .10551 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .18721 m
.35062 .13935 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .30276 m
.38446 .26891 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .5817 m
.38446 .54786 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .69724 m
.38446 .6634 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .81279 m
.35062 .86065 L
s
.35062 .81279 m
.35062 .86065 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .86065 m
.35062 .81279 L
s
.35062 .86065 m
.38446 .82681 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.38446 .10551 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .30276 m
.38446 .26891 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .5817 m
.38446 .54786 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .69724 m
.38446 .6634 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .81279 m
.35062 .86065 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .86065 m
.38446 .82681 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.38446 .05765 m
.38446 .10551 L
s
.38446 .05765 m
.38446 .10551 L
s
.38446 .10551 m
.4183 .07167 L
s
.38446 .10551 m
.4183 .13935 L
s
.38446 .10551 m
.4183 .13935 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .22105 m
.38446 .26891 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .2549 L
s
.38446 .26891 m
.38446 .22105 L
s
.38446 .26891 m
.4183 .30276 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.4183 .30276 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.4183 .30276 L
s
.38446 .38446 m
.38446 .3366 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .4183 L
s
.38446 .38446 m
.38446 .3366 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .4183 L
s
.38446 .45214 m
.38446 .5 L
s
.38446 .45214 m
.4183 .4183 L
s
.38446 .5 m
.38446 .54786 L
s
.38446 .5 m
.38446 .45214 L
s
.38446 .5 m
.4183 .46616 L
s
.38446 .5 m
.4183 .53384 L
s
.38446 .54786 m
.4183 .5817 L
s
.38446 .61554 m
.38446 .6634 L
s
.38446 .61554 m
.4183 .5817 L
s
.38446 .61554 m
.4183 .64938 L
s
.38446 .6634 m
.38446 .61554 L
s
.38446 .6634 m
.4183 .69724 L
s
.38446 .73109 m
.38446 .77895 L
s
.38446 .73109 m
.38446 .77895 L
s
.38446 .73109 m
.4183 .69724 L
s
.38446 .77895 m
.38446 .82681 L
s
.38446 .77895 m
.38446 .73109 L
s
.38446 .77895 m
.4183 .7451 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .82681 m
.38446 .77895 L
s
.38446 .82681 m
.4183 .86065 L
s
.38446 .82681 m
.4183 .86065 L
s
.38446 .89449 m
.38446 .94235 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.38446 .94235 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .94235 m
.38446 .89449 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .2549 L
s
.38446 .3366 m
.4183 .30276 L
s
.38446 .45214 m
.4183 .4183 L
s
.38446 .61554 m
.4183 .5817 L
s
.38446 .61554 m
.4183 .64938 L
s
.38446 .73109 m
.38446 .77895 L
s
.38446 .73109 m
.4183 .69724 L
s
.38446 .77895 m
.4183 .7451 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.4183 .92833 L
s
.4183 .07167 m
.45214 .10551 L
s
.4183 .07167 m
.46616 .07167 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.45214 .10551 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.45214 .10551 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .18721 m
.45214 .22105 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .18721 m
.45214 .22105 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .2549 m
.4183 .30276 L
s
.4183 .2549 m
.45214 .22105 L
s
.4183 .2549 m
.46616 .2549 L
s
.4183 .30276 m
.4183 .35062 L
s
.4183 .30276 m
.4183 .35062 L
s
.4183 .30276 m
.45214 .3366 L
s
.4183 .30276 m
.45214 .3366 L
s
.4183 .30276 m
.46616 .30276 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .4183 m
.4183 .46616 L
s
.4183 .4183 m
.45214 .38446 L
s
.4183 .4183 m
.45214 .38446 L
s
.4183 .4183 m
.46616 .4183 L
s
.4183 .46616 m
.45214 .5 L
s
.4183 .46616 m
.46616 .46616 L
s
.4183 .53384 m
.4183 .5817 L
s
.4183 .53384 m
.45214 .5 L
s
.4183 .53384 m
.46616 .53384 L
s
.4183 .5817 m
.45214 .61554 L
s
.4183 .5817 m
.46616 .5817 L
s
.4183 .64938 m
.4183 .69724 L
s
.4183 .64938 m
.45214 .61554 L
s
.4183 .69724 m
.4183 .7451 L
s
.4183 .69724 m
.45214 .6634 L
s
.4183 .69724 m
.46616 .69724 L
s
.4183 .7451 m
.45214 .77895 L
s
.4183 .7451 m
.46616 .7451 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.45214 .77895 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.45214 .77895 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.46616 .92833 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.46616 .92833 L
s
.45214 .10551 m
.5 .10551 L
s
.45214 .22105 m
.5 .22105 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .38446 m
.5 .38446 L
s
.45214 .38446 m
.5 .38446 L
s
.45214 .5 m
.5 .5 L
s
.45214 .61554 m
.45214 .6634 L
s
.45214 .61554 m
.5 .61554 L
s
.45214 .6634 m
.5 .6634 L
s
.45214 .77895 m
.5 .77895 L
s
.45214 .89449 m
.5 .89449 L
s
.45214 .89449 m
.5 .89449 L
s
.45214 .89449 m
.5 .89449 L
s
.45214 .89449 m
.5 .89449 L
s
.46616 .02381 m
.46616 .07167 L
s
.46616 .02381 m
.5 .05765 L
s
.46616 .07167 m
.5 .10551 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.5 .10551 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.5 .10551 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.5 .10551 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .18721 m
.5 .22105 L
s
.46616 .18721 m
.5 .22105 L
s
.46616 .2549 m
.46616 .30276 L
s
.46616 .2549 m
.5 .22105 L
s
.46616 .30276 m
.5 .26891 L
s
.46616 .30276 m
.5 .3366 L
s
.46616 .30276 m
.5 .3366 L
s
.46616 .4183 m
.46616 .46616 L
s
.46616 .4183 m
.5 .38446 L
s
.46616 .4183 m
.5 .45214 L
s
.46616 .46616 m
.5 .5 L
s
.46616 .53384 m
.46616 .5817 L
s
.46616 .53384 m
.5 .5 L
s
.46616 .5817 m
.5 .54786 L
s
.46616 .5817 m
.5 .61554 L
s
.46616 .69724 m
.46616 .7451 L
s
.46616 .69724 m
.5 .6634 L
s
.46616 .69724 m
.5 .73109 L
s
.46616 .7451 m
.5 .77895 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.5 .77895 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.5 .77895 L
s
.46616 .86065 m
.5 .82681 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .86065 m
.5 .82681 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .92833 m
.46616 .97619 L
s
.46616 .92833 m
.5 .89449 L
s
.46616 .92833 m
.5 .89449 L
s
.46616 .97619 m
.5 .94235 L
s
.5 .05765 m
.5 .10551 L
s
.5 .05765 m
.53384 .02381 L
s
.5 .10551 m
.53384 .07167 L
s
.5 .10551 m
.53384 .13935 L
s
.5 .10551 m
.53384 .13935 L
s
.5 .10551 m
.54786 .10551 L
s
.5 .17319 m
.5 .22105 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .17319 m
.5 .22105 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .22105 m
.5 .26891 L
s
.5 .22105 m
.53384 .18721 L
s
.5 .22105 m
.53384 .2549 L
s
.5 .22105 m
.54786 .22105 L
s
.5 .26891 m
.53384 .30276 L
s
.5 .3366 m
.5 .38446 L
s
.5 .3366 m
.53384 .30276 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .3366 m
.5 .38446 L
s
.5 .3366 m
.53384 .30276 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .38446 m
.53384 .4183 L
s
.5 .38446 m
.54786 .38446 L
s
.5 .38446 m
.54786 .38446 L
s
.5 .45214 m
.5 .5 L
s
.5 .45214 m
.53384 .4183 L
s
.5 .5 m
.5 .54786 L
s
.5 .5 m
.53384 .46616 L
s
.5 .5 m
.53384 .53384 L
s
.5 .5 m
.54786 .5 L
s
.5 .54786 m
.53384 .5817 L
s
.5 .61554 m
.5 .6634 L
s
.5 .61554 m
.53384 .5817 L
s
.5 .61554 m
.54786 .61554 L
s
.5 .6634 m
.53384 .69724 L
s
.5 .6634 m
.54786 .6634 L
s
.5 .73109 m
.5 .77895 L
s
.5 .73109 m
.53384 .69724 L
s
.5 .77895 m
.5 .82681 L
s
.5 .77895 m
.53384 .7451 L
s
.5 .77895 m
.53384 .81279 L
s
.5 .77895 m
.54786 .77895 L
s
.5 .82681 m
.53384 .86065 L
s
.5 .89449 m
.5 .94235 L
s
.5 .89449 m
.53384 .86065 L
s
.5 .89449 m
.53384 .92833 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .89449 m
.5 .94235 L
s
.5 .89449 m
.53384 .86065 L
s
.5 .89449 m
.53384 .92833 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .94235 m
.53384 .97619 L
s
.53384 .02381 m
.53384 .07167 L
s
.53384 .07167 m
.5817 .07167 L
s
.53384 .13935 m
.53384 .18721 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.53384 .18721 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .18721 m
.5817 .18721 L
s
.53384 .18721 m
.5817 .18721 L
s
.53384 .2549 m
.53384 .30276 L
s
.53384 .2549 m
.5817 .2549 L
s
.53384 .30276 m
.5817 .30276 L
s
.53384 .4183 m
.53384 .46616 L
s
.53384 .4183 m
.5817 .4183 L
s
.53384 .46616 m
.5817 .46616 L
s
.53384 .53384 m
.53384 .5817 L
s
.53384 .53384 m
.5817 .53384 L
s
.53384 .5817 m
.5817 .5817 L
s
.53384 .69724 m
.53384 .7451 L
s
.53384 .69724 m
.5817 .69724 L
s
.53384 .7451 m
.5817 .7451 L
s
.53384 .81279 m
.53384 .86065 L
s
.53384 .81279 m
.5817 .81279 L
s
.53384 .86065 m
.5817 .86065 L
s
.53384 .92833 m
.53384 .97619 L
s
.53384 .92833 m
.5817 .92833 L
s
.53384 .92833 m
.5817 .92833 L
s
.54786 .10551 m
.5817 .07167 L
s
.54786 .10551 m
.5817 .13935 L
s
.54786 .10551 m
.5817 .13935 L
s
.54786 .10551 m
.5817 .13935 L
s
.54786 .22105 m
.5817 .18721 L
s
.54786 .22105 m
.5817 .18721 L
s
.54786 .22105 m
.5817 .2549 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.5817 .30276 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.5817 .30276 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .4183 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .4183 L
s
.54786 .5 m
.5817 .46616 L
s
.54786 .5 m
.5817 .53384 L
s
.54786 .61554 m
.54786 .6634 L
s
.54786 .61554 m
.5817 .5817 L
s
.54786 .61554 m
.5817 .64938 L
s
.54786 .6634 m
.5817 .69724 L
s
.54786 .77895 m
.5817 .7451 L
s
.54786 .77895 m
.5817 .81279 L
s
.54786 .89449 m
.5817 .86065 L
s
.54786 .89449 m
.5817 .92833 L
s
.54786 .89449 m
.5817 .92833 L
s
.54786 .89449 m
.5817 .86065 L
s
.54786 .89449 m
.5817 .92833 L
s
.54786 .89449 m
.5817 .92833 L
s
.5817 .07167 m
.61554 .10551 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.61554 .10551 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.61554 .10551 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.61554 .10551 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .18721 m
.61554 .22105 L
s
.5817 .18721 m
.61554 .22105 L
s
.5817 .2549 m
.5817 .30276 L
s
.5817 .2549 m
.61554 .22105 L
s
.5817 .30276 m
.5817 .35062 L
s
.5817 .30276 m
.5817 .35062 L
s
.5817 .30276 m
.61554 .26891 L
s
.5817 .30276 m
.61554 .3366 L
s
.5817 .30276 m
.61554 .3366 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .4183 m
.5817 .46616 L
s
.5817 .4183 m
.61554 .38446 L
s
.5817 .4183 m
.61554 .38446 L
s
.5817 .4183 m
.61554 .45214 L
s
.5817 .46616 m
.61554 .5 L
s
.5817 .53384 m
.5817 .5817 L
s
.5817 .53384 m
.61554 .5 L
s
.5817 .5817 m
.61554 .54786 L
s
.5817 .5817 m
.61554 .61554 L
s
.5817 .64938 m
.5817 .69724 L
s
.5817 .64938 m
.61554 .61554 L
s
.5817 .69724 m
.5817 .7451 L
s
.5817 .69724 m
.61554 .6634 L
s
.5817 .69724 m
.61554 .73109 L
s
.5817 .7451 m
.61554 .77895 L
s
.5817 .81279 m
.5817 .86065 L
s
.5817 .81279 m
.61554 .77895 L
s
.5817 .86065 m
.61554 .82681 L
s
.5817 .86065 m
.61554 .89449 L
s
.5817 .86065 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.61554 .05765 m
.61554 .10551 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .10551 m
.61554 .05765 L
s
.61554 .10551 m
.61554 .05765 L
s
.61554 .10551 m
.64938 .13935 L
s
.61554 .10551 m
.64938 .13935 L
s
.61554 .10551 m
.6634 .10551 L
s
.61554 .10551 m
.6634 .10551 L
s
.61554 .10551 m
.6634 .10551 L
s
.61554 .17319 m
.61554 .22105 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .17319 m
.61554 .22105 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .22105 m
.61554 .26891 L
s
.61554 .22105 m
.64938 .18721 L
s
.61554 .22105 m
.6634 .22105 L
s
.61554 .22105 m
.6634 .22105 L
s
.61554 .26891 m
.64938 .30276 L
s
.61554 .26891 m
.6634 .26891 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.64938 .30276 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.64938 .30276 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .38446 m
.64938 .4183 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.64938 .4183 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .45214 m
.61554 .5 L
s
.61554 .45214 m
.64938 .4183 L
s
.61554 .45214 m
.6634 .45214 L
s
.61554 .45214 m
.6634 .45214 L
s
.61554 .5 m
.61554 .54786 L
s
.61554 .5 m
.6634 .5 L
s
.61554 .5 m
.6634 .5 L
s
.61554 .54786 m
.64938 .5817 L
s
.61554 .54786 m
.6634 .54786 L
s
.61554 .61554 m
.61554 .6634 L
s
.61554 .61554 m
.64938 .5817 L
s
.61554 .61554 m
.6634 .61554 L
s
.61554 .61554 m
.6634 .61554 L
s
.61554 .6634 m
.64938 .69724 L
s
.61554 .6634 m
.6634 .6634 L
s
.61554 .73109 m
.61554 .77895 L
s
.61554 .73109 m
.64938 .69724 L
s
.61554 .73109 m
.6634 .73109 L
s
.61554 .73109 m
.6634 .73109 L
s
.61554 .77895 m
.61554 .82681 L
s
.61554 .77895 m
.64938 .81279 L
s
.61554 .77895 m
.6634 .77895 L
s
.61554 .77895 m
.6634 .77895 L
s
.61554 .82681 m
.64938 .86065 L
s
.61554 .89449 m
.61554 .94235 L
s
.61554 .89449 m
.64938 .86065 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .89449 m
.61554 .94235 L
s
.61554 .89449 m
.64938 .86065 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .94235 m
.6634 .94235 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.64938 .13935 m
.64938 .18721 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.64938 .18721 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .18721 m
.69724 .18721 L
s
.64938 .30276 m
.69724 .30276 L
s
.64938 .4183 m
.69724 .4183 L
s
.64938 .5817 m
.69724 .5817 L
s
.64938 .69724 m
.69724 .69724 L
s
.64938 .81279 m
.64938 .86065 L
s
.64938 .81279 m
.69724 .81279 L
s
.64938 .86065 m
.69724 .86065 L
s
.6634 .22105 m
.6634 .26891 L
s
.6634 .22105 m
.69724 .18721 L
s
.6634 .22105 m
.69724 .2549 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.69724 .30276 L
s
.6634 .38446 m
.6634 .3366 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .4183 L
s
.6634 .38446 m
.6634 .3366 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .4183 L
s
.6634 .45214 m
.6634 .5 L
s
.6634 .45214 m
.6634 .5 L
s
.6634 .45214 m
.69724 .4183 L
s
.6634 .5 m
.6634 .45214 L
s
.6634 .5 m
.6634 .54786 L
s
.6634 .5 m
.69724 .46616 L
s
.6634 .5 m
.69724 .53384 L
s
.6634 .61554 m
.6634 .6634 L
s
.6634 .61554 m
.69724 .5817 L
s
.6634 .61554 m
.69724 .64938 L
s
.6634 .73109 m
.6634 .77895 L
s
.6634 .73109 m
.6634 .77895 L
s
.6634 .73109 m
.69724 .69724 L
s
.6634 .77895 m
.6634 .73109 L
s
.6634 .77895 m
.69724 .7451 L
s
.6634 .77895 m
.69724 .81279 L
s
.6634 .89449 m
.6634 .94235 L
s
.6634 .89449 m
.69724 .86065 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .10551 m
.6634 .05765 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .22105 m
.6634 .26891 L
s
.6634 .22105 m
.69724 .18721 L
s
.6634 .22105 m
.69724 .2549 L
s
.6634 .26891 m
.69724 .30276 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.69724 .30276 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .4183 L
s
.6634 .45214 m
.6634 .5 L
s
.6634 .45214 m
.69724 .4183 L
s
.6634 .5 m
.6634 .54786 L
s
.6634 .5 m
.69724 .46616 L
s
.6634 .5 m
.69724 .53384 L
s
.6634 .54786 m
.69724 .5817 L
s
.6634 .61554 m
.6634 .6634 L
s
.6634 .61554 m
.69724 .5817 L
s
.6634 .61554 m
.69724 .64938 L
s
.6634 .6634 m
.69724 .69724 L
s
.6634 .73109 m
.6634 .77895 L
s
.6634 .73109 m
.69724 .69724 L
s
.6634 .77895 m
.69724 .7451 L
s
.6634 .77895 m
.69724 .81279 L
s
.6634 .89449 m
.6634 .94235 L
s
.6634 .89449 m
.69724 .86065 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .13935 m
.69724 .18721 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.69724 .18721 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .18721 m
.69724 .13935 L
s
.69724 .18721 m
.73109 .22105 L
s
.69724 .18721 m
.7451 .18721 L
s
.69724 .2549 m
.69724 .30276 L
s
.69724 .2549 m
.73109 .22105 L
s
.69724 .30276 m
.69724 .35062 L
s
.69724 .30276 m
.69724 .35062 L
s
.69724 .30276 m
.73109 .26891 L
s
.69724 .30276 m
.73109 .3366 L
s
.69724 .30276 m
.7451 .30276 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .4183 m
.69724 .46616 L
s
.69724 .4183 m
.73109 .38446 L
s
.69724 .4183 m
.73109 .38446 L
s
.69724 .4183 m
.7451 .4183 L
s
.69724 .46616 m
.73109 .5 L
s
.69724 .46616 m
.7451 .46616 L
s
.69724 .53384 m
.69724 .5817 L
s
.69724 .53384 m
.73109 .5 L
s
.69724 .53384 m
.7451 .53384 L
s
.69724 .5817 m
.73109 .61554 L
s
.69724 .5817 m
.7451 .5817 L
s
.69724 .64938 m
.69724 .69724 L
s
.69724 .64938 m
.73109 .61554 L
s
.69724 .69724 m
.69724 .7451 L
s
.69724 .69724 m
.73109 .6634 L
s
.69724 .69724 m
.73109 .73109 L
s
.69724 .69724 m
.7451 .69724 L
s
.69724 .7451 m
.73109 .77895 L
s
.69724 .81279 m
.69724 .86065 L
s
.69724 .81279 m
.73109 .77895 L
s
.69724 .81279 m
.7451 .81279 L
s
.69724 .86065 m
.73109 .89449 L
s
.69724 .86065 m
.7451 .86065 L
s
.69724 .92833 m
.73109 .89449 L
s
.69724 .92833 m
.73109 .89449 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.7451 .13935 L
s
.73109 .22105 m
.73109 .26891 L
s
.73109 .22105 m
.77895 .22105 L
s
.73109 .26891 m
.77895 .26891 L
s
.73109 .3366 m
.73109 .38446 L
s
.73109 .3366 m
.73109 .38446 L
s
.73109 .3366 m
.77895 .3366 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .5 m
.77895 .5 L
s
.73109 .61554 m
.73109 .6634 L
s
.73109 .61554 m
.77895 .61554 L
s
.73109 .6634 m
.77895 .6634 L
s
.73109 .73109 m
.73109 .77895 L
s
.73109 .73109 m
.77895 .73109 L
s
.73109 .77895 m
.77895 .77895 L
s
.7451 .13935 m
.7451 .18721 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .13935 m
.7451 .18721 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .18721 m
.77895 .22105 L
s
.7451 .30276 m
.77895 .26891 L
s
.7451 .30276 m
.77895 .3366 L
s
.7451 .4183 m
.7451 .46616 L
s
.7451 .4183 m
.77895 .38446 L
s
.7451 .4183 m
.77895 .38446 L
s
.7451 .4183 m
.77895 .45214 L
s
.7451 .46616 m
.77895 .5 L
s
.7451 .53384 m
.7451 .5817 L
s
.7451 .53384 m
.77895 .5 L
s
.7451 .5817 m
.77895 .54786 L
s
.7451 .5817 m
.77895 .61554 L
s
.7451 .69724 m
.77895 .6634 L
s
.7451 .69724 m
.77895 .73109 L
s
.7451 .81279 m
.7451 .86065 L
s
.7451 .81279 m
.77895 .77895 L
s
.7451 .86065 m
.77895 .82681 L
s
.77895 .17319 m
.77895 .22105 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .17319 m
.77895 .22105 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .22105 m
.77895 .26891 L
s
.77895 .22105 m
.81279 .18721 L
s
.77895 .22105 m
.81279 .2549 L
s
.77895 .22105 m
.82681 .22105 L
s
.77895 .26891 m
.81279 .30276 L
s
.77895 .3366 m
.77895 .38446 L
s
.77895 .3366 m
.77895 .38446 L
s
.77895 .3366 m
.81279 .30276 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.82681 .38446 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.82681 .38446 L
s
.77895 .45214 m
.77895 .5 L
s
.77895 .45214 m
.81279 .4183 L
s
.77895 .45214 m
.81279 .4183 L
s
.77895 .5 m
.77895 .54786 L
s
.77895 .5 m
.81279 .46616 L
s
.77895 .5 m
.81279 .53384 L
s
.77895 .5 m
.82681 .5 L
s
.77895 .54786 m
.81279 .5817 L
s
.77895 .61554 m
.77895 .6634 L
s
.77895 .61554 m
.81279 .5817 L
s
.77895 .61554 m
.81279 .64938 L
s
.77895 .61554 m
.82681 .61554 L
s
.77895 .6634 m
.81279 .69724 L
s
.77895 .73109 m
.77895 .77895 L
s
.77895 .73109 m
.81279 .69724 L
s
.77895 .77895 m
.77895 .82681 L
s
.77895 .77895 m
.81279 .7451 L
s
.77895 .77895 m
.81279 .81279 L
s
.77895 .77895 m
.82681 .77895 L
s
.77895 .82681 m
.81279 .86065 L
s
.81279 .4183 m
.81279 .46616 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .46616 m
.81279 .4183 L
s
.81279 .46616 m
.86065 .46616 L
s
.81279 .46616 m
.86065 .46616 L
s
.81279 .13935 m
.81279 .18721 L
s
.81279 .13935 m
.81279 .18721 L
s
.81279 .18721 m
.86065 .18721 L
s
.81279 .2549 m
.81279 .30276 L
s
.81279 .2549 m
.86065 .2549 L
s
.81279 .30276 m
.81279 .35062 L
s
.81279 .30276 m
.81279 .35062 L
s
.81279 .30276 m
.86065 .30276 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .53384 m
.81279 .5817 L
s
.81279 .53384 m
.86065 .53384 L
s
.81279 .53384 m
.86065 .53384 L
s
.81279 .5817 m
.86065 .5817 L
s
.81279 .5817 m
.86065 .5817 L
s
.81279 .64938 m
.81279 .69724 L
s
.81279 .64938 m
.86065 .64938 L
s
.81279 .64938 m
.86065 .64938 L
s
.81279 .69724 m
.81279 .7451 L
s
.81279 .69724 m
.86065 .69724 L
s
.81279 .69724 m
.86065 .69724 L
s
.81279 .7451 m
.86065 .7451 L
s
.81279 .81279 m
.81279 .86065 L
s
.81279 .81279 m
.86065 .81279 L
s
.82681 .22105 m
.86065 .18721 L
s
.82681 .22105 m
.86065 .2549 L
s
.82681 .38446 m
.86065 .4183 L
s
.82681 .38446 m
.86065 .4183 L
s
.82681 .38446 m
.86065 .35062 L
s
.82681 .38446 m
.86065 .35062 L
s
.82681 .38446 m
.86065 .4183 L
s
.82681 .5 m
.86065 .53384 L
s
.82681 .5 m
.86065 .46616 L
s
.82681 .5 m
.86065 .46616 L
s
.82681 .5 m
.86065 .53384 L
s
.82681 .61554 m
.86065 .5817 L
s
.82681 .61554 m
.86065 .64938 L
s
.82681 .61554 m
.86065 .5817 L
s
.82681 .61554 m
.86065 .64938 L
s
.82681 .77895 m
.86065 .7451 L
s
.82681 .77895 m
.86065 .81279 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .53384 m
.86065 .5817 L
s
.86065 .53384 m
.86065 .5817 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .5817 m
.86065 .53384 L
s
.86065 .5817 m
.89449 .54786 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .64938 m
.86065 .69724 L
s
.86065 .64938 m
.86065 .69724 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .69724 m
.86065 .64938 L
s
.86065 .69724 m
.86065 .7451 L
s
.86065 .69724 m
.89449 .6634 L
s
.86065 .69724 m
.89449 .73109 L
s
.86065 .69724 m
.89449 .73109 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .46616 m
.86065 .4183 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .2549 m
.86065 .30276 L
s
.86065 .30276 m
.86065 .35062 L
s
.86065 .30276 m
.86065 .35062 L
s
.86065 .30276 m
.89449 .3366 L
s
.86065 .30276 m
.89449 .26891 L
s
.86065 .30276 m
.89449 .3366 L
s
.86065 .30276 m
.89449 .3366 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .53384 m
.86065 .5817 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .5817 m
.89449 .54786 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .64938 m
.86065 .69724 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .69724 m
.86065 .7451 L
s
.86065 .69724 m
.89449 .6634 L
s
.86065 .69724 m
.89449 .73109 L
s
.86065 .69724 m
.89449 .73109 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .38446 m
.89449 .3366 L
s
.89449 .38446 m
.89449 .3366 L
s
.89449 .38446 m
.92833 .4183 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .45214 m
.89449 .5 L
s
.89449 .45214 m
.89449 .5 L
s
.89449 .45214 m
.92833 .4183 L
s
.89449 .5 m
.89449 .54786 L
s
.89449 .5 m
.89449 .45214 L
s
.89449 .5 m
.92833 .46616 L
s
.89449 .5 m
.92833 .53384 L
s
.89449 .5 m
.94235 .5 L
s
.89449 .54786 m
.89449 .5 L
s
.89449 .54786 m
.92833 .5817 L
s
.89449 .61554 m
.89449 .6634 L
s
.89449 .61554 m
.92833 .5817 L
s
.89449 .61554 m
.94235 .61554 L
s
.89449 .6634 m
.89449 .61554 L
s
.89449 .6634 m
.92833 .69724 L
s
.89449 .6634 m
.94235 .6634 L
s
.89449 .73109 m
.92833 .69724 L
s
.89449 .26891 m
.92833 .30276 L
s
.89449 .26891 m
.92833 .30276 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .38446 m
.92833 .4183 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.92833 .4183 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .45214 m
.89449 .5 L
s
.89449 .45214 m
.92833 .4183 L
s
.89449 .5 m
.92833 .46616 L
s
.89449 .5 m
.92833 .53384 L
s
.89449 .5 m
.94235 .5 L
s
.89449 .61554 m
.92833 .5817 L
s
.89449 .61554 m
.94235 .61554 L
s
.89449 .73109 m
.92833 .69724 L
s
.92833 .4183 m
.92833 .46616 L
s
.92833 .46616 m
.97619 .46616 L
s
.92833 .53384 m
.92833 .5817 L
s
.92833 .53384 m
.97619 .53384 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .38446 m
.94235 .3366 L
s
.94235 .5 m
.97619 .46616 L
s
.94235 .5 m
.97619 .53384 L
s
.94235 .61554 m
.94235 .6634 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .3366 m
.94235 .38446 L
s
.008 w
.12413 .20894 Mdot
.21985 .11322 Mdot
.02841 .44003 Mdot
.12413 .34431 Mdot
.21985 .24859 Mdot
.31557 .15287 Mdot
.41129 .05715 Mdot
.02841 .5754 Mdot
.12413 .47968 Mdot
.21985 .38396 Mdot
.31557 .28824 Mdot
.41129 .19252 Mdot
.50701 .0968 Mdot
.12413 .61505 Mdot
.21985 .51933 Mdot
.31557 .42361 Mdot
.41129 .32789 Mdot
.50701 .23217 Mdot
.60273 .13645 Mdot
.12413 .75041 Mdot
.21985 .65469 Mdot
.31557 .55897 Mdot
.41129 .46326 Mdot
.50701 .36754 Mdot
.60273 .27182 Mdot
.69845 .1761 Mdot
.21985 .79006 Mdot
.31557 .69434 Mdot
.41129 .59862 Mdot
.50701 .5029 Mdot
.60273 .40718 Mdot
.69845 .31146 Mdot
.79417 .21575 Mdot
.31557 .82971 Mdot
.41129 .73399 Mdot
.50701 .63827 Mdot
.60273 .54255 Mdot
.69845 .44683 Mdot
.79417 .35111 Mdot
.88989 .25539 Mdot
.41129 .86936 Mdot
.50701 .77364 Mdot
.60273 .67792 Mdot
.69845 .5822 Mdot
.79417 .48648 Mdot
.88989 .39076 Mdot
.50701 .909 Mdot
.60273 .81329 Mdot
.69845 .71757 Mdot
.79417 .62185 Mdot
.88989 .52613 Mdot
.60273 .94865 Mdot
.69845 .85293 Mdot
.79417 .75721 Mdot
.88989 .6615 Mdot
.44003 .02841 Mdot
.5754 .02841 Mdot
.20894 .12413 Mdot
.34431 .12413 Mdot
.47968 .12413 Mdot
.61505 .12413 Mdot
.75041 .12413 Mdot
.11322 .21985 Mdot
.24859 .21985 Mdot
.38396 .21985 Mdot
.51933 .21985 Mdot
.65469 .21985 Mdot
.79006 .21985 Mdot
.15287 .31557 Mdot
.28824 .31557 Mdot
.42361 .31557 Mdot
.55897 .31557 Mdot
.69434 .31557 Mdot
.82971 .31557 Mdot
.05715 .41129 Mdot
.19252 .41129 Mdot
.32789 .41129 Mdot
.46326 .41129 Mdot
.59862 .41129 Mdot
.73399 .41129 Mdot
.86936 .41129 Mdot
.0968 .50701 Mdot
.23217 .50701 Mdot
.36754 .50701 Mdot
.5029 .50701 Mdot
.63827 .50701 Mdot
.77364 .50701 Mdot
.909 .50701 Mdot
.13645 .60273 Mdot
.27182 .60273 Mdot
.40718 .60273 Mdot
.54255 .60273 Mdot
.67792 .60273 Mdot
.81329 .60273 Mdot
.94865 .60273 Mdot
.1761 .69845 Mdot
.31146 .69845 Mdot
.44683 .69845 Mdot
.5822 .69845 Mdot
.71757 .69845 Mdot
.85293 .69845 Mdot
.21575 .79417 Mdot
.35111 .79417 Mdot
.48648 .79417 Mdot
.62185 .79417 Mdot
.75721 .79417 Mdot
.25539 .88989 Mdot
.39076 .88989 Mdot
.52613 .88989 Mdot
.6615 .88989 Mdot
.73229 .11322 Mdot
.82801 .20894 Mdot
.92373 .30466 Mdot
.54085 .05715 Mdot
.63657 .15287 Mdot
.73229 .24859 Mdot
.82801 .34431 Mdot
.92373 .44003 Mdot
.44513 .0968 Mdot
.54085 .19252 Mdot
.63657 .28824 Mdot
.73229 .38396 Mdot
.82801 .47968 Mdot
.92373 .5754 Mdot
.34941 .13645 Mdot
.44513 .23217 Mdot
.54085 .32789 Mdot
.63657 .42361 Mdot
.73229 .51933 Mdot
.82801 .61505 Mdot
.92373 .71076 Mdot
.25369 .1761 Mdot
.34941 .27182 Mdot
.44513 .36754 Mdot
.54085 .46326 Mdot
.63657 .55897 Mdot
.73229 .65469 Mdot
.82801 .75041 Mdot
.15797 .21575 Mdot
.25369 .31146 Mdot
.34941 .40718 Mdot
.44513 .5029 Mdot
.54085 .59862 Mdot
.63657 .69434 Mdot
.73229 .79006 Mdot
.15797 .35111 Mdot
.25369 .44683 Mdot
.34941 .54255 Mdot
.44513 .63827 Mdot
.54085 .73399 Mdot
.63657 .82971 Mdot
.06226 .39076 Mdot
.15797 .48648 Mdot
.25369 .5822 Mdot
.34941 .67792 Mdot
.44513 .77364 Mdot
.54085 .86936 Mdot
.06226 .52613 Mdot
.15797 .62185 Mdot
.25369 .71757 Mdot
.34941 .81329 Mdot
.44513 .909 Mdot
.06226 .6615 Mdot
.15797 .75721 Mdot
.25369 .85293 Mdot
.34941 .94865 Mdot
.79106 .12413 Mdot
.88678 .21985 Mdot
.55997 .02841 Mdot
.65569 .12413 Mdot
.75141 .21985 Mdot
.84713 .31557 Mdot
.94285 .41129 Mdot
.4246 .02841 Mdot
.52032 .12413 Mdot
.61604 .21985 Mdot
.71176 .31557 Mdot
.80748 .41129 Mdot
.9032 .50701 Mdot
.38495 .12413 Mdot
.48067 .21985 Mdot
.57639 .31557 Mdot
.67211 .41129 Mdot
.76783 .50701 Mdot
.86355 .60273 Mdot
.24959 .12413 Mdot
.34531 .21985 Mdot
.44103 .31557 Mdot
.53674 .41129 Mdot
.63246 .50701 Mdot
.72818 .60273 Mdot
.8239 .69845 Mdot
.20994 .21985 Mdot
.30566 .31557 Mdot
.40138 .41129 Mdot
.4971 .50701 Mdot
.59282 .60273 Mdot
.68854 .69845 Mdot
.78425 .79417 Mdot
.17029 .31557 Mdot
.26601 .41129 Mdot
.36173 .50701 Mdot
.45745 .60273 Mdot
.55317 .69845 Mdot
.64889 .79417 Mdot
.74461 .88989 Mdot
.13064 .41129 Mdot
.22636 .50701 Mdot
.32208 .60273 Mdot
.4178 .69845 Mdot
.51352 .79417 Mdot
.60924 .88989 Mdot
.091 .50701 Mdot
.18671 .60273 Mdot
.28243 .69845 Mdot
.37815 .79417 Mdot
.47387 .88989 Mdot
.05135 .60273 Mdot
.14707 .69845 Mdot
.24279 .79417 Mdot
.3385 .88989 Mdot
.06226 .3385 Mdot
.15797 .24279 Mdot
.25369 .14707 Mdot
.34941 .05135 Mdot
.06226 .47387 Mdot
.15797 .37815 Mdot
.25369 .28243 Mdot
.34941 .18671 Mdot
.44513 .091 Mdot
.06226 .60924 Mdot
.15797 .51352 Mdot
.25369 .4178 Mdot
.34941 .32208 Mdot
.44513 .22636 Mdot
.54085 .13064 Mdot
.15797 .64889 Mdot
.25369 .55317 Mdot
.34941 .45745 Mdot
.44513 .36173 Mdot
.54085 .26601 Mdot
.63657 .17029 Mdot
.15797 .78425 Mdot
.25369 .68854 Mdot
.34941 .59282 Mdot
.44513 .4971 Mdot
.54085 .40138 Mdot
.63657 .30566 Mdot
.73229 .20994 Mdot
.25369 .8239 Mdot
.34941 .72818 Mdot
.44513 .63246 Mdot
.54085 .53674 Mdot
.63657 .44103 Mdot
.73229 .34531 Mdot
.82801 .24959 Mdot
.34941 .86355 Mdot
.44513 .76783 Mdot
.54085 .67211 Mdot
.63657 .57639 Mdot
.73229 .48067 Mdot
.82801 .38495 Mdot
.92373 .28924 Mdot
.44513 .9032 Mdot
.54085 .80748 Mdot
.63657 .71176 Mdot
.73229 .61604 Mdot
.82801 .52032 Mdot
.92373 .4246 Mdot
.54085 .94285 Mdot
.63657 .84713 Mdot
.73229 .75141 Mdot
.82801 .65569 Mdot
.92373 .55997 Mdot
.73229 .88678 Mdot
.82801 .79106 Mdot
.92373 .69534 Mdot
.30466 .07627 Mdot
.44003 .07627 Mdot
.5754 .07627 Mdot
.71076 .07627 Mdot
.20894 .17199 Mdot
.34431 .17199 Mdot
.47968 .17199 Mdot
.61505 .17199 Mdot
.75041 .17199 Mdot
.11322 .26771 Mdot
.24859 .26771 Mdot
.38396 .26771 Mdot
.51933 .26771 Mdot
.65469 .26771 Mdot
.79006 .26771 Mdot
.15287 .36343 Mdot
.28824 .36343 Mdot
.42361 .36343 Mdot
.55897 .36343 Mdot
.69434 .36343 Mdot
.82971 .36343 Mdot
.05715 .45915 Mdot
.19252 .45915 Mdot
.32789 .45915 Mdot
.46326 .45915 Mdot
.59862 .45915 Mdot
.73399 .45915 Mdot
.86936 .45915 Mdot
.0968 .55487 Mdot
.23217 .55487 Mdot
.36754 .55487 Mdot
.5029 .55487 Mdot
.63827 .55487 Mdot
.77364 .55487 Mdot
.909 .55487 Mdot
.13645 .65059 Mdot
.27182 .65059 Mdot
.40718 .65059 Mdot
.54255 .65059 Mdot
.67792 .65059 Mdot
.81329 .65059 Mdot
.94865 .65059 Mdot
.1761 .74631 Mdot
.31146 .74631 Mdot
.44683 .74631 Mdot
.5822 .74631 Mdot
.71757 .74631 Mdot
.85293 .74631 Mdot
.21575 .84203 Mdot
.35111 .84203 Mdot
.48648 .84203 Mdot
.62185 .84203 Mdot
.75721 .84203 Mdot
.39076 .93774 Mdot
.52613 .93774 Mdot
.6615 .93774 Mdot
.60273 .05135 Mdot
.69845 .14707 Mdot
.79417 .24279 Mdot
.88989 .3385 Mdot
.50701 .091 Mdot
.60273 .18671 Mdot
.69845 .28243 Mdot
.79417 .37815 Mdot
.88989 .47387 Mdot
.41129 .13064 Mdot
.50701 .22636 Mdot
.60273 .32208 Mdot
.69845 .4178 Mdot
.79417 .51352 Mdot
.88989 .60924 Mdot
.31557 .17029 Mdot
.41129 .26601 Mdot
.50701 .36173 Mdot
.60273 .45745 Mdot
.69845 .55317 Mdot
.79417 .64889 Mdot
.88989 .74461 Mdot
.21985 .20994 Mdot
.31557 .30566 Mdot
.41129 .40138 Mdot
.50701 .4971 Mdot
.60273 .59282 Mdot
.69845 .68854 Mdot
.79417 .78425 Mdot
.12413 .24959 Mdot
.21985 .34531 Mdot
.31557 .44103 Mdot
.41129 .53674 Mdot
.50701 .63246 Mdot
.60273 .72818 Mdot
.69845 .8239 Mdot
.12413 .38495 Mdot
.21985 .48067 Mdot
.31557 .57639 Mdot
.41129 .67211 Mdot
.50701 .76783 Mdot
.60273 .86355 Mdot
.02841 .4246 Mdot
.12413 .52032 Mdot
.21985 .61604 Mdot
.31557 .71176 Mdot
.41129 .80748 Mdot
.50701 .9032 Mdot
.02841 .55997 Mdot
.12413 .65569 Mdot
.21985 .75141 Mdot
.31557 .84713 Mdot
.41129 .94285 Mdot
.12413 .79106 Mdot
.21985 .88678 Mdot
.6615 .06226 Mdot
.75721 .15797 Mdot
.85293 .25369 Mdot
.94865 .34941 Mdot
.52613 .06226 Mdot
.62185 .15797 Mdot
.71757 .25369 Mdot
.81329 .34941 Mdot
.909 .44513 Mdot
.39076 .06226 Mdot
.48648 .15797 Mdot
.5822 .25369 Mdot
.67792 .34941 Mdot
.77364 .44513 Mdot
.86936 .54085 Mdot
.35111 .15797 Mdot
.44683 .25369 Mdot
.54255 .34941 Mdot
.63827 .44513 Mdot
.73399 .54085 Mdot
.82971 .63657 Mdot
.21575 .15797 Mdot
.31146 .25369 Mdot
.40718 .34941 Mdot
.5029 .44513 Mdot
.59862 .54085 Mdot
.69434 .63657 Mdot
.79006 .73229 Mdot
.1761 .25369 Mdot
.27182 .34941 Mdot
.36754 .44513 Mdot
.46326 .54085 Mdot
.55897 .63657 Mdot
.65469 .73229 Mdot
.75041 .82801 Mdot
.13645 .34941 Mdot
.23217 .44513 Mdot
.32789 .54085 Mdot
.42361 .63657 Mdot
.51933 .73229 Mdot
.61505 .82801 Mdot
.71076 .92373 Mdot
.0968 .44513 Mdot
.19252 .54085 Mdot
.28824 .63657 Mdot
.38396 .73229 Mdot
.47968 .82801 Mdot
.5754 .92373 Mdot
.05715 .54085 Mdot
.15287 .63657 Mdot
.24859 .73229 Mdot
.34431 .82801 Mdot
.44003 .92373 Mdot
.11322 .73229 Mdot
.20894 .82801 Mdot
.30466 .92373 Mdot
.07627 .30466 Mdot
.17199 .20894 Mdot
.26771 .11322 Mdot
.07627 .44003 Mdot
.17199 .34431 Mdot
.26771 .24859 Mdot
.36343 .15287 Mdot
.45915 .05715 Mdot
.07627 .5754 Mdot
.17199 .47968 Mdot
.26771 .38396 Mdot
.36343 .28824 Mdot
.45915 .19252 Mdot
.55487 .0968 Mdot
.07627 .71076 Mdot
.17199 .61505 Mdot
.26771 .51933 Mdot
.36343 .42361 Mdot
.45915 .32789 Mdot
.55487 .23217 Mdot
.65059 .13645 Mdot
.17199 .75041 Mdot
.26771 .65469 Mdot
.36343 .55897 Mdot
.45915 .46326 Mdot
.55487 .36754 Mdot
.65059 .27182 Mdot
.74631 .1761 Mdot
.26771 .79006 Mdot
.36343 .69434 Mdot
.45915 .59862 Mdot
.55487 .5029 Mdot
.65059 .40718 Mdot
.74631 .31146 Mdot
.84203 .21575 Mdot
.36343 .82971 Mdot
.45915 .73399 Mdot
.55487 .63827 Mdot
.65059 .54255 Mdot
.74631 .44683 Mdot
.84203 .35111 Mdot
.45915 .86936 Mdot
.55487 .77364 Mdot
.65059 .67792 Mdot
.74631 .5822 Mdot
.84203 .48648 Mdot
.93774 .39076 Mdot
.55487 .909 Mdot
.65059 .81329 Mdot
.74631 .71757 Mdot
.84203 .62185 Mdot
.93774 .52613 Mdot
.65059 .94865 Mdot
.74631 .85293 Mdot
.84203 .75721 Mdot
.93774 .6615 Mdot
.3385 .06226 Mdot
.47387 .06226 Mdot
.60924 .06226 Mdot
.24279 .15797 Mdot
.37815 .15797 Mdot
.51352 .15797 Mdot
.64889 .15797 Mdot
.78425 .15797 Mdot
.14707 .25369 Mdot
.28243 .25369 Mdot
.4178 .25369 Mdot
.55317 .25369 Mdot
.68854 .25369 Mdot
.8239 .25369 Mdot
.05135 .34941 Mdot
.18671 .34941 Mdot
.32208 .34941 Mdot
.45745 .34941 Mdot
.59282 .34941 Mdot
.72818 .34941 Mdot
.86355 .34941 Mdot
.091 .44513 Mdot
.22636 .44513 Mdot
.36173 .44513 Mdot
.4971 .44513 Mdot
.63246 .44513 Mdot
.76783 .44513 Mdot
.9032 .44513 Mdot
.13064 .54085 Mdot
.26601 .54085 Mdot
.40138 .54085 Mdot
.53674 .54085 Mdot
.67211 .54085 Mdot
.80748 .54085 Mdot
.94285 .54085 Mdot
.17029 .63657 Mdot
.30566 .63657 Mdot
.44103 .63657 Mdot
.57639 .63657 Mdot
.71176 .63657 Mdot
.84713 .63657 Mdot
.20994 .73229 Mdot
.34531 .73229 Mdot
.48067 .73229 Mdot
.61604 .73229 Mdot
.75141 .73229 Mdot
.88678 .73229 Mdot
.24959 .82801 Mdot
.38495 .82801 Mdot
.52032 .82801 Mdot
.65569 .82801 Mdot
.79106 .82801 Mdot
.28924 .92373 Mdot
.4246 .92373 Mdot
.55997 .92373 Mdot
.69534 .92373 Mdot
.78015 .11322 Mdot
.87587 .20894 Mdot
.58871 .05715 Mdot
.68443 .15287 Mdot
.78015 .24859 Mdot
.87587 .34431 Mdot
.97159 .44003 Mdot
.49299 .0968 Mdot
.58871 .19252 Mdot
.68443 .28824 Mdot
.78015 .38396 Mdot
.87587 .47968 Mdot
.97159 .5754 Mdot
.39727 .13645 Mdot
.49299 .23217 Mdot
.58871 .32789 Mdot
.68443 .42361 Mdot
.78015 .51933 Mdot
.87587 .61505 Mdot
.30155 .1761 Mdot
.39727 .27182 Mdot
.49299 .36754 Mdot
.58871 .46326 Mdot
.68443 .55897 Mdot
.78015 .65469 Mdot
.87587 .75041 Mdot
.20583 .21575 Mdot
.30155 .31146 Mdot
.39727 .40718 Mdot
.49299 .5029 Mdot
.58871 .59862 Mdot
.68443 .69434 Mdot
.78015 .79006 Mdot
.11011 .25539 Mdot
.20583 .35111 Mdot
.30155 .44683 Mdot
.39727 .54255 Mdot
.49299 .63827 Mdot
.58871 .73399 Mdot
.68443 .82971 Mdot
.11011 .39076 Mdot
.20583 .48648 Mdot
.30155 .5822 Mdot
.39727 .67792 Mdot
.49299 .77364 Mdot
.58871 .86936 Mdot
.11011 .52613 Mdot
.20583 .62185 Mdot
.30155 .71757 Mdot
.39727 .81329 Mdot
.49299 .909 Mdot
.11011 .6615 Mdot
.20583 .75721 Mdot
.30155 .85293 Mdot
.39727 .94865 Mdot
.69534 .07627 Mdot
.79106 .17199 Mdot
.88678 .26771 Mdot
.55997 .07627 Mdot
.65569 .17199 Mdot
.75141 .26771 Mdot
.84713 .36343 Mdot
.94285 .45915 Mdot
.4246 .07627 Mdot
.52032 .17199 Mdot
.61604 .26771 Mdot
.71176 .36343 Mdot
.80748 .45915 Mdot
.9032 .55487 Mdot
.28924 .07627 Mdot
.38495 .17199 Mdot
.48067 .26771 Mdot
.57639 .36343 Mdot
.67211 .45915 Mdot
.76783 .55487 Mdot
.86355 .65059 Mdot
.24959 .17199 Mdot
.34531 .26771 Mdot
.44103 .36343 Mdot
.53674 .45915 Mdot
.63246 .55487 Mdot
.72818 .65059 Mdot
.8239 .74631 Mdot
.20994 .26771 Mdot
.30566 .36343 Mdot
.40138 .45915 Mdot
.4971 .55487 Mdot
.59282 .65059 Mdot
.68854 .74631 Mdot
.78425 .84203 Mdot
.17029 .36343 Mdot
.26601 .45915 Mdot
.36173 .55487 Mdot
.45745 .65059 Mdot
.55317 .74631 Mdot
.64889 .84203 Mdot
.13064 .45915 Mdot
.22636 .55487 Mdot
.32208 .65059 Mdot
.4178 .74631 Mdot
.51352 .84203 Mdot
.60924 .93774 Mdot
.091 .55487 Mdot
.18671 .65059 Mdot
.28243 .74631 Mdot
.37815 .84203 Mdot
.47387 .93774 Mdot
.05135 .65059 Mdot
.14707 .74631 Mdot
.24279 .84203 Mdot
.3385 .93774 Mdot
.11011 .3385 Mdot
.20583 .24279 Mdot
.30155 .14707 Mdot
.39727 .05135 Mdot
.11011 .47387 Mdot
.20583 .37815 Mdot
.30155 .28243 Mdot
.39727 .18671 Mdot
.49299 .091 Mdot
.11011 .60924 Mdot
.20583 .51352 Mdot
.30155 .4178 Mdot
.39727 .32208 Mdot
.49299 .22636 Mdot
.58871 .13064 Mdot
.11011 .74461 Mdot
.20583 .64889 Mdot
.30155 .55317 Mdot
.39727 .45745 Mdot
.49299 .36173 Mdot
.58871 .26601 Mdot
.68443 .17029 Mdot
.20583 .78425 Mdot
.30155 .68854 Mdot
.39727 .59282 Mdot
.49299 .4971 Mdot
.58871 .40138 Mdot
.68443 .30566 Mdot
.78015 .20994 Mdot
.30155 .8239 Mdot
.39727 .72818 Mdot
.49299 .63246 Mdot
.58871 .53674 Mdot
.68443 .44103 Mdot
.78015 .34531 Mdot
.87587 .24959 Mdot
.39727 .86355 Mdot
.49299 .76783 Mdot
.58871 .67211 Mdot
.68443 .57639 Mdot
.78015 .48067 Mdot
.87587 .38495 Mdot
.49299 .9032 Mdot
.58871 .80748 Mdot
.68443 .71176 Mdot
.78015 .61604 Mdot
.87587 .52032 Mdot
.97159 .4246 Mdot
.58871 .94285 Mdot
.68443 .84713 Mdot
.78015 .75141 Mdot
.87587 .65569 Mdot
.97159 .55997 Mdot
.78015 .88678 Mdot
.87587 .79106 Mdot
.3385 .11011 Mdot
.47387 .11011 Mdot
.60924 .11011 Mdot
.74461 .11011 Mdot
.24279 .20583 Mdot
.37815 .20583 Mdot
.51352 .20583 Mdot
.64889 .20583 Mdot
.78425 .20583 Mdot
.14707 .30155 Mdot
.28243 .30155 Mdot
.4178 .30155 Mdot
.55317 .30155 Mdot
.68854 .30155 Mdot
.8239 .30155 Mdot
.05135 .39727 Mdot
.18671 .39727 Mdot
.32208 .39727 Mdot
.45745 .39727 Mdot
.59282 .39727 Mdot
.72818 .39727 Mdot
.86355 .39727 Mdot
.091 .49299 Mdot
.22636 .49299 Mdot
.36173 .49299 Mdot
.4971 .49299 Mdot
.63246 .49299 Mdot
.76783 .49299 Mdot
.9032 .49299 Mdot
.13064 .58871 Mdot
.26601 .58871 Mdot
.40138 .58871 Mdot
.53674 .58871 Mdot
.67211 .58871 Mdot
.80748 .58871 Mdot
.94285 .58871 Mdot
.17029 .68443 Mdot
.30566 .68443 Mdot
.44103 .68443 Mdot
.57639 .68443 Mdot
.71176 .68443 Mdot
.84713 .68443 Mdot
.20994 .78015 Mdot
.34531 .78015 Mdot
.48067 .78015 Mdot
.61604 .78015 Mdot
.75141 .78015 Mdot
.88678 .78015 Mdot
.24959 .87587 Mdot
.38495 .87587 Mdot
.52032 .87587 Mdot
.65569 .87587 Mdot
.79106 .87587 Mdot
.4246 .97159 Mdot
.55997 .97159 Mdot
.65059 .05135 Mdot
.74631 .14707 Mdot
.84203 .24279 Mdot
.93774 .3385 Mdot
.55487 .091 Mdot
.65059 .18671 Mdot
.74631 .28243 Mdot
.84203 .37815 Mdot
.93774 .47387 Mdot
.45915 .13064 Mdot
.55487 .22636 Mdot
.65059 .32208 Mdot
.74631 .4178 Mdot
.84203 .51352 Mdot
.93774 .60924 Mdot
.36343 .17029 Mdot
.45915 .26601 Mdot
.55487 .36173 Mdot
.65059 .45745 Mdot
.74631 .55317 Mdot
.84203 .64889 Mdot
.26771 .20994 Mdot
.36343 .30566 Mdot
.45915 .40138 Mdot
.55487 .4971 Mdot
.65059 .59282 Mdot
.74631 .68854 Mdot
.84203 .78425 Mdot
.17199 .24959 Mdot
.26771 .34531 Mdot
.36343 .44103 Mdot
.45915 .53674 Mdot
.55487 .63246 Mdot
.65059 .72818 Mdot
.74631 .8239 Mdot
.07627 .28924 Mdot
.17199 .38495 Mdot
.26771 .48067 Mdot
.36343 .57639 Mdot
.45915 .67211 Mdot
.55487 .76783 Mdot
.65059 .86355 Mdot
.07627 .4246 Mdot
.17199 .52032 Mdot
.26771 .61604 Mdot
.36343 .71176 Mdot
.45915 .80748 Mdot
.55487 .9032 Mdot
.07627 .55997 Mdot
.17199 .65569 Mdot
.26771 .75141 Mdot
.36343 .84713 Mdot
.45915 .94285 Mdot
.07627 .69534 Mdot
.17199 .79106 Mdot
.26771 .88678 Mdot
.6615 .11011 Mdot
.75721 .20583 Mdot
.85293 .30155 Mdot
.94865 .39727 Mdot
.52613 .11011 Mdot
.62185 .20583 Mdot
.71757 .30155 Mdot
.81329 .39727 Mdot
.909 .49299 Mdot
.39076 .11011 Mdot
.48648 .20583 Mdot
.5822 .30155 Mdot
.67792 .39727 Mdot
.77364 .49299 Mdot
.86936 .58871 Mdot
.25539 .11011 Mdot
.35111 .20583 Mdot
.44683 .30155 Mdot
.54255 .39727 Mdot
.63827 .49299 Mdot
.73399 .58871 Mdot
.82971 .68443 Mdot
.21575 .20583 Mdot
.31146 .30155 Mdot
.40718 .39727 Mdot
.5029 .49299 Mdot
.59862 .58871 Mdot
.69434 .68443 Mdot
.79006 .78015 Mdot
.1761 .30155 Mdot
.27182 .39727 Mdot
.36754 .49299 Mdot
.46326 .58871 Mdot
.55897 .68443 Mdot
.65469 .78015 Mdot
.75041 .87587 Mdot
.13645 .39727 Mdot
.23217 .49299 Mdot
.32789 .58871 Mdot
.42361 .68443 Mdot
.51933 .78015 Mdot
.61505 .87587 Mdot
.0968 .49299 Mdot
.19252 .58871 Mdot
.28824 .68443 Mdot
.38396 .78015 Mdot
.47968 .87587 Mdot
.5754 .97159 Mdot
.05715 .58871 Mdot
.15287 .68443 Mdot
.24859 .78015 Mdot
.34431 .87587 Mdot
.44003 .97159 Mdot
.11322 .78015 Mdot
.20894 .87587 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;RLW9b40<?oo_`00?g=cLda<C820P8NZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmo
OiB;WMKBg2XX;H=kRhjYUM3KddiMD^GQY9no_m[ViUY]KD=EIB4Z<M_Vkl?Ei6F0V;2^]4U5CX61PFYo
L4mOGbL_;n;/k<oOggN?ShRZVHEhU000O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o
002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmo
Ocmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?glo
Oglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0
_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo
_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo
?oooOlS3cdDnCFmlS[g3bcU0B]C>N7j0VLG6dD52Cf]]PW5VO]_Ggd8lBVIbVOoo0_oo1mWIhEiPLko0
c3m0C1lO9FAJKk>ic=;EhC<iC1TL9DaELeioI[C3]c11=?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L008D700<01`L04@L00`071`241`00N@L200870P061`804@L200H70P021`80
NPL007X700D01`L700061`0300L000l700<01`001`L01@071`L007X700251`0400L700d700@01`L0
QPL008D700D01`L7000;1`0500L71`00QPL008D700<01`L00PL00`071`071`0300L7008700<01`L0
Q0L008D700<01`L00`L00`071`051`0300L700<700<01`L0Q0L008D700<01`L010L00`071`031`03
00L700@700<01`L0Q0L006<70P0<1`804PL00`071`051`0500L71`001`L00`071`0@1`8030L206@7
001T1`0300L700/700<01`L040L00`071`061`0300L000P700<01`L04@L00`071`0;1`0300L70687
001P1`l01PL200`70`091`0300L700L70`0<1`801PL?0647001P1`8030L300D700<01`L02`L20003
1`0000H700<01`L010L200041`0700d700<01`L00PL300`70P1Q1`00H0L200`700<01`0050L01007
1`061`0300L700D700<01`005@L200d700<01`L0G`L0060700<01`L02`L00`071`0D1`0300L700L7
00<01`L01`L00`071`0D1`0300L700/700<01`L0G`L005H700<01`L01`L00`071`0;1`0300L700L7
3P091`0300L700L73P091`0300L700/700<01`L01`L00`071`1E1`00DPL200041`0000P700<01`L0
2`L00`071`061`0400L000870P071`0300L700H700<01`L01PL00`071`051`800PL200031`0700L7
00<01`L02`L00`071`051`8000<700L00P1C1`00D`L200870P071`0300L700/700<01`L01@L01@07
1`L000<700<01`L01PL00`071`051`0300L700D700<01`L01`L00`071`02008700<01`L01@L00`07
1`0;1`0300L700D70P021`0300L005<7001C1`0300L700<700<01`L010L00`071`0;1`0300L700@7
00<01`L00`L00`071`0:1`0300L700@700<01`L010L00`071`0:1`0300L700<700<01`L010L00`07
1`0;1`0300L700@700<01`L00`L00`071`1B1`00DPL00`071`051`0300L700<700<01`L02`L00`07
1`031`0300L700D700<01`L02PL00`071`031`0300L700<700<01`L02PL00`071`051`0300L700<7
00<01`L02`L00`071`031`0300L700D700<01`L0D@L0058700<01`L01PL00`071`021`0300L700/7
00<01`L00PL00`071`061`0300L700802@L01@07000700<00PL00`071`071`800PL00`071`061`03
00L7008700<01`L02`L00`071`021`0300L700H700<01`L0D@L0054700<01`L020L01@071`L000d7
00D01`L7000:1`0400L700X700T01`0700L01`002`L00`07000:1`0500L71`003@L01@071`L000X7
00<01`L0D0L0050700<01`L02PL010071`0=1`0400L700`70`0;1`8000<700000P0;1`<030L01007
1`0=1`0400L700`700<01`L0C`L004l700<01`L030L00`07000=1`0300L000h70P0<1`0500L01`00
3@L00`071`0<1`0300L000d700<01`003PL00`071`1>1`00CPL00`071`0>1`803@L2010700<01`L0
2`L300d700<01`L03PL200d70P0@1`0300L704d7001=1`0300L701073`0B1ad04PL?018700<01`L0
C0L004P70P041`0300L700h70`0;1`0400L000l700<01`L010L200D700<01`001@L200H700<01`L0
3@L200031`0700X70`0@1`0300L700870P191`00?PL200T700<01`L00P000`L01`0=1`0400L700X7
00D01`L7000>1`0300L700H700<01`L00PL01@071`L000D700<01`L01@L00`071`0<1`800PL00`07
1`091`0300L000h700@01`000`L00`071`061`80?`L003l700<01`L02`L010071`0<1`0300L700/7
00<01`L00`L00`071`0:1`0300L700/700<01`L00`L00`071`0;1`0300L700X700<01`L00`L00`07
1`0;1`0300L700X700D01`L7000=1`0300L703d7001A1`0300L700L70P0<1`801`L00`071`081`03
00L700X70P071`0300L700/700<01`L01`L200L700<01`L02`L00`071`081`0300L70507000k1`80
2PL200T700<01`L01@L00`071`051`8010L00`071`021`8010L200L700<01`L02PL200T70P0<1`03
00L700D700<01`L00PL200@70P041`801PL200L700<01`L01`L200X70P0l1`00?0L00`071`091`03
00L700P700<01`L00`L00`071`071`0500L71`001PL00`071`041`0300L700<700<01`L02PL00`07
000:1`8030L00`071`031`0300L700@700<01`L010L00`071`021`0300L700H700<01`L00`L00`07
1`091`0300L700T700<01`L0>PL005@700D01`L7000=1`0300L700`70P031`0300L700H70P021`03
00L700d700<01`L00P081`0400L71`803PL00`071`0;1`0500L71`00E@L005D700<01`002`L300/7
0P031`8000<700L02@L00`07000A1`0400L700T700D01`0700021`802`L300/700<01`00EPL003D7
00<01`L04@LL00d700<01`L00`L>01<73P061`0300L700X7700C1`0300L703@7000e1`804@L200`7
00<01`L02`L201470P0<1`804@L200`70P0A1`803@L00`071`0:1`804@L203H7000e1`0300L000l7
0`0;1`803@L00`07000?1`0300L000`700<01`003`L00`07000<1`0300L000l700<01`0030L200`7
0`0?1`0300L003H7000e1`0400L700d700@01`L030L00`071`0;1`0400L700d700@01`L030L01007
1`0=1`0400L700`700@01`L03@L010071`0=1`0300L700X70P000`L01`0<1`0400L703H7000e1`05
00L71`002`L01@071`L000`700<01`L00P091`0300L700802`L01@071`L000`700D01`L7000;1`05
00L71`0030L01@071`L000/70P021`0300L700H70P031`0300L700X700D01`L7000;1`0500L71`00
=PL003D700<01`L00PL00`071`0200D70`021`0300L700X700D01`L700091`800PL200031`0000H7
00<01`L00PL00`071`0:1`0300L700870P061`<010L00`071`0:1`0300L7008700<01`L00`L20087
00@01`070P091`0500L71`0030L00`071`0300D70P021`0300L7008700<01`L0=0L003D700<01`L0
0`L010071`041`0400L7008700<01`L02PL00`071`0;1`8010L00`0700051`0300L700<700<01`L0
2PL00`071`031`0300L700D700<01`L00`L00`071`0:1`0300L700<700<01`L00`L00`0700051`03
00L700/700<01`L02PL01`071`L01`001@L00`0700051`0300L703@7000e1`0300L700@700<01`L0
0`L00`071`041`0300L700X700<01`L02`L00`071`041`0300L700<700<01`L010L00`071`0:1`03
00L700@700<01`L00`L00`071`041`0300L700X700<01`L010L00`071`031`0300L700@700<01`L0
2`L00`071`0:1`0300L700@700<01`L00`L00`071`041`0300L703@7000e1`0300L700D700D01`L7
00071`0300L700X700<01`L02`L00`071`051`0500L71`001`L00`071`0:1`0300L700D700D01`L7
00071`0300L700X700<01`L01@L01@071`L000L700<01`L02`L00`071`0:1`0300L700D700D01`L7
00071`0300L703@7000e1`0300L700<70P0010L01`061`<030L00`071`0200L70`021`8010L300P7
00<01`L02PL010071`L200<700<01`000`L200<700<01`L02PL00`071`061`<010L200870`061`80
0`L00`071`0:1`<01PL0100700L200D700<01`L0=0L003D700<01`L010L010071`081`8030L01@07
1`L000P70P031`0300L700<700<01`L01`L00`071`0:1`0300L7008700<01`L00PL00`071`031`05
00L71`0030L00`071`071`0300L700@700H01`L01`071`0500L71`0030L00`0700071`0500L71`00
1@L00`071`0d1`00=@L00`071`071`0300L700H70P0;1`803@L00`071`071`0300L700L700<01`L0
2PL00`071`071`0300L700L700<01`L02PL00`071`071`0300L700L700<01`L02PL200`70P081`03
00L700L700<01`L0=0L003D700<01`L01`L00`071`071`0300L700X700<01`L02`L00`071`071`03
00L700L700<01`L02PL00`071`071`0300L700L700<01`L02PL00`071`071`0300L700L700<01`L0
2`L00`071`0:1`8020L00`071`071`0300L703@7000e1`0300L700L700<01`L01`L00`071`0:1`03
00L700/700<01`L01`L00`071`071`0300L700X700<01`L01`L00`071`071`0300L700X700<01`L0
1`L00`071`071`0300L700/700<01`L02PL00`071`071`0300L700L700<01`L0=0L002L73`091`03
00L700L770091`0300L700801@L>00T700<01`L01`L>00D70P021`0300L700L770091`0300L700L7
3`0X1`00:0L00`071`0;1`0300L700H700<01`L01PL00`071`0:1`0300L000`70P081`0500L71`00
0PL300031`0700P70P000`L01`071`0300L700H700@01`002@L00`07000200<700@01`L020L00`07
000;1`0300L000`700<01`L01PL00`071`061`0300L700/700<01`L09`L002T700<01`L02`L00`07
1`051`0300L700D700<01`L02PL01@071`L000d700<01`L01@L00`071`051`0500L71`002@L01007
1`071`0300L700D700D01`L700081`0400L71`801PL00`071`051`0300L700/700D01`L7000<1`03
00L700D700<01`L01@L00`071`0;1`0300L702P7000Z1`0300L700/700<01`L010L00`071`041`03
00L700X700<01`L00`L00`071`0;1`0300L700@700<01`L010L00`071`031`0300L700X700<01`L0
10L00`071`041`0300L700X700<01`L00`L00`071`041`0300L700@700<01`L02`L00`071`031`03
00L700X700<01`L010L00`071`041`0300L700/700<01`L0:@L002/700<01`L02`L00`071`031`03
00L700<700<01`L02PL00`071`051`0300L700/700<01`L00`L00`071`031`0300L700D700<01`L0
2PL00`071`031`0300L700<700<01`L02PL00`071`051`0300L700<700<01`L00`L00`071`0;1`03
00L700D700<01`L02PL00`071`031`0300L700<700<01`L02`L00`071`0Z1`00;0L00`071`0;1`03
00L700<010L300/700<01`L01PL00`071`061`800`L01P07000700@700<01`L01PL00`071`0;1`80
0`L00`071`0300d700<01`L01PL00`071`021`<00PL010071`L200P700<01`L01PL00`071`091`<0
10L3008700<01`L02`L00`071`0[1`008`L200P700<01`L00P091`0300L700800`L010071`051`80
0`L00`071`081`0300L700H700<01`L00PL01@0700L000<700<01`L020L00`071`0;1`0500L71`00
0`L00`071`0;1`0300L700P700T01`L700L01`001@L00`071`051`0300L700P700@01`L70P061`03
00L000<70`000`L01`081`800PL00`071`061`8090L002@700<01`L01`L010071`0:1`0400L70087
00<01`L020L010071`0<1`0300L700/700@01`L00PL00`071`0:1`0300L700/700@01`L00PL00`07
1`0;1`0300L700X700@01`L00PL00`071`0;1`0300L700X700D01`L700091`0300L7008000<700L0
2PL00`07000:1`0300L70287000/1`8000<700L02@L200061`0700L03@L00`071`0<1`0300L700/7
00D01`07000>1`0300L700/700D01`07000=1`0300L700`700D01`07000=1`0300L700`700<01`L0
2`L01P0700L01`802PL01007000]1`007`L200`700@01`L02PL200041`0000D70P061`0300L700h7
00<01`L00P091`<040L00`071`061`800`L300<70P081`0300L700h70`091`800PL00`071`0>1`03
00L700@70P051`<000@700002@L01@071`L000X70P0Q1`0080L00`071`0>1ad04PL?01877@0B1`l0
4PLM010700<01`L07`L0030700<01`L02`L200d70P0@1`803@L200l70P0;1`H030L200l70P0=1`80
40L200d70P0=1`0300L702l7000_1`0300L700/700<01`003@L00`07000>1`0300L000d700<01`00
3PL200`700D01`07000=1`0300L700`700<01`003@L00`07000>1`0300L000d700<01`003@L00`07
1`0^1`00;PL00`071`0;1`0400L700d700@01`L030L010071`0=1`0400L700`70`0;1`8000<70000
0P0;1`<030L010071`0=1`0400L700`700@01`L03@L010071`0=1`0300L702d7000]1`0300L700/7
00D01`L7000=1`0500L71`002PL01@071`L000d700D01`L7000:1`0400L700X700T01`0700L01`00
2`L00`07000:1`0500L71`003@L01@071`L000X700D01`L7000=1`0500L71`003@L00`071`0/1`00
;0L00`071`0;1`0300L7008700<01`L02`L01@071`L000T700<01`L00PL00`071`0;1`0300L70087
00<01`L01`L00`071`0:1`0300L7008700<01`L00PL00`071`0:1`0300L700L700<01`L00PL00`07
1`0;1`0300L7008700<01`L01`L01@071`L000d700<01`L00PL00`071`0;1`0300L702/7000[1`<0
2`L300<700<01`L02`L00`071`021`0300L700D700<01`L00`L00`071`0;1`0300L700<700<01`L0
1@L00`071`0:1`0300L700<700<01`L00`L00`071`0:1`0300L700D700<01`L00`L00`071`0;1`03
00L700<700<01`L01@L00`071`021`0300L700/700@01`L70`0;1`<0;0L002X700@01`L02PL01007
1`021`8030L200D700<01`L00`L00`071`041`0300L700/700<01`L010L00`071`031`0300L700X7
00<01`L010L00`071`041`0300L700X700<01`L00`L00`071`041`0300L700/700<01`L010L00`07
1`031`0300L700<70P0<1`800`L00`07000;1`0300L002/7000S1`8010L00`071`041`801@L00`07
1`051`0300L700/700<01`L010L01@071`L000L700<01`L02`L00`071`051`0500L71`0030L00`07
1`051`0300L700D700<01`L02PL01@071`L000L700<01`L02`L00`071`051`0500L71`001PL200`7
0P061`0300L700<70P061`0300L700870P0T1`007PL200@700@01`L70`061`800`L00`071`061`03
00L700/700<01`L00P031`0300L000801PL00`071`0;1`0300L700H70`051`801@L00`071`061`03
00L700H700<01`L00`L200D70`081`0300L700/700<01`L00`L200041`0700<70P021`0300L700/7
00<01`L01PL00`071`0200031`0700@70`041`0300L7008080L001l700<01`L01@L?00T700<01`L0
2`L01@071`L000@700@01`L01PL00`071`0;1`0300L700L73P091`0300L700L73`081`0300L700/7
00<01`L010L010071`051`0400L700d700<01`L01`L?00L700<01`L07PL002L700<01`L02`L00`07
1`071`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L00`071`0:1`0300L700L7
00<01`L01`L00`071`0:1`0300L700L700<01`L02`L00`071`071`0300L700H700<01`L02`L00`07
1`071`0300L700/700<01`L09PL002L700<01`L02`L00`071`071`0300L700/700<01`L01PL00`07
1`071`0300L700/700<01`L010L200031`0700T70`091`0300L700L70`0:1`0400L000H700<01`L0
2`L00`071`071`0300L700H700<01`L02`L00`071`071`0300L700/700<01`L09PL001l70P061`03
00L700/700<01`L00`L2008700<01`L010L200D700<01`L01PL00`071`071`0400L000T70P071`03
00L000/70P031`8010L00`071`021`800`L00`07000:1`0400L700H70P091`8000<700L020L00`07
1`061`0300L700<70P061`0300L700801@L00`071`0;1`0300L700<70P0Q1`007PL00`0700061`03
00L700/700<01`L010L00`071`0?00P700<01`L01`L?00870P051`0300L700X700<01`L00PL00`07
1`021`0300L700<700D01`L7000<1`0300L700<70P021`l02@L00`071`061`l00`L00`071`031`03
00L700/700<01`L010L00`07000O1`007@L00`0700071`0300L700/700<01`L01PL00`07000=1`03
00L700D700<01`L01PL00`071`021`0300L700H700<01`000PL00`071`031`0300L700X700<01`L0
1PL00`0700081`0300L700X700<01`L010L01@0700L000T700D01`L700081`0300L700D700<01`L0
2`L00`0700081`0300L700/700<01`L01@L00`07000N1`0070L01@071`L000H700<01`L02`L00`07
1`051`0500L71`003@L00`071`041`0300L700D700<01`L02`L01@071`L000L700<01`L02PL00`07
1`051`0500L71`001`L00`071`0:1`0300L700D700D01`L7000=1`0300L700D700<01`L010L00`07
1`0;1`0500L71`001`L00`071`0;1`0300L700@700D01`L7000M1`006`L00`071`031`0300L700<7
00<01`L02`L00`071`041`0300L700<700<01`L00`L200H700<01`L00PL200H700<01`L02`L00`07
1`031`0300L700@700<01`L02PL00`071`041`0300L700<700<01`L010L00`071`0:1`0300L700@7
00<01`L00`L00`071`0;1`0300L700<70P051`0300L700@70P051`0300L700<700<01`L010L00`07
1`0;1`0300L700<700<01`L00`L00`071`0J1`006@L200L700<01`L00PL00`071`0;1`0300L70087
0P071`0300L700<700<01`L01@L00`071`021`0300L700870P0<1`801`L00`071`031`0300L700X7
00<01`L00PL200L700<01`L00`L00`071`0:1`0300L700870P071`0300L700/700<01`L00`L00`07
1`021`0300L700H700@01`L70P071`0300L700<700<01`L02`L00`071`021`0300L700D700<01`L0
6@L001D70P000`L01`091`0500L71`003@L01@071`L000X70P0<1`0500L71`000PL200`70P0:1`80
0`L00`071`0:1`0500L71`002PL200<700<01`L02PL01@071`L000X70`0;1`800`L01@071`L000`7
00<01`L020L200<700<01`L02`L01@071`L000T70P000`L0000F1`005PL200`700@01`L03@L01007
1`0=1`0300L700X700@01`L00PL200`70P0<1`0400L700`700@01`L03@L010071`0<1`0400L700d7
00<01`L02PL2008700@01`L030L00`071`0;1`0400L700d700@01`L030L00`07000F1`005PL00`07
1`0<1`0300L000d700<01`003`L00`071`0:1`0500L01`003@L00`071`0=1`0300L000`700<01`00
3`L00`07000<1`0300L000l700<01`L02`L01@0700L000`700<01`L03@L00`07000=1`0300L000h7
00<01`L05@L001D700<01`L03PL200d70P0A1`0300L700X70`0=1`0300L700l70P0<1`804@L200`7
0P0A1`0300L700/70`0<1`0300L700l70P0=1`8040L00`071`0D1`0050L00`071`0@1`l04`LL0187
3`0C1`l04PLL01<73`0B1`0300L701<7000E1`803`L2008700<01`L01@L00`071`02014700<01`L0
1PL010071`L300031`0000X700@01`003PL300H700<01`L00`L00`071`0?1`0300L700@700<01`L0
0`L300h70P000`L01`081`<000@7000010L00`071`051`0300L700l70P021`0300L700H700@01`00
3`L201H7000F1`0300L700`700<01`003@L00`07000?1`0300L700X700L01`0700L000/700<01`00
3@L01@0700L000`700<01`L03@L00`071`0:1`0500L01`003PL200/700L01`0700L000`700<01`L0
3@L00`07000=1`0300L000h70P0F1`005`L00`071`0:1`0400L700d700@01`L03@L0100700091`04
00L0008700<01`L02`L00`071`0;1`0400L7008700<01`L02PL00`071`0;1`0300L700X700@01`L0
0PL00`071`0;1`0300L700/700@01`000PL00`071`071`8000<700L030L010071`0=1`0400L700`7
00<01`L05PL001P700<01`L020L01@071`L000<70P031`800`L01@071`L000/700D01`L700081`80
0PL300031`0700`700<01`L02@L010071`L200870`0:1`0300L700T700<01`L01`L200031`0700<0
0`L00`071`091`0300L700/700<01`000P021`802@L010071`0;1`0500L71`000`L200<70P031`05
00L71`002PL00`071`0G1`006@L00`071`071`0500L71`0010L00`071`021`0500L71`0010L00`07
1`071`0300L700/70P021`0300L0008700<01`L02`L00`071`071`0300L700870P021`0300L000/7
00<01`L01`L00`071`091`0300L000870P041`0300L700L700<01`L02`L010071`L200<700<01`L0
2`L00`071`071`0300L7008700<01`L00PL00`071`021`0500L71`000`L00`071`071`0300L701P7
000J1`0300L700D700<01`L00PL00`071`0;1`0300L700<700<01`L01@L00`071`0;1`0300L70087
00<01`L00`L00`071`041`801@L00`071`041`801@L00`071`021`0300L700/700<01`L01@L00`07
1`0;1`0300L7008700<01`L00`L200H700<01`L00`L200H700<01`L00`L00`071`021`0300L700/7
00<01`L01@L00`071`031`0300L700/700<01`L00PL00`071`051`0300L701T7000K1`0300L700<7
00<01`L00`L00`071`0;1`0300L700@700<01`L00`L00`071`0;1`0300L700<700<01`L010L00`07
1`041`0300L700@700<01`L00`L200870P000`L01`041`0300L700870P071`0300L700<700<01`L0
1@L200@700<01`L00`L0100700031`0300L700<700<01`L01@L00`071`031`0300L700@700<01`L0
0`L00`071`0;1`0300L700<700<01`L010L00`071`0;1`0300L700<700<01`L00`L00`071`0J1`00
70L01@071`L000H700<01`L02`L00`071`051`0500L71`003@L00`071`041`0300L700D700<01`L0
2`L01@071`L000D700<01`001PL00`071`021`0300L700H700D01`L700091`0500L71`001PL01007
1`041`0500L71`003@L00`071`051`0300L700@700<01`L02`L01@071`L000L700<01`L02`L00`07
1`041`0500L71`007@L001d700<01`001`L00`071`0;1`0300L700H700<01`003@L00`071`051`03
00L700H700<01`L02`L00`0700081`0300L700D700<01`L02`L00`07000=1`0300L700D700<01`L0
1PL00`07000=1`0300L700H700<01`L01@L00`071`0;1`0300L000P700<01`L02`L00`071`051`03
00L001h7000@1a001`L00`071`0;1`0300L700L73`081`0300L700L73`091`0300L700H77@081`03
00L700L73`091`0300L700H73`091`0300L700/700<01`L010LA0147000@1`0300L000/70P071`03
00L700/700<01`L01`L00`071`0;1`0300L700H700<01`L01`L00`071`0;1`0300L700L700<01`L0
1PL00`071`0;1`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L00`071`061`03
00L700/700<01`L01`L00`071`0;1`0300L700D70P0<1`804@L0010700<01`L02`L00`071`021`80
0PL00`071`061`800`L00`071`061`8030L200P700<01`L01`L00`071`0;1`0300L700L700<01`L0
1PL00`071`0;1`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L00`071`061`80
30L200P700@01`L70P081`0300L7008010L00`071`0;1`0300L700l7000>1`<03@L00`071`031`04
00L000T700<01`L00P091`0300L700/70P071`0300L700870P031`0300L700/700<01`L00`L20087
00<01`L01PL300/700<01`L02@L300P700<01`L00P051`0300L700/700<01`L00P051`0300L700D7
0`0<1`801`L200@700<01`L01PL2008700<01`L00PL00`071`0;1`<03`L000l70P0=1`0300L700H7
3`041`800`L00`071`0;1`801`L00`071`031`0500L71`003@L00`071`041`0400L700P700<01`00
2`L00`071`0:1`8020L01@071`L000D700<01`L02`L01@071`L000D700<01`L01PL00`071`0;1`04
00L71`8010L@00L700<01`L02`L00`07000?1`0040L00`071`0;1`0300L700D700<01`0010L00`07
1`061`0300L7008700D01`L7000=1`0300L700D700<01`0020L00`071`0;1`0300L700H700<01`00
1`L00`071`0;1`0300L700/700<01`L01@L00`0700081`0300L700/700<01`L01PL00`0700071`03
00L700/700<01`L00PL01@071`L000T700L01`L700L000L700<01`L02`L00`071`0?1`0040L00`07
1`0;1`0300L700@700D01`L7000=1`0300L700D700<01`L02`L00`071`041`0500L71`001`L00`07
1`0;1`0300L700D700D01`L700061`0300L700/700<01`L02`L00`071`041`0500L71`001`L00`07
1`0;1`0300L700D700D01`L700061`0300L700/700<01`L01@L00`071`0;1`0500L71`001PL00`07
1`0;1`0300L700l7000@1`0300L700/700<01`L00`L00`071`031`<00`L200H700<01`L010L00`07
1`0;1`0300L700870P031`<01PL00`071`0;1`0300L700@700<01`L00P000`L01`0500X70P0010L0
000;1`@00PL300<700<01`L010L00`071`0;1`0300L700@70`031`8010L00`071`0;1`0300L700@7
00<01`L010L200<70`051`0300L700<700<01`L02`L00`071`0?1`0040L00`071`0;1`0300L70087
00<01`L01@L200@700<01`L01@L00`071`031`0300L700/700<01`L00PL200@700<01`001@L00`07
1`0;1`0300L700<700<01`L00PL01`071`0700L00P0;1`0500L01`002`L01P070007008700<01`L0
0PL00`071`031`0300L700/700<01`L00`L010071`041`0300L7008700<01`L02`L00`071`031`03
00L700H700<01`L00PL00`071`051`0300L7008700<01`L02`L00`071`0?1`0040L00`071`0;1`03
00L7008700<01`L01PL00`071`0;1`0300L7008700<01`L02`L00`071`021`0300L700H700<01`L0
0PL00`071`0;1`0300L7008700<01`L01PL00`071`0300X70P0010L0000;1`<00PL00`071`061`03
00L7008700<01`L02`L00`071`021`0300L700H700<01`L00PL00`071`0;1`0300L7008700<01`L0
2`L00`071`061`0300L7008700<01`L02`L00`071`0?1`0040L00`071`0;1`0500L71`002PL00`07
1`0;1`0500L71`003@L01@071`L000X700D01`L7000=1`0500L71`002PL00`071`0200/700D01`07
000;1`0500L01`002PL01@071`L000d700D01`L7000:1`0500L71`003@L01@071`L000d700<01`L0
20L01@071`L000d700<01`L03`L0010700<01`L02`L010071`0<1`0300L700/700@01`L03@L01007
1`0<1`0400L700d700@01`L030L010071`0=1`0300L700/700@01`L030L010071`0=1`0400L700`7
00@01`L03@L010071`0=1`0300L700X700@01`L03@L00`071`0?1`0040L00`071`0;1`0300L000/7
0P000`L01`091`8000@700L03@L00`07000>1`0300L000d700<01`003PL00`07000=1`0300L700/7
00<01`003PL00`07000=1`0300L000h700<01`003@L0100700L200X700@01`002`L00`07000=1`03
00L700l7000@1`0300L700/70P0=1`0400L700X700<01`L00P0<1`<040L200d70P0@1`803@L00`07
1`0;1`8040L200d70P0@1`<030L200<700<01`L01`L01@071`L000`70P0=1`0300L700l7000@1`l0
10L200/77P0B1`l04PLM01873`0B1ah02`L200@73`0A1`004@L200X70`041`0300L700T70P0<1`03
00L000d700<01`L03PL00`071`0;1`0300L0010700<01`L02`L00`07000=1`0300L700h700<01`00
3@L00`071`0>1`0300L700/700<01`003@L00`071`0:1`0300L7008000<700L02@L20187000B1`03
00L700L700<01`L00P0>1`0300L700/700D01`L7000=1`0300L700`700<01`L02`L01@071`L000h7
00<01`L02`L01@071`L000d700<01`L030L01@071`L000d700<01`L030L00`071`0;1`0500L71`00
3@L00`071`0<1`800PL00`071`081`0300L70107000>1`802`L00`071`031`0300L700870P061`03
00L700<70P061`0300L700<700<01`L020L200031`0700T70`0=1`0300L700<700<01`L00P081`04
00L71`8020L00`071`031`0300L700H70P031`0300L700H70P021`0300L700<700<01`L02`L200/7
00@01`002PL00`071`031`0300L700<70P061`0300L700@70P041`0300L700<700<01`L02@L200l7
000?1`0300L700P700<01`L01@L00`071`021`0300L700<700<01`L01@L00`071`031`0300L700D7
00<01`L020L010071`0:1`0300L700/700<01`L01@L00`071`0200H700<01`L00`L200H700<01`L0
1@L00`071`041`<010L00`071`041`<000<700L01PL00`071`0;1`0300L700P700D01`L700091`03
00L700D700<01`L00`L00`071`051`0300L700@700D01`L700071`0300L700T700<01`L03@L001T7
00<01`L01PL00`071`071`0300L700/700<01`L01`L00`071`0:1`0300L700L700<01`L02`L00`07
1`071`0400L700H700<01`L010L00`071`031`0300L700L700<01`L010L00`071`031`0300L700D7
00<01`002@L00`071`0;1`0300L700L700<01`L02PL00`071`071`0300L700/700<01`L01`L00`07
1`061`0300L701P7000H1`0300L700P700<01`L01@L00`071`0;1`0300L700T700<01`L02PL00`07
1`051`0300L700H70P031`0300L700H70P000`L01`061`0300L700X700<01`L02@L00`071`0:1`03
00L700D700@01`0020L010071`L200P700<01`L01@L00`071`0:1`0300L700T700<01`L02`L00`07
1`051`0300L700P700<01`L05`L000l70P061`0300L700X70P041`0300L700T70`0=1`0300L70087
0P061`0300L700<700@01`L70P051`0400L700X70P000`L01`041`0300L700H70P021`0300L700/7
00<01`L00P081`0300L700<700<01`000P091`0500L71`0010L200<700<01`L00`L00`071`041`80
10L00`071`0;1`<02`L010071`L300`700<01`L00`L20147000@1`0300L700<700<01`L030L01@07
1`L000d700<01`L03@L00`071`021`0300L700D700D01`L700051`0300L700D700<01`L02PL01007
1`031`0300L700P700<01`003`L010071`091`0500L71`000`L00`071`091`0300L700H700<01`L0
0PL01@071`L000P700D01`L7000?1`8030L01@071`L000h700<01`L00`L00`071`0?1`005@L00`07
1`0>1`0300L000d700<01`L03`L200/70`0=1`0300L700l700<01`0030L00`071`0?1`0300L700X7
00<01`004@L00`071`0;1`<02`L2014700<01`L02`L00`07000@1`0300L701@7000D1`0300L70107
3`0C1a`04`L>01<73P0C1ad04PL?018700<01`L04`L000L70P0;1`<03`L200d70P0A1`8030L20003
1`0000X700@01`003PL200`70P0A1`8030L200h70P000`L01`081`800PL200`70P0A1`803@L200l7
0`0;1`8020L000P700<01`L02@L00`07000>1`0300L000d700<01`003`L00`07000<1`0500L01`00
2`L00`07000=1`0300L000`700<01`003`L00`07000<1`0300L000h70P0;1`0500L01`0030L00`07
000?1`0300L000d700<01`003PL300`700<01`L01PL001@700@01`L030L010071`0=1`0400L700d7
00@01`L030L010071`0=1`0300L700/700@01`L030L010071`0=1`0400L700`700@01`L03@L00`07
1`0;1`0400L700`700@01`L03@L010071`0=1`0400L700`700@01`L05@L001@700D01`L7000:1`05
00L71`003@L01@071`L000X70P031`0300L700X700D01`L7000=1`0300L700P70P031`0300L700X7
00D01`L7000:1`800`L00`071`0:1`0500L71`002PL200`70P031`0300L700X700D01`L7000:1`80
0`L00`071`0;1`0500L71`002@L200<700<01`L04`L000L70P0;1`<00PL200L700<01`L00PL00`07
1`0;1`0300L700870P071`0300L700<700<01`L02PL00`071`021`8030L200L700<01`L00`L00`07
1`0:1`0300L700870P071`0300L700<700<01`L02PL00`071`021`801`L00`071`0;1`0300L700<7
00<01`L02PL00`071`021`801`L00`071`031`0300L700/700<01`L00PL00`071`051`0400L71`<0
2`L200P700081`0300L700T700<01`0010L00`071`031`0300L700<700<01`L02`L00`071`041`03
00L700<700<01`L010L00`071`0:1`0300L700800PL00`071`071`800PL00`071`031`0300L700@7
00<01`L02PL00`071`041`0300L700<700<01`L010L00`071`0:1`0300L700@700<01`L00`L00`07
1`0200T700@01`000`L00`071`0:1`0300L700@700<01`L00`L00`071`041`0300L700/700<01`L0
0`L00`071`031`0300L700<70P0<1`0300L700H7000D1`0300L7008710031`0300L700@700<01`L0
2`L00`071`051`0300L700@010L200/70P031`0500L71`0020L3008700D01`L700071`0300L700X7
00<01`L01@L500L700<01`L02PL00`071`051`0600L71`0710081`0500L71`000PL200`70P041`@0
0PL00`071`051`0300L700/700<01`L010L010071`L400@700<01`L04`L001@700<01`L00`L01P07
000700L700<01`L02`L00`071`061`0600L000L01@L00`071`0:1`0300L700H700<01`L01PL200<7
00<01`0020L00`071`0:1`0300L700H70`081`0300L700X700<01`L01PL00`0700031`0300L000L7
00<01`L01PL00`071`0:1`801@L01@0700L000P700<01`L02`L00`071`051`0700L01`0700041`03
00L701<7000D1`0300L700L700<01`L01PL00`071`0;1`0300L700L700<01`L01`L00`071`0:1`03
00L700L73`091`0300L700X700<01`L01`L00`071`071`0300L700X700<01`L01`L?00T700<01`L0
2PL00`071`071`0300L700L700<01`L02`L00`071`061`0300L700L700<01`L04`L001@700<01`L0
1`L00`071`061`0300L700/700<01`L01`L00`071`071`0300L700X700<01`L01`L00`071`0200T7
00<01`L00P051`0300L700X700<01`L01`L00`071`071`0300L700X700<01`L00`L2008700<01`L0
1`L2008700<01`L01`L00`071`0:1`0300L700L700<01`L01`L00`071`0;1`0300L700H700<01`L0
1`L00`071`0C1`003`L200<700<01`L01`L00`071`031`8000<700L030L300L700<01`L01`L01007
00091`0300L700@70P000`L01`021`0300L700L700@01`L70P041`0300L700T70P091`0300L700L7
0P0;1`0300L700870`021`0300L700P700D01`L01`0200H700<01`L01`L200031`0700P700<01`L0
1@L300d70`061`0300L700L700<01`L00P0A1`0040L01@071`L000T700<01`L010L00`07000=1`03
00L000L700<01`L01`L010071`091`0300L700D700<01`003@L00`071`021`0600L000L02PL300T7
00<01`L01`L300X700@01`000PL01@071`L000d700@01`L01PL00`071`081`0300L000T700<01`L0
1PL200d700<01`001PL00`071`071`0500L71`004@L000H73`091`0300L700H73`091`0300L700L7
3P091`0300L700/700<01`L01@L00`07000=00T700<01`L01`L>008700<01`L010L00`071`0;1`03
00L700L73P091`0300L700L73`081`0300L700L73`071`001`L00`071`0;1`0300L700H700<01`L0
1@L00`07000=1`0300L700H700<01`L01PL00`071`0:1`0300L000P700<01`L02`L00`071`061`03
00L000`700<01`L01PL00`071`061`0300L700X700<01`0020L00`071`0;1`0300L700H700<01`00
30L00`071`061`0300L700H700<01`L02`L00`0700071`0300L700H700<01`L02`L00`071`061`00
20L00`071`061`800`L00`071`051`801@L01@071`L000d700<01`L01@L00`071`051`0300L700X7
00D01`L700071`0300L700/700<01`L01@L01@071`L000`700<01`L01@L00`071`051`0300L700X7
00D01`L700071`0300L700/700<01`L01@L01@071`L000`700<01`L01@L00`071`051`0300L700/7
00D01`L700041`<01`L010071`L200P700<01`L01`L000T700<01`L01PL00`071`021`0300L700@7
0P041`0300L700<700<01`L02`L00`071`041`0300L700@700<01`L02PL00`071`031`0300L700@7
00<01`L02`L00`071`041`0300L700<700<01`L02PL00`071`041`0300L700@700<01`L02PL00`07
1`031`0300L700@700<01`L02`L00`071`041`0300L700<700<01`L02PL00`071`041`0300L700@7
00<01`L02`L00`071`031`0300L700870P061`0300L700<700<01`L01@L00`071`081`002PL00`07
1`0;1`0300L700<700<01`L00PL200H700<01`L00PL200L700<01`L00PL200D700<01`L010L200@7
00<01`L01@L00`071`031`0300L700/700<01`L00`L00`071`051`0300L700X700<01`L00`L00`07
1`031`0300L700X700<01`L01@L00`071`031`0300L700/700<01`L00`L00`071`051`0300L70087
0P061`0300L700<70P041`0300L700D70P041`0300L700@70P041`0300L700<700<01`L02`L00`07
1`091`002`L00`071`0;1`0300L7008700<01`L00PL200L700<01`L00PL00`071`061`0300L70087
00<01`L00PL00`071`061`0300L7008700<01`L01PL00`071`021`0300L700/700<01`L00PL00`07
1`061`0300L700/700<01`L00PL00`071`021`0300L700/700<01`L01PL00`071`021`0300L700/7
00<01`L00PL00`071`061`0300L700<700<01`L01@L00`071`021`800`L00`071`071`0500L71`00
20L00`071`021`0300L7008700<01`L02`L00`071`0:1`0030L00`071`0;1`0500L71`000`L00`07
1`071`8030L200<700D01`L7000=1`0300L700P700D01`L7000=1`0500L71`002PL00`071`0;1`05
00L71`000`L00`071`0;1`0300L700P700D01`L7000=1`0500L71`002PL00`071`0;1`0500L71`00
0`L200`70P091`0500L71`000`L00`071`0;1`0300L700/7000=1`0300L700/700@01`L00PL00`07
1`091`8030L2008700@01`L03@L00`071`0:1`0400L700d700@01`L030L00`071`0;1`0400L70087
00<01`L02`L00`071`0:1`0400L700d700@01`L030L00`071`0;1`0400L7008700<01`002`L00`07
000:1`0400L7008700<01`L02`L00`071`0<1`003PL00`071`081`@000@700L03PL00`071`0;1`03
00L000@02`L00`071`0<1`0300L000H70`041`0300L000h700<01`L02`L500d700<01`L030L00`07
00031`@01PL00`07000>1`0300L700T71@000`L01`0<1`0300L700`700@01`07100:1`0300L700d7
000?1`0300L700P700<01`000`0@1`0300L700/710000`L01`091`0300L700h70P071`8010L200l7
0P0;1`H030L200l70P041`0300L000H70P0@1`0300L700T700<01`000P0=1`0300L700h70`0010L0
1`091`0300L700h7000@1`l04PLM01873`0@1b4040L?01877@0B1`l04@L000l700<01`L02`L30107
00<01`L02`L300d700<01`L03PL200d70P0@1`0300L700X71@0<1`803`L200d70P0@1`0300L700/7
0`0=1`0300L700h70`0=1`0300L700h7000>1`0300L700P7100010L01`0>1`0300L700/700<01`00
100;1`0300L700`700<01`001PL300@700<01`003PL00`071`0;1`D03@L00`071`0<1`0300L000<7
10061`0300L000h700<01`L02@L500031`0700`700<01`L030L0100700L400X700<01`L03@L000d7
00<01`L02PL300051`071`0030L00`071`0;1`0500L700L00`0<1`0300L700X700@01`L01`L200@7
00@01`L030L00`071`0;1`0300L7008000<700L030L00`071`0:1`0400L700@700<01`001PL01007
1`0<1`0300L700/700@01`000PL00`071`0;1`0300L700X700@01`L00PL00`07000;1`0300L700`7
000<1`0300L700/700D01`L700031`0300L700L70P0<1`800`L01@071`L000d700<01`L020L01@07
1`L000d700D01`L7000:1`0300L700/700D01`L700031`0300L700/700<01`L020L01@071`L000d7
00D01`L7000:1`0300L700/700D01`L700031`8030L200T700D01`L700031`0300L700/700<01`L0
2`L000/700<01`L02`L00`071`021`0400L71`<01`L200870P081`800PL200@700<01`L01@L200<7
00<01`L01`L00`071`021`0300L700/700<01`L00PL00`071`071`0300L700X700<01`L00PL00`07
1`021`0300L700X700<01`L01`L00`071`021`0300L700/700<01`L00PL00`071`071`0400L71`80
1`L00`071`021`800`L00`071`061`800`L00`071`051`<00`L00`071`021`0300L700/700<01`L0
2PL000X700<01`L02`L00`071`031`0300L700870P061`0300L700<700<01`L01@L00`071`031`03
00L700<700<01`L01@L00`071`021`0300L700D700<01`L00`L00`071`0;1`0300L700<700<01`L0
1@L00`071`0:1`0300L700<700<01`L00`L00`071`0:1`0300L700D700<01`L00`L00`071`0;1`03
00L700<700<01`L01@L00`071`031`0300L700@700<01`L00`L200@700<01`L01PL00`071`021`03
00L700D700<01`L00PL00`071`031`0300L700/700<01`L02@L000T700<01`L01@L200@700<01`L0
10L200@700<01`L00`L00`071`0;1`0300L700@700<01`L010L00`071`0:1`0300L700<700<01`L0
10L00`071`0;1`0300L700@700<01`L00`L00`071`0:1`0300L700@700<01`L010L00`071`0:1`03
00L700<700<01`L010L00`071`0;1`0300L700@700<01`L00`L00`071`0:1`0300L700@700<01`L0
10L00`071`0;1`0300L700<700@01`L70`061`0300L700870P071`0300L700P700081`0300L700L7
00D01`L700071`801@L01@071`L000d700<01`L01@L00`071`051`0300L700X700D01`L700071`03
00L700/700<01`L01@L01@071`L000`700<01`L01@L00`071`051`0300L700X700D01`L700071`03
00L700/700<01`L01@L01@071`L000`700<01`L01@L00`071`051`0300L700/700D01`L700051`80
1`L00`071`021`0300L700H700<01`L01`L000L700<01`L02`L00`071`061`0300L700D700<01`00
3@L00`071`061`0300L700H700<01`L02PL00`0700081`0300L700/700<01`L01PL00`07000<1`03
00L700H700<01`L01PL00`071`0:1`0300L000P700<01`L02`L00`071`061`0300L000`700<01`L0
1PL00`071`061`0300L700/700<01`001`L00`071`061`0300L700/700<01`L01PL000H73`091`03
00L700H73`091`0300L700L73P091`0300L700/700<01`L010L200031`0000`02@L00`071`071`h0
00<700001PL00`071`0;1`0300L700L73P091`0300L700L73`081`0300L700L73`071`003`L200<7
00<01`L01`L00`071`031`8000<700L030L300L700<01`L01`L0100700091`0300L700@70P000`L0
1`0<1`0400L71`800PL00`07000;1`802@L00`071`071`<02PL01@071`0700800`L00`071`0;1`04
00L000H700<01`L01`L200031`0700P700<01`L01@L300d70`061`0300L700L700<01`L00P0A1`00
40L01@071`L000T700<01`L010L00`07000=1`0300L000L700<01`L01`L010071`091`0300L700D7
00<01`000PL200T700<01`L00`041`0300L700X700<01`L01`L00`071`071`802`L00`071`031`80
0PL00`071`071`800PL010071`061`0300L700P700<01`002@L00`071`061`803@L00`0700061`03
00L700L700D01`L7000A1`0050L00`071`071`0300L700H700<01`L02`L00`071`071`0300L700L7
00<01`L02PL00`071`071`0500L71`002@L01@071`L000D700<01`L02PL00`071`071`0300L700L7
00<01`L02PL00`071`041`0400L700X700@01`L02@L00`071`0:1`0300L700L700<01`L01`L00`07
1`0;1`0300L700H700<01`L01`L00`071`0C1`0050L00`071`071`0300L700H700<01`L02`L00`07
1`071`0300L700L700<01`L02PL00`071`071`l02@L00`071`0:1`0300L700L700<01`L01`L00`07
1`0:1`0300L700L73`091`0300L700X700<01`L01`L00`071`071`0300L700/700<01`L01PL00`07
1`071`0300L701<7000D1`0300L700871@000`L01`061`0300L700/700<01`L01PL00`07000300@7
0P0;1`8020L00`071`051`<00`L00`0700081`0300L700X700<01`L01PL300P700<01`L02PL00`07
1`061`0300L0008710071`0300L700D70P0<1`8010L400031`0700L700<01`L02`L00`071`051`03
00L000@010L00`071`0C1`0050L00`071`031`0300L000<700<01`L010L00`071`0;1`0300L700D7
00L01`L700L000D700<01`L02PL00`071`051`0300L700L70P021`0500L71`001`L00`071`0:1`03
00L700D700<01`000P071`0300L700X700<01`L01@L01@071`L0008700<01`0020L00`071`051`03
00L700X70P051`<00PL00`071`051`0300L700/700<01`L010L010071`L200031`0700<700<01`L0
4`L000L70P0;1`<010L00`071`031`0300L700<700<01`L02`L00`071`041`0300L700<700<01`L0
10L00`071`0:1`0300L700800PL00`071`071`800PL00`071`031`0300L700@700<01`L02PL00`07
1`041`0300L700<700<01`L010L00`071`0:1`0300L700@700<01`L00`L00`071`0200T700@01`00
0`L00`071`0:1`0300L700@700<01`L00`L00`071`041`0300L700/700<01`L00`L00`071`031`03
00L700870`0;1`8020L000P700<01`L02@L00`0700021`801`L00`071`021`0300L700/700<01`L0
0PL200L700<01`L00`L00`071`0:1`0400L71`<02`L300L700<01`L00`L00`071`0:1`0300L70087
0P071`0300L700<700<01`L02PL00`071`021`801`L010071`0:1`0300L000<700<01`L02PL00`07
1`021`801`L00`071`031`0300L700/700<01`L00PL00`071`051`0300L700870P0<1`0300L700H7
000D1`0500L71`002PL01@071`L000d700D01`L7000:1`800`L00`071`0:1`0500L71`003@L00`07
1`081`800`L00`071`0:1`0500L71`002PL200<700<01`L02PL01@071`L000X70P0<1`800`L00`07
1`0:1`0500L71`002PL200<700<01`L02`L01@071`L000T70P031`0300L701<7000D1`0400L700`7
00@01`L03@L010071`0=1`0400L700`700@01`L03@L00`071`0;1`0400L700`700@01`L03@L01007
1`0<1`0400L700d700<01`L02`L010071`0<1`0400L700d700@01`L03@L010071`0<1`0400L701D7
00071`802`L300h700<01`003@L00`07000?1`0300L000`700<01`003@L00`071`0=1`0300L000`7
00<01`003`L00`07000<1`0300L000l700<01`L02`L00`07000<1`0300L000l700<01`003@L00`07
000>1`<02`L200P700081`0300L700T70`0?1`803@L201470P0<1`8000<700002PL01007000>1`80
30L201470P0<1`803PL200031`0700P70P021`8030L201470P0=1`8040L200`700<01`L01PL001@7
00<01`L040L?01877@031`0300L700d73P0C1`h040L00`071`0M01873`0B1`0300L701<7000E1`03
00L700h700<01`003@L00`071`0?1`802`L300d700<01`L03`L00`07000<1`0300L700l700<01`L0
2PL00`07000A1`0300L700/70`0<1`0300L700l700<01`L02`L00`07000@1`0300L701@7000?1`80
1@L00`071`0;1`800`L00`071`0:1`803`L010071`L200L700D01`L700041`801`L00`071`091`80
0PL01@071`L000T70P000`L01`0>1`0400L000T700D01`L700021`802`L00`071`051`8010L01@07
1`L000L70P031`0300L700d70P0<1`0300L700803PL00`071`021`804@L0010700<01`L010L00`07
1`0:1`8010L00`071`0:1`803@L00`071`031`0300L700@700<01`L00`L00`071`021`0300L70087
0P021`0300L700L70`000`L01`041`0300L700L700@01`L03@L01@071`L000P700<01`L00`L00`07
1`0200T700<01`L00P051`0500L71`001@L00`071`051`0300L7008700<01`L02`L00`07000;1`03
00L700870P0<1`0300L700@700<01`L03`L001P700<01`L020L00`071`051`0300L700/700<01`L0
2@L00`071`0:1`0300L700D700<01`L01`L01@071`L000T700<01`001`L00`071`0:1`0300L700T7
00<01`L02PL00`071`051`0400L700P700<01`L00PL00`071`061`0300L700D700<01`L02PL00`07
1`091`0300L700/700<01`L01@L00`071`081`0300L701L7000I1`0300L700L700<01`L01PL00`07
1`0;1`0300L700L700<01`L02`L00`071`061`0300L700/700<01`L01`L0100700051`0300L700@7
0P051`0300L700L700<01`L00`L200H700<01`L00`L200031`0700P700<01`L02`L00`071`061`03
00L700/700<01`L01`L00`071`0;1`0300L700H700<01`L01`L00`071`0H1`003PL200X700<01`L0
1@L010071`L200D700<01`L010L200D700<01`L01@L00`071`071`800PL00`071`071`803@L00`07
1`051`0300L000801PL00`071`021`<01PL00`071`051`0300L700D70P041`0300L700D70P000`L0
1`061`0300L700X70P0:1`0300L700802@L00`071`051`0300L700870P071`0300L700<70P031`03
00L700D700<01`L020L200l7000?1`0300L700T700<01`L00`L00`071`031`0300L700@700<01`L0
10L00`071`041`0300L700<700<01`L02@L00`07000;1`803@L00`071`031`0500L71`0020L00`07
1`021`0300L700H700<01`L00`L00`071`071`0500L71`002@L010071`051`0300L700/70P0;1`04
00L700X700<01`L00`L00`071`041`0300L700@700<01`L01@L00`071`021`0300L700<700<01`L0
2PL00`071`0=1`004@L200T700<01`000P0>1`0300L700/700D01`L7000=1`0300L700`700<01`L0
2`L01@071`L000h700<01`L02`L01@071`L000d700<01`L030L01@071`L000d700<01`L030L00`07
1`0;1`0500L71`003@L00`071`0<1`800PL00`071`071`804PL0018700<01`L020L00`07000@1`03
00L700/700<01`003@L00`071`0>1`0300L700/700<01`0040L00`071`0;1`0300L000d700<01`L0
3PL00`07000=1`0300L700h700<01`L02`L00`07000=1`0300L700h700<01`002`L00`071`0@1`00
40L?00@70P0;1ah04PL?01877@0B1`l04PLN00/70P041`l04@L0010700<01`L02`L200@700<01`L0
2@L200`70P0=1`8040L200d70P0@1`803@L00`071`0;1`8040L200d70P0@1`<030L200d700<01`L0
2PL010071`L200d700<01`L03`L0010700<01`L02`L00`07000;1`8000<700L02@L200041`0700d7
00<01`003PL00`07000=1`0300L000h700<01`003@L00`071`0;1`0300L000h700<01`003@L00`07
000>1`0300L000d700@01`070P0:1`0400L000/700<01`003@L00`071`0?1`0040L00`071`0;1`04
00L700/70P0<1`800PL00`071`0;1`0400L700`700@01`L03@L010071`0<1`0400L700d700<01`L0
2`L010071`0<1`0400L700d700@01`L030L010071`0=1`0600L700L02`L00`07000:1`0400L700d7
00<01`L03`L0010700<01`L02`L01@071`L000X700<01`L02`L01@071`L000d700D01`L7000:1`05
00L71`003@L01@071`L000X700D01`L7000=1`0300L700/700D01`L7000:1`0500L71`003@L01@07
1`L000X700D01`L7000=1`0500L71`003@L00`071`081`0500L71`003@L00`071`0?1`0040L00`07
1`0;1`0500L71`002@L00`071`0;1`0300L7008700<01`L02`L01@071`L000T700<01`L00PL00`07
1`0;1`0300L7008700<01`L01`L00`07000200X70P0010L0000;1`<000<700L020L00`071`021`03
00L700/700<01`L00PL00`071`071`0500L71`003@L00`071`021`0300L700/700<01`L01`L01@07
1`L000d700<01`L03`L0010700<01`L02`L00`071`021`0300L700D70P031`801`L00`071`031`03
00L700/700<01`L00PL200<70P000`L01`041`0300L700/700<01`L00`L010071`L200871P0:1`80
00@700002`L400031`07008010L00`071`031`0300L700/700<01`L00`L0100700031`8010L00`07
1`0;1`0300L700<700<01`L01@L200<70P071`0300L7008700<01`L02`L00`071`0?1`0040L00`07
1`0;1`0300L700<700<01`L00`L00`0700041`0300L700@700<01`L010L00`071`0;1`0300L700<7
00<01`L00PL200H700<01`L02`L00`071`041`0700L71`0700021`0400L000/700D01`07000;1`04
00L0008700<01`000`L00`071`041`0300L700/700<01`L010L00`0700031`8010L00`071`0;1`03
00L700@700<01`L01@L00`071`021`801@L00`071`031`0300L700/700<01`L03`L0010700<01`L0
2`L00`071`041`0500L71`003@L00`071`051`0300L700/700<01`L010L01@071`L000L700<01`L0
2`L00`071`051`0500L71`001PL00`071`0;1`0300L700/700<01`L010L01@071`L000L700<01`L0
2`L00`071`051`0500L71`001PL00`071`0;1`0300L700D700<01`L02`L01@071`L000H700<01`L0
2`L00`071`0?1`0040L00`071`0;1`0300L700D700<01`000`L200P700@01`L70P031`0300L700/7
00<01`L01@L00`0700081`0300L700/700<01`L01PL00`0700071`0300L700/700<01`L02`L00`07
1`051`0300L000P700<01`L02`L00`071`061`0300L000L700<01`L02`L010071`L200<700<01`L0
1PL200<700<01`001`L00`071`0;1`0300L700l7000>1`<03@L00`071`051a001@L01@071`L000d7
0P071`0300L700870P031`0300L700/700<01`L00`L2008700<01`L01PL300/700<01`L02@L300P7
00<01`L00P051`0300L700/700<01`L00P051`0300L700D70P0=1`0300L7008700@01`L74@071`03
00L700/70`0?1`003`L200d700<01`L00PL2008700<01`L01PL200<700<01`L01PL200`70`071`03
00L700<700D01`L7000=1`0300L700@700@01`L020L00`07000;1`0300L700X70P081`0500L71`00
1@L00`071`0;1`0500L71`001@L00`071`061`8030L200P700@01`L70P081`8000<7000010L00`07
1`0;1`0300L000l7000@1`0300L700/700<01`L00`L010071`091`0500L71`002@L00`071`0;1`03
00L700H700<01`L01`L00`071`0;1`0300L700L700<01`L01PL00`071`0;1`0300L700/700<01`L0
1PL00`071`071`0300L700/700<01`L01`L00`071`061`8030L200P700<01`L00PL00`071`061`05
00L71`0010L00`071`0;1`0300L700l7000@1`<02`L200L700<01`L02`L00`071`071`0300L700/7
00<01`L01PL00`071`071`0300L700/700<01`L01`L00`071`061`0300L700/700<01`L02`L00`07
1`061`0300L700L700<01`L02`L00`071`071`0300L700H700<01`L02`L00`071`071`0300L700/7
00<01`L010L300/70`0A1`0040L@00L700<01`L02`L00`071`071`l020L00`071`071`l02@L00`07
1`061ad020L00`071`071`l02@L00`071`061`l02@L00`071`0;1`0300L700D7400A1`007@L00`07
00071`0300L700/700<01`L01PL00`07000=1`0300L700D700<01`L01PL00`071`0;1`0300L000P7
00<01`L01@L00`071`0;1`0300L000d700<01`L01@L00`071`061`0300L000d700<01`L01PL00`07
1`051`0300L700/700<01`0020L00`071`0;1`0300L700D700<01`007PL001`700D01`L700061`03
00L700/700<01`L01@L01@071`L000d700<01`L010L00`071`051`0300L700/700D01`L700041`80
00<700L01@L010071`L200P700D01`L700081`800`L00`071`041`0400L000@700D01`L7000=1`03
00L700D700<01`L010L00`071`0;1`0500L71`001`L00`071`0;1`0300L700@700D01`L7000M1`00
6`L00`071`031`0300L700<700<01`L02`L00`071`041`0300L700<700<01`L02`L00`071`031`03
00L700@700<01`L02`L00`071`031`0300L7008700<01`001@L00`071`031`0300L700D700<01`L0
0`L00`071`061`0300L7008700<01`L00`L010071`031`0300L700<700<01`L02`L00`071`041`03
00L700<700<01`L02`L00`071`031`0300L700@700<01`L02`L00`071`031`0300L700<700<01`L0
6PL001X700<01`L01@L00`071`021`0300L700/700<01`L00`L00`071`051`0300L700/700<01`L0
0PL00`071`031`0300L700@70P051`0300L700@70P051`0300L7008700<01`L02`L00`071`051`03
00L700/700<01`L00PL00`071`031`801PL00`071`031`801PL00`071`031`0300L7008700<01`L0
2`L00`071`051`0300L700<700<01`L02`L00`071`021`0300L700D700<01`L06@L001T700<01`L0
1PL00`071`021`0300L700/700<01`L00PL00`071`071`0300L700X700<01`L00PL00`071`021`03
00L700H700<01`L00PL00`071`061`8010L00`071`021`0300L700X700<01`L01`L00`071`0:1`03
00L7008700<01`L00PL00`0700071`0300L700<700<01`L01@L00`071`021`0300L7008700<01`L0
2PL00`071`071`0300L7008700<01`L02`L00`071`021`0300L700H700<01`L060L001P700<01`L0
20L01@071`L000<70P031`800`L01@071`L000/700<01`L02PL200870`000`L01`0<1`0300L700T7
00@01`L70P021`<02PL00`071`091`0300L700L70P000`L01`0300<700<01`L02@L00`071`0;1`03
00L000800PL200`700<01`L02@L01@071`L000<70P031`800`L01@071`L000X700<01`L05`L001L7
00<01`L02PL010071`041`0300L7008700D01`L700021`0300L700/700@01`002@L01@0700070080
3@L00`071`0;1`0300L7008000D700L700091`0300L700/700<01`L01`L01@071`0700800PL00`07
1`0;1`0300L700/700@01`000PL200P70P000`L01`0<1`0400L700@700<01`L00PL01@071`L00087
00<01`L02PL00`071`0F1`005PL00`071`0<1`0300L000d700<01`003`L00`07000:1`0400L01`<0
2`L300d700D01`07000<1`0300L700d700<01`L02PL01@0700L000d70`0:1`8000H700L01`0;1`80
3`L00`07000=1`0300L000h700<01`L05@L001D70P0?1`803@L2014700<01`L02PL3008700<01`L0
20L010071`0>1`<030L00`071`0?1`0300L700X70`0?1`0300L000X700<01`L00`0<1`0300L700l7
0P0=1`803`L201H7000D1`0300L001073`0C1a`04PL?01<73`0B1a`04`L?01470P0E1`005@L00`07
1`0>1`800PL00`071`051`0300L700804@L00`071`061`0400L71`<000<700L02PL00`071`0?1`80
1`L00`071`021`804@L200D700<01`L010L2014700<01`L02@L00`07000200@700<01`L01@L00`07
1`0?1`800PL00`071`061`0400L0010700<01`L050L001H700<01`L030L00`07000=1`0300L000l7
00<01`L02PL01@0700L000d700<01`L03@L00`07000<1`0300L000l700<01`0030L00`07000?1`03
00L700/700D01`07000<1`0300L700d700<01`003@L00`07000>1`0300L701D7000E1`<030L01007
1`0=1`0400L700d700<01`L02PL010071`021`8030L200`700@01`L030L010071`0=1`0400L700`7
00@01`L030L200/70`021`0400L700`700<01`L02`L010071`0=1`0400L700`70`0F1`005PL00`07
000:1`0500L71`003@L01@071`L000X70P0<1`0500L71`000`L00`071`0;1`0300L700P70P031`03
00L700X700D01`L7000:1`800`L00`071`0:1`0500L71`002PL300/70P031`0500L71`0030L00`07
1`081`800`L00`071`0;1`0500L71`002@L2008700<01`L050L001T70P071`0300L7008700<01`L0
2`L00`071`021`801`L00`071`021`801`L010071`L200@70P0<1`801`L00`071`031`0300L700X7
00<01`L00PL200L700<01`L00`L00`071`0:1`0300L700870P071`0300L700/700<01`L00PL200@7
00<01`L01@L200<70P071`0300L700<700<01`L02`L00`071`021`0300L700D700<01`L06@L001/7
00<01`L00`L00`071`031`0300L700/700<01`L010L00`071`031`0300L700@700<01`L010L00`07
1`031`0300L700@700<01`L02`L00`071`031`0300L700@700<01`L02PL00`071`041`0300L700<7
00<01`L010L00`071`0:1`0300L700@700<01`L00`L00`071`0;1`0300L700@700<01`L00`L00`07
1`051`0300L700<700<01`L00`L00`071`041`0300L700/700<01`L00`L00`071`031`0300L701X7
000L1`0500L71`001PL00`071`0;1`0300L700D700D01`L7000=1`0300L700@700<01`L01@L00`07
1`0;1`0500L71`001`L00`071`0:1`0300L700D700D01`L700071`0300L700X700<01`L01@L01@07
1`L000d700<01`L01@L00`071`041`0300L700/700D01`L700071`0300L700/700<01`L010L01@07
1`L001d7000M1`0300L000L700<01`L02`L00`071`061`0300L000d700<01`L01@L00`071`061`04
00L71`8020L0100700L200D700<01`L02PL00`071`061`0300L000P700<01`L02PL00`071`031`80
00@700L020L200<700<01`L01PL00`071`051`0300L700/700<01`0020L00`071`0;1`0300L700D7
00<01`007PL001h70`061`0300L700/700<01`L00`L200873`081`0300L700L73`031`0300L700<7
00<01`L02PL010071`L200@700<01`L00PL200<700<01`L02PL00`071`041`0300L700l02@L00`07
1`061`l00PL200D700<01`L02`L00`071`031`8000<700L07PL0020700<01`L010L00`071`0;1`03
00L700@700@01`L01`L00`071`031`0300L700H700<01`L01`L010071`0:1`0300L700@70P000`L0
1`091`<010L00`071`021`0300L700<700@01`L70`0:1`0400L000H70P0:1`0300L000T700<01`L0
1PL00`071`041`0300L700@700D01`L700051`0300L700/700<01`L010L00`071`0O1`009`L00`07
1`0;1`0300L700L700<01`L02`L00`071`061`0300L700L700<01`L02`L00`071`051`0300L000/7
0P091`0300L700L700<01`002PL010071`061`0300L700/700<01`L01`L00`071`061`0300L700/7
00<01`L01`L00`071`0;1`0300L702H7000W1`0300L700/700<01`L01`L00`071`0;1`0300L700H7
00<01`L01`L00`071`0;1`0300L700L700<01`L02PL00`071`071`0300L700L700<01`L02PL00`07
1`071`0300L700/700<01`L01`L00`071`061`0300L700/700<01`L01`L00`071`0;1`0300L702H7
000N1`801`L?00T700<01`L02`L00`071`0200@700@01`001PL00`071`0;1`0300L700H73`091`03
00L700L73`081`0300L700/700<01`L00`L2008700<01`L00PL2008700<01`L02`L00`071`071`l0
1PL20207000O1`0400L71`800`L00`0700051`<00`L00`071`061`0300L700/700D01`L700031`05
00L01`001PL00`071`0;1`0300L700H70`061`0300L700<700<01`L01PL00`071`061`0300L700@7
00<01`L00`L00`0700081`0300L700/700<01`L010L01@0700L000@700@01`L03@L00`071`061`04
00L71`<01PL200<70P031`0300L701h7000T1`0300L7008700<01`L01@L00`071`031`0300L700@7
0P0<1`801PL01@071`L000L700<01`L02`L00`071`051`0500L71`0030L00`071`051`0300L700D7
00<01`L02PL01@071`L000L700<01`L02`L00`071`051`0500L71`001PL200`70P061`0300L700@7
00<01`L010L00`071`031`0300L70287000Z1`0400L000X700@01`000`L00`071`0;1`0300L700<7
00<01`L00`L00`071`041`0300L700/700<01`L010L00`071`031`0300L700X700<01`L010L00`07
1`041`0300L700X700<01`L00`L00`071`041`0300L700/700<01`L010L00`071`031`0300L700<7
0P0<1`800PL200031`0700T70P000`L01`0Z1`00:`L00`07000;1`0300L000<700<01`L02`L00`07
1`021`0300L700D700<01`L00`L00`071`0;1`0300L700<700<01`L01@L00`071`0:1`0300L700<7
00<01`L00`L00`071`0:1`0300L700D700<01`L00`L00`071`0;1`0300L700<700<01`L01@L00`07
1`021`0300L700/700<01`L00PL200`70P0/1`00;0L00`071`0;1`0300L7008700<01`L02`L00`07
1`021`0300L700H700<01`L00PL00`071`0;1`0300L7008700<01`L01PL00`071`0;1`0300L70087
00<01`L00PL00`071`0;1`0300L700H700<01`L00PL00`071`0;1`0300L7008700<01`L01PL00`07
1`021`0300L700/700<01`L00PL00`071`0;1`0300L702/7000]1`0300L700/700D01`L7000=1`05
00L71`002PL01@071`L000d700D01`L7000:1`0400L000X70`001PL0000700X70P000`L01`091`05
00L71`003@L01@071`L000X700D01`L7000=1`0500L71`003@L00`071`0/1`00;PL00`071`0;1`04
00L700d700@01`L030L010071`0=1`0400L700`700<01`002`L200031`07008030L200`700@01`L0
3@L010071`0<1`0400L700d700@01`L03@L00`071`0]1`00;`L00`071`0;1`0300L000d700<01`00
3PL00`07000=1`0300L000h70P0;1`8000@7000030L200h700<01`003@L00`07000>1`0300L000d7
00<01`003@L00`071`0^1`00<0L00`071`0;1`803@L201070P0=1`8040L00`071`0:1`D030L200l7
0P0=1`8040L200d70P0=1`0300L702l7000O1`8040LM01873`0B1ad04PL?01877@0?1`808@L00207
00<01`L02@L2008700<01`L01`L300041`0000H700<01`L010L00`071`0>1`0500L71`002@L30107
00<01`L01`L010071`L300@700<01`L01PL00`071`0>1`<02PL010071`0@1`0300L700D700<01`L0
0`L300870P091`0300L700802`L00`071`0O1`00;@L00`07000;1`0700L01`07000=1`0300L700`7
00<01`L02`L01@0700L000h700<01`L02`L01@0700L000d700<01`L030L01@0700L000d700<01`L0
30L00`071`0;1`0500L01`000PL00`071`081`0400L702d7000S1`802@L01007000:1`0400L00087
00<01`L01`L2008700<01`L02PL00`071`0;1`0400L7008700<01`L02PL00`071`0;1`0400L70087
00<01`L02`L00`071`0:1`0400L7008700<01`L02`L00`071`0:1`0300L700802@L00`071`020003
1`0700T70P000`L01`081`8090L002@700<01`L01PL01@071`L000T700<01`000P031`0400L000H7
00D01`L7000:1`0300L700D70P041`<000<700L00PL00`071`081`0300L700X70P031`0300L70080
3@L00`071`081`0400L71`<000<700L00`L200L700<01`L020L00`071`021`0300L700<70P000`L0
1`021`<000<700L02@L010071`091`0300L70287000/1`0300L700/700@01`L70P041`0300L000X7
00<01`L01`L00`071`071`0500L71`000PL00`0700041`0300L700L700<01`L02PL200<700@01`L7
0P0<1`0300L700L700<01`L00PL00`0700021`0300L7008700<01`L01PL00`071`071`0300L700T7
0P041`0300L0008700<01`L02`L00`071`0[1`00:`L00`071`0;1`0300L700<700<01`L00`L00`07
1`0:1`0300L700D700<01`L02`L00`071`031`0300L700<700<01`L01@L00`071`0:1`0300L700<7
00<01`L00`L00`071`0:1`0300L700D700<01`L00`L00`071`031`0300L700/700<01`L01@L00`07
1`0:1`0300L700<700<01`L00`L00`071`0;1`0300L702X7000Z1`0300L700/700<01`L010L00`07
1`041`0300L700X700<01`L00`L00`071`0;1`0300L700@700<01`L010L00`071`031`0300L700X7
00<01`L010L00`071`041`0300L700X700<01`L00`L00`071`041`0300L700@700<01`L02`L00`07
1`031`0300L700X700<01`L010L00`071`041`0300L700/700<01`L0:@L002T700<01`L02`L00`07
1`051`0300L700D700<01`L02PL01@071`L000d700<01`L01@L00`071`041`800`L00`071`061`80
0PL00`071`051`0300L700D700<01`L00P081`0400L71`801PL00`071`051`0300L700/700D01`L7
000<1`0300L700D700<01`L01@L00`071`0;1`0300L702P7000X1`0300L700/700<01`L01PL00`07
1`061`0300L700X700<01`003@L00`071`061`0300L700D70P000`L01`091`0300L000P700<01`L0
1PL010071`091`0500L01`001PL00`071`061`0300L700/700<01`0030L00`071`061`0300L700H7
00<01`L02`L00`071`0W1`009`L?00T700<01`L01`LL00T700<01`L00P051`h02@L00`071`071`h0
1@L2008700<01`L01`LL00T700<01`L01`L?02P7000e1`0300L700L700<01`L01`L00`071`0:1`03
00L700/700<01`L01`L01@071`L000D700<01`L02PL00`071`071`0300L700L700<01`L02PL00`07
1`041`0400L700T70P0<1`0300L700X700<01`L01`L00`071`071`0300L703@7000e1`0300L700L7
00<01`L01`L00`071`0:1`0300L700/700<01`L01`L00`071`071`0300L700X700<01`L01`L00`07
1`071`0300L700X700<01`L01`L00`071`071`0300L700/700<01`L02PL00`071`071`0300L700L7
00<01`L0=0L003D700<01`L01`L00`071`061`802`L200d700<01`L01`L00`071`071`0300L700X7
00<01`L01`L00`071`071`0300L700X700<01`L01`L00`071`071`0300L700X70P0<1`8020L00`07
1`071`0300L703@7000e1`0300L700<70P021`0300L700D70`0<1`0300L700801`L300870P041`80
2@L00`071`0:1`0400L71`8010L00`071`021`800`L00`071`0:1`0300L700H70P051`800PL300H7
0P031`0300L700X70`071`0300L700801@L00`071`0d1`00=@L00`071`041`0500L01`001`L200`7
00D01`L700081`800`L00`071`021`<020L00`071`0:1`0300L7008700L01`L700L000@700D01`L7
000<1`0300L700H70`051`0600L700L01`L01@071`L000`700<01`001PL00`0700021`0300L700<7
00<01`L0=0L003D700<01`L01@L01@071`L000L700<01`L02PL00`071`0;1`0300L700D700D01`L7
00071`0300L700X700<01`L01@L01@071`L000L700<01`L02PL00`071`051`0500L71`001`L00`07
1`0;1`0300L700X700<01`L01@L01@071`L000L700<01`L0=0L003D700<01`L010L00`071`031`03
00L700@700<01`L02PL00`071`0;1`0300L700@700<01`L00`L00`071`041`0300L700X700<01`L0
10L00`071`031`0300L700@700<01`L02PL00`071`041`0300L700<700<01`L010L00`071`0;1`03
00L700X700<01`L010L00`071`031`0300L700@700<01`L0=0L003D700<01`L00`L0100700041`04
00L0008700<01`L02PL00`071`0;1`8010L300D700<01`L00`L00`071`0:1`0300L700870P061`80
1@L00`071`0:1`0300L700<700<01`L00PL200031`0700<70P0=1`0300L700X700<01`L00P000`L0
1`031`8000<700L010L00`071`0d1`00=@L00`071`021`0500L71`001@L00`0700021`0300L700X7
00<01`L00P091`8000@700000PL00`071`041`0300L7008700<01`L02PL00`071`021`801`L200@7
00<01`L02PL00`071`021`0300L700@700<01`L00`021`0300L700H70P031`0300L700X700@01`L7
0P061`0400L700@700<01`L0=0L003D700D01`L7000;1`0500L71`0030L01@071`L000T700D01`L7
000;1`0500L71`0030L01@071`L000/700D01`L7000<1`0500L71`002`L2008700<01`L01`L01@07
1`L000`700D01`L7000;1`0500L71`00=PL003D700@01`L03@L01007000;1`803@L010071`0=1`04
00L700`700@01`L03@L010071`0<1`0400L700d700@01`L030L200`70P000`L01`0<1`0400L703H7
000e1`0300L000l700<01`0030L00`071`0;1`0300L000l700<01`0030L00`07000?1`0300L000`7
00<01`003`L00`07000=1`0300L700X70`0?1`0300L003H7000e1`804@L200`700<01`L02`L20147
0P0<1`804@L200`70P0A1`803@L00`071`0:1`804@L203H7000e1`0300L70147700<1`801@L>01<7
3P051`8030LL01<700<01`L0=0L005D700<01`0030L200`700<01`L00PL00`07000<1`0300L700l7
00<01`L02PL00`0700051`0300L700T700<01`002`L00`07001F1`00E0L01@071`L000d700<01`L0
30L200<700<01`L01PL2008700<01`L03@L00`071`0200P700@01`L70P0>1`0300L700/700D01`L7
001E1`00>`L200X70P0:1`0300L700<700<01`L01PL200<700<01`L00`L200H70P041`0300L700H7
00@01`L70`091`<010L00`071`051`0300L700<700<01`L00`L200H700@01`L70P081`0300L700<7
00<01`L020L200X70P0l1`00?0L00`071`091`0300L700L700<01`L01@L00`071`061`0300L70087
00<01`L00`L00`071`021`801`L00`071`0:1`802@L200`700<01`L01@L00`071`031`0300L70087
0P051`0300L700@70P071`0300L700P700<01`L02@L00`071`0j1`00D@L00`071`071`8030L200L7
00<01`L020L00`071`0:1`801`L00`071`0;1`0300L700L70P071`0300L700/700<01`L020L00`07
1`1@1`00D0L00`071`0:1`0300L700/700<01`L00`L00`071`0:1`0300L700/700<01`L00`L00`07
1`0;1`0300L700X700<01`L00`L00`071`0;1`0300L700X700<01`L0C`L003h70P0<1`8000<700L0
3@L00`071`0;1`0500L71`003PL00`071`0;1`0500L71`003@L00`071`0<1`0500L71`003@L00`07
1`0<1`0400L000`70P0o1`00?`L00`071`061`800`L201070`0;1`0400L000l700<01`L010L200D7
00<01`001@L200H700<01`L03@L200031`0700X70`0@1`0300L000870P091`0300L703d700191`05
00L71`004PL?00031`0700l77@0A1a004PL00`071`021`0300L704L7001>1`0300L700h70P0=1`80
40L00`071`0;1`<03@L00`071`0>1`803@L2010700<01`L0C@L004l700<01`L030L00`07000=1`03
00L000h70P0;1`8000@7000030L200h700<01`003@L00`07000>1`0300L704h7001@1`0300L700X7
00@01`L03@L010071`0<1`0300L000/70P000`L01`0200`70P0<1`0400L700d700@01`L030L00`07
1`1?1`00D@L00`071`081`0500L71`003@L01@071`L000X700@01`002PL300061`0000L02PL20003
1`0700T700D01`L7000=1`0500L71`002PL00`071`1@1`00D@L00`071`071`0300L7008700<01`L0
2`L00`071`021`0300L700L700@01`L02@L020071`0700L00PL00`071`081`0300L000T700<01`L0
0PL00`071`0;1`0300L7008700<01`L01`L00`071`1@1`00DPL00`071`051`0300L700<700<01`L0
2`L00`071`031`0300L700D700<01`L02PL00`071`031`0300L700<700<01`L02PL00`071`051`03
00L700<700<01`L02`L00`071`031`0300L700D700<01`L0D@L005<700<01`L00`L00`071`041`03
00L700/700<01`L010L00`071`031`0300L700X700<01`L010L00`071`041`0300L700X700<01`L0
0`L00`071`041`0300L700/700<01`L010L00`071`031`0300L70587001B1`<000@700001`L00`07
1`0;1`0300L700D700<01`L00P021`8020L00`071`051`0300L700D700<01`L01PL200870P021`03
00L700D700<01`L02`L00`071`051`800PL305<7001C1`0500L01`0020L00`071`0;1`0300L700H7
00@01`000`L00`071`051`0300L700H700<01`L01PL00`071`061`0700L71`0700081`0300L700/7
00<01`L01PL00`0700021`0300L70547001F1`0300L700L700<01`L02`L00`071`071`h02@L00`07
1`071`h02@L00`071`0;1`0300L700L700<01`L0E@L0060700<01`L02`L00`071`0D1`0300L700L7
00<01`L01`L00`071`0D1`0300L700/700<01`L0G`L006070P0<1`<050L0100700061`0300L700@7
0P000`L01`0C1`<030L20647001P1`8030L00`07000D1`0400L700H700<01`L01@L00`07000E1`80
3@L00`071`1O1`00H0L?00H70P0<1`<02@L00`071`071`<030L200H73`1Q1`00H`L200`70P031`03
00L700/70P081`0300L000P700<01`003@L00`071`0200`70P1T1`00I0L00`071`0;1`0300L70107
00<01`L01@L01@071`L000L700<01`L04@L00`071`0;1`0300L7068700251`0300L700@700<01`L0
0`L00`071`041`0300L708@700251`0300L700<700<01`L01@L00`071`031`0300L708@700251`03
00L7008700<01`L01`L00`071`021`0300L708@700251`0500L71`002`L01@071`L008H700251`04
00L700d700@01`L0QPL007T70P021`801PL00`07000?1`0300L000H70P021`80NPL007X700D01`L7
00061`804@L200L700D01`L7001j1`00Q@L00`071`0A1`0300L708@7003o1b47003o1b47003o1b47
003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.4473, -10.4473, 0.0728037, \
0.0728037}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[octatiling, averageTypeII]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0478596 0.5 0.0478596 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .46616 m
.05765 .5 L
s
.02381 .46616 m
.07167 .46616 L
s
.02381 .53384 m
.05765 .5 L
s
.02381 .53384 m
.07167 .53384 L
s
.05765 .3366 m
.05765 .38446 L
s
.05765 .3366 m
.05765 .38446 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .38446 m
.05765 .3366 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .3366 m
.05765 .38446 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .3366 m
.10551 .3366 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .38446 m
.10551 .38446 L
s
.05765 .5 m
.10551 .5 L
s
.05765 .5 m
.10551 .5 L
s
.05765 .61554 m
.05765 .6634 L
s
.05765 .61554 m
.10551 .61554 L
s
.05765 .61554 m
.10551 .61554 L
s
.05765 .6634 m
.10551 .6634 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .26891 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .30276 m
.10551 .3366 L
s
.07167 .4183 m
.07167 .46616 L
s
.07167 .4183 m
.10551 .38446 L
s
.07167 .4183 m
.10551 .38446 L
s
.07167 .4183 m
.10551 .45214 L
s
.07167 .4183 m
.10551 .38446 L
s
.07167 .4183 m
.10551 .45214 L
s
.07167 .46616 m
.10551 .5 L
s
.07167 .46616 m
.10551 .5 L
s
.07167 .53384 m
.07167 .5817 L
s
.07167 .53384 m
.10551 .5 L
s
.07167 .53384 m
.10551 .5 L
s
.07167 .5817 m
.10551 .61554 L
s
.07167 .5817 m
.10551 .54786 L
s
.07167 .5817 m
.10551 .61554 L
s
.07167 .69724 m
.10551 .73109 L
s
.07167 .69724 m
.10551 .6634 L
s
.07167 .69724 m
.10551 .73109 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.10551 .3366 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .45214 m
.10551 .5 L
s
.10551 .45214 m
.10551 .5 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .5 m
.10551 .45214 L
s
.10551 .5 m
.10551 .54786 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .61554 m
.10551 .6634 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .73109 m
.13935 .69724 L
s
.10551 .73109 m
.13935 .69724 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .26891 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.10551 .38446 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .3366 m
.13935 .30276 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .35062 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .38446 m
.13935 .4183 L
s
.10551 .45214 m
.10551 .5 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .45214 m
.13935 .4183 L
s
.10551 .5 m
.10551 .54786 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .46616 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .5 m
.13935 .53384 L
s
.10551 .54786 m
.13935 .5817 L
s
.10551 .54786 m
.13935 .5817 L
s
.10551 .54786 m
.13935 .5817 L
s
.10551 .61554 m
.10551 .6634 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .5817 L
s
.10551 .61554 m
.13935 .64938 L
s
.10551 .6634 m
.13935 .69724 L
s
.10551 .6634 m
.13935 .69724 L
s
.10551 .73109 m
.13935 .69724 L
s
.10551 .73109 m
.13935 .69724 L
s
.13935 .18721 m
.17319 .22105 L
s
.13935 .18721 m
.18721 .18721 L
s
.13935 .2549 m
.13935 .30276 L
s
.13935 .2549 m
.13935 .30276 L
s
.13935 .2549 m
.17319 .22105 L
s
.13935 .2549 m
.18721 .2549 L
s
.13935 .30276 m
.13935 .35062 L
s
.13935 .30276 m
.13935 .35062 L
s
.13935 .30276 m
.18721 .30276 L
s
.13935 .35062 m
.13935 .30276 L
s
.13935 .35062 m
.17319 .38446 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .35062 m
.13935 .30276 L
s
.13935 .35062 m
.17319 .38446 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .35062 m
.18721 .35062 L
s
.13935 .4183 m
.13935 .46616 L
s
.13935 .4183 m
.13935 .46616 L
s
.13935 .4183 m
.17319 .38446 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .46616 m
.13935 .4183 L
s
.13935 .46616 m
.17319 .5 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.17319 .5 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .5817 m
.13935 .53384 L
s
.13935 .5817 m
.13935 .53384 L
s
.13935 .5817 m
.17319 .61554 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .64938 m
.13935 .69724 L
s
.13935 .64938 m
.13935 .69724 L
s
.13935 .64938 m
.17319 .61554 L
s
.13935 .64938 m
.18721 .64938 L
s
.13935 .69724 m
.13935 .7451 L
s
.13935 .69724 m
.13935 .64938 L
s
.13935 .69724 m
.18721 .69724 L
s
.13935 .7451 m
.13935 .69724 L
s
.13935 .7451 m
.17319 .77895 L
s
.13935 .7451 m
.18721 .7451 L
s
.13935 .81279 m
.17319 .77895 L
s
.13935 .81279 m
.18721 .81279 L
s
.13935 .46616 m
.13935 .4183 L
s
.13935 .46616 m
.17319 .5 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .46616 m
.18721 .46616 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.17319 .5 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .5817 m
.13935 .53384 L
s
.13935 .5817 m
.17319 .61554 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .30276 m
.18721 .30276 L
s
.13935 .4183 m
.17319 .38446 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .4183 m
.18721 .4183 L
s
.13935 .53384 m
.13935 .5817 L
s
.13935 .53384 m
.17319 .5 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .53384 m
.18721 .53384 L
s
.13935 .5817 m
.17319 .61554 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .5817 m
.18721 .5817 L
s
.13935 .64938 m
.13935 .69724 L
s
.13935 .64938 m
.17319 .61554 L
s
.13935 .64938 m
.18721 .64938 L
s
.13935 .69724 m
.18721 .69724 L
s
.17319 .22105 m
.22105 .22105 L
s
.17319 .38446 m
.22105 .38446 L
s
.17319 .38446 m
.22105 .38446 L
s
.17319 .5 m
.22105 .5 L
s
.17319 .61554 m
.22105 .61554 L
s
.17319 .77895 m
.22105 .77895 L
s
.18721 .13935 m
.18721 .18721 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .13935 m
.18721 .18721 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .13935 m
.22105 .17319 L
s
.18721 .18721 m
.22105 .22105 L
s
.18721 .2549 m
.18721 .30276 L
s
.18721 .2549 m
.22105 .22105 L
s
.18721 .30276 m
.18721 .35062 L
s
.18721 .30276 m
.18721 .35062 L
s
.18721 .30276 m
.22105 .26891 L
s
.18721 .30276 m
.22105 .3366 L
s
.18721 .30276 m
.22105 .3366 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .35062 m
.22105 .38446 L
s
.18721 .4183 m
.18721 .46616 L
s
.18721 .4183 m
.18721 .46616 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .45214 L
s
.18721 .46616 m
.18721 .4183 L
s
.18721 .46616 m
.22105 .5 L
s
.18721 .53384 m
.18721 .5817 L
s
.18721 .53384 m
.18721 .5817 L
s
.18721 .53384 m
.22105 .5 L
s
.18721 .5817 m
.18721 .53384 L
s
.18721 .5817 m
.22105 .54786 L
s
.18721 .5817 m
.22105 .61554 L
s
.18721 .64938 m
.18721 .69724 L
s
.18721 .64938 m
.22105 .61554 L
s
.18721 .69724 m
.18721 .7451 L
s
.18721 .69724 m
.22105 .6634 L
s
.18721 .69724 m
.22105 .73109 L
s
.18721 .7451 m
.22105 .77895 L
s
.18721 .81279 m
.18721 .86065 L
s
.18721 .81279 m
.22105 .77895 L
s
.18721 .86065 m
.22105 .82681 L
s
.18721 .4183 m
.18721 .46616 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .38446 L
s
.18721 .4183 m
.22105 .45214 L
s
.18721 .46616 m
.22105 .5 L
s
.18721 .53384 m
.18721 .5817 L
s
.18721 .53384 m
.22105 .5 L
s
.18721 .5817 m
.22105 .54786 L
s
.18721 .5817 m
.22105 .61554 L
s
.22105 .17319 m
.22105 .22105 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .17319 m
.22105 .22105 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .17319 m
.2549 .13935 L
s
.22105 .22105 m
.22105 .26891 L
s
.22105 .22105 m
.2549 .18721 L
s
.22105 .22105 m
.26891 .22105 L
s
.22105 .26891 m
.2549 .30276 L
s
.22105 .26891 m
.26891 .26891 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.2549 .30276 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.22105 .38446 L
s
.22105 .3366 m
.2549 .30276 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .3366 m
.26891 .3366 L
s
.22105 .38446 m
.2549 .4183 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .38446 m
.2549 .4183 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .38446 m
.26891 .38446 L
s
.22105 .45214 m
.22105 .5 L
s
.22105 .45214 m
.2549 .4183 L
s
.22105 .5 m
.22105 .54786 L
s
.22105 .5 m
.2549 .46616 L
s
.22105 .5 m
.2549 .53384 L
s
.22105 .5 m
.26891 .5 L
s
.22105 .54786 m
.2549 .5817 L
s
.22105 .61554 m
.22105 .6634 L
s
.22105 .61554 m
.2549 .5817 L
s
.22105 .61554 m
.26891 .61554 L
s
.22105 .6634 m
.2549 .69724 L
s
.22105 .6634 m
.26891 .6634 L
s
.22105 .73109 m
.22105 .77895 L
s
.22105 .73109 m
.2549 .69724 L
s
.22105 .73109 m
.26891 .73109 L
s
.22105 .77895 m
.22105 .82681 L
s
.22105 .77895 m
.2549 .81279 L
s
.22105 .77895 m
.26891 .77895 L
s
.22105 .82681 m
.2549 .86065 L
s
.2549 .13935 m
.2549 .18721 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .13935 m
.2549 .18721 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .13935 m
.30276 .13935 L
s
.2549 .18721 m
.30276 .18721 L
s
.2549 .30276 m
.30276 .30276 L
s
.2549 .4183 m
.2549 .46616 L
s
.2549 .4183 m
.30276 .4183 L
s
.2549 .46616 m
.30276 .46616 L
s
.2549 .53384 m
.2549 .5817 L
s
.2549 .53384 m
.30276 .53384 L
s
.2549 .5817 m
.30276 .5817 L
s
.2549 .69724 m
.30276 .69724 L
s
.2549 .81279 m
.2549 .86065 L
s
.2549 .81279 m
.30276 .81279 L
s
.2549 .86065 m
.30276 .86065 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .07167 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .10551 m
.30276 .13935 L
s
.26891 .22105 m
.26891 .26891 L
s
.26891 .22105 m
.30276 .18721 L
s
.26891 .22105 m
.30276 .2549 L
s
.26891 .26891 m
.30276 .30276 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.30276 .30276 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.26891 .38446 L
s
.26891 .3366 m
.30276 .30276 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .4183 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .35062 L
s
.26891 .38446 m
.30276 .4183 L
s
.26891 .5 m
.30276 .46616 L
s
.26891 .5 m
.30276 .53384 L
s
.26891 .61554 m
.26891 .6634 L
s
.26891 .61554 m
.30276 .5817 L
s
.26891 .61554 m
.30276 .64938 L
s
.26891 .6634 m
.30276 .69724 L
s
.26891 .73109 m
.26891 .77895 L
s
.26891 .73109 m
.30276 .69724 L
s
.26891 .77895 m
.30276 .7451 L
s
.26891 .77895 m
.30276 .81279 L
s
.26891 .89449 m
.30276 .86065 L
s
.26891 .89449 m
.30276 .92833 L
s
.26891 .89449 m
.30276 .92833 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .07167 m
.3366 .10551 L
s
.30276 .13935 m
.30276 .18721 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.30276 .18721 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.3366 .10551 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .13935 m
.35062 .13935 L
s
.30276 .18721 m
.3366 .22105 L
s
.30276 .18721 m
.3366 .22105 L
s
.30276 .18721 m
.35062 .18721 L
s
.30276 .18721 m
.35062 .18721 L
s
.30276 .2549 m
.30276 .30276 L
s
.30276 .2549 m
.3366 .22105 L
s
.30276 .2549 m
.3366 .22105 L
s
.30276 .30276 m
.30276 .35062 L
s
.30276 .30276 m
.30276 .35062 L
s
.30276 .30276 m
.3366 .26891 L
s
.30276 .30276 m
.3366 .3366 L
s
.30276 .30276 m
.3366 .3366 L
s
.30276 .30276 m
.35062 .30276 L
s
.30276 .30276 m
.35062 .30276 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .35062 m
.3366 .38446 L
s
.30276 .4183 m
.30276 .46616 L
s
.30276 .4183 m
.3366 .38446 L
s
.30276 .4183 m
.3366 .45214 L
s
.30276 .4183 m
.3366 .38446 L
s
.30276 .4183 m
.3366 .38446 L
s
.30276 .4183 m
.3366 .45214 L
s
.30276 .4183 m
.35062 .4183 L
s
.30276 .4183 m
.35062 .4183 L
s
.30276 .46616 m
.3366 .5 L
s
.30276 .46616 m
.3366 .5 L
s
.30276 .53384 m
.30276 .5817 L
s
.30276 .53384 m
.3366 .5 L
s
.30276 .53384 m
.3366 .5 L
s
.30276 .5817 m
.3366 .54786 L
s
.30276 .5817 m
.3366 .61554 L
s
.30276 .5817 m
.3366 .61554 L
s
.30276 .5817 m
.35062 .5817 L
s
.30276 .5817 m
.35062 .5817 L
s
.30276 .64938 m
.30276 .69724 L
s
.30276 .64938 m
.3366 .61554 L
s
.30276 .64938 m
.3366 .61554 L
s
.30276 .69724 m
.30276 .7451 L
s
.30276 .69724 m
.3366 .6634 L
s
.30276 .69724 m
.3366 .73109 L
s
.30276 .69724 m
.35062 .69724 L
s
.30276 .69724 m
.35062 .69724 L
s
.30276 .7451 m
.3366 .77895 L
s
.30276 .81279 m
.30276 .86065 L
s
.30276 .81279 m
.3366 .77895 L
s
.30276 .81279 m
.35062 .81279 L
s
.30276 .81279 m
.35062 .81279 L
s
.30276 .86065 m
.3366 .89449 L
s
.30276 .86065 m
.3366 .89449 L
s
.30276 .86065 m
.35062 .86065 L
s
.30276 .86065 m
.35062 .86065 L
s
.30276 .92833 m
.3366 .89449 L
s
.30276 .92833 m
.3366 .89449 L
s
.30276 .92833 m
.3366 .89449 L
s
.30276 .92833 m
.3366 .89449 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .10551 m
.3366 .05765 L
s
.3366 .10551 m
.38446 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.3366 .10551 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .05765 m
.38446 .05765 L
s
.3366 .10551 m
.38446 .10551 L
s
.3366 .22105 m
.3366 .26891 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .26891 m
.3366 .22105 L
s
.3366 .26891 m
.38446 .26891 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .38446 m
.3366 .3366 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .45214 m
.3366 .5 L
s
.3366 .45214 m
.3366 .5 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .5 m
.3366 .54786 L
s
.3366 .5 m
.3366 .45214 L
s
.3366 .5 m
.38446 .5 L
s
.3366 .54786 m
.3366 .5 L
s
.3366 .54786 m
.38446 .54786 L
s
.3366 .61554 m
.3366 .6634 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .6634 m
.3366 .61554 L
s
.3366 .6634 m
.38446 .6634 L
s
.3366 .89449 m
.3366 .94235 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .94235 m
.3366 .89449 L
s
.3366 .94235 m
.38446 .94235 L
s
.3366 .10551 m
.38446 .10551 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .22105 m
.38446 .22105 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.3366 .38446 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .3366 m
.38446 .3366 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .38446 m
.38446 .38446 L
s
.3366 .45214 m
.3366 .5 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .45214 m
.38446 .45214 L
s
.3366 .5 m
.38446 .5 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .61554 m
.38446 .61554 L
s
.3366 .73109 m
.3366 .77895 L
s
.3366 .73109 m
.38446 .73109 L
s
.3366 .73109 m
.38446 .73109 L
s
.3366 .77895 m
.38446 .77895 L
s
.3366 .77895 m
.38446 .77895 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.3366 .89449 m
.38446 .89449 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.38446 .10551 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.38446 .10551 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .18721 m
.35062 .13935 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .30276 m
.38446 .26891 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .5817 m
.38446 .54786 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .69724 m
.38446 .6634 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .81279 m
.35062 .86065 L
s
.35062 .81279 m
.35062 .86065 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .86065 m
.35062 .81279 L
s
.35062 .86065 m
.38446 .82681 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .13935 m
.35062 .18721 L
s
.35062 .13935 m
.38446 .10551 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .13935 m
.38446 .17319 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .18721 m
.38446 .22105 L
s
.35062 .30276 m
.38446 .26891 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .30276 m
.38446 .3366 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .38446 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .4183 m
.38446 .45214 L
s
.35062 .5817 m
.38446 .54786 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .5817 m
.38446 .61554 L
s
.35062 .69724 m
.38446 .6634 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .69724 m
.38446 .73109 L
s
.35062 .81279 m
.35062 .86065 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .81279 m
.38446 .77895 L
s
.35062 .86065 m
.38446 .82681 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.35062 .86065 m
.38446 .89449 L
s
.38446 .05765 m
.38446 .10551 L
s
.38446 .05765 m
.38446 .10551 L
s
.38446 .10551 m
.4183 .07167 L
s
.38446 .10551 m
.4183 .13935 L
s
.38446 .10551 m
.4183 .13935 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.38446 .22105 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .17319 m
.4183 .13935 L
s
.38446 .22105 m
.38446 .26891 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .2549 L
s
.38446 .26891 m
.38446 .22105 L
s
.38446 .26891 m
.4183 .30276 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.4183 .30276 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.38446 .38446 L
s
.38446 .3366 m
.4183 .30276 L
s
.38446 .38446 m
.38446 .3366 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .4183 L
s
.38446 .38446 m
.38446 .3366 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .35062 L
s
.38446 .38446 m
.4183 .4183 L
s
.38446 .45214 m
.38446 .5 L
s
.38446 .45214 m
.4183 .4183 L
s
.38446 .5 m
.38446 .54786 L
s
.38446 .5 m
.38446 .45214 L
s
.38446 .5 m
.4183 .46616 L
s
.38446 .5 m
.4183 .53384 L
s
.38446 .54786 m
.4183 .5817 L
s
.38446 .61554 m
.38446 .6634 L
s
.38446 .61554 m
.4183 .5817 L
s
.38446 .61554 m
.4183 .64938 L
s
.38446 .6634 m
.38446 .61554 L
s
.38446 .6634 m
.4183 .69724 L
s
.38446 .73109 m
.38446 .77895 L
s
.38446 .73109 m
.38446 .77895 L
s
.38446 .73109 m
.4183 .69724 L
s
.38446 .77895 m
.38446 .82681 L
s
.38446 .77895 m
.38446 .73109 L
s
.38446 .77895 m
.4183 .7451 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .82681 m
.38446 .77895 L
s
.38446 .82681 m
.4183 .86065 L
s
.38446 .82681 m
.4183 .86065 L
s
.38446 .89449 m
.38446 .94235 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.38446 .94235 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .94235 m
.38446 .89449 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .18721 L
s
.38446 .22105 m
.4183 .2549 L
s
.38446 .3366 m
.4183 .30276 L
s
.38446 .45214 m
.4183 .4183 L
s
.38446 .61554 m
.4183 .5817 L
s
.38446 .61554 m
.4183 .64938 L
s
.38446 .73109 m
.38446 .77895 L
s
.38446 .73109 m
.4183 .69724 L
s
.38446 .77895 m
.4183 .7451 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .77895 m
.4183 .81279 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .86065 L
s
.38446 .89449 m
.4183 .92833 L
s
.38446 .89449 m
.4183 .92833 L
s
.4183 .07167 m
.45214 .10551 L
s
.4183 .07167 m
.46616 .07167 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.45214 .10551 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.4183 .18721 L
s
.4183 .13935 m
.45214 .10551 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .13935 m
.46616 .13935 L
s
.4183 .18721 m
.45214 .22105 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .18721 m
.45214 .22105 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .18721 m
.46616 .18721 L
s
.4183 .2549 m
.4183 .30276 L
s
.4183 .2549 m
.45214 .22105 L
s
.4183 .2549 m
.46616 .2549 L
s
.4183 .30276 m
.4183 .35062 L
s
.4183 .30276 m
.4183 .35062 L
s
.4183 .30276 m
.45214 .3366 L
s
.4183 .30276 m
.45214 .3366 L
s
.4183 .30276 m
.46616 .30276 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .35062 m
.45214 .38446 L
s
.4183 .4183 m
.4183 .46616 L
s
.4183 .4183 m
.45214 .38446 L
s
.4183 .4183 m
.45214 .38446 L
s
.4183 .4183 m
.46616 .4183 L
s
.4183 .46616 m
.45214 .5 L
s
.4183 .46616 m
.46616 .46616 L
s
.4183 .53384 m
.4183 .5817 L
s
.4183 .53384 m
.45214 .5 L
s
.4183 .53384 m
.46616 .53384 L
s
.4183 .5817 m
.45214 .61554 L
s
.4183 .5817 m
.46616 .5817 L
s
.4183 .64938 m
.4183 .69724 L
s
.4183 .64938 m
.45214 .61554 L
s
.4183 .69724 m
.4183 .7451 L
s
.4183 .69724 m
.45214 .6634 L
s
.4183 .69724 m
.46616 .69724 L
s
.4183 .7451 m
.45214 .77895 L
s
.4183 .7451 m
.46616 .7451 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.45214 .77895 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.4183 .86065 L
s
.4183 .81279 m
.45214 .77895 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .81279 m
.46616 .81279 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.45214 .89449 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .86065 m
.46616 .86065 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.46616 .92833 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.45214 .89449 L
s
.4183 .92833 m
.46616 .92833 L
s
.45214 .10551 m
.5 .10551 L
s
.45214 .22105 m
.5 .22105 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.45214 .38446 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .3366 m
.5 .3366 L
s
.45214 .38446 m
.5 .38446 L
s
.45214 .38446 m
.5 .38446 L
s
.45214 .5 m
.5 .5 L
s
.45214 .61554 m
.45214 .6634 L
s
.45214 .61554 m
.5 .61554 L
s
.45214 .6634 m
.5 .6634 L
s
.45214 .77895 m
.5 .77895 L
s
.45214 .89449 m
.5 .89449 L
s
.45214 .89449 m
.5 .89449 L
s
.45214 .89449 m
.5 .89449 L
s
.45214 .89449 m
.5 .89449 L
s
.46616 .02381 m
.46616 .07167 L
s
.46616 .02381 m
.5 .05765 L
s
.46616 .07167 m
.5 .10551 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.5 .10551 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.5 .10551 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.46616 .18721 L
s
.46616 .13935 m
.5 .10551 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .13935 m
.5 .17319 L
s
.46616 .18721 m
.5 .22105 L
s
.46616 .18721 m
.5 .22105 L
s
.46616 .2549 m
.46616 .30276 L
s
.46616 .2549 m
.5 .22105 L
s
.46616 .30276 m
.5 .26891 L
s
.46616 .30276 m
.5 .3366 L
s
.46616 .30276 m
.5 .3366 L
s
.46616 .4183 m
.46616 .46616 L
s
.46616 .4183 m
.5 .38446 L
s
.46616 .4183 m
.5 .45214 L
s
.46616 .46616 m
.5 .5 L
s
.46616 .53384 m
.46616 .5817 L
s
.46616 .53384 m
.5 .5 L
s
.46616 .5817 m
.5 .54786 L
s
.46616 .5817 m
.5 .61554 L
s
.46616 .69724 m
.46616 .7451 L
s
.46616 .69724 m
.5 .6634 L
s
.46616 .69724 m
.5 .73109 L
s
.46616 .7451 m
.5 .77895 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.5 .77895 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.46616 .86065 L
s
.46616 .81279 m
.5 .77895 L
s
.46616 .86065 m
.5 .82681 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .86065 m
.5 .82681 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .86065 m
.5 .89449 L
s
.46616 .92833 m
.46616 .97619 L
s
.46616 .92833 m
.5 .89449 L
s
.46616 .92833 m
.5 .89449 L
s
.46616 .97619 m
.5 .94235 L
s
.5 .05765 m
.5 .10551 L
s
.5 .05765 m
.53384 .02381 L
s
.5 .10551 m
.53384 .07167 L
s
.5 .10551 m
.53384 .13935 L
s
.5 .10551 m
.53384 .13935 L
s
.5 .10551 m
.54786 .10551 L
s
.5 .17319 m
.5 .22105 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .17319 m
.5 .22105 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .17319 m
.53384 .13935 L
s
.5 .22105 m
.5 .26891 L
s
.5 .22105 m
.53384 .18721 L
s
.5 .22105 m
.53384 .2549 L
s
.5 .22105 m
.54786 .22105 L
s
.5 .26891 m
.53384 .30276 L
s
.5 .3366 m
.5 .38446 L
s
.5 .3366 m
.53384 .30276 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .3366 m
.5 .38446 L
s
.5 .3366 m
.53384 .30276 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .3366 m
.54786 .3366 L
s
.5 .38446 m
.53384 .4183 L
s
.5 .38446 m
.54786 .38446 L
s
.5 .38446 m
.54786 .38446 L
s
.5 .45214 m
.5 .5 L
s
.5 .45214 m
.53384 .4183 L
s
.5 .5 m
.5 .54786 L
s
.5 .5 m
.53384 .46616 L
s
.5 .5 m
.53384 .53384 L
s
.5 .5 m
.54786 .5 L
s
.5 .54786 m
.53384 .5817 L
s
.5 .61554 m
.5 .6634 L
s
.5 .61554 m
.53384 .5817 L
s
.5 .61554 m
.54786 .61554 L
s
.5 .6634 m
.53384 .69724 L
s
.5 .6634 m
.54786 .6634 L
s
.5 .73109 m
.5 .77895 L
s
.5 .73109 m
.53384 .69724 L
s
.5 .77895 m
.5 .82681 L
s
.5 .77895 m
.53384 .7451 L
s
.5 .77895 m
.53384 .81279 L
s
.5 .77895 m
.54786 .77895 L
s
.5 .82681 m
.53384 .86065 L
s
.5 .89449 m
.5 .94235 L
s
.5 .89449 m
.53384 .86065 L
s
.5 .89449 m
.53384 .92833 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .89449 m
.5 .94235 L
s
.5 .89449 m
.53384 .86065 L
s
.5 .89449 m
.53384 .92833 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .89449 m
.54786 .89449 L
s
.5 .94235 m
.53384 .97619 L
s
.53384 .02381 m
.53384 .07167 L
s
.53384 .07167 m
.5817 .07167 L
s
.53384 .13935 m
.53384 .18721 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.53384 .18721 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .13935 m
.5817 .13935 L
s
.53384 .18721 m
.5817 .18721 L
s
.53384 .18721 m
.5817 .18721 L
s
.53384 .2549 m
.53384 .30276 L
s
.53384 .2549 m
.5817 .2549 L
s
.53384 .30276 m
.5817 .30276 L
s
.53384 .4183 m
.53384 .46616 L
s
.53384 .4183 m
.5817 .4183 L
s
.53384 .46616 m
.5817 .46616 L
s
.53384 .53384 m
.53384 .5817 L
s
.53384 .53384 m
.5817 .53384 L
s
.53384 .5817 m
.5817 .5817 L
s
.53384 .69724 m
.53384 .7451 L
s
.53384 .69724 m
.5817 .69724 L
s
.53384 .7451 m
.5817 .7451 L
s
.53384 .81279 m
.53384 .86065 L
s
.53384 .81279 m
.5817 .81279 L
s
.53384 .86065 m
.5817 .86065 L
s
.53384 .92833 m
.53384 .97619 L
s
.53384 .92833 m
.5817 .92833 L
s
.53384 .92833 m
.5817 .92833 L
s
.54786 .10551 m
.5817 .07167 L
s
.54786 .10551 m
.5817 .13935 L
s
.54786 .10551 m
.5817 .13935 L
s
.54786 .10551 m
.5817 .13935 L
s
.54786 .22105 m
.5817 .18721 L
s
.54786 .22105 m
.5817 .18721 L
s
.54786 .22105 m
.5817 .2549 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.5817 .30276 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.54786 .38446 L
s
.54786 .3366 m
.5817 .30276 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .4183 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .35062 L
s
.54786 .38446 m
.5817 .4183 L
s
.54786 .5 m
.5817 .46616 L
s
.54786 .5 m
.5817 .53384 L
s
.54786 .61554 m
.54786 .6634 L
s
.54786 .61554 m
.5817 .5817 L
s
.54786 .61554 m
.5817 .64938 L
s
.54786 .6634 m
.5817 .69724 L
s
.54786 .77895 m
.5817 .7451 L
s
.54786 .77895 m
.5817 .81279 L
s
.54786 .89449 m
.5817 .86065 L
s
.54786 .89449 m
.5817 .92833 L
s
.54786 .89449 m
.5817 .92833 L
s
.54786 .89449 m
.5817 .86065 L
s
.54786 .89449 m
.5817 .92833 L
s
.54786 .89449 m
.5817 .92833 L
s
.5817 .07167 m
.61554 .10551 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.61554 .10551 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.61554 .10551 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.5817 .18721 L
s
.5817 .13935 m
.61554 .10551 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .13935 m
.61554 .17319 L
s
.5817 .18721 m
.61554 .22105 L
s
.5817 .18721 m
.61554 .22105 L
s
.5817 .2549 m
.5817 .30276 L
s
.5817 .2549 m
.61554 .22105 L
s
.5817 .30276 m
.5817 .35062 L
s
.5817 .30276 m
.5817 .35062 L
s
.5817 .30276 m
.61554 .26891 L
s
.5817 .30276 m
.61554 .3366 L
s
.5817 .30276 m
.61554 .3366 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .35062 m
.61554 .38446 L
s
.5817 .4183 m
.5817 .46616 L
s
.5817 .4183 m
.61554 .38446 L
s
.5817 .4183 m
.61554 .38446 L
s
.5817 .4183 m
.61554 .45214 L
s
.5817 .46616 m
.61554 .5 L
s
.5817 .53384 m
.5817 .5817 L
s
.5817 .53384 m
.61554 .5 L
s
.5817 .5817 m
.61554 .54786 L
s
.5817 .5817 m
.61554 .61554 L
s
.5817 .64938 m
.5817 .69724 L
s
.5817 .64938 m
.61554 .61554 L
s
.5817 .69724 m
.5817 .7451 L
s
.5817 .69724 m
.61554 .6634 L
s
.5817 .69724 m
.61554 .73109 L
s
.5817 .7451 m
.61554 .77895 L
s
.5817 .81279 m
.5817 .86065 L
s
.5817 .81279 m
.61554 .77895 L
s
.5817 .86065 m
.61554 .82681 L
s
.5817 .86065 m
.61554 .89449 L
s
.5817 .86065 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.5817 .92833 m
.61554 .89449 L
s
.61554 .05765 m
.61554 .10551 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .10551 m
.61554 .05765 L
s
.61554 .10551 m
.61554 .05765 L
s
.61554 .10551 m
.64938 .13935 L
s
.61554 .10551 m
.64938 .13935 L
s
.61554 .10551 m
.6634 .10551 L
s
.61554 .10551 m
.6634 .10551 L
s
.61554 .10551 m
.6634 .10551 L
s
.61554 .17319 m
.61554 .22105 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .17319 m
.61554 .22105 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .17319 m
.64938 .13935 L
s
.61554 .22105 m
.61554 .26891 L
s
.61554 .22105 m
.64938 .18721 L
s
.61554 .22105 m
.6634 .22105 L
s
.61554 .22105 m
.6634 .22105 L
s
.61554 .26891 m
.64938 .30276 L
s
.61554 .26891 m
.6634 .26891 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.64938 .30276 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.61554 .38446 L
s
.61554 .3366 m
.64938 .30276 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .3366 m
.6634 .3366 L
s
.61554 .38446 m
.64938 .4183 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.64938 .4183 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .38446 m
.6634 .38446 L
s
.61554 .45214 m
.61554 .5 L
s
.61554 .45214 m
.64938 .4183 L
s
.61554 .45214 m
.6634 .45214 L
s
.61554 .45214 m
.6634 .45214 L
s
.61554 .5 m
.61554 .54786 L
s
.61554 .5 m
.6634 .5 L
s
.61554 .5 m
.6634 .5 L
s
.61554 .54786 m
.64938 .5817 L
s
.61554 .54786 m
.6634 .54786 L
s
.61554 .61554 m
.61554 .6634 L
s
.61554 .61554 m
.64938 .5817 L
s
.61554 .61554 m
.6634 .61554 L
s
.61554 .61554 m
.6634 .61554 L
s
.61554 .6634 m
.64938 .69724 L
s
.61554 .6634 m
.6634 .6634 L
s
.61554 .73109 m
.61554 .77895 L
s
.61554 .73109 m
.64938 .69724 L
s
.61554 .73109 m
.6634 .73109 L
s
.61554 .73109 m
.6634 .73109 L
s
.61554 .77895 m
.61554 .82681 L
s
.61554 .77895 m
.64938 .81279 L
s
.61554 .77895 m
.6634 .77895 L
s
.61554 .77895 m
.6634 .77895 L
s
.61554 .82681 m
.64938 .86065 L
s
.61554 .89449 m
.61554 .94235 L
s
.61554 .89449 m
.64938 .86065 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .89449 m
.61554 .94235 L
s
.61554 .89449 m
.64938 .86065 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .89449 m
.6634 .89449 L
s
.61554 .94235 m
.6634 .94235 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.61554 .05765 m
.6634 .05765 L
s
.64938 .13935 m
.64938 .18721 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.64938 .18721 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .13935 m
.69724 .13935 L
s
.64938 .18721 m
.69724 .18721 L
s
.64938 .30276 m
.69724 .30276 L
s
.64938 .4183 m
.69724 .4183 L
s
.64938 .5817 m
.69724 .5817 L
s
.64938 .69724 m
.69724 .69724 L
s
.64938 .81279 m
.64938 .86065 L
s
.64938 .81279 m
.69724 .81279 L
s
.64938 .86065 m
.69724 .86065 L
s
.6634 .22105 m
.6634 .26891 L
s
.6634 .22105 m
.69724 .18721 L
s
.6634 .22105 m
.69724 .2549 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.69724 .30276 L
s
.6634 .38446 m
.6634 .3366 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .4183 L
s
.6634 .38446 m
.6634 .3366 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .4183 L
s
.6634 .45214 m
.6634 .5 L
s
.6634 .45214 m
.6634 .5 L
s
.6634 .45214 m
.69724 .4183 L
s
.6634 .5 m
.6634 .45214 L
s
.6634 .5 m
.6634 .54786 L
s
.6634 .5 m
.69724 .46616 L
s
.6634 .5 m
.69724 .53384 L
s
.6634 .61554 m
.6634 .6634 L
s
.6634 .61554 m
.69724 .5817 L
s
.6634 .61554 m
.69724 .64938 L
s
.6634 .73109 m
.6634 .77895 L
s
.6634 .73109 m
.6634 .77895 L
s
.6634 .73109 m
.69724 .69724 L
s
.6634 .77895 m
.6634 .73109 L
s
.6634 .77895 m
.69724 .7451 L
s
.6634 .77895 m
.69724 .81279 L
s
.6634 .89449 m
.6634 .94235 L
s
.6634 .89449 m
.69724 .86065 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .10551 m
.6634 .05765 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .22105 m
.6634 .26891 L
s
.6634 .22105 m
.69724 .18721 L
s
.6634 .22105 m
.69724 .2549 L
s
.6634 .26891 m
.69724 .30276 L
s
.6634 .3366 m
.6634 .38446 L
s
.6634 .3366 m
.69724 .30276 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .35062 L
s
.6634 .38446 m
.69724 .4183 L
s
.6634 .45214 m
.6634 .5 L
s
.6634 .45214 m
.69724 .4183 L
s
.6634 .5 m
.6634 .54786 L
s
.6634 .5 m
.69724 .46616 L
s
.6634 .5 m
.69724 .53384 L
s
.6634 .54786 m
.69724 .5817 L
s
.6634 .61554 m
.6634 .6634 L
s
.6634 .61554 m
.69724 .5817 L
s
.6634 .61554 m
.69724 .64938 L
s
.6634 .6634 m
.69724 .69724 L
s
.6634 .73109 m
.6634 .77895 L
s
.6634 .73109 m
.69724 .69724 L
s
.6634 .77895 m
.69724 .7451 L
s
.6634 .77895 m
.69724 .81279 L
s
.6634 .89449 m
.6634 .94235 L
s
.6634 .89449 m
.69724 .86065 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .89449 m
.69724 .92833 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .05765 m
.6634 .10551 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .13935 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .07167 L
s
.6634 .10551 m
.69724 .13935 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .13935 m
.69724 .18721 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.69724 .18721 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .18721 m
.69724 .13935 L
s
.69724 .18721 m
.73109 .22105 L
s
.69724 .18721 m
.7451 .18721 L
s
.69724 .2549 m
.69724 .30276 L
s
.69724 .2549 m
.73109 .22105 L
s
.69724 .30276 m
.69724 .35062 L
s
.69724 .30276 m
.69724 .35062 L
s
.69724 .30276 m
.73109 .26891 L
s
.69724 .30276 m
.73109 .3366 L
s
.69724 .30276 m
.7451 .30276 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .35062 m
.73109 .38446 L
s
.69724 .4183 m
.69724 .46616 L
s
.69724 .4183 m
.73109 .38446 L
s
.69724 .4183 m
.73109 .38446 L
s
.69724 .4183 m
.7451 .4183 L
s
.69724 .46616 m
.73109 .5 L
s
.69724 .46616 m
.7451 .46616 L
s
.69724 .53384 m
.69724 .5817 L
s
.69724 .53384 m
.73109 .5 L
s
.69724 .53384 m
.7451 .53384 L
s
.69724 .5817 m
.73109 .61554 L
s
.69724 .5817 m
.7451 .5817 L
s
.69724 .64938 m
.69724 .69724 L
s
.69724 .64938 m
.73109 .61554 L
s
.69724 .69724 m
.69724 .7451 L
s
.69724 .69724 m
.73109 .6634 L
s
.69724 .69724 m
.73109 .73109 L
s
.69724 .69724 m
.7451 .69724 L
s
.69724 .7451 m
.73109 .77895 L
s
.69724 .81279 m
.69724 .86065 L
s
.69724 .81279 m
.73109 .77895 L
s
.69724 .81279 m
.7451 .81279 L
s
.69724 .86065 m
.73109 .89449 L
s
.69724 .86065 m
.7451 .86065 L
s
.69724 .92833 m
.73109 .89449 L
s
.69724 .92833 m
.73109 .89449 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .07167 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.73109 .10551 L
s
.69724 .13935 m
.7451 .13935 L
s
.69724 .13935 m
.7451 .13935 L
s
.73109 .22105 m
.73109 .26891 L
s
.73109 .22105 m
.77895 .22105 L
s
.73109 .26891 m
.77895 .26891 L
s
.73109 .3366 m
.73109 .38446 L
s
.73109 .3366 m
.73109 .38446 L
s
.73109 .3366 m
.77895 .3366 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .38446 m
.77895 .38446 L
s
.73109 .5 m
.77895 .5 L
s
.73109 .61554 m
.73109 .6634 L
s
.73109 .61554 m
.77895 .61554 L
s
.73109 .6634 m
.77895 .6634 L
s
.73109 .73109 m
.73109 .77895 L
s
.73109 .73109 m
.77895 .73109 L
s
.73109 .77895 m
.77895 .77895 L
s
.7451 .13935 m
.7451 .18721 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .13935 m
.7451 .18721 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .13935 m
.77895 .17319 L
s
.7451 .18721 m
.77895 .22105 L
s
.7451 .30276 m
.77895 .26891 L
s
.7451 .30276 m
.77895 .3366 L
s
.7451 .4183 m
.7451 .46616 L
s
.7451 .4183 m
.77895 .38446 L
s
.7451 .4183 m
.77895 .38446 L
s
.7451 .4183 m
.77895 .45214 L
s
.7451 .46616 m
.77895 .5 L
s
.7451 .53384 m
.7451 .5817 L
s
.7451 .53384 m
.77895 .5 L
s
.7451 .5817 m
.77895 .54786 L
s
.7451 .5817 m
.77895 .61554 L
s
.7451 .69724 m
.77895 .6634 L
s
.7451 .69724 m
.77895 .73109 L
s
.7451 .81279 m
.7451 .86065 L
s
.7451 .81279 m
.77895 .77895 L
s
.7451 .86065 m
.77895 .82681 L
s
.77895 .17319 m
.77895 .22105 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .17319 m
.77895 .22105 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .17319 m
.81279 .13935 L
s
.77895 .22105 m
.77895 .26891 L
s
.77895 .22105 m
.81279 .18721 L
s
.77895 .22105 m
.81279 .2549 L
s
.77895 .22105 m
.82681 .22105 L
s
.77895 .26891 m
.81279 .30276 L
s
.77895 .3366 m
.77895 .38446 L
s
.77895 .3366 m
.77895 .38446 L
s
.77895 .3366 m
.81279 .30276 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.82681 .38446 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .35062 L
s
.77895 .38446 m
.81279 .4183 L
s
.77895 .38446 m
.82681 .38446 L
s
.77895 .45214 m
.77895 .5 L
s
.77895 .45214 m
.81279 .4183 L
s
.77895 .45214 m
.81279 .4183 L
s
.77895 .5 m
.77895 .54786 L
s
.77895 .5 m
.81279 .46616 L
s
.77895 .5 m
.81279 .53384 L
s
.77895 .5 m
.82681 .5 L
s
.77895 .54786 m
.81279 .5817 L
s
.77895 .61554 m
.77895 .6634 L
s
.77895 .61554 m
.81279 .5817 L
s
.77895 .61554 m
.81279 .64938 L
s
.77895 .61554 m
.82681 .61554 L
s
.77895 .6634 m
.81279 .69724 L
s
.77895 .73109 m
.77895 .77895 L
s
.77895 .73109 m
.81279 .69724 L
s
.77895 .77895 m
.77895 .82681 L
s
.77895 .77895 m
.81279 .7451 L
s
.77895 .77895 m
.81279 .81279 L
s
.77895 .77895 m
.82681 .77895 L
s
.77895 .82681 m
.81279 .86065 L
s
.81279 .4183 m
.81279 .46616 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .46616 m
.81279 .4183 L
s
.81279 .46616 m
.86065 .46616 L
s
.81279 .46616 m
.86065 .46616 L
s
.81279 .13935 m
.81279 .18721 L
s
.81279 .13935 m
.81279 .18721 L
s
.81279 .18721 m
.86065 .18721 L
s
.81279 .2549 m
.81279 .30276 L
s
.81279 .2549 m
.86065 .2549 L
s
.81279 .30276 m
.81279 .35062 L
s
.81279 .30276 m
.81279 .35062 L
s
.81279 .30276 m
.86065 .30276 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .35062 m
.86065 .35062 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .4183 m
.86065 .4183 L
s
.81279 .53384 m
.81279 .5817 L
s
.81279 .53384 m
.86065 .53384 L
s
.81279 .53384 m
.86065 .53384 L
s
.81279 .5817 m
.86065 .5817 L
s
.81279 .5817 m
.86065 .5817 L
s
.81279 .64938 m
.81279 .69724 L
s
.81279 .64938 m
.86065 .64938 L
s
.81279 .64938 m
.86065 .64938 L
s
.81279 .69724 m
.81279 .7451 L
s
.81279 .69724 m
.86065 .69724 L
s
.81279 .69724 m
.86065 .69724 L
s
.81279 .7451 m
.86065 .7451 L
s
.81279 .81279 m
.81279 .86065 L
s
.81279 .81279 m
.86065 .81279 L
s
.82681 .22105 m
.86065 .18721 L
s
.82681 .22105 m
.86065 .2549 L
s
.82681 .38446 m
.86065 .4183 L
s
.82681 .38446 m
.86065 .4183 L
s
.82681 .38446 m
.86065 .35062 L
s
.82681 .38446 m
.86065 .35062 L
s
.82681 .38446 m
.86065 .4183 L
s
.82681 .5 m
.86065 .53384 L
s
.82681 .5 m
.86065 .46616 L
s
.82681 .5 m
.86065 .46616 L
s
.82681 .5 m
.86065 .53384 L
s
.82681 .61554 m
.86065 .5817 L
s
.82681 .61554 m
.86065 .64938 L
s
.82681 .61554 m
.86065 .5817 L
s
.82681 .61554 m
.86065 .64938 L
s
.82681 .77895 m
.86065 .7451 L
s
.82681 .77895 m
.86065 .81279 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .53384 m
.86065 .5817 L
s
.86065 .53384 m
.86065 .5817 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .5817 m
.86065 .53384 L
s
.86065 .5817 m
.89449 .54786 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .64938 m
.86065 .69724 L
s
.86065 .64938 m
.86065 .69724 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .69724 m
.86065 .64938 L
s
.86065 .69724 m
.86065 .7451 L
s
.86065 .69724 m
.89449 .6634 L
s
.86065 .69724 m
.89449 .73109 L
s
.86065 .69724 m
.89449 .73109 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .46616 m
.86065 .4183 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .2549 m
.86065 .30276 L
s
.86065 .30276 m
.86065 .35062 L
s
.86065 .30276 m
.86065 .35062 L
s
.86065 .30276 m
.89449 .3366 L
s
.86065 .30276 m
.89449 .26891 L
s
.86065 .30276 m
.89449 .3366 L
s
.86065 .30276 m
.89449 .3366 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .35062 m
.89449 .38446 L
s
.86065 .4183 m
.86065 .46616 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .38446 L
s
.86065 .4183 m
.89449 .45214 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .46616 m
.89449 .5 L
s
.86065 .53384 m
.86065 .5817 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .53384 m
.89449 .5 L
s
.86065 .5817 m
.89449 .54786 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .5817 m
.89449 .61554 L
s
.86065 .64938 m
.86065 .69724 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .64938 m
.89449 .61554 L
s
.86065 .69724 m
.86065 .7451 L
s
.86065 .69724 m
.89449 .6634 L
s
.86065 .69724 m
.89449 .73109 L
s
.86065 .69724 m
.89449 .73109 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .38446 m
.89449 .3366 L
s
.89449 .38446 m
.89449 .3366 L
s
.89449 .38446 m
.92833 .4183 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .45214 m
.89449 .5 L
s
.89449 .45214 m
.89449 .5 L
s
.89449 .45214 m
.92833 .4183 L
s
.89449 .5 m
.89449 .54786 L
s
.89449 .5 m
.89449 .45214 L
s
.89449 .5 m
.92833 .46616 L
s
.89449 .5 m
.92833 .53384 L
s
.89449 .5 m
.94235 .5 L
s
.89449 .54786 m
.89449 .5 L
s
.89449 .54786 m
.92833 .5817 L
s
.89449 .61554 m
.89449 .6634 L
s
.89449 .61554 m
.92833 .5817 L
s
.89449 .61554 m
.94235 .61554 L
s
.89449 .6634 m
.89449 .61554 L
s
.89449 .6634 m
.92833 .69724 L
s
.89449 .6634 m
.94235 .6634 L
s
.89449 .73109 m
.92833 .69724 L
s
.89449 .26891 m
.92833 .30276 L
s
.89449 .26891 m
.92833 .30276 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.89449 .38446 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.92833 .30276 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .3366 m
.94235 .3366 L
s
.89449 .38446 m
.92833 .4183 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.92833 .4183 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .38446 m
.94235 .38446 L
s
.89449 .45214 m
.89449 .5 L
s
.89449 .45214 m
.92833 .4183 L
s
.89449 .5 m
.92833 .46616 L
s
.89449 .5 m
.92833 .53384 L
s
.89449 .5 m
.94235 .5 L
s
.89449 .61554 m
.92833 .5817 L
s
.89449 .61554 m
.94235 .61554 L
s
.89449 .73109 m
.92833 .69724 L
s
.92833 .4183 m
.92833 .46616 L
s
.92833 .46616 m
.97619 .46616 L
s
.92833 .53384 m
.92833 .5817 L
s
.92833 .53384 m
.97619 .53384 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .38446 m
.94235 .3366 L
s
.94235 .5 m
.97619 .46616 L
s
.94235 .5 m
.97619 .53384 L
s
.94235 .61554 m
.94235 .6634 L
s
.94235 .3366 m
.94235 .38446 L
s
.94235 .3366 m
.94235 .38446 L
s
.008 w
.42821 .04533 Mdot
.52393 .04533 Mdot
.61965 .04533 Mdot
.23677 .14105 Mdot
.33249 .14105 Mdot
.42821 .14105 Mdot
.52393 .14105 Mdot
.61965 .14105 Mdot
.71537 .14105 Mdot
.81109 .14105 Mdot
.14105 .23677 Mdot
.23677 .23677 Mdot
.33249 .23677 Mdot
.42821 .23677 Mdot
.52393 .23677 Mdot
.61965 .23677 Mdot
.71537 .23677 Mdot
.81109 .23677 Mdot
.14105 .33249 Mdot
.23677 .33249 Mdot
.33249 .33249 Mdot
.42821 .33249 Mdot
.52393 .33249 Mdot
.61965 .33249 Mdot
.71537 .33249 Mdot
.81109 .33249 Mdot
.90681 .33249 Mdot
.04533 .42821 Mdot
.14105 .42821 Mdot
.23677 .42821 Mdot
.33249 .42821 Mdot
.42821 .42821 Mdot
.52393 .42821 Mdot
.61965 .42821 Mdot
.71537 .42821 Mdot
.81109 .42821 Mdot
.90681 .42821 Mdot
.04533 .52393 Mdot
.14105 .52393 Mdot
.23677 .52393 Mdot
.33249 .52393 Mdot
.42821 .52393 Mdot
.52393 .52393 Mdot
.61965 .52393 Mdot
.71537 .52393 Mdot
.81109 .52393 Mdot
.90681 .52393 Mdot
.04533 .61965 Mdot
.14105 .61965 Mdot
.23677 .61965 Mdot
.33249 .61965 Mdot
.42821 .61965 Mdot
.52393 .61965 Mdot
.61965 .61965 Mdot
.71537 .61965 Mdot
.81109 .61965 Mdot
.90681 .61965 Mdot
.14105 .71537 Mdot
.23677 .71537 Mdot
.33249 .71537 Mdot
.42821 .71537 Mdot
.52393 .71537 Mdot
.61965 .71537 Mdot
.71537 .71537 Mdot
.81109 .71537 Mdot
.90681 .71537 Mdot
.14105 .81109 Mdot
.23677 .81109 Mdot
.33249 .81109 Mdot
.42821 .81109 Mdot
.52393 .81109 Mdot
.61965 .81109 Mdot
.71537 .81109 Mdot
.81109 .81109 Mdot
.33249 .90681 Mdot
.42821 .90681 Mdot
.52393 .90681 Mdot
.61965 .90681 Mdot
.71537 .90681 Mdot
.77073 .12774 Mdot
.83842 .19542 Mdot
.9061 .26311 Mdot
.56768 .06006 Mdot
.63537 .12774 Mdot
.70305 .19542 Mdot
.77073 .26311 Mdot
.83842 .33079 Mdot
.9061 .39847 Mdot
.97379 .46616 Mdot
.43232 .06006 Mdot
.5 .12774 Mdot
.56768 .19542 Mdot
.63537 .26311 Mdot
.70305 .33079 Mdot
.77073 .39847 Mdot
.83842 .46616 Mdot
.9061 .53384 Mdot
.36463 .12774 Mdot
.43232 .19542 Mdot
.5 .26311 Mdot
.56768 .33079 Mdot
.63537 .39847 Mdot
.70305 .46616 Mdot
.77073 .53384 Mdot
.83842 .60153 Mdot
.9061 .66921 Mdot
.22927 .12774 Mdot
.29695 .19542 Mdot
.36463 .26311 Mdot
.43232 .33079 Mdot
.5 .39847 Mdot
.56768 .46616 Mdot
.63537 .53384 Mdot
.70305 .60153 Mdot
.77073 .66921 Mdot
.83842 .73689 Mdot
.16158 .19542 Mdot
.22927 .26311 Mdot
.29695 .33079 Mdot
.36463 .39847 Mdot
.43232 .46616 Mdot
.5 .53384 Mdot
.56768 .60153 Mdot
.63537 .66921 Mdot
.70305 .73689 Mdot
.77073 .80458 Mdot
.0939 .26311 Mdot
.16158 .33079 Mdot
.22927 .39847 Mdot
.29695 .46616 Mdot
.36463 .53384 Mdot
.43232 .60153 Mdot
.5 .66921 Mdot
.56768 .73689 Mdot
.63537 .80458 Mdot
.70305 .87226 Mdot
.0939 .39847 Mdot
.16158 .46616 Mdot
.22927 .53384 Mdot
.29695 .60153 Mdot
.36463 .66921 Mdot
.43232 .73689 Mdot
.5 .80458 Mdot
.56768 .87226 Mdot
.63537 .93994 Mdot
.02621 .46616 Mdot
.0939 .53384 Mdot
.16158 .60153 Mdot
.22927 .66921 Mdot
.29695 .73689 Mdot
.36463 .80458 Mdot
.43232 .87226 Mdot
.5 .93994 Mdot
.0939 .66921 Mdot
.16158 .73689 Mdot
.22927 .80458 Mdot
.29695 .87226 Mdot
.36463 .93994 Mdot
.33249 .09319 Mdot
.42821 .09319 Mdot
.52393 .09319 Mdot
.61965 .09319 Mdot
.71537 .09319 Mdot
.14105 .18891 Mdot
.23677 .18891 Mdot
.33249 .18891 Mdot
.42821 .18891 Mdot
.52393 .18891 Mdot
.61965 .18891 Mdot
.71537 .18891 Mdot
.81109 .18891 Mdot
.14105 .28463 Mdot
.23677 .28463 Mdot
.33249 .28463 Mdot
.42821 .28463 Mdot
.52393 .28463 Mdot
.61965 .28463 Mdot
.71537 .28463 Mdot
.81109 .28463 Mdot
.90681 .28463 Mdot
.04533 .38035 Mdot
.14105 .38035 Mdot
.23677 .38035 Mdot
.33249 .38035 Mdot
.42821 .38035 Mdot
.52393 .38035 Mdot
.61965 .38035 Mdot
.71537 .38035 Mdot
.81109 .38035 Mdot
.90681 .38035 Mdot
.04533 .47607 Mdot
.14105 .47607 Mdot
.23677 .47607 Mdot
.33249 .47607 Mdot
.42821 .47607 Mdot
.52393 .47607 Mdot
.61965 .47607 Mdot
.71537 .47607 Mdot
.81109 .47607 Mdot
.90681 .47607 Mdot
.04533 .57179 Mdot
.14105 .57179 Mdot
.23677 .57179 Mdot
.33249 .57179 Mdot
.42821 .57179 Mdot
.52393 .57179 Mdot
.61965 .57179 Mdot
.71537 .57179 Mdot
.81109 .57179 Mdot
.90681 .57179 Mdot
.14105 .66751 Mdot
.23677 .66751 Mdot
.33249 .66751 Mdot
.42821 .66751 Mdot
.52393 .66751 Mdot
.61965 .66751 Mdot
.71537 .66751 Mdot
.81109 .66751 Mdot
.90681 .66751 Mdot
.14105 .76323 Mdot
.23677 .76323 Mdot
.33249 .76323 Mdot
.42821 .76323 Mdot
.52393 .76323 Mdot
.61965 .76323 Mdot
.71537 .76323 Mdot
.81109 .76323 Mdot
.23677 .85895 Mdot
.33249 .85895 Mdot
.42821 .85895 Mdot
.52393 .85895 Mdot
.61965 .85895 Mdot
.71537 .85895 Mdot
.81109 .85895 Mdot
.42821 .95467 Mdot
.52393 .95467 Mdot
.61965 .95467 Mdot
.66921 .0939 Mdot
.73689 .16158 Mdot
.80458 .22927 Mdot
.87226 .29695 Mdot
.93994 .36463 Mdot
.46616 .02621 Mdot
.53384 .0939 Mdot
.60153 .16158 Mdot
.66921 .22927 Mdot
.73689 .29695 Mdot
.80458 .36463 Mdot
.87226 .43232 Mdot
.93994 .5 Mdot
.39847 .0939 Mdot
.46616 .16158 Mdot
.53384 .22927 Mdot
.60153 .29695 Mdot
.66921 .36463 Mdot
.73689 .43232 Mdot
.80458 .5 Mdot
.87226 .56768 Mdot
.93994 .63537 Mdot
.26311 .0939 Mdot
.33079 .16158 Mdot
.39847 .22927 Mdot
.46616 .29695 Mdot
.53384 .36463 Mdot
.60153 .43232 Mdot
.66921 .5 Mdot
.73689 .56768 Mdot
.80458 .63537 Mdot
.87226 .70305 Mdot
.19542 .16158 Mdot
.26311 .22927 Mdot
.33079 .29695 Mdot
.39847 .36463 Mdot
.46616 .43232 Mdot
.53384 .5 Mdot
.60153 .56768 Mdot
.66921 .63537 Mdot
.73689 .70305 Mdot
.80458 .77073 Mdot
.12774 .22927 Mdot
.19542 .29695 Mdot
.26311 .36463 Mdot
.33079 .43232 Mdot
.39847 .5 Mdot
.46616 .56768 Mdot
.53384 .63537 Mdot
.60153 .70305 Mdot
.66921 .77073 Mdot
.73689 .83842 Mdot
.12774 .36463 Mdot
.19542 .43232 Mdot
.26311 .5 Mdot
.33079 .56768 Mdot
.39847 .63537 Mdot
.46616 .70305 Mdot
.53384 .77073 Mdot
.60153 .83842 Mdot
.66921 .9061 Mdot
.06006 .43232 Mdot
.12774 .5 Mdot
.19542 .56768 Mdot
.26311 .63537 Mdot
.33079 .70305 Mdot
.39847 .77073 Mdot
.46616 .83842 Mdot
.53384 .9061 Mdot
.06006 .56768 Mdot
.12774 .63537 Mdot
.19542 .70305 Mdot
.26311 .77073 Mdot
.33079 .83842 Mdot
.39847 .9061 Mdot
.46616 .97379 Mdot
.12774 .77073 Mdot
.19542 .83842 Mdot
.26311 .9061 Mdot
.38035 .04533 Mdot
.47607 .04533 Mdot
.57179 .04533 Mdot
.18891 .14105 Mdot
.28463 .14105 Mdot
.38035 .14105 Mdot
.47607 .14105 Mdot
.57179 .14105 Mdot
.66751 .14105 Mdot
.76323 .14105 Mdot
.18891 .23677 Mdot
.28463 .23677 Mdot
.38035 .23677 Mdot
.47607 .23677 Mdot
.57179 .23677 Mdot
.66751 .23677 Mdot
.76323 .23677 Mdot
.85895 .23677 Mdot
.09319 .33249 Mdot
.18891 .33249 Mdot
.28463 .33249 Mdot
.38035 .33249 Mdot
.47607 .33249 Mdot
.57179 .33249 Mdot
.66751 .33249 Mdot
.76323 .33249 Mdot
.85895 .33249 Mdot
.09319 .42821 Mdot
.18891 .42821 Mdot
.28463 .42821 Mdot
.38035 .42821 Mdot
.47607 .42821 Mdot
.57179 .42821 Mdot
.66751 .42821 Mdot
.76323 .42821 Mdot
.85895 .42821 Mdot
.95467 .42821 Mdot
.09319 .52393 Mdot
.18891 .52393 Mdot
.28463 .52393 Mdot
.38035 .52393 Mdot
.47607 .52393 Mdot
.57179 .52393 Mdot
.66751 .52393 Mdot
.76323 .52393 Mdot
.85895 .52393 Mdot
.95467 .52393 Mdot
.09319 .61965 Mdot
.18891 .61965 Mdot
.28463 .61965 Mdot
.38035 .61965 Mdot
.47607 .61965 Mdot
.57179 .61965 Mdot
.66751 .61965 Mdot
.76323 .61965 Mdot
.85895 .61965 Mdot
.95467 .61965 Mdot
.09319 .71537 Mdot
.18891 .71537 Mdot
.28463 .71537 Mdot
.38035 .71537 Mdot
.47607 .71537 Mdot
.57179 .71537 Mdot
.66751 .71537 Mdot
.76323 .71537 Mdot
.85895 .71537 Mdot
.18891 .81109 Mdot
.28463 .81109 Mdot
.38035 .81109 Mdot
.47607 .81109 Mdot
.57179 .81109 Mdot
.66751 .81109 Mdot
.76323 .81109 Mdot
.85895 .81109 Mdot
.28463 .90681 Mdot
.38035 .90681 Mdot
.47607 .90681 Mdot
.57179 .90681 Mdot
.66751 .90681 Mdot
.73689 .0939 Mdot
.80458 .16158 Mdot
.87226 .22927 Mdot
.53384 .02621 Mdot
.60153 .0939 Mdot
.66921 .16158 Mdot
.73689 .22927 Mdot
.80458 .29695 Mdot
.87226 .36463 Mdot
.93994 .43232 Mdot
.46616 .0939 Mdot
.53384 .16158 Mdot
.60153 .22927 Mdot
.66921 .29695 Mdot
.73689 .36463 Mdot
.80458 .43232 Mdot
.87226 .5 Mdot
.93994 .56768 Mdot
.33079 .0939 Mdot
.39847 .16158 Mdot
.46616 .22927 Mdot
.53384 .29695 Mdot
.60153 .36463 Mdot
.66921 .43232 Mdot
.73689 .5 Mdot
.80458 .56768 Mdot
.87226 .63537 Mdot
.26311 .16158 Mdot
.33079 .22927 Mdot
.39847 .29695 Mdot
.46616 .36463 Mdot
.53384 .43232 Mdot
.60153 .5 Mdot
.66921 .56768 Mdot
.73689 .63537 Mdot
.80458 .70305 Mdot
.87226 .77073 Mdot
.19542 .22927 Mdot
.26311 .29695 Mdot
.33079 .36463 Mdot
.39847 .43232 Mdot
.46616 .5 Mdot
.53384 .56768 Mdot
.60153 .63537 Mdot
.66921 .70305 Mdot
.73689 .77073 Mdot
.80458 .83842 Mdot
.12774 .29695 Mdot
.19542 .36463 Mdot
.26311 .43232 Mdot
.33079 .5 Mdot
.39847 .56768 Mdot
.46616 .63537 Mdot
.53384 .70305 Mdot
.60153 .77073 Mdot
.66921 .83842 Mdot
.73689 .9061 Mdot
.06006 .36463 Mdot
.12774 .43232 Mdot
.19542 .5 Mdot
.26311 .56768 Mdot
.33079 .63537 Mdot
.39847 .70305 Mdot
.46616 .77073 Mdot
.53384 .83842 Mdot
.60153 .9061 Mdot
.06006 .5 Mdot
.12774 .56768 Mdot
.19542 .63537 Mdot
.26311 .70305 Mdot
.33079 .77073 Mdot
.39847 .83842 Mdot
.46616 .9061 Mdot
.53384 .97379 Mdot
.06006 .63537 Mdot
.12774 .70305 Mdot
.19542 .77073 Mdot
.26311 .83842 Mdot
.33079 .9061 Mdot
.28463 .09319 Mdot
.38035 .09319 Mdot
.47607 .09319 Mdot
.57179 .09319 Mdot
.66751 .09319 Mdot
.18891 .18891 Mdot
.28463 .18891 Mdot
.38035 .18891 Mdot
.47607 .18891 Mdot
.57179 .18891 Mdot
.66751 .18891 Mdot
.76323 .18891 Mdot
.85895 .18891 Mdot
.09319 .28463 Mdot
.18891 .28463 Mdot
.28463 .28463 Mdot
.38035 .28463 Mdot
.47607 .28463 Mdot
.57179 .28463 Mdot
.66751 .28463 Mdot
.76323 .28463 Mdot
.85895 .28463 Mdot
.09319 .38035 Mdot
.18891 .38035 Mdot
.28463 .38035 Mdot
.38035 .38035 Mdot
.47607 .38035 Mdot
.57179 .38035 Mdot
.66751 .38035 Mdot
.76323 .38035 Mdot
.85895 .38035 Mdot
.95467 .38035 Mdot
.09319 .47607 Mdot
.18891 .47607 Mdot
.28463 .47607 Mdot
.38035 .47607 Mdot
.47607 .47607 Mdot
.57179 .47607 Mdot
.66751 .47607 Mdot
.76323 .47607 Mdot
.85895 .47607 Mdot
.95467 .47607 Mdot
.09319 .57179 Mdot
.18891 .57179 Mdot
.28463 .57179 Mdot
.38035 .57179 Mdot
.47607 .57179 Mdot
.57179 .57179 Mdot
.66751 .57179 Mdot
.76323 .57179 Mdot
.85895 .57179 Mdot
.95467 .57179 Mdot
.09319 .66751 Mdot
.18891 .66751 Mdot
.28463 .66751 Mdot
.38035 .66751 Mdot
.47607 .66751 Mdot
.57179 .66751 Mdot
.66751 .66751 Mdot
.76323 .66751 Mdot
.85895 .66751 Mdot
.18891 .76323 Mdot
.28463 .76323 Mdot
.38035 .76323 Mdot
.47607 .76323 Mdot
.57179 .76323 Mdot
.66751 .76323 Mdot
.76323 .76323 Mdot
.85895 .76323 Mdot
.18891 .85895 Mdot
.28463 .85895 Mdot
.38035 .85895 Mdot
.47607 .85895 Mdot
.57179 .85895 Mdot
.66751 .85895 Mdot
.76323 .85895 Mdot
.38035 .95467 Mdot
.47607 .95467 Mdot
.57179 .95467 Mdot
.63537 .06006 Mdot
.70305 .12774 Mdot
.77073 .19542 Mdot
.83842 .26311 Mdot
.9061 .33079 Mdot
.5 .06006 Mdot
.56768 .12774 Mdot
.63537 .19542 Mdot
.70305 .26311 Mdot
.77073 .33079 Mdot
.83842 .39847 Mdot
.9061 .46616 Mdot
.97379 .53384 Mdot
.36463 .06006 Mdot
.43232 .12774 Mdot
.5 .19542 Mdot
.56768 .26311 Mdot
.63537 .33079 Mdot
.70305 .39847 Mdot
.77073 .46616 Mdot
.83842 .53384 Mdot
.9061 .60153 Mdot
.29695 .12774 Mdot
.36463 .19542 Mdot
.43232 .26311 Mdot
.5 .33079 Mdot
.56768 .39847 Mdot
.63537 .46616 Mdot
.70305 .53384 Mdot
.77073 .60153 Mdot
.83842 .66921 Mdot
.9061 .73689 Mdot
.22927 .19542 Mdot
.29695 .26311 Mdot
.36463 .33079 Mdot
.43232 .39847 Mdot
.5 .46616 Mdot
.56768 .53384 Mdot
.63537 .60153 Mdot
.70305 .66921 Mdot
.77073 .73689 Mdot
.83842 .80458 Mdot
.16158 .26311 Mdot
.22927 .33079 Mdot
.29695 .39847 Mdot
.36463 .46616 Mdot
.43232 .53384 Mdot
.5 .60153 Mdot
.56768 .66921 Mdot
.63537 .73689 Mdot
.70305 .80458 Mdot
.77073 .87226 Mdot
.0939 .33079 Mdot
.16158 .39847 Mdot
.22927 .46616 Mdot
.29695 .53384 Mdot
.36463 .60153 Mdot
.43232 .66921 Mdot
.5 .73689 Mdot
.56768 .80458 Mdot
.63537 .87226 Mdot
.0939 .46616 Mdot
.16158 .53384 Mdot
.22927 .60153 Mdot
.29695 .66921 Mdot
.36463 .73689 Mdot
.43232 .80458 Mdot
.5 .87226 Mdot
.56768 .93994 Mdot
.02621 .53384 Mdot
.0939 .60153 Mdot
.16158 .66921 Mdot
.22927 .73689 Mdot
.29695 .80458 Mdot
.36463 .87226 Mdot
.43232 .93994 Mdot
.0939 .73689 Mdot
.16158 .80458 Mdot
.22927 .87226 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;RLW9b40<?oo_`00?g=cLda<C820P8NZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmo
OiB;WMKBg2XX;H=kRhjYUM3KddiMD^GQY9no_m[ViUY]KD=EIB4Z<M_Vkl?Ei6F0V;2^]4U5CX61PFYo
L4mOGbL_;n;/k<oOggN?ShRZVHEhU000O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o
002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmo
Ocmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?glo
Oglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0
_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo
_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo
?oooOlS3cdDnCFmlS[g3bcU0B]C>N7j0VLG6dD52Cf]]PW5VO]_Ggd8lBVIbVOoo0_oo1mWIhEiPLko0
c3m0C1lO9FAJKk>ic=;EhC<iC1TL9DaELeioI[C3]c11=?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L008D700<01`L04@L00`071`241`00Q@L201470P261`00Q@L300l700<01`00
QPL008D700@01`L03@L010071`261`00Q@L01@071`L000/700D01`L700261`00Q@L00`071`021`03
00L700L700<01`L00PL00`071`241`00K0L200`70P091`0300L7008000<700L01PL0100700021`03
00L700L70P0<1`80K@L006d700<01`L02`L00`071`071`0500L71`000PL00`071`031`0500L71`00
0PL00`071`081`0300L700/700<01`L0J`L008D700<01`L01@L01@071`L000L700<01`L0Q0L008D7
00<01`L01PL00`0700081`0300L708@7001P1`l030L200P700<01`L01PL200T700<01`L01PL200`7
3`1Q1`00H0L00`071`061`0300L7008700<01`L02`L00`071`061`0300L700L700<01`L01`L00`07
1`071`0300L700X700<01`L00`L00`071`051`0300L705l7001P1`0300L700/700<01`L050L00`07
1`071`0300L700L700<01`L050L00`071`0;1`0300L705l7001P1`0300L700/700<01`L050L00`07
1`071`0300L700L700<01`L050L00`071`0;1`0300L705l7001F1`0300L700L700<01`L02`L00`07
1`071`h02@L00`071`071`h02@L00`071`0;1`0300L700L700<01`L0E@L005D700<01`0020L00`07
1`0;1`0300L700H700<01`0030L00`071`061`0300L700H700<01`L02PL00`0700081`0300L700/7
00<01`L01PL00`07001F1`00E0L01@071`L000L700<01`L02`L00`071`051`0500L71`0030L00`07
1`051`0300L700D700<01`L02PL01@071`L000L700<01`L02`L00`071`051`0500L71`00E@L005<7
00<01`L00`L00`071`041`0300L700/700<01`L010L00`071`031`0300L700X700<01`L010L00`07
1`041`0300L700X700<01`L00`L00`071`041`0300L700/700<01`L010L00`071`031`0300L70587
001B1`0300L700D700<01`L00`L00`071`0;1`0300L700<700<01`L01@L00`071`0:1`0300L700<7
00<01`L00`L00`071`0:1`0300L700D700<01`L00`L00`071`0;1`0300L700<700<01`L01@L00`07
1`1A1`00DPL00`071`061`0300L7008700<01`L02`L00`071`021`0300L700H700<01`L02`L00`07
1`021`0300L7008700<01`L02`L00`071`061`0300L7008700<01`L02`L00`071`021`0300L700H7
00<01`L0D@L004X70P051`802@L00`07000200/70`021`801`L200031`0700H70P001@L000L000<7
00H01`L700L200031`0000L700@01`001`L200870`0;1`<000<700L020L200@70P1<1`00B`L00`07
1`021`0300L000X700@01`0030L200870P081`0400L700L700@01`L00PL010071`021`0500L71`00
0PL00`071`041`0500L71`0020L01P071`0700/7100;1`8010L00`071`1:1`00C`L00`071`0<1`03
00L000d700<01`003PL00`071`0;1`0500L01`003@L00`071`0<1`0300L000d700<01`003PL00`07
1`1>1`00CPL00`071`0>1`803@L2010700<01`L02`L300d700<01`L03PL200d70P0@1`0300L704d7
001=1`0300L701073`0B1ad04PL?018700<01`L0C0L004h700<01`L03PL00`071`0;1`0300L00107
00<01`L02`L00`07000=1`0300L700h700<01`003@L00`071`0>1`0300L704d7001?1`0300L700`7
00<01`L02`L01@071`L000h700<01`L02`L01@071`L000d700<01`L030L01@071`L000d700<01`L0
30L00`071`1>1`00D0L00`071`0:1`0300L700/700<01`L00`L00`071`0:1`0300L700/700<01`L0
0`L00`071`0;1`0300L700X700<01`L00`L00`071`0;1`0300L700X700<01`L0C`L0054700<01`L0
1`L200`70P071`0300L700P700<01`L02PL200L700<01`L02`L00`071`071`801`L00`071`0;1`03
00L700P700<01`L0D0L0058700<01`L01@L00`071`0;1`0300L700P70P071`0300L700X700<01`L0
20L200`700<01`L01@L00`071`081`8030L200L700<01`L0D@L004470P0@1`<00`L00`071`0;1`<0
2`L00`071`031`802`L00`071`031`801PL00`071`091`801@L00`071`091`<03@L010071`L30107
0P121`00@PL00`071`0?1`800PL00`071`0;1`0400L700`700L01`L700L000X700<01`L01@L00`07
1`051`0300L700T70P031`0300L700/700<01`003@L01@071`L0018700<01`L0@0L005D700<01`00
3@L00`071`0?1`0300L000`700<01`L03`L00`071`0:1`0300L0014700<01`L02`L00`07001F1`00
=@L00`071`0A1a`04`L>01<73P0C1a`04`L00`071`0d1`00=@L200`70P031`801`L200<700<01`L0
1@L200@70P061`802@L200031`0000T70P000`L0000;1`8000<700002@L200031`0000T70P061`80
0`L200P700@01`L70P071`800`L200`70P0f1`00=@L300`700H01`L01`081`0500L71`0020L00`07
1`021`0300L000H700<01`L01PL00`0700021`0300L700L700D01`07000<1`8000<700L02@L01@07
00L000T700<01`L00`L00`0700041`0300L700H700<01`L00PL00`071`051`0300L000<700<01`L0
2@L00`07000f1`00=@L010071`0=1`0400L700`700<01`L02`L010071`0=1`0400L700`700@01`L0
3@L010071`0<1`0400L700d700@01`L03@L00`071`0:1`0400L700d700@01`L0=PL003D700D01`L7
000;1`0500L71`0030L00`071`0;1`0500L71`002`L01@071`L000`700D01`L7000;1`0500L71`00
30L01@071`L000/700D01`L7000=1`0300L700X700D01`L7000;1`0500L71`00=PL003D700<01`L0
0PL00`071`071`0300L7008700<01`L02PL00`071`0;1`0300L7008700<01`L01`L00`071`021`03
00L700X700<01`L00PL00`071`071`0300L7008700<01`L02PL00`071`021`0300L700L700<01`L0
0PL00`071`0;1`0300L700X700<01`L00PL00`071`071`0300L7008700<01`L0=0L003D700@01`00
0PL00`071`051`0300L700<70`0:1`0300L700D70P041`0300L700<700<01`L010L200D700<01`L0
2PL200@700<01`L01@L00`071`021`8030L00`071`031`801PL00`071`031`0300L700870P071`03
00L700L70P000`L01`041`0300L700D700<01`L00P000`L01`0e1`00=@L010071`031`0300L700<7
00<01`L010L00`07000:1`0300L700H700<01`L00PL00`071`041`0300L700<70P051`0300L700X7
0P051`0300L700<700<01`L010L00`071`0:1`0300L700@700<01`L00`L00`071`041`0300L700<7
00<01`L01@L00`071`081`0300L000H700<01`L00`L00`071`021`0300L003H7000e1`0300L700D7
00D01`L700071`0300L700X700<01`L02`L00`071`051`0500L71`001`L00`071`0:1`0300L700D7
00D01`L700071`0300L700X700<01`L01@L01@071`L000L700<01`L02`L00`071`0:1`0300L700D7
00D01`L700071`0300L703@7000e1`0300L700H700<01`0020L00`071`0:1`0300L700/700<01`L0
1PL00`0700081`0300L700X700<01`L01PL00`0700081`0300L700X700<01`L01PL00`0700081`03
00L700/700<01`L02PL00`071`061`0300L000P700<01`L0=0L003D700<01`L01`L00`071`071`03
00L700X700<01`L02`L00`071`071`0300L700L700<01`L02PL00`071`071`0300L700L700<01`L0
2PL00`071`071`0300L700L700<01`L02`L00`071`0:1`0300L700L700<01`L01`L00`071`0d1`00
=@L00`071`071`0300L700L700<01`L02PL00`071`0;1`0300L700L700<01`L01`L00`071`0:1`03
00L700L700<01`L01`L00`071`0:1`0300L700L700<01`L01`L00`071`0;1`0300L700X700<01`L0
1`L00`071`071`0300L703@7000e1`0300L700L700<01`L01`L00`071`0:1`0300L700/700<01`L0
1`L00`071`071`0300L700X700<01`L01`L00`071`071`0300L700X700<01`L01`L00`071`071`03
00L700/700<01`L02PL00`071`071`0300L700L700<01`L0=0L003D700<01`L01`L00`071`071`03
00L700X700<01`L02`L00`071`071`0300L700L700<01`L02PL00`071`071`0300L700L700<01`L0
2PL00`071`071`0300L700L700<01`L02`L00`071`0:1`0300L700L700<01`L01`L00`071`0d1`00
9`L@00P700@01`L70P041a`01`L300T73P021`801@L00`071`031`800PL>00T70`071a`010L200<7
00<01`L01PL@02P7000X1`0300L700/700<01`L01PL00`071`021`0500L71`002@L01P071`0700L7
00<01`L00`L00`071`051`8020L01@0700L000X700@01`L01@L00`071`041`0300L000/70P000`L0
1`071`0300L000H700<01`L00`L00`071`051`0300L000<700<01`L01PL00`071`021`0500L71`00
20L200`700<01`L09`L002T700@01`L70P081`0300L700D700@01`0010L00`071`0:1`800PL00`07
1`0;1`0400L000@700<01`L01@L010071`L300X700<01`L010L200L700<01`L020L300<700<01`L0
1@L00`071`021`8000<700L030L00`071`0200`700<01`L00PL200031`0700H700<01`L01PL200<7
00<01`L0:0L002X700D01`L700091`0300L700@700@01`L00`L00`071`0:1`0300L000<700<01`L0
2`L00`0700041`0300L700@700<01`L00`L200/700<01`L010L00`071`041`0300L700X700<01`L0
0`L00`071`041`0300L700<70P0=1`0300L700870P0<1`0300L7008700<01`001PL00`071`081`04
00L702/7000[1`0300L700/700<01`L00`L00`071`031`0300L700X700<01`L01@L00`071`0;1`03
00L700<700<01`L00`L00`071`051`0300L700X700<01`L00`L00`071`031`0300L700X700<01`L0
1@L00`071`031`0300L700<700<01`L02`L00`071`051`0300L700X700<01`L00`L00`071`031`03
00L700/700<01`L0:PL002`700<01`L02`L00`071`021`0300L7008700<01`L02`L00`071`061`03
00L700/700<01`L00PL00`071`021`0300L700H700<01`L02`L00`071`021`0300L7008700<01`L0
2`L00`071`061`0300L7008700<01`L00PL00`071`0;1`0300L700H700<01`L02`L00`071`021`03
00L7008700<01`L02`L00`071`0[1`00;@L00`071`0;1`0500L71`000`L00`071`0;1`0300L700P7
00<01`L02`L01@071`L000<700<01`L020L00`071`0;1`0500L71`000`L00`071`0;1`0300L700P7
00D01`L700031`0300L700/700<01`L020L00`071`0;1`0500L71`000`L00`071`0;1`0300L702`7
000^1`0300L700/700@01`L00PL00`071`0;1`0300L700X700<01`L02`L010071`021`0300L700X7
00<01`L02`L010071`021`0300L700/700<01`L02PL010071`021`0300L700/700<01`L02PL00`07
1`0;1`0400L7008700<01`L02`L00`071`0]1`00;`L00`071`0;1`0500L01`003@L00`071`0<1`03
00L700/700D01`07000>1`0300L700/700D01`07000=1`0300L700`700D01`07000=1`0300L700`7
00<01`L02`L01@0700L000d700<01`L0;PL0030700<01`L02`L300d700<01`L03PL00`071`0;1`<0
40L00`071`0;1`<03@L00`071`0>1`<03@L00`071`0>1`0300L700/70`0=1`0300L702l7000a1ad0
4PL?01877@0B1`l04PLM0387000`1`0300L700/70P0=1`8040L200d70P0@1`0300L700/70`0=1`03
00L700h70P0=1`8040L200d70P0=1`0300L702l7000T1`802@L00`071`051`8010L00`07000:1`80
00@700L03PL300d700<01`000P0<1`0300L700<70P061`0500L01`001PL200D700<01`L02PL30003
1`0700`70`0>1`0300L000802`L00`0700041`801`L00`071`071`809@L002D700<01`L01PL00`07
1`071`0500L71`000PL00`071`091`0300L0008700<01`L02PL01007000=1`0300L700802`L00`07
1`051`0300L700<700@01`L00PL00`071`041`0300L700@700<01`L02PL010071`0=1`0400L000`7
00H01`L01`0;1`0400L700@700<01`L01PL00`071`071`0300L702<7000W1`8010L00`071`051`80
10L01@071`L000<70P081`0400L71`802@L00`07000200/70`031`0300L700D70P000`L01`091`80
00<700L00PL01P071`L01`802PL0100700071`0400L71`<02`L2008700<01`L01`L200<700<01`L0
1PL200<700D01`L700041`801`L010071`L202T7000X1`0500L71`002@L01@071`L000@700<01`L0
0PL00`071`061`0400L71`8020L010071`L200`70P041`0300L700D700<01`002`L200@700<01`L0
0PL00`07000:1`0400L700H700<01`L00PL00`07000;1`800`L00`071`071`0500L71`002@L01@07
1`L000@700<01`L00PL00`071`061`0500L71`00:@L002/700<01`L02`L00`071`031`0300L700/7
00<01`L00PL00`071`051`0300L700<700<01`L02`L00`071`031`0300L700D700<01`L02PL00`07
1`031`0300L700<700<01`L02PL00`071`051`0300L700<700<01`L02`L00`071`031`0300L700D7
00<01`L00PL00`071`0;1`0300L700<700<01`L02`L00`071`0Z1`00:PL00`071`0;1`0300L700@7
00<01`L02`L00`071`031`0300L700<700<01`L010L00`071`0;1`0300L700@700<01`L00`L00`07
1`0:1`0300L700@700<01`L010L00`071`0:1`0300L700<700<01`L010L00`071`0;1`0300L700@7
00<01`L00`L00`071`031`0300L700/700<01`L010L00`071`0;1`0300L702T7000Y1`0300L700/7
00<01`L01@L00`071`0;1`0300L700@700D01`L700071`0300L700/700<01`L01@L01@071`L000`7
00<01`L01@L00`071`051`0300L700X700D01`L700071`0300L700/700<01`L01@L01@071`L000H7
00<01`L02`L00`071`051`0300L700/700<01`L0:0L002P700<01`L02`L00`071`061`0300L700/7
00<01`L01@L00`0700081`0300L700/700<01`L01PL00`07000<1`0300L700H700<01`L01PL00`07
1`0:1`0300L000P700<01`L02`L00`071`061`0300L000L700<01`L02`L00`071`061`0300L700/7
00<01`L09`L002L73`091`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L>00T7
00<01`L01`L>00T700<01`L02`L00`071`071`0300L700H700<01`L02`L00`071`071`l0:0L002L7
00<01`L02`L00`071`071`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L00`07
1`0:1`0300L700L700<01`L01`L00`071`0:1`0300L700L700<01`L02`L00`071`071`0300L700H7
00<01`L02`L00`071`071`0300L700/700<01`L09PL001X70P0;1`0300L700<70P061`0300L700L7
00@01`002PL00`071`041`<02@L00`071`051`8010L00`071`071`0300L7008020L00`071`061`80
2@L00`071`061`800PL00`071`071`0300L700870P071`0300L700L70`061`0300L700P70P000`L0
1`081`0300L700@70P051`0300L700T70P0K1`006`L00`071`091`0300L700@700<01`L010L00`07
1`071`0400L700X700<01`L01@L200T700<01`L01PL00`071`021`0300L700L700D01`L700081`03
00L700L700<01`L01`L00`071`071`0400L700T700<01`L00`L00`071`051`0300L700L700<01`00
1PL00`071`091`0300L000T700<01`L01@L00`071`031`0300L700X700<01`L06@L001h700<01`L0
1PL00`071`0;1`0300L700L73`081`0300L700L73`091`0300L700X700<01`L01`L00`071`071`03
00L700X700<01`L01`L?00T700<01`L01PL?00T700<01`L02`L00`071`061`0300L701d7000M1`03
00L000L700<01`L02`L00`071`061`0300L000d700<01`L01@L00`071`061`0300L700/700<01`00
20L00`071`0:1`0300L700H700<01`0020L00`071`0:1`0300L700H700<01`003@L00`071`061`03
00L700D700<01`L02`L00`0700081`0300L700/700<01`L01@L00`07000N1`0070L01@071`L000H7
00<01`L02`L00`071`051`0500L71`003@L00`071`041`0300L700D700<01`L02`L01@071`L000L7
00<01`L02PL00`071`051`0500L71`001`L00`071`0:1`0300L700D700D01`L7000=1`0300L700D7
00<01`L010L00`071`0;1`0500L71`001`L00`071`0;1`0300L700@700D01`L7000M1`006`L00`07
1`031`0300L700<700<01`L02`L00`071`041`0300L700<700<01`L02`L00`071`031`0300L700@7
00<01`L02`L00`071`031`0300L700@700<01`L02PL00`071`041`0300L700<700<01`L010L00`07
1`0:1`0300L700@700<01`L00`L00`071`0;1`0300L700@700<01`L00`L00`071`0;1`0300L700<7
00<01`L010L00`071`0;1`0300L700<700<01`L00`L00`071`0J1`006@L300H700<01`L00PL200`7
0P031`801`L200`70P031`0300L700870P000`L000091`8000<7000010L00`071`031`0400L000T7
00<01`L010071`0400L0008700<01`L01`L200031`0700<70P041`8000<700L020L2008700<01`L0
0`L010071`L200`70P071`0300L700870P0;1`<010L00`071`041`806`L001P700@01`L01`L01007
1`L200`70P021`0300L700P70P0<1`0500L71`000`L00`071`021`0300L700H700<01`L00PL00`07
1`031`800`L010071`091`0500L71`002PL3008700<01`L020L00`0700031`0300L700D700<01`L0
0P081`0400L71`800`L010071`L200/700<01`0020L200<700<01`L02PL200<700<01`L01PL301T7
000G1`0300L700X700@01`L03@L010071`0=1`0300L700X700@01`L00PL00`071`0;1`0300L700/7
00@01`L030L010071`0=1`0400L700`700@01`L03@L00`071`0;1`0400L7008700<01`L02PL00`07
1`0;1`0400L700d700@01`L030L00`071`0F1`005PL00`071`0;1`8000<700L030L01007000>1`03
00L7008020L01@0700L000D70P061`0300L700P70P031`0300L000`70`0?1`<030L00`0700031`80
2PL00`071`041`801@L01@0700L000L70P031`0300L700`70P000`L01`0<1`0400L000d700<01`L0
5@L001D700<01`L03@L300d70P000`L01`0>1`0400L700T70`071`0300L700<700<01`L02PL00`07
1`021`8030L201470P0<1`801@L00`071`091`0300L700@700<01`L010L300T700@01`L040L300d7
0P000`L01`0=1`0300L701@7000D1`0300L701073`0C1a`04`L>01<73P0C1a`04`L?018700<01`L0
4`L001D700<01`L03PL200d70P0A1`0300L700X70`0=1`0300L700l70`0<1`0300L700l700<01`L0
2PL3014700<01`L02`L300`700<01`L03`L200d70P0@1`0300L701@7000F1`0300L700`700<01`00
3@L00`07000?1`0300L700X700D01`07000=1`0300L700d700D01`07000<1`0300L700d700<01`L0
2PL01@0700L000l700<01`L02`L01@0700L000`700<01`L03@L00`07000=1`0300L000h700<01`L0
5@L001L700<01`L02PL010071`0=1`0400L700d700<01`L02PL010071`021`0300L700/700<01`L0
2`L010071`021`0300L700X700<01`L02`L00`071`0:1`0400L7008700<01`L02`L00`071`0;1`04
00L7008700<01`L02PL00`071`0;1`0400L700d700@01`L030L00`071`0F1`0060L00`071`081`05
00L71`003@L01@071`L000/700<01`L02PL01@071`L000<700<01`L02`L00`071`091`0500L71`00
0`L00`071`0:1`0300L700T700<01`L02PL01@071`L000<700<01`L02@L00`071`0;1`0500L71`00
0`L00`071`0:1`0300L700T700D01`L7000=1`0500L71`002PL00`071`0G1`006@L00`071`071`05
00L71`003@L00`071`021`0300L700L700<01`L02`L01@071`L000@700<01`L02`L00`071`071`03
00L7008700D01`L7000=1`0300L700L700<01`L02`L01@071`L000@700<01`L01`L00`071`0;1`03
00L7008700D01`L7000=1`0300L700L700<01`L00PL00`071`0;1`0500L71`002@L00`071`0H1`00
6PL00`071`051`0300L7008700<01`L02`L00`071`031`0300L700D700<01`L02`L00`071`021`03
00L700<700<01`L02`L00`071`051`0300L700<700<01`L00PL00`071`0;1`0300L700D700<01`L0
2`L00`071`021`0300L700<700<01`L01@L00`071`0;1`0300L700<700<01`L00PL00`071`0;1`03
00L700D700<01`L00`L00`071`0;1`0300L7008700<01`L01@L00`071`0I1`006`L00`071`031`03
00L700<700<01`L02`L00`071`041`0300L700<700<01`L02`L00`071`031`0300L700@700<01`L0
2`L00`071`031`0300L700@700<01`L00`L00`071`0;1`0300L700<700<01`L02`L00`071`031`03
00L700@700<01`L00`L00`071`0;1`0300L700@700<01`L00`L00`071`0;1`0300L700<700<01`L0
10L00`071`0;1`0300L700<700<01`L00`L00`071`0J1`006PL300<700<01`L010L00`071`031`80
1PL00`071`051`0400L71`8030L00`071`021`<01`L00`071`071`800PL01@071`L000L700<01`L0
0P021`0300L700/70`000`L01`0<1`0300L700800PL00`071`051`0500L71`000PL200T700<01`L0
1@L300@700<01`L02PL200<700<01`L01@L00`071`041`801@L00`071`041`0400L71`<06`L001X7
0P0010L01`071`801@L00`071`041`801`L0100700L300T700<01`L00P021`801`L200T700<01`L0
0P000`L01`071`0300L000800`L00`071`051`8010L300@70P071`0300L700870P000`L01`071`04
00L000<700<01`L01@L200P700@01`070P021`0300L700L70P001@L000L000L70P071`0400L71`<0
1`L0100700L201/7000@1`l020L200`70P081`l010L01@071`L000P740091`0400L700D77@061`03
00L000T740081`0300L7008700@01`L73`091`0300L700X70P081`l04@L0010700<01`L02`L00`07
1`061`0300L700/700<01`L01`L00`071`0;1`0300L700H700<01`L01`L00`071`0;1`0300L700L7
00<01`L01PL00`071`0;1`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L00`07
1`061`0300L700/700<01`L01`L00`071`0;1`0300L700H700<01`L02`L00`071`0?1`0040L00`07
1`0;1`0300L700H700<01`L02`L00`071`071`0300L700/700<01`L01PL00`071`071`0300L700/7
00<01`L01`L00`071`061`0300L700/700<01`L02`L00`071`061`0300L700L700<01`L02`L00`07
1`071`0300L700H700<01`L02`L00`071`071`0300L700/700<01`L01PL00`071`0;1`0300L700l7
000@1`0300L700/700<01`L01PL00`071`0;1`0300L700L700<01`L02`L00`071`061`0300L700L7
00<01`L02`L00`071`071`0300L700H700<01`L02`L00`071`0;1`0300L700H700<01`L01`L00`07
1`0;1`0300L700L700<01`L01PL00`071`0;1`0300L700L700<01`L02`L00`071`061`0300L700/7
00<01`L03`L0010700<01`L02`L00`071`061`l02@L00`071`0;1`0300L700H700<01`L01`L00`07
1`0;1`0300L700L700<01`L01PL00`071`0;1`0300L700/700<01`L01PL00`071`071`0300L700/7
00<01`L01`L00`071`061`0300L700/700<01`L01`L?00P700<01`L02`L00`071`0?1`0040L00`07
1`0;1`0300L700D700<01`003@L00`071`061`0300L700/700<01`L01@L00`0700081`0300L700/7
00<01`L01PL00`0700071`0300L700/700<01`L02`L00`071`051`0300L000P700<01`L02`L00`07
1`061`0300L000L700<01`L02`L00`071`061`0300L700/700<01`001`L00`071`0;1`0300L700l7
000@1`0300L700/700<01`L010L01@071`L000d700<01`L01@L00`071`0;1`0300L700@700D01`L7
00071`0300L700/700<01`L01@L01@071`L000H700<01`L02`L00`071`0;1`0300L700@700D01`L7
00071`0300L700/700<01`L01@L01@071`L000H700<01`L02`L00`071`051`0300L700/700D01`L7
00061`0300L700/700<01`L03`L0010700<01`L02`L00`071`031`0300L700<700<01`L02`L00`07
1`041`0300L700/700<01`L00`L00`071`031`0300L700@700<01`L02`L00`071`041`0300L700<7
00<01`L00`L00`071`0;1`0300L700/700<01`L00`L00`071`031`0300L700@700<01`L02`L00`07
1`041`0300L700<700<01`L00`L00`071`0;1`0300L700@700<01`L02`L00`071`031`0300L700<7
00<01`L02`L00`071`0?1`0040L200`700<01`L00PL300D700<01`L02@L300D700<01`L020L20003
1`0700<700<01`L01@L010071`L300d700<01`L00P000`L01`061`0300L7008700@01`L70P081`03
00L700H70P031`0300L7008700<01`L01@L0100700021`0300L700/70`031`0300L700D700<01`L0
0PL300/700<01`L00`L300/700<01`L00`L300@700<01`L02PL20147000@1`8030L00`071`021`03
00L000H700<01`L02@L00`0700041`0300L700T700<01`0010L00`071`061`0400L71`803@L01007
1`L200P700<01`L00PL00`071`021`0300L700H700<01`L01`L01@071`L000@700<01`L01PL00`07
00021`0300L700/700<01`000PL00`071`061`0300L7008700<01`002`L00`071`021`0400L700X7
00<01`L01@L200@700<01`L02`L00`071`0?1`0040L00`071`0;1`0500L71`002PL00`071`0;1`05
00L71`003@L01@071`L000X700D01`L7000=1`0500L71`002PL01@071`L000d700<01`L02`L01@07
1`L000X700D01`L7000=1`0500L71`002PL01@071`L000d700D01`L7000=1`0300L700P700D01`L7
000=1`0300L700l7000@1`0300L700/700@01`L030L00`071`0;1`0400L700d700@01`L030L01007
1`0=1`0400L700`700@01`L03@L00`071`0;1`0400L700`700@01`L03@L010071`0<1`0400L700d7
00@01`L03@L00`071`0:1`0400L700d700<01`L03`L000`70P021`0300L700L70P021`0300L000H7
0P061`0300L700<70P061`0300L000<70P081`0400L01`802`L300/70`000`L01`081`800`L00`07
00061`801@L00`071`031`801PL00`0700031`802@L00`07000200/70`0;1`8000@700L020L200<7
00<01`001PL200D700<01`L00`L200L700<01`000PL200T700<01`L00P0=1`003@L010071`0:1`03
00L7008020L00`071`051`0300L700<700<01`L01@L200@700<01`L01PL200<700<01`L02PL200`7
0`0;1`0300L700870P071`0300L700<700<01`L010L00`071`041`801@L00`071`081`8000<700L0
2PL200d700<01`L00P091`0400L71`8020L00`071`021`0300L700D700<01`L01PL200<700<01`L0
1`L01@071`L000d7000@1`l04PLM01873`0B1ad04PL?01877@0B1`l04@L001d700<01`0040L00`07
1`0;1`0300L000d700<01`L03PL00`071`0;1`0300L0010700<01`L02`L00`07000=1`0300L700h7
00<01`003@L00`071`0>1`0300L700/700<01`003@L00`071`0>1`0300L001h7000L1`0500L71`00
3PL00`071`0;1`0500L71`003@L00`071`0<1`0300L700/700D01`L7000>1`0300L700/700D01`L7
000=1`0300L700`700D01`L7000=1`0300L700`700<01`L02`L01@071`L000d700<01`L030L01@07
1`L001d7000J1`801@L00`071`091`803@L00`071`021`803@L010071`L200L700<01`L020L20003
1`0700@700<01`L01`L200031`0700`700@01`000PL00`071`0;1`0400L000T700<01`L00`L01007
000:1`0300L700D70P031`0300L700/70P041`0300L700/70P0;1`0300L700<70P0K1`006PL200H7
00<01`L020L200`700<01`L010L200d700D01`L700061`0300L700X70P071`0300L700L70P0=1`05
00L71`000`L00`071`0;1`0300L000P700<01`L01@L00`07000;1`0300L700D700@01`L03@L00`07
00051`0300L700/700<01`L020L00`071`051`0300L701T7000I1`0300L700H700<01`L01`L00`07
1`0;1`0300L700L700<01`L02PL00`071`071`0300L700/700<01`L01`L00`071`071`0300L700X7
00<01`L01`L00`071`0:1`0300L700L700<01`L01`L00`071`0;1`0300L700L700<01`L02PL00`07
1`071`0300L700/700<01`L01`L00`071`061`0300L701P7000H1`0300L700P700<01`L01@L00`07
1`0;1`0300L700T700<01`L02PL00`071`051`0300L700/700<01`L02@L00`071`051`0300L700X7
00<01`L02@L00`071`0:1`0300L700D700<01`L02@L00`071`0;1`0300L700D700<01`L02PL00`07
1`091`0300L700/700<01`L01@L00`071`081`0300L701L7000G1`0300L700X700<01`L00`L00`07
1`0;1`0300L700/700<01`L02PL00`071`031`0300L700/700<01`L02`L00`071`031`0300L700X7
00<01`L02`L00`071`0:1`0300L700<700<01`L02`L00`071`0;1`0300L700<700<01`L02PL00`07
1`0;1`0300L700/700<01`L00`L00`071`0:1`0300L701H7000F1`0300L700`700D01`L7000=1`03
00L700d700<01`L02PL01@071`L000d700<01`L03@L01@071`L000`700<01`L03@L00`071`0:1`05
00L71`003`L00`071`0;1`0500L71`0030L00`071`0=1`0300L700/700D01`L7000>1`0300L701D7
000E1`0300L700h700<01`003@L00`071`0?1`0300L700X700<01`003@L00`071`0?1`0300L000`7
00<01`L03`L00`071`0:1`0300L0014700<01`L02`L00`07000<1`0300L700l700<01`L02`L00`07
000@1`0300L701@7000D1`0300L701073`0C1a`04`L>01<73P0C1a`04`L?018700<01`L04`L001@7
0P0@1`803@L201470P0<1`803@L00`071`0?1`8030L201470P0<1`804@L00`071`0;1`8030L20147
0P0=1`8040L201D7000<1`801PL00`0700031`802@L01007000<1`<02`L2008700<01`001`L200<7
00<01`001@L200H700<01`L00`L200P700@01`070P091`0300L000802`L300031`0700P70P0010L0
1`081`801@L00`071`031`801PL00`0700031`801`L00`0700021`802`L300/70`000`L01`081`80
0`L00`0700061`803@L000d700<01`L00P021`0400L700<700<01`L01PL200031`0000`7100;1`03
00L000870`061`0500L71`000PL00`071`021`801`L00`071`031`0400L71`800PL010071`021`03
00L700L70P000`L0000<1`0400L000X700<01`000PL00`071`0200@700<01`L00PL00`071`051`80
10L010071`041`0300L700870P001@L01`L0008700<01`L020L200031`0700/70P000`L000091`04
00L7008700<01`L00P031`0300L700/7000A1`0400L700<700<01`L020L01@0700L000d700<01`L0
0P0:1`800`L00`07000:1`0500L71`0010L00`071`061`0300L700L70`031`0300L700X70P021`03
00L700P70P031`0300L700X700D01`L700021`0300L700D70P091`0300L700800`L00`071`081`03
00L000<700<01`L020L200041`0700d700<01`L00P091`800`L01@071`L00147000D1`0300L70087
0P071`0300L7008700<01`L02`L00`071`021`801`L00`071`031`0300L700X700<01`L00PL200`7
0P071`0300L700<700<01`L02PL00`071`021`801`L00`071`031`0300L700X700<01`L00PL200L7
00<01`L02`L00`071`031`0300L700X700<01`L00PL200L700<01`L00`L00`071`0;1`0300L70087
00<01`L01@L00`071`031`0300L701<7000D1`0300L700@700<01`L00`L00`071`031`0300L700/7
00<01`L010L00`071`031`0300L700@700<01`L02PL00`071`041`0300L700/700<01`L00`L00`07
1`041`0300L700X700<01`L010L00`071`031`0300L700@700<01`L02PL00`071`041`0300L700<7
00<01`L02`L00`071`041`0300L700X700<01`L010L00`071`031`0300L700@700<01`L02`L00`07
1`031`0300L700<700<01`L010L00`071`0C1`0050L00`071`051`0500L71`001PL00`071`0;1`03
00L700D700D01`L700071`0300L700X700<01`L01@L00`071`0;1`0500L71`001`L00`071`0:1`03
00L700D700D01`L700071`0300L700X700<01`L01@L01@071`L000d700<01`L01@L00`071`0:1`03
00L700D700D01`L700071`0300L700/700<01`L010L01@071`L000L700<01`L04`L001@700<01`L0
1PL00`0700071`0300L700/700<01`L01PL00`0700081`0300L700X700<01`L01PL00`071`0;1`03
00L000P700<01`L02PL00`071`061`0300L000P700<01`L02PL00`071`061`0300L000d700<01`L0
1PL00`071`0:1`0300L700H700<01`0020L00`071`0;1`0300L700D700<01`0020L00`071`0C1`00
50L00`071`071`0300L700H700<01`L02`L00`071`071`0300L700L700<01`L02PL00`071`071`l0
2@L00`071`0:1`0300L700L700<01`L01`L00`071`0:1`0300L700L73`091`0300L700X700<01`L0
1`L00`071`071`0300L700/700<01`L01PL00`071`071`0300L701<7000D1`0300L700L700<01`L0
1PL00`071`0;1`0300L700L700<01`L01`L00`071`0:1`0300L700L700<01`L02`L00`071`071`03
00L700X700<01`L01`L00`071`071`0300L700X700<01`L01`L00`071`0;1`0300L700L700<01`L0
2PL00`071`071`0300L700L700<01`L02`L00`071`061`0300L700L700<01`L04`L001@700<01`L0
1`L00`071`061`0300L700/700<01`L01`L00`071`071`0300L700X700<01`L01`L00`071`0;1`03
00L700L700<01`L02PL00`071`071`0300L700L700<01`L02PL00`071`071`0300L700/700<01`L0
1`L00`071`0:1`0300L700L700<01`L01`L00`071`0;1`0300L700H700<01`L01`L00`071`0C1`00
50L00`071`071`0300L700H700<01`L02`L00`071`071`0300L700L700<01`L02PL00`071`071`03
00L700/700<01`L01`L00`071`0:1`0300L700L700<01`L01`L00`071`0:1`0300L700L700<01`L0
2`L00`071`071`0300L700X700<01`L01`L00`071`071`0300L700/700<01`L01PL00`071`071`03
00L701<700061`l01@L2008700<01`L01PL?00T700@01`001PL>00T700<01`L01@L200@700<01`L0
1`L>00P70P091`h02@L00`071`021`801`L00`071`071`h01PL200031`0700P73`081`0300L70080
1@L?00L700071`0300L700/700<01`L00`L010071`071`0300L000D700<01`L01@L00`071`061`04
00L700D700<01`L02PL00`0700081`0300L700H700<01`L00PL00`071`061`0300L0008700<01`L0
1`L00`071`061`0300L700H700<01`L020L01@0700L000P700<01`L00`L00`071`051`0300L700H7
00@01`002`L00`071`041`0300L000P700<01`L01PL00`071`021`0300L000L700D01`L700041`03
00L700/700<01`L01PL000P700<01`L02`L00`071`051`0300L700@700D01`L7000=1`0300L700D7
00<01`L01@L00`071`0:1`0500L71`001`L00`071`0;1`0300L700D700D01`L7000<1`0300L700D7
00<01`L01@L00`071`0:1`0500L71`001`L00`071`0;1`0300L700D700D01`L7000<1`0300L700D7
00<01`L01@L00`071`0;1`0500L71`001PL00`071`051`0300L700/700<01`L01`L000T700<01`L0
0P091`0300L700800PL00`071`031`0300L7008000<700L02@L200031`0700D700@01`L70P000`L0
1`091`<01@L00`071`021`<02`L300H700<01`L00PL200`70P051`0300L700<70P0<1`8010L00`07
1`041`<02`L200D700<01`L00`L300X700@01`000`L00`071`041`0400L000X70`031`0300L700<7
00<01`L00P021`0300L700L70P021`0300L700P7000:1`0400L700X700@01`L00PL00`071`021`03
00L7008700@01`L02PL010071`051`0300L700870P0<1`0300L700D700<01`L00PL200`70P051`03
00L700@70P0<1`0300L700<700<01`L00`L200/700<01`001@L00`071`031`0300L000/70P041`03
00L700D70P0;1`0300L000<700<01`L00`L01@071`L000T700@01`L010L00`071`021`0700L71`07
000;1`0300L000/7000;1`0300L700/700<01`L00PL00`071`021`0300L700H700<01`L02`L00`07
1`021`0300L7008700<01`L02`L00`071`061`0300L7008700<01`L02`L00`071`021`0300L700H7
00<01`L02`L00`071`021`0300L7008700<01`L02`L00`071`061`0300L7008700<01`L02`L00`07
1`021`0300L700H700<01`L02`L00`071`021`0300L7008700<01`L02`L00`071`061`0300L70087
00<01`L00PL00`071`0;1`0300L700X7000<1`0300L700/700D01`L700031`0300L700P700<01`L0
2`L01@071`L000<700<01`L02`L00`071`081`0500L71`003@L01@071`L000X700<01`L02`L01@07
1`L000<700<01`L02`L00`071`081`0500L71`003@L01@071`L000X700<01`L02`L01@071`L000<7
00<01`L02`L00`071`081`0500L71`000`L00`071`0;1`0300L700/7000=1`0300L700/700@01`L0
0PL00`071`0:1`0300L700/700@01`L00PL00`071`0;1`0300L700X700@01`L03@L010071`0<1`03
00L700/700@01`L00PL00`071`0;1`0300L700X700@01`L03@L010071`0<1`0300L700/700@01`L0
0PL00`071`0;1`0300L700X700@01`L00PL00`071`0;1`0300L700`7000>1`0300L700/700D01`07
000>1`0300L700/700D01`07000=1`0300L700`700<01`003@L00`07000>1`0300L700/700D01`07
000=1`0300L700`700<01`003@L00`07000>1`0300L700/700D01`07000=1`0300L700`700D01`07
000=1`0300L700d7000?1`0300L700/70`0@1`0300L700/70`0=1`0300L700h70P0=1`8040L00`07
1`0;1`<03@L00`071`0>1`803@L2010700<01`L02`L300d700<01`L03PL300d700<01`L03PL00107
3`051`802`LM01074@021`803PLM00h70P021a4040LM00/70P051`l04@L000l700<01`002`L300D7
00<01`L020L00`071`051`0300L700<70`0:1`0400L701070P0=1`800PL00`071`0;1`0300L700<7
00<01`L01@L300P700<01`L00PL00`071`0<1`0400L000d70`0?1`0400L700X70`061`0300L700@7
00<01`L02@L00`071`021`<030L20107000>1`0300L700/700D01`07000>1`0300L700/700D01`07
000=1`0300L700`700<01`003@L00`07000>1`0300L700/700D01`07000=1`0300L700`700<01`00
3@L00`07000>1`0300L700/700D01`07000=1`0300L700`700D01`07000=1`0300L700d7000=1`03
00L700/700@01`L00PL00`071`0:1`0300L700/700@01`L00PL00`071`0;1`0300L700X700@01`L0
3@L010071`0<1`0300L700/700@01`L00PL00`071`0;1`0300L700X700@01`L03@L010071`0<1`03
00L700/700@01`L00PL00`071`0;1`0300L700X700@01`L00PL00`071`0;1`0300L700`7000<1`03
00L700/700D01`L700031`0300L700P700<01`L02`L01@071`L000<700<01`L02`L00`071`081`05
00L71`003@L01@071`L000X700<01`L02`L01@071`L000<700<01`L02`L00`071`081`0500L71`00
3@L01@071`L000X700<01`L02`L01@071`L000<700<01`L02`L00`071`081`0500L71`000`L00`07
1`0;1`0300L700/7000;1`0300L700/700<01`L00PL01@071`L000T700<01`L02`L00`071`021`03
00L7008700<01`L02PL00`071`071`0300L7008700<01`L02`L00`071`021`0300L700L700<01`L0
2PL00`071`021`0300L7008700<01`L02PL00`071`071`0300L7008700<01`L02`L00`071`021`03
00L700L700<01`L02PL00`071`021`0300L7008700<01`L02`L00`071`071`0500L71`0010L00`07
1`0;1`0300L700X7000:1`0400L000X700@01`000PL00`071`021`0400L71`800PL00`071`071`80
0PL00`071`031`0400L71`<02`L200L700@01`L70`0;1`<01@L00`071`031`<02`L200D700<01`L0
0`L200/70`051`0300L700<70`0;1`8010L00`071`051`802`L300<700<01`L00`L00`071`0200T7
00@01`0010L00`071`021`0300L7008000<700L02@L200031`0700X700091`0500L71`002@L01@07
1`L0008700<01`L00`L01`071`L01`002`L00`0700061`0300L7008700<01`002`L200D700<01`L0
0`L200`70P061`0300L700<700<01`L02PL200D700<01`L010L00`071`0:1`8010L00`071`041`03
00L000/70P051`0300L700<700<01`002PL010071`031`0300L700@700@01`L02PL00`0700031`03
00L700<700D01`L700021`0300L700P700@01`L02PL000P700<01`L02`L00`071`051`0300L700@7
00D01`L7000=1`0300L700D700<01`L01@L00`071`0:1`0500L71`001`L00`071`0;1`0300L700D7
00D01`L7000<1`0300L700D700<01`L01@L00`071`0:1`0500L71`001`L00`071`0;1`0300L700D7
00D01`L7000<1`0300L700D700<01`L01@L00`071`0;1`0500L71`001PL00`071`051`0300L700/7
00<01`L01`L000H70P0=1`0300L700870P021`0300L700D700<01`0010L200L700<01`L01PL01007
00051`0300L700T70P000`L01`071`0300L700D70P041`0300L700H700@01`070P091`0300L700D7
0P081`0300L700L70P0010L01`081`0300L700870P071`0300L700H700@01`002`L00`071`031`80
00<700L01`L00`071`051`8010L00`0700071`0300L7008010L00`071`0:1`8020L000H73`061`04
00L700P73`091`0400L700H73P091`0300L700H700<01`L00PL00`071`071`h02@L00`071`071`h0
2@L00`071`031`0300L700D700<01`L01`L>00L700<01`002@L?00P700D01`L700051`l01`L001@7
00<01`L01`L00`071`061`0300L700/700<01`L01`L00`071`071`0300L700X700<01`L01`L00`07
1`0;1`0300L700L700<01`L02PL00`071`071`0300L700L700<01`L02PL00`071`071`0300L700/7
00<01`L01`L00`071`0:1`0300L700L700<01`L01`L00`071`0;1`0300L700H700<01`L01`L00`07
1`0C1`0050L00`071`071`0300L700H700<01`L02`L00`071`071`0300L700L700<01`L02PL00`07
1`071`0300L700/700<01`L01`L00`071`0:1`0300L700L700<01`L01`L00`071`0:1`0300L700L7
00<01`L02`L00`071`071`0300L700X700<01`L01`L00`071`071`0300L700/700<01`L01PL00`07
1`071`0300L701<7000D1`0300L700L700<01`L01PL00`071`0;1`0300L700L700<01`L01`L00`07
1`0:1`0300L700L700<01`L02`L00`071`071`0300L700X700<01`L01`L00`071`071`0300L700X7
00<01`L01`L00`071`0;1`0300L700L700<01`L02PL00`071`071`0300L700L700<01`L02`L00`07
1`061`0300L700L700<01`L04`L001@700<01`L01`L00`071`061`0300L700/700<01`L01`L00`07
1`071`0300L700X700<01`L01`L?00T700<01`L02PL00`071`071`0300L700L700<01`L02PL00`07
1`071`l02@L00`071`0:1`0300L700L700<01`L01`L00`071`0;1`0300L700H700<01`L01`L00`07
1`0C1`0050L00`071`061`0300L000L700<01`L02`L00`071`061`0300L000P700<01`L02PL00`07
1`061`0300L700/700<01`0020L00`071`0:1`0300L700H700<01`0020L00`071`0:1`0300L700H7
00<01`003@L00`071`061`0300L700X700<01`L01PL00`0700081`0300L700/700<01`L01@L00`07
00081`0300L701<7000D1`0300L700D700D01`L700061`0300L700/700<01`L01@L01@071`L000L7
00<01`L02PL00`071`051`0300L700/700D01`L700071`0300L700X700<01`L01@L01@071`L000L7
00<01`L02PL00`071`051`0500L71`003@L00`071`051`0300L700X700<01`L01@L01@071`L000L7
00<01`L02`L00`071`041`0500L71`001`L00`071`0C1`0050L00`071`041`0300L700<700<01`L0
0`L00`071`0;1`0300L700@700<01`L00`L00`071`041`0300L700X700<01`L010L00`071`0;1`03
00L700<700<01`L010L00`071`0:1`0300L700@700<01`L00`L00`071`041`0300L700X700<01`L0
10L00`071`031`0300L700/700<01`L010L00`071`0:1`0300L700@700<01`L00`L00`071`041`03
00L700/700<01`L00`L00`071`031`0300L700@700<01`L04`L001@700<01`L00PL200L700<01`L0
0PL00`071`0;1`0300L700870P071`0300L700<700<01`L02PL00`071`021`8030L200L700<01`L0
0`L00`071`0:1`0300L700870P071`0300L700<700<01`L02PL00`071`021`801`L00`071`0;1`03
00L700<700<01`L02PL00`071`021`801`L00`071`031`0300L700/700<01`L00PL00`071`051`03
00L700<700<01`L04`L001070P021`0500L71`002PL300031`0700`700<01`000P0:1`800`L300X7
00D01`L700031`8020L00`071`061`@00`L00`071`0:1`800PL00`071`081`800PL200`700H01`L7
00L200L70P081`800PL200<700<01`L01`L200031`07008700<01`L020L400031`0700`700<01`00
0P091`800`L00`071`020147000<1`800`L010071`021`0300L7008020L200031`0000`70P000`L0
1`091`8000L700L700L000D70P031`0400L700@70P071`0300L700870P041`0400L7008700@01`00
2@L200031`0000/70P021`0300L700L70P001@L01`L000<700@01`L70P041`0300L700@70`041`04
00L700<70P051`0300L0008700@01`002PL400/70`021`0300L700H70P021`0400L700<700<01`L0
0P0=1`003@L00`071`041`0300L000@700<01`L01`L01007000<1`<030L01P071`0700P700L01`L7
00L000H700<01`L010L00`071`041`0300L700H700<01`000PL00`071`071`0500L01`0030L20003
1`0700T700D01`0700091`0300L700<700<01`L010L00`071`041`0300L000@700<01`L01@L00`07
00031`0300L700T700<01`0030L200031`0700T700L01`L700L000L700<01`L02`L001@70P0@1`80
3@L201470P0<1`803@L00`071`0?1`8030L201470P0<1`804@L00`071`0;1`8030L201470P0=1`80
40L201D7000D1`0300L701073`0C1a`04`L>01<73P0C1a`04`L?018700<01`L04`L001D700<01`L0
3PL00`07000=1`0300L700l700<01`L02PL00`07000=1`0300L700l700<01`0030L00`071`0?1`03
00L700X700<01`004@L00`071`0;1`0300L000`700<01`L03`L00`071`0;1`0300L0010700<01`L0
50L001H700<01`L030L01@071`L000d700<01`L03@L00`071`0:1`0500L71`003@L00`071`0=1`05
00L71`0030L00`071`0=1`0300L700X700D01`L7000?1`0300L700/700D01`L7000<1`0300L700d7
00<01`L02`L01@071`L000h700<01`L05@L001L700<01`L02PL00`071`031`0300L700/700<01`L0
2`L00`071`0:1`0300L700<700<01`L02`L00`071`0;1`0300L700<700<01`L02PL00`071`0;1`03
00L700X700<01`L00`L00`071`0;1`0300L700/700<01`L00`L00`071`0:1`0300L700/700<01`L0
2`L00`071`031`0300L700X700<01`L05PL001P700<01`L020L00`071`051`0300L700/700<01`L0
2@L00`071`0:1`0300L700D700<01`L02`L00`071`091`0300L700D700<01`L02PL00`071`091`03
00L700X700<01`L01@L00`071`091`0300L700/700<01`L01@L00`071`0:1`0300L700T700<01`L0
2`L00`071`051`0300L700P700<01`L05`L001T700<01`L01`L00`071`061`0300L700/700<01`L0
1`L00`071`0;1`0300L700H700<01`L02`L00`071`071`0300L700H700<01`L02`L00`071`071`03
00L700/700<01`L01PL00`071`071`0300L700/700<01`L01PL00`071`0;1`0300L700L700<01`L0
2`L00`071`061`0300L700L700<01`L060L001X70P061`0300L700P70P0<1`0300L700<70`0=1`03
00L700801PL00`071`091`<01`L00`071`061`<03@L00`071`0200<700<01`L02`L300P700<01`L0
1@L300/700<01`L010L2008700<01`L02`L300D700<01`L02PL200X700<01`L010L201/7000K1`03
00L700<700<01`L02PL00`071`0;1`0300L700<700<01`L02`L00`071`021`0300L700D700<01`L0
2@L00`0700051`0300L700P700<01`003@L010071`021`0300L700/700@01`L02@L00`071`031`04
00L700X700<01`L01PL01@071`L000d70P041`0300L700/70P0;1`0300L700<70P0K1`0070L01@07
1`L000h700<01`L02`L01@071`L000d700<01`L030L00`071`0;1`0500L71`003PL00`071`0;1`05
00L71`003@L00`071`0<1`0500L71`003@L00`071`0<1`0300L700/700D01`L7000=1`0300L700`7
00D01`L7000M1`007@L00`07000@1`0300L700/700<01`003@L00`071`0>1`0300L700/700<01`00
40L00`071`0;1`0300L000d700<01`L03PL00`07000=1`0300L700h700<01`L02`L00`07000=1`03
00L700h700<01`007PL001073`0B1ad04PL?01877@0B1`l04PLM01873`0A1`0030L2008700<01`L0
1`L200870P071`801`L00`071`021`801`L200<70P081`800PL200/70`0;1`@02PL200@70P061`80
1@L00`071`031`801PL200@70P0:1`@02`L200`70P021`8020L200<70P071`8010L00`071`041`80
20L200870P091`0300L700803@L000d700@01`L02PL01P071`0700L700<01`L010L00`071`041`03
00L700@700<01`0010L00`071`061`0300L0008700<01`L02@L300`70P000`L01`091`0700L71`07
00071`0300L700<700<01`L010L00`071`041`0300L000@700<01`L01`L01@0700L000/70`0<1`05
00L01`002@L01`071`L01`001`L00`071`031`0300L700@700<01`L01@L00`0700031`0300L700L7
00D01`L7000=1`0040L00`071`0;1`0400L700`700<01`L02`L010071`0=1`0400L700`700@01`L0
3@L010071`0<1`0400L700d700<01`L02`L010071`0<1`0400L700d700@01`L030L010071`0=1`04
00L700d700<01`L02PL010071`0=1`0300L700l7000@1`0300L700/700D01`L7000:1`0300L700/7
00D01`L7000=1`0500L71`002PL01@071`L000d700D01`L7000:1`0500L71`003@L00`071`0;1`05
00L71`002PL01@071`L000d700D01`L7000:1`0500L71`003@L01@071`L000d700<01`L020L01@07
1`L000d700<01`L03`L001070P0<1`0600L71`070P061`0300L700P70P000`L01`031`0300L700P7
0P000`L01`021`0300L700L700<01`L00`0=1`0300L700<02@L01@071`L000<70P081`0300L700H7
0P031`0500L71`002@L3008700<01`L02`L3008700<01`L01`L010071`L300/700<01`L00PL01007
000:1`0300L700@70P000`L01`021`0300L700X70P0A1`0040L200`700<01`L00PL00`0700051`03
00L700X70P051`0300L700T700<01`0010L00`071`051`0300L700870P0=1`0700L71`0700071`03
00L7008700<01`L00PL00`071`061`0300L700L700D01`L700041`0300L700D700@01`L00PL00`07
1`0;1`0300L000<700<01`L01@L00`071`021`0300L000/700<01`L00`L00`07000;1`0300L700@7
0P041`0300L700/700<01`L03`L0010700<01`L02`L00`071`031`0300L700<700<01`L02`L00`07
1`041`0300L700/700<01`L00`L00`071`031`0300L700@700<01`L02`L00`071`041`0300L700<7
00<01`L00`L00`071`0;1`0300L700/700<01`L00`L00`071`031`0300L700@700<01`L02`L00`07
1`041`0300L700<700<01`L00`L00`071`0;1`0300L700@700<01`L02`L00`071`031`0300L700<7
00<01`L02`L00`071`0?1`0040L00`071`0;1`0300L700@700D01`L7000=1`0300L700D700<01`L0
2`L00`071`041`0500L71`001`L00`071`0;1`0300L700D700D01`L700061`0300L700/700<01`L0
2`L00`071`041`0500L71`001`L00`071`0;1`0300L700D700D01`L700061`0300L700/700<01`L0
1@L00`071`0;1`0500L71`001PL00`071`0;1`0300L700l7000@1`0300L700/700<01`L01@L00`07
000=1`0300L700H700<01`L02`L00`071`051`0300L000P700<01`L02`L00`071`061`0300L000L7
00<01`L02`L00`071`0;1`0300L700D700<01`0020L00`071`0;1`0300L700H700<01`001`L00`07
1`0;1`0300L700H700<01`L02`L00`0700071`0300L700/700<01`L03`L0010700<01`L02`L00`07
1`061`l02@L00`071`0;1`0300L700H700<01`L01`L00`071`0;1`0300L700L700<01`L01PL00`07
1`0;1`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L00`071`061`0300L700/7
00<01`L01`L?00P700<01`L02`L00`071`0?1`0040L00`071`0;1`0300L700H700<01`L02`L00`07
1`071`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L00`071`061`0300L700/7
00<01`L02`L00`071`061`0300L700L700<01`L02`L00`071`071`0300L700H700<01`L02`L00`07
1`071`0300L700/700<01`L01PL00`071`0;1`0300L700l7000@1`0300L700/700<01`L01PL00`07
1`0;1`0300L700L700<01`L02`L00`071`061`0300L700L700<01`L02`L00`071`071`0300L700H7
00<01`L02`L00`071`0;1`0300L700H700<01`L01`L00`071`0;1`0300L700L700<01`L01PL00`07
1`0;1`0300L700L700<01`L02`L00`071`061`0300L700/700<01`L03`L0010700<01`L02`L00`07
1`061`0300L700/700<01`L01`L00`071`0;1`0300L700H700<01`L01`L00`071`0;1`0300L700L7
00<01`L01PL00`071`0;1`0300L700/700<01`L01PL00`071`071`0300L700/700<01`L01`L00`07
1`061`0300L700/700<01`L01`L00`071`0;1`0300L700H700<01`L02`L00`071`0?1`0040L?00P7
00<01`L02`L00`071`071`l020L00`071`071`l02@L00`071`061ad020L00`071`071`l02@L00`07
1`061`l02@L00`071`0;1`0300L700H73`0A1`006PL200041`0700L70P041`801PL200L700<01`00
10091`0300L7008000@700001`L200P70P021`8000<700L01`L00`07000200<700<01`L01@L200@7
0`041`801`L010071`L300031`0700L700@01`000PL200L70P081`<000<700000PL00`071`071`D0
00<700L01PL200H70P031`<01`L0100700L201/7000K1`800`L00`071`041`801@L00`071`041`80
1PL010071`L200031`0700T700@01`L00PL200L70P091`0300L700800PL00`071`051`0300L70080
0PL00`071`071`0900L71`0700L000@700<01`L01PL010071`L200031`0700H700D01`L700031`03
00L700H70P071`0300L0008700<01`002`L00`0700031`0300L700D700<01`L01@L00`071`021`80
1PL01`071`L01`006`L001/700<01`L00`L00`071`031`0300L700/700<01`L010L00`071`031`03
00L700/700<01`L00`L00`071`041`0300L700/700<01`L00`L00`071`041`0300L700<700<01`L0
2`L00`071`031`0300L700/700<01`L00`L00`071`041`0300L700<700<01`L02`L00`071`041`03
00L700<700<01`L02`L00`071`031`0300L700@700<01`L02`L00`071`031`0300L700<700<01`L0
6PL001X700<01`L01@L00`071`021`0300L700/700<01`L00`L00`071`051`0300L700/700<01`L0
0PL00`071`031`0300L700/700<01`L01@L00`071`031`0300L7008700<01`L02`L00`071`051`03
00L700/700<01`L00PL00`071`031`0300L700D700<01`L02`L00`071`031`0300L7008700<01`L0
2`L00`071`051`0300L700<700<01`L02`L00`071`021`0300L700D700<01`L06@L001T700<01`L0
1PL00`071`021`0300L700/700<01`L00PL00`071`071`0300L700X700<01`L00PL00`071`021`03
00L700/700<01`L01`L00`071`021`0300L7008700<01`L02PL00`071`071`0300L700X700<01`L0
0PL00`071`021`0300L700L700<01`L02`L00`071`021`0300L7008700<01`L02PL00`071`071`03
00L7008700<01`L02`L00`071`021`0300L700H700<01`L060L001P700<01`L020L01@071`L000d7
00D01`L7000;1`0300L700X700D01`L700031`0300L700/700<01`L02@L01@071`L000<700<01`L0
2PL00`071`091`0300L700X700D01`L700031`0300L700T700<01`L02`L01@071`L000<700<01`L0
2PL00`071`091`0500L71`003@L01@071`L000X700<01`L05`L001L700<01`L02PL010071`0=1`04
00L700d700<01`L02PL010071`021`0300L700/700<01`L02`L010071`021`0300L700X700<01`L0
2`L00`071`0:1`0400L7008700<01`L02`L00`071`0;1`0400L7008700<01`L02PL00`071`0;1`04
00L700d700@01`L030L00`071`0F1`005PL00`071`0<1`0300L000d700<01`003`L00`071`0:1`05
00L01`003@L00`071`0=1`0500L01`0030L00`071`0=1`0300L700X700D01`07000?1`0300L700/7
00D01`07000<1`0300L700d700<01`003@L00`07000>1`0300L701D7000E1`0300L700h70P0=1`80
4@L00`071`0:1`<03@L00`071`0?1`<030L00`071`0?1`0300L700X70`0A1`0300L700/70`0<1`03
00L700l70P0=1`8040L00`071`0D1`0050L00`071`0@1`l04`LL01<73P0C1`h04`LL01<73`0B1`03
00L701<7000E1`0300L700`7100=1`@03`L0100700091`<01PL200D700<01`L02@L200@70P0<1`80
4@L200`70P041`802`L00`071`031`801PL300P70P021`0300L700d7100=1`@03PL00`071`0D1`00
5PL00`071`0<1`0300L000d700@01`003PL01@071`L000P700D01`0700061`0300L700@700<01`L0
2@L01`071`L01`0030L300l700<01`0030L00`0700041`0300L700P700<01`L01@L00`071`031`05
00L01`0020L01@071`L000l700<01`003@L01007000=1`0300L701D7000G1`0300L700X700@01`L0
3@L010071`0=1`0300L700X700@01`L00PL00`071`0;1`0300L700/700@01`L030L010071`0=1`04
00L700`700@01`L03@L00`071`0;1`0400L7008700<01`L02PL00`071`0;1`0400L700d700@01`L0
30L00`071`0F1`0060L0100700071`0400L71`8030L2008700<01`L01`L300/70P031`0500L71`00
0`L200P700@01`L70P051`800`L0100700091`0300L700802PL3008700<01`L01`L200031`070087
00<01`L010L200870P071`800`L200<700@01`L70P0;1`<020L200870P0;1`<00`L00`071`051`@0
6@L001T70`061`0300L700870P0<1`800`L200L70P0<1`800`L00`071`021`800PL00`071`071`80
0PL00`071`021`0300L700<700@01`L02@L010071`L300L700@01`L00PL00`071`081`0300L000@7
0P051`0300L000X700@01`L01@L00`071`021`0300L700X70P071`0300L700<700<01`L02PL200@7
00<01`L01@L00`071`0I1`006`L00`071`031`0300L700<700<01`L02`L00`071`041`0300L700<7
00<01`L02`L00`071`031`0300L700@700<01`L02`L00`071`031`0300L700@700<01`L02PL00`07
1`041`0300L700<700<01`L010L00`071`0:1`0300L700@700<01`L00`L00`071`0;1`0300L700@7
00<01`L00`L00`071`0;1`0300L700<700<01`L010L00`071`0;1`0300L700<700<01`L00`L00`07
1`0J1`0070L01@071`L000H700<01`L02`L00`071`051`0500L71`003@L00`071`041`0300L700D7
00<01`L02`L01@071`L000L700<01`L02PL00`071`051`0500L71`001`L00`071`0:1`0300L700D7
00D01`L7000=1`0300L700D700<01`L010L00`071`0;1`0500L71`001`L00`071`0;1`0300L700@7
00D01`L7000M1`007@L00`0700071`0300L700/700<01`L01PL00`07000=1`0300L700D700<01`L0
1PL00`071`0;1`0300L000P700<01`L02PL00`071`061`0300L000P700<01`L02PL00`071`061`03
00L000d700<01`L01PL00`071`051`0300L700/700<01`0020L00`071`0;1`0300L700D700<01`00
7PL001h700<01`L01PL00`071`0;1`0300L700L73`081`0300L700L73`091`0300L700X700<01`L0
1`L00`071`071`0300L700X700<01`L01`L?00T700<01`L01PL?00T700<01`L02`L00`071`061`03
00L701d7000W1`0300L700/700<01`L01`L00`071`0;1`0300L700H700<01`L01`L00`071`0;1`03
00L700L700<01`L02PL00`071`071`0300L700L700<01`L02PL00`071`071`0300L700/700<01`L0
1`L00`071`061`0300L700/700<01`L01`L00`071`0;1`0300L702H7000J1`802`L00`071`031`80
1PL00`071`071`0400L000X700<01`L010L300T700<01`L01@L200@700<01`L01`L00`071`0200P7
00<01`L01PL200T700<01`L01PL2008700<01`L01`L00`071`021`801`L00`071`071`<01PL00`07
1`081`8000<700L020L00`071`041`801@L00`071`091`806`L001/700<01`L02@L00`071`041`03
00L700@700<01`L01`L010071`0:1`0300L700D70P091`0300L700H700<01`L00PL00`071`071`05
00L71`0020L00`071`071`0300L700L700<01`L01`L010071`091`0300L700<700<01`L01@L00`07
1`071`0300L000H700<01`L02@L00`0700091`0300L700D700<01`L00`L00`071`0:1`0300L701T7
000W1`l02@L00`071`0;1`0300L700H700<01`L01`L00`071`0;1`0300L700L73P091`0300L700L7
3P091`0300L700/700<01`L01`L00`071`061`0300L700/700<01`L01`L?02P7000X1`0300L700/7
00<01`L01PL00`071`0;1`0300L700D700<01`0020L00`071`0;1`0300L700H700<01`0030L00`07
1`061`0300L700H700<01`L02PL00`0700081`0300L700/700<01`L01PL00`0700071`0300L700/7
00<01`L01PL00`071`0;1`0300L702L7000Y1`0300L700/700<01`L01@L00`071`0;1`0300L700@7
00D01`L700071`0300L700/700<01`L01@L01@071`L000`700<01`L01@L00`071`051`0300L700X7
00D01`L700071`0300L700/700<01`L01@L01@071`L000H700<01`L02`L00`071`051`0300L700/7
00<01`L0:0L002X700<01`L02`L00`071`041`0300L700/700<01`L00`L00`071`031`0300L700@7
00<01`L02`L00`071`041`0300L700<700<01`L02PL00`071`041`0300L700@700<01`L02PL00`07
1`031`0300L700@700<01`L02`L00`071`041`0300L700<700<01`L00`L00`071`0;1`0300L700@7
00<01`L02`L00`071`0Y1`00:`L00`071`0;1`0300L700<700<01`L02`L00`071`021`0300L700D7
00<01`L00`L00`071`0;1`0300L700<700<01`L01@L00`071`0:1`0300L700<700<01`L00`L00`07
1`0:1`0300L700D700<01`L00`L00`071`0;1`0300L700<700<01`L01@L00`071`021`0300L700/7
00<01`L00`L00`071`0;1`0300L702X7000W1`800`L00`071`061`800`L00`071`021`0400L71`80
20L010071`L200P700<01`L00`0;1`<010L00`071`041`<02`L300@700<01`L00PL300/70`061`03
00L700870`0;1`800`L00`071`061`800`L00`071`061`800`L00`071`021`0400L71`8020L00`07
1`0202T7000X1`0300L7008700<01`L01PL00`071`021`0500L71`0010L00`071`061`0400L71`80
2@L00`071`0200`70P031`0300L700H700<01`002`L00`0700031`0500L71`000PL00`071`081`04
00L700L700L01`L700L000/70P021`0300L700P700D01`L700091`0500L71`000`L00`071`031`03
00L700D700<01`L00PL00`071`0W1`0090L200P700<01`L01PL200<700@01`L02PL200051`071`00
30L400d700<01`L00P0;1`0300L700@70P051`0400L7008700<01`L00`L200H700<01`L02@L20087
00<01`L02`L400`700<01`L00`0;1`0400L700<70P081`0300L700H70P0U1`009@L00`071`071`03
00L700H700<01`L00PL00`07000;1`0500L01`003PL300d700D01`07000<1`0300L700@700<01`L0
10L01@0700L000L700<01`L00`L00`071`0;1`8000<700L030L00`07000>1`0500L01`002`L00`07
00051`0300L700D700<01`L020L00`071`0S1`00<0L00`071`0;1`803@L201070P0=1`8040L00`07
1`0;1`<03@L00`071`0>1`803@L201070P0=1`803@L00`071`0_1`00<@LM01873`0B1ad04PL?0187
7@0b1`00<0L00`071`0;1`<03@L00`071`0>1`0300L700/70`0@1`0300L700/70`0=1`0300L700h7
0`0=1`0300L700h700<01`L02`L300d700<01`L0;`L002l700<01`L02`L01@0700L000d700<01`L0
30L00`071`0;1`0500L01`003PL00`071`0;1`0500L01`003@L00`071`0<1`0500L01`003@L00`07
1`0<1`0300L700/700D01`07000=1`0300L702h7000^1`0300L700/700@01`L00PL00`071`0;1`03
00L700X700<01`L02`L010071`021`0300L700X700<01`L02`L010071`021`0300L700/700<01`L0
2PL010071`021`0300L700/700<01`L02PL00`071`0;1`0400L7008700<01`L02`L00`071`0]1`00
;@L00`071`0;1`0500L71`000`L00`071`0;1`0300L700P700<01`L02`L01@071`L000<700<01`L0
20L00`071`0;1`0500L71`000`L00`071`0;1`0300L700P700D01`L700031`0300L700/700<01`L0
20L00`071`0;1`0500L71`000`L00`071`0;1`0300L702`7000/1`0300L700/700<01`L00PL00`07
1`021`0300L700X700<01`L01`L00`071`0;1`0300L7008700<01`L00PL00`071`071`0300L700X7
00<01`L00PL00`071`021`0300L700X700<01`L01`L00`071`021`0300L7008700<01`L02`L00`07
1`071`0300L700X700<01`L00PL00`071`021`0300L700/700<01`L0:`L002/700<01`L02`L00`07
1`031`0300L700<700<01`L02PL00`071`051`0300L700/700<01`L00`L00`071`031`0300L700D7
00<01`L02PL00`071`031`0300L700<700<01`L02PL00`071`051`0300L700<700<01`L00`L00`07
1`0;1`0300L700D700<01`L02PL00`071`031`0300L700<700<01`L02`L00`071`0Z1`00:PL00`07
1`0200T700<01`L010L0100700031`0300L700X70`031`0300L700/70`041`0300L700@700<01`L0
0`L200/700<01`L00`L200H700<01`L02@L200D700<01`L010L00`071`021`<03@L010071`L300`7
00@01`L70P000`L01`051`0300L700L70P021`0300L702T7000Y1`0300L7008700<01`L01PL00`07
1`051`0400L700@700<01`L02PL2008700<01`L02`L010071`041`0300L700D700L01`L700L000X7
00<01`L01@L00`071`051`0300L700T70P031`0300L700D700<01`L00`L00`07000=1`0500L71`00
30L00`071`031`0300L000L700<01`L01`L01@071`L002X7000W1`8030L200P700@01`L70P031`03
00L700H70P021`0300L000H70P051`0300L700@70`081`0300L000802PL0100700051`0300L700<7
0P000`L01`091`<000<700L01`L300H700<01`L00PL200L700<01`000PL200P700@01`L70P031`03
00L700H70P0;1`80:@L002L740081`0300L7008700<01`L00PLL00P70P091`h00`L00`071`031`03
00L700@700<01`L03P091`0300L000L770051`0500L71`002@L?02P7000e1`0300L700L700<01`L0
1`L00`071`0:1`0300L700/700<01`L01`L00`071`071`0300L700X700<01`L01`L00`071`071`03
00L700X700<01`L01`L00`071`071`0300L700/700<01`L02PL00`071`071`0300L700L700<01`L0
=0L003D700<01`L01`L00`071`071`0300L700X700<01`L02`L00`071`071`0300L700L700<01`L0
2PL00`071`071`0300L700L700<01`L02PL00`071`071`0300L700L700<01`L02`L00`071`0:1`03
00L700L700<01`L01`L00`071`0d1`00=@L00`071`071`0300L700L700<01`L02PL00`071`0;1`03
00L700L700<01`L01`L00`071`0:1`0300L700L700<01`L01`L00`071`0:1`0300L700L700<01`L0
1`L00`071`0;1`0300L700X700<01`L01`L00`071`071`0300L703@7000e1`0300L700L700<01`L0
1`L00`071`0:1`0300L700/700<01`L01`L00`071`071`0300L700X700<01`L01`L00`071`071`03
00L700X700<01`L01`L00`071`071`0300L700/700<01`L02PL00`071`071`0300L700L700<01`L0
=0L003D700<01`L01PL00`0700081`0300L700X700<01`L02`L00`071`061`0300L000P700<01`L0
2PL00`071`061`0300L000P700<01`L02PL00`071`061`0300L000P700<01`L02`L00`071`0:1`03
00L700H700<01`0020L00`071`0d1`00=@L00`071`051`0500L71`001`L00`071`0:1`0300L700/7
00<01`L01@L01@071`L000L700<01`L02PL00`071`051`0500L71`001`L00`071`0:1`0300L700D7
00D01`L700071`0300L700/700<01`L02PL00`071`051`0500L71`001`L00`071`0d1`00=@L01007
00031`0300L700<700<01`L010L300X700<01`L01@L200@700<01`L010L00`071`031`801@L00`07
1`0:1`801@L00`071`031`0300L700<70P0<1`0300L700<70P051`0300L700@700<01`L00PL200L7
00<01`L01`L200031`0700D700<01`L00`L010071`L200031`0703D7000e1`0400L7008700<01`L0
1@L00`071`031`0300L000X700<01`L01PL00`071`021`0300L700<700<01`L01@L00`071`031`03
00L700X70P041`0300L700D700<01`L00`L00`071`0:1`0300L700<70P061`0300L700<700<01`L0
0`L00`071`051`0300L700P700<01`001@L00`071`051`0700L71`07000f1`00=@L00`071`021`03
00L700L700<01`L00PL00`071`0:1`0300L700/700<01`L00PL00`071`071`0300L7008700<01`L0
2PL00`071`021`0300L700L700<01`L00PL00`071`0:1`0300L7008700<01`L01`L00`071`021`03
00L700/700<01`L02PL00`071`021`0300L700L700<01`L00PL00`071`0d1`00=@L01@071`L000/7
00D01`L7000<1`0300L700/700D01`L7000;1`0500L71`0030L01@071`L000/700D01`L7000<1`05
00L71`002`L01@071`L000d700<01`L02PL01@071`L000/700D01`L7000f1`00=@L010071`0=1`04
00L700`700<01`L02`L010071`0=1`0400L700`700@01`L03@L010071`0<1`0400L700d700@01`L0
3@L00`071`0:1`0400L700d700@01`L0=PL003D700<01`003`L00`07000<1`0300L700/700<01`00
3`L00`07000<1`0300L000l700<01`0030L00`07000?1`0300L000d700<01`L02PL00`07000?1`03
00L003H7000e1`8030L200<70P071`800`L00`071`051`8010L200H70P091`8000<700002@L20003
1`0000/70P000`L000091`8000<700002@L200H70P031`8020L010071`L200L70P031`8030L203H7
000e1`803@L00`071`021a`020L00`071`081`h00`L00`071`0:1`0300L700h02`L00`071`051a`0
1@L00`071`0;1`0300L703@7001E1`0300L000d700<01`L03`L00`07000<1`0300L700l700<01`L0
2PL00`07000A1`0300L700/700<01`00EPL004470P0A1`800PL00`071`0;1`0400L000`700@01`L7
0`0:1`0300L700@70P071`0300L700P70`031`0300L700X70P000`L01`0<1`0300L700804@L20487
00121`0300L700h700<01`000`L00`071`0;1`0300L000/700<01`L00`L200/700<01`L010L00`07
1`041`0300L700X700<01`L00`L00`071`0:1`803@L00`071`021`804@L00`071`101`00DPL00`07
1`051`0300L700/700<01`L020L200L700<01`L02PL00`071`081`8030L00`071`051`0300L700P7
0P0<1`801`L00`071`1A1`00D@L00`071`071`8030L200L700<01`L020L00`071`0:1`801`L00`07
1`0;1`0300L700L70P071`0300L700/700<01`L020L00`071`1@1`00D0L00`071`0:1`0300L700/7
00<01`L00`L00`071`0:1`0300L700/700<01`L00`L00`071`0;1`0300L700X700<01`L00`L00`07
1`0;1`0300L700X700<01`L0C`L004l700<01`L030L00`071`0;1`0500L71`003PL00`071`0;1`05
00L71`003@L00`071`0<1`0500L71`003@L00`071`0<1`0300L704h7001>1`0300L700h700<01`L0
2`L00`07000@1`0300L700/700<01`003@L00`071`0>1`0300L000d700<01`L03PL00`071`1=1`00
C@L00`071`0@1`l04PLM01873`0B1`0300L704`7001>1`0300L700h70P0=1`8040L00`071`0;1`<0
3@L00`071`0>1`803@L2010700<01`L0C@L004l700<01`L030L00`07000=1`0300L000h700<01`L0
2`L01@0700L000d700<01`L030L00`07000=1`0300L000h700<01`L0CPL004X70P041`<02PL400/7
0`021`801`L2008700<01`L010L200031`00008700@01`L00PL00`071`0200031`0000H700<01`L0
0P071`800PL300/7100:1`<00`L204`7001;1`0300L700<70P091`0300L7008030L200<700<01`L0
1PL00`0700081`0600L700L00`L01@071`L0008700@01`L01`L010071`071`800PL00`07000;1`<0
00<700L02@L00`071`031`0300L704X7001A1`0300L700L700<01`L00PL00`071`0;1`0300L70087
00<01`L01`L00`071`0:1`0300L7008700<01`L00PL00`071`0:1`0300L700L700<01`L00PL00`07
1`0;1`0300L7008700<01`L01`L00`071`1@1`00DPL00`071`051`0300L700<700<01`L02`L00`07
1`031`0300L700D700<01`L02PL00`071`031`0300L700<700<01`L02PL00`071`051`0300L700<7
00<01`L02`L00`071`031`0300L700D700<01`L0D@L005<700<01`L00`L00`071`041`0300L700/7
00<01`L010L00`071`031`0300L700X700<01`L010L00`071`041`0300L700X700<01`L00`L00`07
1`041`0300L700/700<01`L010L00`071`031`0300L70587001D1`0500L71`001`L00`071`0;1`03
00L700D700D01`L7000<1`0300L700D700<01`L01@L00`071`0:1`0500L71`001`L00`071`0;1`03
00L700D700D01`L7001E1`00E@L00`0700081`0300L700/700<01`L01PL00`07000<1`0300L700H7
00<01`L01PL00`071`0:1`0300L000P700<01`L02`L00`071`061`0300L005H7001F1`0300L700L7
00<01`L02`L00`071`071`h02@L00`071`071`h02@L00`071`0;1`0300L700L700<01`L0E@L00607
00<01`L02`L00`071`0D1`0300L700L700<01`L01`L00`071`0D1`0300L700/700<01`L0G`L00607
00<01`L02`L00`071`0D1`0300L700L700<01`L01`L00`071`0D1`0300L700/700<01`L0G`L00607
00<01`L01@L200@700<01`L02PL200P700<01`L01PL200T700<01`L01PL200`700<01`L00PL200L7
00<01`L0G`L006073`0=1`0300L700H700<01`L01`L00`071`071`0300L700L700<01`L02PL?0647
00251`0300L700H700<01`0020L00`071`241`00Q@L00`071`051`0500L71`001`L00`071`241`00
K0L200`70P091`0300L700800PL00`071`031`0300L700800PL00`071`071`8030L206d7001]1`03
00L700/700<01`L01`L01`071`L01`001`L010071`021`0300L700P700<01`L02`L00`071`1[1`00
Q@L00`071`021`0300L700L700<01`L00PL00`071`241`00Q@L01@071`L000/700D01`L700261`00
Q@L010071`0=1`0400L708H700251`0300L000l700<01`00QPL008D70P0A1`80QPL008D70P0B1`03
00L708@7003o1b47003o1b47003o1b47003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.4473, -10.4473, 0.0728037, \
0.0728037}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Partial lattices of the Average Lattice", "Subtitle",
  Background->RGBColor[1, 0, 1]],

Cell[CellGroupData[{

Cell["j = 2, k =1", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AL021, Axes \[Rule] True, Prolog \[Rule] PointSize[0.025], 
      PlotRange \[Rule] \ {{\(-20\), 20}, {\(-20\), 20}}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[130]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.5 0.025 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -9 -9 ]
[.125 .4875 9 0 ]
[.25 .4875 -9 -9 ]
[.25 .4875 9 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -6 -9 ]
[.75 .4875 6 0 ]
[.875 .4875 -6 -9 ]
[.875 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -12 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -12 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-20)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-15)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-10)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(10)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(15)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(20)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-20)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-15)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-10)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(10)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(15)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(20)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.025 w
.17115 .26108 Mdot
.23365 .24077 Mdot
.29615 .22046 Mdot
.35865 .20015 Mdot
.42115 .17985 Mdot
.48365 .15954 Mdot
.54615 .13923 Mdot
.60865 .11892 Mdot
.67115 .09862 Mdot
.73365 .07831 Mdot
.79615 .058 Mdot
.17115 .32679 Mdot
.23365 .30649 Mdot
.29615 .28618 Mdot
.35865 .26587 Mdot
.42115 .24556 Mdot
.48365 .22526 Mdot
.54615 .20495 Mdot
.60865 .18464 Mdot
.67115 .16433 Mdot
.73365 .14403 Mdot
.79615 .12372 Mdot
.17115 .39251 Mdot
.23365 .3722 Mdot
.29615 .35189 Mdot
.35865 .33159 Mdot
.42115 .31128 Mdot
.48365 .29097 Mdot
.54615 .27066 Mdot
.60865 .25036 Mdot
.67115 .23005 Mdot
.73365 .20974 Mdot
.79615 .18943 Mdot
.17115 .45823 Mdot
.23365 .43792 Mdot
.29615 .41761 Mdot
.35865 .3973 Mdot
.42115 .377 Mdot
.48365 .35669 Mdot
.54615 .33638 Mdot
.60865 .31607 Mdot
.67115 .29577 Mdot
.73365 .27546 Mdot
.79615 .25515 Mdot
.17115 .52394 Mdot
.23365 .50363 Mdot
.29615 .48333 Mdot
.35865 .46302 Mdot
.42115 .44271 Mdot
.48365 .4224 Mdot
.54615 .4021 Mdot
.60865 .38179 Mdot
.67115 .36148 Mdot
.73365 .34117 Mdot
.79615 .32087 Mdot
.17115 .58966 Mdot
.23365 .56935 Mdot
.29615 .54904 Mdot
.35865 .52874 Mdot
.42115 .50843 Mdot
.48365 .48812 Mdot
.54615 .46781 Mdot
.60865 .44751 Mdot
.67115 .4272 Mdot
.73365 .40689 Mdot
.79615 .38658 Mdot
.17115 .65537 Mdot
.23365 .63507 Mdot
.29615 .61476 Mdot
.35865 .59445 Mdot
.42115 .57414 Mdot
.48365 .55384 Mdot
.54615 .53353 Mdot
.60865 .51322 Mdot
.67115 .49291 Mdot
.73365 .47261 Mdot
.79615 .4523 Mdot
.17115 .72109 Mdot
.23365 .70078 Mdot
.29615 .68048 Mdot
.35865 .66017 Mdot
.42115 .63986 Mdot
.48365 .61955 Mdot
.54615 .59925 Mdot
.60865 .57894 Mdot
.67115 .55863 Mdot
.73365 .53832 Mdot
.79615 .51802 Mdot
.17115 .78681 Mdot
.23365 .7665 Mdot
.29615 .74619 Mdot
.35865 .72589 Mdot
.42115 .70558 Mdot
.48365 .68527 Mdot
.54615 .66496 Mdot
.60865 .64466 Mdot
.67115 .62435 Mdot
.73365 .60404 Mdot
.79615 .58373 Mdot
.17115 .85252 Mdot
.23365 .83222 Mdot
.29615 .81191 Mdot
.35865 .7916 Mdot
.42115 .77129 Mdot
.48365 .75099 Mdot
.54615 .73068 Mdot
.60865 .71037 Mdot
.67115 .69006 Mdot
.73365 .66976 Mdot
.79615 .64945 Mdot
.17115 .91824 Mdot
.23365 .89793 Mdot
.29615 .87763 Mdot
.35865 .85732 Mdot
.42115 .83701 Mdot
.48365 .8167 Mdot
.54615 .7964 Mdot
.60865 .77609 Mdot
.67115 .75578 Mdot
.73365 .73547 Mdot
.79615 .71517 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[130]:=",
  ImageSize->{236, 236},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003/0000k0P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc>`7003/1`00k0L00>`7003/1`00k0L006T7
10031`80NPL006T700<01`L00`L010071`1i1`00JPL00`071`021`0400L700@70P1c1`00H`L400@7
00D01`L700021`0300L7008700<01`L0LPL006`700@01`L00PL00`071`021`0300L70787001Y1`04
00L7008700@01`L010L00`071`1b1`00JPL200@70P051`0300L70787001g1`0300L70787001g1`03
00L70787001g1`0300L70787001g1`0300L70787001g1`0300L70787001g1`0300L70787001g1`03
00L703`7100b1`00M`L00`071`0l1`@0<PL007L700<01`L0?0L40387001g1`0300L703`7100b1`00
M`L00`071`0_1`@0?`L007L700<01`L0;`L403l7001g1`0300L702l7100o1`00M`L00`071`0_1`@0
?`L007L700<01`L0LPL007L700<01`L08@L404d7001g1`0300L70247101=1`00M`L00`071`0Q1`@0
C@L007L700<01`L08@L404d7001g1`0300L701<7101K1`00J@L400870`051`0300L701<7100U1`@0
<PL006/700<01`L010L00`071`021`0300L701<7100U1`@0<PL006/700<01`L010L00`071`021`80
50L402D7100b1`00H`L400@700@01`L70`051`0300L703`7100b1`00J`L01@071`L000L700<01`L0
1@L406T7001Y1`<00`L00`071`051`0300L700D7100V1`@0?`L006/700@01`L710041`0300L700D7
100V1`@0?`L007L700<01`L01@L402H7100o1`00LPL400031`070307100o1`00LPL400031`070287
101=1`00LPL400031`070287101=1`00LPL400031`070287101=1`00M`L00`071`0Q1`@0C@L006@7
100?1`0300L70787001T1`@03`L00`071`0C1`@0F`L006@7100?1`0300L701<7100U1`@0<PL006@7
100?1`0300L701<7100U1`@0<PL005H7100M1`0300L701<7100U1`@0<PL005H7100M1`0300L700D7
100c1`@0<PL005H7100M1`0300L700D7100V1`@0?`L005H7100M1`0300L700D7100V1`@0?`L007L7
00<01`L01@L402H7100o1`00B0L402/700<01`L0;`L403l700181`@09PL400031`0707<700181`@0
9PL400031`070287101=1`00B0L402H710000`L01`0R1`@0C@L003/7100c1`@000<700L08PL404d7
000k1`@09@L400l700<01`L08@L404d7000k1`@09@L400031`0000800`L200D700<01`L04`L405/7
000k1`@09@L400<700D01`L700021`0300L7008700<01`L04`L402D7100b1`00I0L400<700D01`L7
00021`0300L700870P0D1`@09@L40387000]1`@0<PL400@700D01`L700021`0300L7008700<01`L0
4`L402D7100b1`00;@L402D7100A1`0500L71`000PL00`071`021`0300L703`7100b1`00;@L402D7
100?1`<00`L010071`041`0300L700D7101Y1`00;@L402D7100A1`0300L700870P051`0300L700D7
100V1`@0?`L005H7100M1`0300L700D7100V1`@0?`L004P7100[1`0300L700D7100V1`@0?`L004P7
100V1`@000<700L0<0L403l700181`@09PL400031`070287101=1`00B0L402H710000`L01`0R1`@0
C@L0078710000`L01`0R1`@0C@L003/7100h1`0300L70247101=1`00>`L402D7100?1`0300L70787
000k1`@09@L400l700<01`L04`L405/7000k1`@09@L400l700<01`L04`L402D7100b1`00;@L403<7
100?1`0300L701<7100U1`@0<PL002d7100U1`@07@L00`071`0C1`@09@L40387000]1`@09@L401d7
00<01`L01@L403<7100b1`00;@L402D7100M1`0300L700D7100V1`@0?`L005H7100M1`0300L700D7
100V1`@0?`L007L700<01`L01@L402H7100o1`00B0L402/700<01`L0;`L403l700181`@09PL40003
1`0707<700181`@09PL400031`070287101=1`00B0L402H710000`L01`0R1`@0C@L003/7100`1`L0
00<700L08PL404d7000k1`@09@L400X700<01`L00PL00`071`0Q1`@0C@L003/7100U1`@02PL00`07
1`021`8050L405/7000k1`@09@L400031`0000800PL300D700<01`L04`L402D7100b1`00I0L400L7
00<01`L01@L00`071`0C1`@09@L40387000]1`@0?PL00`071`051`0300L701<7100U1`@0<PL002d7
100U1`@05@L400@700<01`L0?0L40387000]1`@09@L401d700<01`L01@L406T7000]1`@09@L401d7
00<01`L01@L402H7100o1`00EPL401d700<01`L01@L402H7100o1`00B0L402/700<01`L01@L402H7
100o1`00B0L402H710000`L01`0`1`@0?`L004P7100V1`@000<700L08PL404d700181`@09PL40003
1`070287101=1`00LPL400031`070287101=1`00>`L403P700<01`L08@L404d7000k1`@09@L400l7
00<01`L0LPL003/7100U1`@03`L00`071`0C1`@0F`L003/7100U1`@03`L00`071`0C1`@09@L40387
000]1`@0<`L400l700<01`L04`L402D7100b1`001`L400<70P0B1`@00PL30087100=1`@00`L200l7
10021`<060L00`071`0C1`H05PL400<70P041`@02PL400870`0C1`@00`L200<700071`0300L700<7
00@01`L04`L00`071`041`0300L000<03`L01@071`L0008700<01`L030L400D700<01`L05@L00`07
1`051`@040L00`071`0E1`0500L71`000PL010071`L400`700<01`L010L00`071`0@1`0300L700<7
00@01`L00PL000P700<01`L00PL010071`0C1`0300L700@700<01`000`0?1`0500L71`000PL00`07
1`0<1`@01@L00`071`0E1`0300L700D7100@1`0300L701<710021`0400L701<700<01`L010L00`07
1`0A1`0300L7008700@01`L00PL000031`00008010L01@071`L0008700<01`L02@L400@700@01`L7
0`0=1`@010L01@071`L0008700<01`L030L400870`0H1`0300L700D7100=1`<05PL4008700@01`L0
4`L010071`L301D700D01`L700021`400@L11`002PL010071`021`0300L7014700D01`L7000G1`05
00L71`000PL00`071`0B1`0300L701P700<01`L01@L400d700<01`L05PL4008700@01`L04`L01@07
1`L001P700@01`L00PL100470@L000L700@01`L00PL010071`0A1`<00`L00`071`0C1`<00`L00`07
1`05010700<01`L060L00`071`0F1`0300L701H710021`0400L701470`031`0300L701<700@01`L0
0PL010071`021`0020L200@70P0D1`0400L71`@050L00`071`021`8000<700000P0@1`@04PL40003
1`0701L7100G1`0300L700870P0D1`0400L71`@04`L200@70P031`00B0L402H710000`L01`0R1`@0
C@L004P7100V1`@000<700L08PL404d7000k1`@0<`L400031`070287101=1`002@OM00H700091`03
00L7008700<01`L00`L00`071`021`0300L700<700<01`L00PL00`071`031`0300L7008700<01`L0
0`L00`071`021`D000<700L00`L00`071`031`0300L7008700<01`L00`L00`071`021`0300L700<7
00<01`L010041`0300L7008700<01`L00`L00`071`021`0300L700<700<01`L00PL00`071`031`@0
00<700L010L00`071`021`0300L700<700<01`L00PL00`071`031`0300L7008700<01`L00`L00`07
1`021`0300L700<700<01`L00PL00`071`031`0300L7008700<01`L00`L00`071`021`0300L700<7
00<01`L010L003/7100U1`@03`L00`071`0C1`@09@L40387001T1`@03`L00`071`0C1`@09@L40387
000]1`@0APL00`071`0C1`@09@L40387000]1`@09@L401d700<01`L0?0L40387000]1`@09@L401d7
00<01`L01@L406T7000]1`@09@L401d700<01`L01@L402H7100o1`00EPL401d700<01`L01@L402H7
100o1`00B0L402/700<01`L01@L402H7100o1`00B0L402H710000`L01`0`1`@0?`L004P7100V1`@0
00<700L08PL404d700181`@09PL400031`070287101=1`00LPL400031`070287101=1`00>`L403P7
00<01`L08@L404d7000k1`@09@L400l700<01`L0LPL003/7100U1`@03`L00`071`0C1`@0F`L003/7
100U1`@03`L00`071`0C1`@09@L40387000]1`@0<`L400l700<01`L04`L402D7100b1`00;@L402D7
100M1`0300L701<7100U1`@0<PL002d7100U1`@07@L00`071`051`@0<`L40387000]1`@09@L401d7
00<01`L01@L402H7100o1`00EPL401d700<01`L01@L402H7100o1`00B0L402/700<01`L01@L402H7
100o1`00B0L402/700<01`L0;`L403l700181`@08`L700031`0707<700181`@09PL400031`070287
101=1`00LPL400031`000287101=1`00>`L403071`000`L01`0R1`@0C@L003/7100U1`@01`L00`07
1`051`0300L70247101=1`00>`L402D710071`0300L700D700<01`L04`L405/7000k1`@09@L400L7
10041`0300L701<7100U1`@0<PL002d7100c1`@03`L00`071`0C1`@09@L40387000]1`@09@L401d7
00<01`L04`L402D7100b1`00;@L402D7100M1`0300L703`7100b1`00;@L402D7100M1`0300L700D7
101Y1`00EPL401d700<01`L01@L402H7100o1`00M`L00`071`051`@09PL403l700181`@0:`L00`07
1`051`@09PL403l700181`@09PL400031`070307100o1`00B0L402H710000`L01`0R1`@0C@L004P7
100V1`@000<700L08PL404d7000k1`@0<`L400031`070287101=1`00>`L402D7100?1`0300L70247
101=1`00>`L402D7100?1`0300L70787000k1`@09@L400l700<01`L04`L405/7001T1`@03`L00`07
1`0C1`@09@L40387000]1`@0APL00`071`0C1`@09@L40387000]1`@09@L401d700<01`L04`L402D7
100b1`00;@L402D7100M1`0300L700D7100c1`@0<PL002d7100U1`@07@L00`071`051`@09PL403l7
001F1`@07@L00`071`051`@09PL403l700181`@0:`L00`071`051`@09PL403l700181`@07@L400<7
1P000`L01`0`1`@0?`L004P7100O1`0500L71`000PL400031`0707<700181`@07`L01@071`L00087
10000`L0000R1`@0C@L006/700D01`L700021`@000<700L08PL404d7000k1`@0;0L01@071`L00087
00<01`L00PL00`071`0Q1`@0C@L003/7100U1`@000@700000`L010071`041`0300L70247101=1`00
>`L402D710031`0300L700870P051`0300L701<7101K1`00>`L402D7100?1`0300L701<7101K1`00
;@L403<7100?1`0300L701<7101K1`00;@L402D7100M1`0300L701<7101K1`00;@L402D7100M1`03
00L700D7101Y1`00;@L402D7100M1`0300L700D7101Y1`00EPL401d700<01`L01@L406T7001g1`03
00L700D7101Y1`00B0L402/700<01`L0LPL004P7100V1`@000<700L0L`L004P7100V1`@000<700L0
L`L004P7100V1`@000<700L0L`L003/7100c1`@000<700L0L`L003/7100U1`@03`L00`071`1b1`00
>`L402D7100?1`0300L70787000k1`@09@L400l700<01`L0LPL006@7100?1`0300L70787000]1`@0
APL00`071`1b1`00;@L402D7100M1`0300L70787000]1`@09@L401d700<01`L0LPL002d7100U1`@0
7@L00`071`1b1`00EPL400l710021`<01@L00`071`1b1`00B0L401l700<01`L010L00`071`021`03
00L7078700181`@07`L00`071`041`0300L700870P1c1`00B0L401l700@01`L70`051`0300L70787
00181`@07`L01@071`L000L700<01`L0LPL006T70`031`0300L700D700<01`L0LPL003/7100/1`04
00L71`@010L00`071`1b1`00>`L403P700<01`L0LPL003/7100h1`0300L70787000k1`@0>0L00`07
1`1b1`00;@L404H700<01`L0LPL002d710161`0300L70787000]1`@0APL00`071`1b1`00;@L404H7
00<01`L0LPL007L700<01`L0LPL007L700<01`L0LPL007L700<01`L0LPL007L700<01`L0LPL007L7
00<01`L0LPL007L700<01`L0LPL007L700<01`L0LPL007L700<01`L0LPL007L700<01`L0LPL007L7
00<01`L0LPL007L700<01`L0LPL007L700<01`L0LPL007L700<01`L0LPL007L700<01`L0LPL006T7
10031`801@L00`071`1b1`00J@L00`071`031`0400L700@700<01`L0LPL006X700<01`L00PL01007
1`041`80L`L006/700D01`L700021`0300L707L7001/1`0400L7008700<01`L0M`L006T700@01`L0
0PL010071`1i1`00JPL200@70P1j1`00k0L00>`7003/1`00\
\>"],
  ImageRangeCache->{{{0, 235}, {235, 0}} -> {-21.6366, -21.3638, 0.18182, \
0.18182}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[130]="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(basis21 = 
      FullSimplify[{A[2, 1, \[Alpha]] /. {m \[Rule] 1, n \[Rule] 0}, 
          A[2, 1, \[Alpha]] /. {m \[Rule] 0, 
              n \[Rule] 1}}]\), "\[IndentingNewLine]", 
    \(orig\  = \ 
      FullSimplify[
        A[2, 1, \[Alpha]] /. {m \[Rule] 0, n \[Rule] 0}]\)}], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    \({{\(-0.6541039886902862`\), 
        2.153493849327038`}, {1.8458960113097138`, \(-1.2874609518508957`\)}}\
\)], "Output",
  CellLabel->"Out[131]="],

Cell[BoxData[
    \({\(-0.6541039886902862`\), \(-0.47516171126863`\)}\)], "Output",
  CellLabel->"Out[132]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[basis21 - orig]\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \({{0.`, 
        2.8075978380173243`}, {2.321057722578344`, \(-0.8122992405822658`\)}}\
\)], "Output",
  CellLabel->"Out[133]="]
}, Open  ]],

Cell[BoxData[
    \(\(rad21\  = \ 
        N[\@\(\((basis21[\([1]\)]\  - \ orig)\) . \((basis21[\([1]\)]\  - \ \
orig)\)\)];\)\)], "Input",
  CellLabel->"In[134]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Append[basis21 - orig, {0, 0}], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-10\), 10}, {\(-10\), 10}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[135]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.5 .64038 Mdot
.61605 .45939 Mdot
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[135]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L0088710031`80U@L008@700D01`L700021`0300L7098700241`0500L71`000PL00`07
1`031`80S@L007`710041`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`07
1`031`0300L708`700221`<00`L010071`051`0300L708`700241`0300L700870P061`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L007d700<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<7
00<01`L0S0L007h700<01`L02PL00`071`031`80S@L007H710041`0300L700L70`061`0300L708`7
001o1`0300L700H700<01`L01PL00`071`2<1`00O0L010071`081`0300L700H700<01`L0S0L007`7
10081`@01@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`700281`<01PL00`071`2<1`00R`L00`071`031`0300L708`7
002;1`0300L700<70P2=1`00PPL400870`061`0300L708`700281`0300L700H700<01`L0S0L008P7
00<01`L01PL00`071`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00O0L400<700<01`L00PL300H7
00<01`L0S0L007`700<01`L030L00`071`031`0300L708`7001m1`0300L700/700<01`L00`L208d7
001f1`@010L00`071`071`<01PL00`071`2<1`00O`L00`071`061`0300L700H700<01`L0S0L007`7
00@01`L020L00`071`061`0300L708`7001m1`802@L400D700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L701X71P1/1`00T@L00`071`0H1`X0JPL0094700<01`L060L:06X7002A1`8060L<06T7
002A1`0300L701L7301Y1`00T@L00`071`0G1``0J@L0094700<01`L05`L<06T700071`@00`L201L7
00<01`L00`L00`071`021`<06@L301T710031`0300L700870`0H1`0300L701L73`0I1`<06PL00`07
1`031`0300L700870`0F1`@00`L200<700091`0500L71`000PL00`071`0D1`0300L700/700<01`L0
6@L00`071`0F1`0300L700`700<01`L05@L00`071`0G1``00`L00`071`0I1`0300L701L700<01`L0
2`L00`071`0E1`0500L71`000PL100470@L000T700D01`L700021`0300L701D700<01`L02PL00`07
1`0I1`0300L701L700<01`L02`L00`071`0E1`0300L701P72P041`0300L701T700<01`L060L00`07
1`0:1`0300L701D700D01`L700021`400@L11`0000<700000P041`0500L71`000PL00`071`0=1`@0
10L00`071`071`<04`L400870`0C1`@010L00`071`071`<060L201T72P0010L0000I1`<06`L00`07
1`071`<060L01@071`L000870@011`4700091`0500L71`000PL00`071`0F1`0300L700H700<01`L0
6@L00`071`0L1`0300L700H700<01`L05@L601X71P031`0300L701T700<01`L070L00`071`061`03
00L701P700D01`L700021`400@L11`001`L300<700@01`L05@L010071`081`0300L701T700<01`L0
6@L010071`081`0300L701<72P0E1`0400L700P700<01`L06@L00`071`0I1`0400L700P700<01`L0
5PL300<700@01`L00PL000T700<01`L00PL201H710081`@060L401T70P091`@04PL:01H70P091`@0
60L401P710081`@05`L00`071`021`800`L008/730291`00R`L<08T7002;1``0R@L000T7o`0B00H7
00091`0300L700<700<01`L010L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@7
00<01`L010L00`071`041`0300L700@700<01`L00`L00`071`041`0300L700@700<01`L010L00`07
1`041`0300L700<700<01`L010L00`071`041`0300L700@73P061`0300L700@700<01`L010L00`07
1`041`0300L700<700<01`L010L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@7
00<01`L010L00`071`041`0300L700@700<01`L00`L00`071`041`0300L700@700<01`L010L00`07
1`041`0300L700@700091`0300L701l700<01`L07`L00`071`0O1`0300L701T7300L1`0300L701l7
00<01`L07`L00`071`0O1`0300L700@7002<1`X0RPL008`72P2:1`00SPL608`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L007`710031`0300L70087
0`031`H0S0L007`700<01`L030L;08X7001m1`0300L700/72`2:1`00OPL00`071`071`l0R@L007l7
00<01`L01PL00`071`0<08T7001l1`0400L700P700<01`L030291`00O@L200T73`291`00R`L<08T7
002;1``0R@L008`72P2:1`00S0L:08X7002>1`H0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L008P70`061`0300L708`7
002;1`0300L700<700<01`L0S0L008/700<01`L00`L208d700281`<01PL00`071`2<1`00R0L00`07
1`061`0300L708`700281`0300L700H700<01`L0S0L008P710051`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L007d7
00<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<700<01`L0S0L007h7
00<01`L02PL00`071`031`80S@L007h700<01`L01`L300H700<01`L0S0L007l700<01`L01PL00`07
1`061`0300L708`7001l1`0400L700P700<01`L01PL00`071`2<1`00O0L400P710051`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0088710031`801PL00`071`2<1`00Q0L01@071`L0008700<01`L00`L00`071`2<1`00
Q0L01@071`L0008700<01`L00`L208d700241`0500L71`000PL00`071`2B1`00Q0L01@071`L00087
00<01`L0TPL008870`031`0400L709@700241`0300L700870P2E1`00o`LQ1`00o`LQ1`00o`LQ1`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.6619, -10.5516, 0.0735301, \
0.0735301}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[135]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice021\  = tiling2D[SphericalCut[N[AL021], 10], \ rad21]\)], "Input",\

  CellLabel->"In[136]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05146 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.46757 0.0544218 0.524269 0.0544218 [
[ 0 0 0 0 ]
[ 1 1.05146 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.05146 L
0 1.05146 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.15986 .15766 m
.29592 .11345 L
s
.15986 .15766 m
.15986 .30071 L
s
.29592 .11345 m
.43197 .06924 L
s
.29592 .11345 m
.29592 .2565 L
s
.43197 .06924 m
.56803 .02503 L
s
.43197 .06924 m
.43197 .2123 L
s
.56803 .02503 m
.56803 .16809 L
s
.02381 .34492 m
.15986 .30071 L
s
.02381 .34492 m
.02381 .48797 L
s
.15986 .30071 m
.29592 .2565 L
s
.15986 .30071 m
.15986 .44377 L
s
.29592 .2565 m
.43197 .2123 L
s
.29592 .2565 m
.29592 .39956 L
s
.43197 .2123 m
.56803 .16809 L
s
.43197 .2123 m
.43197 .35535 L
s
.56803 .16809 m
.70408 .12388 L
s
.56803 .16809 m
.56803 .31115 L
s
.70408 .12388 m
.70408 .26694 L
s
.02381 .48797 m
.15986 .44377 L
s
.02381 .48797 m
.02381 .63103 L
s
.15986 .44377 m
.29592 .39956 L
s
.15986 .44377 m
.15986 .58682 L
s
.29592 .39956 m
.43197 .35535 L
s
.29592 .39956 m
.29592 .54262 L
s
.43197 .35535 m
.56803 .31115 L
s
.43197 .35535 m
.43197 .49841 L
s
.56803 .31115 m
.70408 .26694 L
s
.56803 .31115 m
.56803 .4542 L
s
.70408 .26694 m
.84014 .22273 L
s
.70408 .26694 m
.70408 .41 L
s
.84014 .22273 m
.84014 .36579 L
s
.02381 .63103 m
.15986 .58682 L
s
.02381 .63103 m
.02381 .77409 L
s
.15986 .58682 m
.29592 .54262 L
s
.15986 .58682 m
.15986 .72988 L
s
.29592 .54262 m
.43197 .49841 L
s
.29592 .54262 m
.29592 .68567 L
s
.43197 .49841 m
.56803 .4542 L
s
.43197 .49841 m
.43197 .64147 L
s
.56803 .4542 m
.70408 .41 L
s
.56803 .4542 m
.56803 .59726 L
s
.70408 .41 m
.84014 .36579 L
s
.70408 .41 m
.70408 .55305 L
s
.84014 .36579 m
.84014 .50885 L
s
.02381 .77409 m
.15986 .72988 L
s
.15986 .72988 m
.29592 .68567 L
s
.15986 .72988 m
.15986 .87294 L
s
.29592 .68567 m
.43197 .64147 L
s
.29592 .68567 m
.29592 .82873 L
s
.43197 .64147 m
.56803 .59726 L
s
.43197 .64147 m
.43197 .78452 L
s
.56803 .59726 m
.70408 .55305 L
s
.56803 .59726 m
.56803 .74032 L
s
.70408 .55305 m
.84014 .50885 L
s
.70408 .55305 m
.70408 .69611 L
s
.84014 .50885 m
.97619 .46464 L
s
.84014 .50885 m
.84014 .6519 L
s
.97619 .46464 m
.97619 .60769 L
s
.15986 .87294 m
.29592 .82873 L
s
.29592 .82873 m
.43197 .78452 L
s
.29592 .82873 m
.29592 .97178 L
s
.43197 .78452 m
.56803 .74032 L
s
.43197 .78452 m
.43197 .92758 L
s
.56803 .74032 m
.70408 .69611 L
s
.56803 .74032 m
.56803 .88337 L
s
.70408 .69611 m
.84014 .6519 L
s
.70408 .69611 m
.70408 .83916 L
s
.84014 .6519 m
.97619 .60769 L
s
.84014 .6519 m
.84014 .79496 L
s
.29592 .97178 m
.43197 .92758 L
s
.43197 .92758 m
.56803 .88337 L
s
.56803 .88337 m
.70408 .83916 L
s
.56803 .88337 m
.56803 1.02643 L
s
.70408 .83916 m
.84014 .79496 L
s
.70408 .83916 m
.70408 .98222 L
s
.56803 1.02643 m
.70408 .98222 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[136]:=",
  ImageSize->{288, 302.812},
  ImageMargins->{{43, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001;PP10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00:870P1l1`00W`L300031`0707/7002L1`<010L00`071`1j1`00V@L300L7
00<01`L0NPL009H70`0:1`0300L707X7002C1`<03@L00`071`1j1`00S`L4010700<01`L0NPL008`7
0`0D1`0300L707X700291`<05`L00`071`1j1`00QPL301X700<01`L0NPL008<70`0M1`0300L707X7
00201`<080L00`071`1j1`00O@L302<700<01`L0NPL007X70`0V1`0300L707X7001g1`<000<700L0
9PL00`071`1j1`00L`L400@700<01`L09@L00`071`1j1`00L0L300P700<01`L09@L00`071`1j1`00
K@L300/700<01`L09@L00`071`1j1`00JPL300h700<01`L09@L00`071`1j1`00IPL4014700<01`L0
9@L00`071`1j1`00H`L301D700<01`L09@L00`071`1j1`00H0L301P700<01`L09@L00`071`1j1`00
G@L301/700<01`L09@L00`071`1j1`00F@L401h700<01`L09@L00`071`1j1`00EPL3028700<01`L0
9@L00`071`1j1`00D`L302D700<01`L09@L00`071`1j1`00D0L300031`0702D700<01`L09@L00`07
1`1j1`00C@L300@700<01`L090L00`071`0U1`0300L707X7001:1`<01`L00`071`0T1`0300L702D7
00<01`L08`L205D700171`<02PL00`071`0T1`0300L702D700<01`L080L300031`0705@700141`<0
3@L00`071`0T1`0300L702D700<01`L07@L300@700<01`L0D`L004470`0@1`0300L702@700<01`L0
9@L00`071`0J1`<01`L00`071`1C1`00?PL301<700<01`L090L00`071`0U1`0300L701L70`0:1`03
00L705<7000k1`<05PL00`071`0T1`0300L702D700<01`L050L300d700<01`L0D`L003P70`0I1`03
00L702@700<01`L09@L00`071`0A1`<040L00`071`1C1`00=@L301`700<01`L090L00`071`0U1`03
00L700h70`0C1`0300L705<7000b1`<07`L00`071`0T1`0300L702D700<01`L02`L301H700<01`L0
D`L002l70`0R1`0300L702@700<01`L09@L00`071`081`<06@L00`071`1C1`00;@L202D700<01`L0
90L00`071`0U1`0300L700D70`0L1`0300L705<7000]1`0300L702@700<01`L090L00`071`0U1`03
00L700870`0O1`0300L705<7000]1`0300L702@700<01`L090L00`071`0U1`0300L000808PL00`07
1`1C1`00;@L00`071`0T1`0300L702@700<01`L090L302D700<01`L0D`L002d700<01`L090L00`07
1`0T1`0300L702470`000`L01`0U1`0300L705<7000]1`0300L702@700<01`L090L00`071`0N1`<0
10L00`071`0T1`0300L705<7000]1`0300L702@700<01`L090L00`071`0K1`<01`L00`071`0T1`03
00L705<7000]1`0300L702@700<01`L090L00`071`0H1`<02PL00`071`0T1`0300L705<7000]1`03
00L702@700<01`L090L00`071`0E1`<03@L00`071`0T1`0300L705<7000]1`0300L702@700<01`L0
90L00`071`0A1`@040L00`071`0T1`0300L705<7000]1`0300L702@700<01`L090L00`071`0>1`<0
50L00`071`0T1`0300L705<7000]1`0300L702@700<01`L090L00`071`0;1`<05`L00`071`0T1`03
00L705<7000]1`0300L702@700<01`L090L00`071`081`<06PL00`071`0T1`0300L705<7000]1`03
00L702@700<01`L090L00`071`051`<07@L00`071`0T1`0300L705<7000]1`0300L702@700<01`L0
90L00`071`021`<080L00`071`0T1`0300L705<7000]1`0300L702@700<01`L090L00`07000202<7
00<01`L090L00`071`1C1`00;@L00`071`0T1`0300L702<70`0V1`0300L702@700<01`L0D`L002d7
00<01`L090L00`071`0P1`<000<700L09PL00`071`0T1`0300L705<7000]1`0300L702@700<01`L0
70L400@700<01`L09@L00`071`0T1`0300L705<7000]1`0300L702@700<01`L06@L300P700<01`L0
9@L00`071`0T1`0300L702<70P0^1`00;@L00`071`0T1`0300L701H70`0;1`0300L702D700<01`L0
90L00`071`0P1`<000<700L0;@L002d700<01`L090L00`071`0C1`<03PL00`071`0U1`0300L702@7
00<01`L070L400@700<01`L0;0L002d700<01`L090L00`071`0?1`@04@L00`071`0U1`0300L702@7
00<01`L06@L300P700<01`L0;0L002d700<01`L090L00`071`0<1`<05@L00`071`0U1`0300L702@7
00<01`L05PL300/700<01`L0;0L002d700<01`L090L00`071`091`<060L00`071`0U1`0300L702@7
00<01`L04`L300h700<01`L0;0L002d700<01`L090L00`071`061`<06`L00`071`0U1`0300L702@7
00<01`L03`L4014700<01`L0;0L002d700<01`L090L00`071`021`@07PL00`071`0U1`0300L702@7
00<01`L030L301D700<01`L0;0L002d700<01`L090L00`070002028700<01`L09@L00`071`0T1`03
00L700T70`0H1`0300L702`7000]1`0300L702<70`0U1`0300L702D700<01`L090L00`071`061`<0
6`L00`071`0/1`00;@L00`071`0P1`<000<700L09@L00`071`0U1`0300L702@700<01`L00PL401h7
00<01`L0;0L002d700<01`L07@L300@700<01`L090L00`071`0U1`0300L702@700<01`000P0R1`03
00L702`7000]1`0300L701X70`071`0300L702@700<01`L09@L00`071`0S1`<09@L00`071`0/1`00
;@L00`071`0G1`<02PL00`071`0T1`0300L702D700<01`L080L300031`0702D700<01`L0;0L002d7
00<01`L050L300d700<01`L090L00`071`0U1`0300L701d70`041`0300L702@700<01`L0;0L002d7
00<01`L04@L3010700<01`L090L00`071`0U1`0300L701X70`071`0300L702@700<01`L0;0L002d7
00<01`L03PL301<700<01`L090L00`071`0U1`0300L701L70`0:1`0300L702@700<01`L0;0L002d7
00<01`L02`L301H700<01`L090L00`071`0U1`0300L701@70`0=1`0300L702@700<01`L0;0L002d7
00<01`L020L301T700<01`L090L00`071`0U1`0300L701470`0@1`0300L702@700<01`L0;0L002d7
00<01`L01@L301`700<01`L090L00`071`0U1`0300L700h70`0C1`0300L702@700<01`L0;0L002d7
00<01`L00PL301l700<01`L090L00`071`0U1`0300L700/70`0F1`0300L702@700<01`L0;0L002d7
00<01`000P0R1`0300L702@700<01`L09@L00`071`081`<06@L00`071`0T1`0300L702`7000/1`<0
9@L00`071`0T1`0300L702D700<01`L01@L301`700<01`L090L00`071`0/1`00:@L300031`0702D7
00<01`L090L00`071`0U1`0300L700870`0O1`0300L702@700<01`L0;0L002H70`041`0300L702@7
00<01`L090L00`071`0U1`0300L000808PL00`071`0T1`0300L702`7000S1`<01`L00`071`0T1`03
00L702@700<01`L090L302D700<01`L090L00`071`0/1`0080L300X700<01`L090L00`071`0T1`03
00L702470`000`L01`0U1`0300L702@700<01`L0;0L001d70`0=1`0300L702@700<01`L090L00`07
1`0N1`<010L00`071`0T1`0300L702@700<01`L0;0L001X70`0@1`0300L702@700<01`L090L00`07
1`0K1`<01`L00`071`0T1`0300L702@700<01`L0;0L001L70`0C1`0300L702@700<01`L090L00`07
1`0H1`<02PL00`071`0T1`0300L702@700<01`L0;0L001@70`0F1`0300L702@700<01`L090L00`07
1`0E1`<03@L00`071`0T1`0300L702@700<01`L0;0L001470`0I1`0300L702@700<01`L090L00`07
1`0A1`@040L00`071`0T1`0300L702@700<01`L0;0L000h70`0L1`0300L702@700<01`L090L00`07
1`0>1`<050L00`071`0T1`0300L702@700<01`L0;0L000/70`0O1`0300L702@700<01`L090L00`07
1`0;1`<05`L00`071`0T1`0300L702@700<01`L0;0L000P70`0R1`0300L702@700<01`L090L00`07
1`081`<06PL00`071`0T1`0300L702@700<01`L0;0L000H70P0U1`0300L702@700<01`L090L00`07
1`051`<07@L00`071`0T1`0300L702@700<01`L0;0L000H700<01`L090L00`071`0T1`0300L702@7
00<01`L00PL3020700<01`L090L00`071`0T1`0300L702`700061`0300L702@700<01`L090L00`07
1`0T1`0300L000808`L00`071`0T1`0300L702@700<01`L0;0L000H700<01`L090L00`071`0T1`03
00L702<70`0V1`0300L702@700<01`L090L00`071`0/1`001PL00`071`0T1`0300L702@700<01`L0
80L300031`0702H700<01`L090L00`071`0T1`0300L702`700061`0300L702@700<01`L090L00`07
1`0L1`@010L00`071`0U1`0300L702@700<01`L090L00`071`0/1`001PL00`071`0T1`0300L702@7
00<01`L06@L300P700<01`L09@L00`071`0T1`0300L702<70P0^1`001PL00`071`0T1`0300L702@7
00<01`L05PL300/700<01`L09@L00`071`0T1`0300L702070`000`L01`0]1`001PL00`071`0T1`03
00L702@700<01`L04`L300h700<01`L09@L00`071`0T1`0300L701`710041`0300L702`700061`03
00L702@700<01`L090L00`071`0?1`@04@L00`071`0U1`0300L702@700<01`L06@L300P700<01`L0
;0L000H700<01`L090L00`071`0T1`0300L700`70`0E1`0300L702D700<01`L090L00`071`0F1`<0
2`L00`071`0/1`001PL00`071`0T1`0300L702@700<01`L02@L301P700<01`L09@L00`071`0T1`03
00L701<70`0>1`0300L702`700061`0300L702@700<01`L090L00`071`061`<06`L00`071`0U1`03
00L702@700<01`L03`L4014700<01`L0;0L000H700<01`L090L00`071`0T1`0300L70087100N1`03
00L702D700<01`L090L00`071`0<1`<05@L00`071`0/1`001PL00`071`0T1`0300L702@700<01`00
0P0R1`0300L702D700<01`L090L00`071`091`<060L00`071`0/1`001PL00`071`0T1`0300L702<7
0`0U1`0300L702D700<01`L090L00`071`061`<06`L00`071`0/1`001PL00`071`0T1`0300L70207
0`000`L01`0U1`0300L702D700<01`L090L00`071`021`@07PL00`071`0/1`001PL00`071`0T1`03
00L701d70`041`0300L702@700<01`L09@L00`071`0T1`0300L000808PL00`071`0/1`001PL00`07
1`0T1`0300L701X70`071`0300L702@700<01`L09@L00`071`0S1`<09@L00`071`0/1`001PL00`07
1`0T1`0300L701L70`0:1`0300L702@700<01`L09@L00`071`0P1`<000<700L09@L00`071`0/1`00
1PL00`071`0T1`0300L701@70`0=1`0300L702@700<01`L09@L00`071`0M1`<010L00`071`0T1`03
00L702`700061`0300L702@700<01`L04@L3010700<01`L090L00`071`0U1`0300L701X70`071`03
00L702@700<01`L0;0L000H700<01`L090L00`071`0>1`<04`L00`071`0T1`0300L702D700<01`L0
5`L300X700<01`L090L00`071`0/1`001PL00`071`0T1`0300L700/70`0F1`0300L702@700<01`L0
9@L00`071`0D1`<03@L00`071`0T1`0300L702`700061`0300L702@700<01`L020L301T700<01`L0
90L00`071`0U1`0300L701470`0@1`0300L702@700<01`L0;0L000H700<01`L090L00`071`051`<0
70L00`071`0T1`0300L702D700<01`L03PL301<700<01`L090L00`071`0/1`001PL00`071`0T1`03
00L700870`0O1`0300L702@700<01`L09@L00`071`0;1`<05PL00`071`0T1`0300L702`700061`03
00L702@700<01`000P0R1`0300L702@700<01`L09@L00`071`081`<06@L00`071`0T1`0300L702`7
00061`0300L702<70`0U1`0300L702@700<01`L09@L00`071`051`<070L00`071`0T1`0300L702`7
00061`0300L702070`000`L01`0U1`0300L702@700<01`L09@L00`071`021`<07`L00`071`0T1`03
00L702`700061`0300L701d70`041`0300L702@700<01`L090L00`071`0U1`0300L000808PL00`07
1`0T1`0300L702`700061`0300L701X70`071`0300L702@700<01`L090L00`071`0T1`<09@L00`07
1`0T1`0300L702`700061`0300L701L70`0:1`0300L702@700<01`L090L00`071`0Q1`<000<700L0
9@L00`071`0T1`0300L702`700061`0300L701@70`0=1`0300L702@700<01`L090L00`071`0N1`<0
10L00`071`0T1`0300L702@700<01`L0;0L000H700<01`L04@L3010700<01`L090L00`071`0T1`03
00L701/70`071`0300L702@700<01`L090L00`071`0S1`801`L000H700<01`L03PL301<700<01`L0
90L00`071`0T1`0300L701P70`0:1`0300L702@700<01`L090L00`071`0P1`<000<700L01PL000H7
00<01`L02`L301H700<01`L090L00`071`0T1`0300L701D70`0=1`0300L702@700<01`L090L00`07
1`0M1`<010L00`071`051`001PL00`071`081`<06@L00`071`0T1`0300L702@700<01`L04@L40107
00<01`L090L00`071`0T1`0300L701X70`071`0300L700D700061`0300L700D70`0L1`0300L702@7
00<01`L090L00`071`0>1`<050L00`071`0T1`0300L702@700<01`L05`L300X700<01`L01@L000H7
00<01`L00PL301l700<01`L090L00`071`0T1`0300L700/70`0G1`0300L702@700<01`L090L00`07
1`0D1`<03@L00`071`051`001PL00`070002028700<01`L090L00`071`0T1`0300L700P70`0J1`03
00L702@700<01`L090L00`071`0A1`<040L00`071`051`001PL202D700<01`L090L00`071`0T1`03
00L700D70`0M1`0300L702@700<01`L090L00`071`0>1`<04`L00`071`051`001PL00`071`0T1`03
00L702@700<01`L090L00`071`021`<080L00`071`0T1`0300L702@700<01`L02`L301H700<01`L0
1@L000H700<01`L090L00`071`0T1`0300L702@700<01`000P0S1`0300L702@700<01`L090L00`07
1`081`<06@L00`071`051`001PL00`071`0T1`0300L702@700<01`L08`L302H700<01`L090L00`07
1`0T1`0300L700D70`0L1`0300L700D700061`0300L702@700<01`L090L00`071`0P1`<000<700L0
9PL00`071`0T1`0300L702@700<01`L00PL301l700<01`L01@L000H700<01`L090L00`071`0T1`03
00L701`710041`0300L702D700<01`L090L00`071`0T1`0300L000808PL00`071`051`001PL00`07
1`0T1`0300L702@700<01`L06@L300P700<01`L09@L00`071`0T1`0300L702<70`0U1`0300L700D7
00061`0300L702@700<01`L090L00`071`0F1`<02`L00`071`0U1`0300L702@700<01`L080L30003
1`0702D700<01`L01@L000H700<01`L090L00`071`0T1`0300L701<70`0>1`0300L702D700<01`L0
90L00`071`0L1`@010L00`071`0T1`0300L700D700061`0300L702@700<01`L090L00`071`0?1`@0
4@L00`071`0U1`0300L702@700<01`L06@L300P700<01`L090L00`071`051`001PL00`071`0T1`03
00L702@700<01`L030L301D700<01`L09@L00`071`0T1`0300L701H70`0;1`0300L702@700<01`L0
1@L000H700<01`L090L00`071`0T1`0300L700T70`0H1`0300L702D700<01`L090L00`071`0C1`<0
3PL00`071`0T1`0300L700D700061`0300L702@700<01`L090L00`071`061`<06`L00`071`0U1`03
00L702@700<01`L03`L4014700<01`L090L00`071`051`001PL00`071`0T1`0300L702@700<01`L0
0PL401h700<01`L09@L00`071`0T1`0300L700`70`0E1`0300L702@700<01`L01@L000H700<01`L0
90L00`071`0T1`0300L000808PL00`071`0U1`0300L702@700<01`L02@L301P700<01`L090L00`07
1`051`001PL00`071`0T1`0300L702<70`0U1`0300L702D700<01`L090L00`071`061`<06`L00`07
1`0T1`0300L700D700061`0300L702@700<01`L080L300031`0702D700<01`L09@L00`071`0T1`03
00L70087100N1`0300L702@700<01`L01@L000H700<01`L090L00`071`0M1`<010L00`071`0T1`03
00L702D700<01`L090L00`070002028700<01`L090L00`071`051`001PL00`071`0T1`0300L701X7
0`071`0300L702@700<01`L09@L00`071`0S1`<09@L00`071`0T1`0300L700D700061`0300L702@7
00<01`L05`L300X700<01`L090L00`071`0U1`0300L702070`000`L01`0U1`0300L702@700<01`L0
1@L000H700<01`L090L00`071`0D1`<03@L00`071`0T1`0300L702D700<01`L07@L300@700<01`L0
90L00`071`0T1`0300L700D700061`0300L702@700<01`L04@L3010700<01`L090L00`071`0U1`03
00L701X70`071`0300L702@700<01`L090L00`071`051`001PL00`071`0T1`0300L700h70`0C1`03
00L702@700<01`L09@L00`071`0G1`<02PL00`071`0T1`0300L702@700<01`L01@L000H700<01`L0
90L00`071`0;1`<05PL00`071`0T1`0300L702D700<01`L050L300d700<01`L090L00`071`0T1`03
00L700D700061`0300L702@700<01`L020L301T700<01`L090L00`071`0U1`0300L701470`0@1`03
00L702@700<01`L090L00`071`051`001PL00`071`0T1`0300L700D70`0L1`0300L702@700<01`L0
9@L00`071`0>1`<04`L00`071`0T1`0300L702@700<01`L01@L000H700<01`L090L00`071`021`<0
7`L00`071`0T1`0300L702D700<01`L02`L301H700<01`L090L00`071`0T1`0300L700D700061`03
00L702@700<01`000P0R1`0300L702@700<01`L09@L00`071`081`<06@L00`071`0T1`0300L702@7
00<01`L01@L000H700<01`L08`L302D700<01`L090L00`071`0U1`0300L700D70`0L1`0300L702@7
00<01`L090L00`071`051`001PL00`071`0P1`<000<700L09@L00`071`0T1`0300L702D700<01`L0
0PL301l700<01`L090L00`071`0T1`0300L700D700061`0300L701d70`041`0300L702@700<01`L0
90L00`071`0U1`0300L000808PL00`071`0T1`0300L702@700<01`L01@L000H700<01`L06PL300L7
00<01`L090L00`071`0T1`0300L702@70`0U1`0300L702@700<01`L090L00`071`051`001PL00`07
1`0G1`<02PL00`071`0T1`0300L702@700<01`L08@L300031`0702D700<01`L090L00`071`0T1`03
00L700D700061`0300L701@70`0=1`0300L702@700<01`L090L00`071`0N1`<010L00`071`0T1`03
00L702@700<01`L090L00`071`051`001PL00`071`0A1`<040L00`071`0T1`0300L702@700<01`L0
6`L300L700<01`L090L00`071`0T1`0300L702<70P071`001PL00`071`0>1`<04`L00`071`0T1`03
00L702@700<01`L060L300X700<01`L090L00`071`0T1`0300L702070`091`001PL00`071`0;1`<0
5PL00`071`0T1`0300L702@700<01`L05@L300d700<01`L090L00`071`0T1`0300L701d70`0<1`00
1PL00`071`081`<06@L00`071`0T1`0300L702@700<01`L04@L4010700<01`L090L00`071`0T1`03
00L701X70`0?1`001PL00`071`051`<070L00`071`0T1`0300L702@700<01`L03PL301@700<01`L0
90L00`071`0T1`0300L701L70`0B1`001PL00`071`021`<07`L00`071`0T1`0300L702@700<01`L0
2`L301L700<01`L090L00`071`0T1`0300L701@70`0E1`001PL00`070002028700<01`L090L00`07
1`0T1`0300L700P70`0J1`0300L702@700<01`L090L00`071`0A1`<060L000H70P0U1`0300L702@7
00<01`L090L00`071`051`<07@L00`071`0T1`0300L702@700<01`L03PL301/700061`0300L702@7
00<01`L090L00`071`0T1`0300L700870`0P1`0300L702@700<01`L090L00`071`0;1`<07PL000H7
00<01`L090L00`071`0T1`0300L702@700<01`000P0S1`0300L702@700<01`L090L00`071`081`<0
8@L000H700<01`L090L00`071`0T1`0300L702<70`0V1`0300L702@700<01`L090L00`071`051`<0
90L000H700<01`L090L00`071`0T1`0300L702070`000`L01`0V1`0300L702@700<01`L090L00`07
1`021`<09`L000H700<01`L090L00`071`0T1`0300L701`710041`0300L702D700<01`L090L00`07
1`0T1`0300L00080:PL000H700<01`L090L00`071`0T1`0300L701T70`081`0300L702D700<01`L0
90L00`071`0S1`<0;@L000H700<01`L090L00`071`0T1`0300L701H70`0;1`0300L702D700<01`L0
90L00`071`0P1`<000<700L0;@L000H700<01`L090L00`071`0T1`0300L701<70`0>1`0300L702D7
00<01`L090L00`071`0L1`@010L00`071`0/1`001PL00`071`0T1`0300L702@700<01`L03`L40147
00<01`L09@L00`071`0T1`0300L701T70`081`0300L702`700061`0300L702@700<01`L090L00`07
1`0<1`<05@L00`071`0U1`0300L702@700<01`L05PL300/700<01`L0;0L000H700<01`L090L00`07
1`0T1`0300L700T70`0H1`0300L702D700<01`L090L00`071`0C1`<03PL00`071`0/1`001PL00`07
1`0T1`0300L702@700<01`L01PL301/700<01`L09@L00`071`0T1`0300L700l7100A1`0300L702`7
00061`0300L702@700<01`L090L00`071`021`@07PL00`071`0U1`0300L702@700<01`L030L301D7
00<01`L0;0L000H700<01`L090L00`071`0T1`0300L000808PL00`071`0U1`0300L702@700<01`L0
2@L301P700<01`L0;0L000H700<01`L090L00`071`0S1`<09@L00`071`0U1`0300L702@700<01`L0
1PL301/700<01`L0;0L000H700<01`L090L00`071`0P1`<000<700L09@L00`071`0U1`0300L702@7
00<01`L00PL401h700<01`L0;0L000H700<01`L090L00`071`0M1`<010L00`071`0T1`0300L702D7
00<01`L090L00`070002028700<01`L0;0L000H700<01`L090L00`071`0J1`<01`L00`071`0T1`03
00L702D700<01`L08`L302D700<01`L0;0L000H700<01`L090L00`071`0G1`<02PL00`071`0T1`03
00L702D700<01`L080L300031`0702D700<01`L0;0L000H700<01`L090L00`071`0D1`<03@L00`07
1`0T1`0300L702D700<01`L07@L300@700<01`L090L00`071`0/1`001PL00`071`0T1`0300L70147
0`0@1`0300L702@700<01`L09@L00`071`0J1`<01`L00`071`0T1`0300L702`700061`0300L702@7
00<01`L03PL301<700<01`L090L00`071`0U1`0300L701L70`0:1`0300L702@700<01`L0;0L000H7
00<01`L090L00`071`0;1`<05PL00`071`0T1`0300L702D700<01`L050L300d700<01`L090L00`07
1`0/1`001PL00`071`0T1`0300L700P70`0I1`0300L702@700<01`L09@L00`071`0A1`<040L00`07
1`0T1`0300L702`700061`0300L702@700<01`L01@L301`700<01`L090L00`071`0U1`0300L700h7
0`0C1`0300L702@700<01`L0;0L000H700<01`L090L00`071`021`<07`L00`071`0T1`0300L702D7
00<01`L02`L301H700<01`L090L00`071`0/1`001PL00`071`0T1`0300L000808PL00`071`0T1`03
00L702D700<01`L020L301T700<01`L090L00`071`0/1`001PL00`071`0S1`<09@L00`071`0T1`03
00L702D700<01`L01@L301`700<01`L090L00`071`0/1`001PL00`071`0P1`<000<700L09@L00`07
1`0T1`0300L702D700<01`L00PL301l700<01`L090L00`071`0/1`001PL00`071`0M1`<010L00`07
1`0T1`0300L702@700<01`L09@L00`070002028700<01`L090L00`071`0/1`001PL00`071`0J1`<0
1`L00`071`0T1`0300L702@700<01`L090L302D700<01`L090L00`071`0/1`001PL00`071`0G1`<0
2PL00`071`0T1`0300L702@700<01`L08@L300031`0702D700<01`L090L00`071`0/1`001PL00`07
1`0D1`<03@L00`071`0T1`0300L702@700<01`L07PL300@700<01`L090L00`071`0T1`0300L702`7
00061`0300L701470`0@1`0300L702@700<01`L090L00`071`0K1`<01`L00`071`0T1`0300L702@7
00<01`L0;0L000H700<01`L03PL301<700<01`L090L00`071`0T1`0300L701P70`0:1`0300L702@7
00<01`L090L00`071`0/1`001PL00`071`0;1`<05PL00`071`0T1`0300L702@700<01`L05@L300d7
00<01`L090L00`071`0T1`0300L702`700061`0300L700P70`0I1`0300L702@700<01`L090L00`07
1`0A1`@040L00`071`0T1`0300L702@700<01`L0;0L000H700<01`L01@L301`700<01`L090L00`07
1`0T1`0300L700h70`0D1`0300L702@700<01`L090L00`071`0/1`001PL00`071`021`<07`L00`07
1`0T1`0300L702@700<01`L02`L301L700<01`L090L00`071`0T1`0300L702`700061`0300L00080
8PL00`071`0T1`0300L702@700<01`L020L301X700<01`L090L00`071`0T1`0300L702`700061`80
9@L00`071`0T1`0300L702@700<01`L01@L301d700<01`L090L00`071`0T1`0300L702`7000]1`03
00L702@700<01`L090L00`071`021`<080L00`071`0T1`0300L702@700<01`L0;0L002d700<01`L0
90L00`071`0T1`0300L000808`L00`071`0T1`0300L702@700<01`L0;0L002d700<01`L090L00`07
1`0S1`<09PL00`071`0T1`0300L702@700<01`L0;0L002d700<01`L090L00`071`0P1`<000<700L0
9PL00`071`0T1`0300L702@700<01`L0;0L002d700<01`L090L00`071`0M1`<010L00`071`0U1`03
00L702@700<01`L090L00`071`0/1`00;@L00`071`0T1`0300L701X70`071`0300L702D700<01`L0
90L00`071`0S1`80;PL002d700<01`L090L00`071`0G1`<02PL00`071`0U1`0300L702@700<01`L0
80L30307000]1`0300L702@700<01`L050L300d700<01`L09@L00`071`0T1`0300L701d70`0c1`00
;@L00`071`0T1`0300L701470`0@1`0300L702D700<01`L090L00`071`0J1`<0=PL002d700<01`L0
90L00`071`0>1`<04`L00`071`0U1`0300L702@700<01`L05`L303T7000]1`0300L702@700<01`L0
2`L301H700<01`L09@L00`071`0T1`0300L701@70`0l1`00;@L00`071`0T1`0300L700P70`0I1`03
00L702D700<01`L090L00`071`0A1`<0?`L002d700<01`L090L00`071`051`<070L00`071`0U1`03
00L702@700<01`L03PL30487000]1`0300L702@700<01`L00PL301l700<01`L09@L00`071`0T1`03
00L700/70`151`00;@L00`071`0T1`0300L000808PL00`071`0U1`0300L702@700<01`L020L304P7
000]1`0300L702<70`0U1`0300L702D700<01`L090L00`071`051`<0B`L002d700<01`L080L30003
1`0702D700<01`L09@L00`071`0T1`0300L700870`1>1`00;@L00`071`0L1`@010L00`071`0T1`03
00L702D700<01`L090L00`0700020547000]1`0300L701T70`081`0300L702@700<01`L09@L00`07
1`0S1`<0E0L002d700<01`L05PL300/700<01`L090L00`071`0U1`0300L702070`000`L01`1D1`00
;@L00`071`0C1`<03PL00`071`0T1`0300L702D700<01`L070L400@700<01`L0D`L002d700<01`L0
3`L4014700<01`L090L00`071`0U1`0300L701T70`081`0300L705<7000]1`0300L700`70`0E1`03
00L702@700<01`L09@L00`071`0F1`<02`L00`071`1C1`00;@L00`071`091`<060L00`071`0T1`03
00L702D700<01`L04`L300h700<01`L0D`L002d700<01`L01PL301/700<01`L090L00`071`0U1`03
00L700l7100A1`0300L705<7000]1`0300L70087100N1`0300L702@700<01`L09@L00`071`0<1`<0
5@L00`071`1C1`00;@L00`070002028700<01`L090L00`071`0U1`0300L700T70`0H1`0300L705<7
000]1`809@L00`071`0T1`0300L702D700<01`L01PL301/700<01`L0D`L005@700<01`L090L00`07
1`0U1`0300L70087100N1`0300L705<7001D1`0300L702@700<01`L09@L00`070002028700<01`L0
D`L005@700<01`L090L00`071`0T1`<09@L00`071`1C1`00E0L00`071`0T1`0300L702470`000`L0
1`0U1`0300L705<7001D1`0300L702@700<01`L07PL300@700<01`L090L00`071`1C1`00E0L00`07
1`0T1`0300L701/70`071`0300L702@700<01`L0D`L005@700<01`L090L00`071`0H1`<02PL00`07
1`0T1`0300L705<7001D1`0300L702@700<01`L05@L300d700<01`L090L00`071`1C1`00E0L00`07
1`0T1`0300L70147100@1`0300L702@700<01`L0D`L005@700<01`L090L00`071`0>1`<050L00`07
1`0T1`0300L705<7001D1`0300L702@700<01`L02`L301L700<01`L090L00`071`1C1`00E0L00`07
1`0T1`0300L700P70`0J1`0300L702@700<01`L0D`L005@700<01`L090L00`071`051`<07@L00`07
1`0T1`0300L705<7001D1`0300L702@700<01`L00PL3020700<01`L090L00`071`1C1`00E0L00`07
1`0T1`0300L000808`L00`071`0T1`0300L705<7001D1`0300L702<70`0V1`0300L702@700<01`L0
D`L005@700<01`L080L302T700<01`L090L00`071`1C1`00E0L00`071`0M1`<0;0L00`071`0T1`03
00L705<7001D1`0300L701X70`0_1`0300L702@700<01`L0D`L005@700<01`L05`L3038700<01`L0
90L00`071`1C1`00E0L00`071`0D1`<0=@L00`071`0T1`0300L705<7001D1`0300L701470`0h1`03
00L702@700<01`L0D`L005@700<01`L03PL303/700<01`L090L00`071`1C1`00E0L00`071`0;1`<0
?PL00`071`0T1`0300L705<7001D1`0300L700P70`111`0300L702@700<01`L0D`L005@700<01`L0
1@L304@700<01`L090L00`071`1C1`00E0L00`071`021`<0A`L00`071`0T1`0300L705<7001D1`03
00L00080BPL00`071`0T1`0300L705<7001D1`80C@L00`071`0T1`0300L705<7002S1`0300L702@7
00<01`L0D`L00:<700<01`L090L00`071`1C1`00X`L00`071`0S1`80E@L00:<700<01`L080L305L7
002S1`0300L701`7101J1`00X`L00`071`0I1`<0GPL00:<700<01`L05PL30647002S1`0300L701<7
0`1T1`00X`L00`071`0?1`@0I`L00:<700<01`L030L306/7002S1`0300L700T70`1^1`00X`L00`07
1`061`<0L@L00:<700<01`L00PL407@7002S1`0300L00080N0L00:<70P1k1`00o`LQ1`00o`LQ1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {301.812, 0}} -> {-8.59169, -9.63493, \
0.064025, 0.064025}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[136]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice21\  = 
      tiling2D[SphericalCut[N[Join[AL021, \ AL121, \ AL221, \ AL321]], 10], \ 
        rad21]\)], "Input",
  CellLabel->"In[137]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9557 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.49998 0.0493231 0.477831 0.0493231 [
[ 0 0 0 0 ]
[ 1 .9557 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9557 L
0 .9557 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.2211 .14556 m
.34441 .1055 L
s
.2211 .14556 m
.2211 .27522 L
s
.34441 .1055 m
.46772 .06543 L
s
.34441 .1055 m
.34441 .23515 L
s
.46772 .06543 m
.59103 .02537 L
s
.46772 .06543 m
.46772 .19509 L
s
.59103 .02537 m
.59103 .15502 L
s
.09779 .31528 m
.2211 .27522 L
s
.09779 .31528 m
.09779 .44494 L
s
.2211 .27522 m
.34441 .23515 L
s
.2211 .27522 m
.2211 .40487 L
s
.34441 .23515 m
.46772 .19509 L
s
.34441 .23515 m
.34441 .36481 L
s
.46772 .19509 m
.59103 .15502 L
s
.46772 .19509 m
.46772 .32474 L
s
.59103 .15502 m
.71433 .11496 L
s
.59103 .15502 m
.59103 .28468 L
s
.71433 .11496 m
.71433 .24461 L
s
.09779 .44494 m
.2211 .40487 L
s
.09779 .44494 m
.09779 .57459 L
s
.2211 .40487 m
.34441 .36481 L
s
.2211 .40487 m
.2211 .53452 L
s
.34441 .36481 m
.46772 .32474 L
s
.34441 .36481 m
.34441 .49446 L
s
.46772 .32474 m
.59103 .28468 L
s
.46772 .32474 m
.46772 .45439 L
s
.59103 .28468 m
.71433 .24461 L
s
.59103 .28468 m
.59103 .41433 L
s
.71433 .24461 m
.83764 .20455 L
s
.71433 .24461 m
.71433 .37426 L
s
.83764 .20455 m
.83764 .3342 L
s
.09779 .57459 m
.2211 .53452 L
s
.09779 .57459 m
.09779 .70424 L
s
.2211 .53452 m
.34441 .49446 L
s
.2211 .53452 m
.2211 .66418 L
s
.34441 .49446 m
.46772 .45439 L
s
.34441 .49446 m
.34441 .62411 L
s
.46772 .45439 m
.59103 .41433 L
s
.46772 .45439 m
.46772 .58405 L
s
.59103 .41433 m
.71433 .37426 L
s
.59103 .41433 m
.59103 .54398 L
s
.71433 .37426 m
.83764 .3342 L
s
.71433 .37426 m
.71433 .50392 L
s
.83764 .3342 m
.83764 .46385 L
s
.09779 .70424 m
.2211 .66418 L
s
.2211 .66418 m
.34441 .62411 L
s
.2211 .66418 m
.2211 .79383 L
s
.34441 .62411 m
.46772 .58405 L
s
.34441 .62411 m
.34441 .75377 L
s
.46772 .58405 m
.59103 .54398 L
s
.46772 .58405 m
.46772 .7137 L
s
.59103 .54398 m
.71433 .50392 L
s
.59103 .54398 m
.59103 .67364 L
s
.71433 .50392 m
.83764 .46385 L
s
.71433 .50392 m
.71433 .63357 L
s
.83764 .46385 m
.96095 .42379 L
s
.83764 .46385 m
.83764 .59351 L
s
.96095 .42379 m
.96095 .55344 L
s
.2211 .79383 m
.34441 .75377 L
s
.34441 .75377 m
.46772 .7137 L
s
.34441 .75377 m
.34441 .88342 L
s
.46772 .7137 m
.59103 .67364 L
s
.46772 .7137 m
.46772 .84335 L
s
.59103 .67364 m
.71433 .63357 L
s
.59103 .67364 m
.59103 .80329 L
s
.71433 .63357 m
.83764 .59351 L
s
.71433 .63357 m
.71433 .76322 L
s
.83764 .59351 m
.96095 .55344 L
s
.83764 .59351 m
.83764 .72316 L
s
.34441 .88342 m
.46772 .84335 L
s
.46772 .84335 m
.59103 .80329 L
s
.59103 .80329 m
.71433 .76322 L
s
.59103 .80329 m
.59103 .93294 L
s
.71433 .76322 m
.83764 .72316 L
s
.71433 .76322 m
.71433 .89288 L
s
.59103 .93294 m
.71433 .89288 L
s
.23634 .06282 m
.35965 .02275 L
s
.23634 .06282 m
.23634 .19247 L
s
.35965 .02275 m
.35965 .15241 L
s
.11304 .23254 m
.23634 .19247 L
s
.11304 .23254 m
.11304 .36219 L
s
.23634 .19247 m
.35965 .15241 L
s
.23634 .19247 m
.23634 .32213 L
s
.35965 .15241 m
.48296 .11234 L
s
.35965 .15241 m
.35965 .28206 L
s
.48296 .11234 m
.60627 .07228 L
s
.48296 .11234 m
.48296 .242 L
s
.60627 .07228 m
.60627 .20193 L
s
.11304 .36219 m
.23634 .32213 L
s
.11304 .36219 m
.11304 .49185 L
s
.23634 .32213 m
.35965 .28206 L
s
.23634 .32213 m
.23634 .45178 L
s
.35965 .28206 m
.48296 .242 L
s
.35965 .28206 m
.35965 .41172 L
s
.48296 .242 m
.60627 .20193 L
s
.48296 .242 m
.48296 .37165 L
s
.60627 .20193 m
.72957 .16187 L
s
.60627 .20193 m
.60627 .33158 L
s
.72957 .16187 m
.72957 .29152 L
s
.11304 .49185 m
.23634 .45178 L
s
.11304 .49185 m
.11304 .6215 L
s
.23634 .45178 m
.35965 .41172 L
s
.23634 .45178 m
.23634 .58143 L
s
.35965 .41172 m
.48296 .37165 L
s
.35965 .41172 m
.35965 .54137 L
s
.48296 .37165 m
.60627 .33158 L
s
.48296 .37165 m
.48296 .5013 L
s
.60627 .33158 m
.72957 .29152 L
s
.60627 .33158 m
.60627 .46124 L
s
.72957 .29152 m
.85288 .25145 L
s
.72957 .29152 m
.72957 .42117 L
s
.85288 .25145 m
.85288 .38111 L
s
.11304 .6215 m
.23634 .58143 L
s
.11304 .6215 m
.11304 .75115 L
s
.23634 .58143 m
.35965 .54137 L
s
.23634 .58143 m
.23634 .71109 L
s
.35965 .54137 m
.48296 .5013 L
s
.35965 .54137 m
.35965 .67102 L
s
.48296 .5013 m
.60627 .46124 L
s
.48296 .5013 m
.48296 .63096 L
s
.60627 .46124 m
.72957 .42117 L
s
.60627 .46124 m
.60627 .59089 L
s
.72957 .42117 m
.85288 .38111 L
s
.72957 .42117 m
.72957 .55083 L
s
.85288 .38111 m
.85288 .51076 L
s
.11304 .75115 m
.23634 .71109 L
s
.23634 .71109 m
.35965 .67102 L
s
.23634 .71109 m
.23634 .84074 L
s
.35965 .67102 m
.48296 .63096 L
s
.35965 .67102 m
.35965 .80068 L
s
.48296 .63096 m
.60627 .59089 L
s
.48296 .63096 m
.48296 .76061 L
s
.60627 .59089 m
.72957 .55083 L
s
.60627 .59089 m
.60627 .72055 L
s
.72957 .55083 m
.85288 .51076 L
s
.72957 .55083 m
.72957 .68048 L
s
.85288 .51076 m
.97619 .4707 L
s
.85288 .51076 m
.85288 .64042 L
s
.97619 .4707 m
.97619 .60035 L
s
.23634 .84074 m
.35965 .80068 L
s
.35965 .80068 m
.48296 .76061 L
s
.35965 .80068 m
.35965 .93033 L
s
.48296 .76061 m
.60627 .72055 L
s
.48296 .76061 m
.48296 .89026 L
s
.60627 .72055 m
.72957 .68048 L
s
.60627 .72055 m
.60627 .8502 L
s
.72957 .68048 m
.85288 .64042 L
s
.72957 .68048 m
.72957 .81013 L
s
.85288 .64042 m
.97619 .60035 L
s
.85288 .64042 m
.85288 .77007 L
s
.35965 .93033 m
.48296 .89026 L
s
.48296 .89026 m
.60627 .8502 L
s
.60627 .8502 m
.72957 .81013 L
s
.72957 .81013 m
.85288 .77007 L
s
.14712 .18563 m
.27043 .14556 L
s
.14712 .18563 m
.14712 .31528 L
s
.27043 .14556 m
.39373 .1055 L
s
.27043 .14556 m
.27043 .27522 L
s
.39373 .1055 m
.51704 .06543 L
s
.39373 .1055 m
.39373 .23515 L
s
.51704 .06543 m
.64035 .02537 L
s
.51704 .06543 m
.51704 .19509 L
s
.64035 .02537 m
.64035 .15502 L
s
.02381 .35535 m
.14712 .31528 L
s
.02381 .35535 m
.02381 .485 L
s
.14712 .31528 m
.27043 .27522 L
s
.14712 .31528 m
.14712 .44494 L
s
.27043 .27522 m
.39373 .23515 L
s
.27043 .27522 m
.27043 .40487 L
s
.39373 .23515 m
.51704 .19509 L
s
.39373 .23515 m
.39373 .36481 L
s
.51704 .19509 m
.64035 .15502 L
s
.51704 .19509 m
.51704 .32474 L
s
.64035 .15502 m
.76366 .11496 L
s
.64035 .15502 m
.64035 .28468 L
s
.76366 .11496 m
.76366 .24461 L
s
.02381 .485 m
.14712 .44494 L
s
.14712 .44494 m
.27043 .40487 L
s
.14712 .44494 m
.14712 .57459 L
s
.27043 .40487 m
.39373 .36481 L
s
.27043 .40487 m
.27043 .53452 L
s
.39373 .36481 m
.51704 .32474 L
s
.39373 .36481 m
.39373 .49446 L
s
.51704 .32474 m
.64035 .28468 L
s
.51704 .32474 m
.51704 .45439 L
s
.64035 .28468 m
.76366 .24461 L
s
.64035 .28468 m
.64035 .41433 L
s
.76366 .24461 m
.88696 .20455 L
s
.76366 .24461 m
.76366 .37426 L
s
.88696 .20455 m
.88696 .3342 L
s
.14712 .57459 m
.27043 .53452 L
s
.14712 .57459 m
.14712 .70424 L
s
.27043 .53452 m
.39373 .49446 L
s
.27043 .53452 m
.27043 .66418 L
s
.39373 .49446 m
.51704 .45439 L
s
.39373 .49446 m
.39373 .62411 L
s
.51704 .45439 m
.64035 .41433 L
s
.51704 .45439 m
.51704 .58405 L
s
.64035 .41433 m
.76366 .37426 L
s
.64035 .41433 m
.64035 .54398 L
s
.76366 .37426 m
.88696 .3342 L
s
.76366 .37426 m
.76366 .50392 L
s
.88696 .3342 m
.88696 .46385 L
s
.14712 .70424 m
.27043 .66418 L
s
.27043 .66418 m
.39373 .62411 L
s
.27043 .66418 m
.27043 .79383 L
s
.39373 .62411 m
.51704 .58405 L
s
.39373 .62411 m
.39373 .75377 L
s
.51704 .58405 m
.64035 .54398 L
s
.51704 .58405 m
.51704 .7137 L
s
.64035 .54398 m
.76366 .50392 L
s
.64035 .54398 m
.64035 .67364 L
s
.76366 .50392 m
.88696 .46385 L
s
.76366 .50392 m
.76366 .63357 L
s
.88696 .46385 m
.88696 .59351 L
s
.27043 .79383 m
.39373 .75377 L
s
.39373 .75377 m
.51704 .7137 L
s
.39373 .75377 m
.39373 .88342 L
s
.51704 .7137 m
.64035 .67364 L
s
.51704 .7137 m
.51704 .84335 L
s
.64035 .67364 m
.76366 .63357 L
s
.64035 .67364 m
.64035 .80329 L
s
.76366 .63357 m
.88696 .59351 L
s
.76366 .63357 m
.76366 .76322 L
s
.88696 .59351 m
.88696 .72316 L
s
.39373 .88342 m
.51704 .84335 L
s
.51704 .84335 m
.64035 .80329 L
s
.64035 .80329 m
.76366 .76322 L
s
.64035 .80329 m
.64035 .93294 L
s
.76366 .76322 m
.88696 .72316 L
s
.76366 .76322 m
.76366 .89288 L
s
.64035 .93294 m
.76366 .89288 L
s
.28567 .06282 m
.40897 .02275 L
s
.28567 .06282 m
.28567 .19247 L
s
.40897 .02275 m
.40897 .15241 L
s
.16236 .23254 m
.28567 .19247 L
s
.16236 .23254 m
.16236 .36219 L
s
.28567 .19247 m
.40897 .15241 L
s
.28567 .19247 m
.28567 .32213 L
s
.40897 .15241 m
.53228 .11234 L
s
.40897 .15241 m
.40897 .28206 L
s
.53228 .11234 m
.65559 .07228 L
s
.53228 .11234 m
.53228 .242 L
s
.65559 .07228 m
.65559 .20193 L
s
.03905 .40226 m
.16236 .36219 L
s
.03905 .40226 m
.03905 .53191 L
s
.16236 .36219 m
.28567 .32213 L
s
.16236 .36219 m
.16236 .49185 L
s
.28567 .32213 m
.40897 .28206 L
s
.28567 .32213 m
.28567 .45178 L
s
.40897 .28206 m
.53228 .242 L
s
.40897 .28206 m
.40897 .41172 L
s
.53228 .242 m
.65559 .20193 L
s
.53228 .242 m
.53228 .37165 L
s
.65559 .20193 m
.7789 .16187 L
s
.65559 .20193 m
.65559 .33158 L
s
.7789 .16187 m
.7789 .29152 L
s
.03905 .53191 m
.16236 .49185 L
s
.16236 .49185 m
.28567 .45178 L
s
.16236 .49185 m
.16236 .6215 L
s
.28567 .45178 m
.40897 .41172 L
s
.28567 .45178 m
.28567 .58143 L
s
.40897 .41172 m
.53228 .37165 L
s
.40897 .41172 m
.40897 .54137 L
s
.53228 .37165 m
.65559 .33158 L
s
.53228 .37165 m
.53228 .5013 L
s
.65559 .33158 m
.7789 .29152 L
s
.65559 .33158 m
.65559 .46124 L
s
.7789 .29152 m
.90221 .25145 L
s
.7789 .29152 m
.7789 .42117 L
s
.90221 .25145 m
.90221 .38111 L
s
.16236 .6215 m
.28567 .58143 L
s
.16236 .6215 m
.16236 .75115 L
s
.28567 .58143 m
.40897 .54137 L
s
.28567 .58143 m
.28567 .71109 L
s
.40897 .54137 m
.53228 .5013 L
s
.40897 .54137 m
.40897 .67102 L
s
.53228 .5013 m
.65559 .46124 L
s
.53228 .5013 m
.53228 .63096 L
s
.65559 .46124 m
.7789 .42117 L
s
.65559 .46124 m
.65559 .59089 L
s
.7789 .42117 m
.90221 .38111 L
s
.7789 .42117 m
.7789 .55083 L
s
.90221 .38111 m
.90221 .51076 L
s
.16236 .75115 m
.28567 .71109 L
s
.28567 .71109 m
.40897 .67102 L
s
.28567 .71109 m
.28567 .84074 L
s
.40897 .67102 m
.53228 .63096 L
s
.40897 .67102 m
.40897 .80068 L
s
.53228 .63096 m
.65559 .59089 L
s
.53228 .63096 m
.53228 .76061 L
s
.65559 .59089 m
.7789 .55083 L
s
.65559 .59089 m
.65559 .72055 L
s
.7789 .55083 m
.90221 .51076 L
s
.7789 .55083 m
.7789 .68048 L
s
.90221 .51076 m
.90221 .64042 L
s
.28567 .84074 m
.40897 .80068 L
s
.40897 .80068 m
.53228 .76061 L
s
.40897 .80068 m
.40897 .93033 L
s
.53228 .76061 m
.65559 .72055 L
s
.53228 .76061 m
.53228 .89026 L
s
.65559 .72055 m
.7789 .68048 L
s
.65559 .72055 m
.65559 .8502 L
s
.7789 .68048 m
.90221 .64042 L
s
.7789 .68048 m
.7789 .81013 L
s
.40897 .93033 m
.53228 .89026 L
s
.53228 .89026 m
.65559 .8502 L
s
.65559 .8502 m
.7789 .81013 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[137]:=",
  ImageSize->{288, 275.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00014`P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L006H70P0<1`80ZPL006<70`000`L01`081`<000<700L0<@L200`70P1X1`00
G`L400@700<01`L010L300@700<01`L0;@L300031`0700P70`000`L01`1W1`00G0L300P700<01`L0
10071`0300L702X70`041`0300L700@70`041`0300L706H7001I1`<02`L300/700<01`L09PL400L7
00<01`L010071`0300L706H7001E1`@02`L400d700<01`L08`L300/70`0;1`0300L706H7001B1`<0
30L300<700<01`L02`L00`071`0P1`<02`L400d700<01`L0IPL004l70`0<1`<01PL00`071`0;1`03
00L701d70`0;1`<00`L00`071`0;1`0300L706H7001<1`<02`L400T700<01`L02`L00`071`0J1`<0
2`L300H700<01`L02`L00`071`1V1`00B0L400/70`0=1`0300L700/700<01`L05PL400X710091`03
00L700/700<01`L0IPL004D70`0<1`<040L00`071`0;1`0300L701<70`0;1`<03@L00`071`0;1`03
00L706H700131`803@L201<700<01`L02`L00`071`0@1`<02`L3010700<01`L02`L00`071`1V1`00
@`L00`071`0<1`0300L7018700<01`L02`L00`071`0=1`<02`L301<700<01`L02`L00`071`1V1`00
@`L00`071`0<1`0300L7018700<01`L02`L00`071`0:1`<000<700L020L300031`0701<700<01`L0
2`L00`071`1V1`00@`L00`071`0<1`0300L7018700<01`L02`L00`071`071`<010L00`071`041`<0
10L00`071`0B1`0300L700802@L010071`L206<700131`0300L700`700<01`L04PL00`071`0;1`03
00L700@70`071`0400L71`<01`L00`071`0B1`<000<700L020L400031`07068700131`0300L700`7
00<01`L04PL00`071`0;1`0400L71`<02PL400X700<01`L03`L400<700<01`L01@L300@700<01`L0
H@L004<700<01`L030L00`071`0B1`0300L700/7100;1`<03@L00`071`0<1`<00`L01@071`L000@7
0`021`0300L7008700<01`L0H@L004<700<01`L030L00`071`0B1`0300L700T70`0<1`800PL00`07
1`0;1`0300L700T70`061`0600L71`070`051`0300L7008700<01`L0H@L004<700<01`L030L00`07
1`0B1`0300L700H70`021`0300L700L70`041`0300L700/700<01`L01PL300T700<01`L00`081`03
00L7008700<01`L0H@L004<700<01`L030L00`071`0B1`0300L700<70`051`0300L700@70`071`03
00L700/700<01`L010L200`70`000`L01`081`0300L7008700<01`L0H@L004<700<01`L030L00`07
1`0B1`0300L700<020L010071`L300X700<01`L02`L010071`L300/710031`0300L700L700<01`L0
0PL00`071`1Q1`00@`L00`071`0<1`0300L701870`0;1`@03@L00`071`0;1`@02`L300<700D01`L7
00091`0300L7008700<01`L0H@L004<700<01`L030L00`071`0?1`@02`L3010700<01`L02@L300/7
0`061`0500L71`002@L00`071`021`0300L7064700131`0300L700`700<01`L030L300<700<01`L0
1PL3008700<01`L03PL00`071`061`<00PL00`071`061`<02@L01@071`L000T700<01`L00PL00`07
1`1Q1`00@`L00`071`0<1`0300L700T70`000`L01`031`0300L700<70`000`L01`021`0300L700h7
00<01`L00`L300D700<01`L00`L300`700D01`L700091`0300L7008700<01`L0H@L004<700<01`L0
30L00`071`061`<010L00`071`021`0300L000<010L01@071`L0010700<01`L00`081`0300L700<0
3`L01@071`L000T700<01`L00PL00`071`0<1`803@L204@700131`0300L700`700<01`L00PL400L7
00@01`L70`081`0500L71`0040L300031`0700P70`000`L01`0?1`0500L71`002@L00`071`021`03
00L700T70`000`L01`091`<000<700L0@`L004<700<01`L030L00`07000200/710000`L01`081`05
00L71`003@L400<700<01`L010L400<700<01`L03PL01@071`L000T700<01`L00PL00`071`061`<0
10L00`071`051`<010L00`071`121`00@`L00`071`0;1`<02`L400@700<01`L01`L01@071`L000T7
10031`0500L71`000PL400<700D01`L7000@1`0500L71`002@L00`071`021`0300L700<70`071`03
00L700870`071`0300L7048700131`0300L700P70`000`L01`081`<00`L00`071`021`0300L700L7
00D01`L700061`<01`L010071`L300L700D01`L7000@1`0500L71`002@L00`071`021`0300L700<0
2PL00`07000200X700<01`L0@PL004<700<01`L01@L300@700<01`L010L300H700<01`L00PL00`07
1`071`0500L71`000`L300X71@091`0500L71`0040L01@071`L000T700<01`L00PL300`70`0=1`03
00L7048700131`0400L71`@01`L010071`L300T700<01`L00PL00`071`071`0400L71`@02`L300<7
00<01`L01`L01@071`L0010700D01`L700091`0300L700<02`L300031`0700d700<01`L0@PL004<7
100;1`@030L00`071`021`0300L700L700<01`000P0;1`<00PL01@071`L000T700D01`L7000@1`05
00L71`002@L3008700<01`L01PL300@700<01`L030L00`071`121`00@@L300/7100?1`0300L70087
00<01`L01@L4008700<01`L01@L400D700D01`L700091`0500L71`0040L01@071`L000H710041`03
00L700<70`071`0300L700`700<01`L0@PL003l70P021`0300L700H70`031`0300L700d700<01`L0
0PL00`071`021`<00PL01@071`L000@70`091`0500L71`002@L01@071`L0010700D01`L700031`<0
0`L00`071`021`0300L700<02PL00`071`0<1`0300L70487000o1`0500L71`001@L300031`0700<7
00<01`L03@L00`071`021`0300L000801@L01P071`L01`<030L01@071`L000T700D01`L7000@1`04
00L71`@01PL00`071`021`<03@L00`071`0<1`0300L70487000o1`0500L71`000PL300@700<01`L0
0PL00`071`0=1`0400L71`<020L00`071`0300l700D01`L700091`0500L71`0040L00`07000200T7
00<01`000`0?1`0300L700`700<01`L0@PL003l700@01`L70`071`0300L7008700<01`L03@L40003
1`0700P70`000`L01`0?1`0500L71`002@L01@071`L000l70`021`0300L700H70`031`0300L700d7
00<01`L030L00`071`121`00?`L500T700<01`L00PL00`071`0;1`<010L00`071`041`@00`L00`07
1`0>1`0500L71`002@L01@071`L000`70`000`L01`021`0300L700<70`000`L01`031`0300L700d7
00<01`L030L00`071`121`00?@L300<700<01`L01`L00`071`021`0300L700P70`021`0300L70087
00@01`L70`031`0500L71`0040L01@071`L000T700D01`L700091`<010L01@071`L000870`041`03
00L7008700<01`L03@L010071`L200T700<01`L00P101`00>`L2008700D01`L700091`0300L70087
00<01`L01@L300D700<01`L00PL400H700D01`L7000@1`0500L71`002@L01@071`L000D710071`03
00L700@01`L00`071`021`0300L700d710000`L01`081`<000<700L0?`L003P70`041`0500L71`00
2@L00`071`021`0300L700870`081`0300L700<02@L01@071`L0010700D01`L700091`0500L71`00
0PL300/70`000`L01`081`0300L7008700<01`L02PL400@700<01`L010L400<700<01`L0?PL003D7
0`071`0500L71`002@L00`071`021`0300L000802`L3008700<01`L01`L01@071`L0010700D01`L7
00091`0400L71`<02`L400<700<01`L01`L00`071`021`0300L700L70`031`0300L7008700<01`L0
10031`0500L71`00@0L003870`0:1`0500L71`002@L010071`L300`70`041`0300L700L700D01`L7
000@1`0500L71`002@L500X70`031`0500L71`002@L00`071`021`0300L700@70`061`0300L70087
0`071`0500L71`00@0L002l70`0=1`0500L71`002@L400031`0700T70`021`0300L7008700<01`L0
1`L01@071`L0010700D01`L700071`<00`L00`071`051`<01PL01@071`L000T700<01`L00PL00`07
1`0400T700<01`000`091`0500L71`00@0L002`70`0@1`0500L71`001`L300@700<01`L01@L300D7
00<01`L00PL00`071`071`0500L71`0040L01@071`L000<710021`0500L71`000`L400T700D01`L7
00091`0300L700870`0<1`<00`L00`071`071`0500L71`00@0L002X70P0C1`0500L71`0010L30087
00<01`L00PL00`071`021`<020L00`071`021`0300L700L700D01`L7000@1`0400L71`@01PL01007
1`L400d700D01`L700091`0300L000<02`L300031`0700<700<01`L01`L01@071`L00407000Z1`03
00L7018700H01`L700L300D700<01`L00PL00`07000200/700<01`L00PL00`071`071`0500L71`00
40L00`07000200T700<01`000P0@1`0500L71`0020L300<700<01`L01@L400@700<01`L00PL00`07
1`071`0500L71`00@0L002X700<01`L04PL00`071`0300P700@01`L70`0>1`0300L7008700<01`L0
1`L01@071`L000l70`021`0300L700H70`021`0300L700h700D01`L700041`@000<700L00`L00`07
1`021`<020L00`071`021`0300L700L700D01`L700101`00:PL00`071`0B1`<000<700L020L40003
1`0700h700<01`L00PL00`071`071`0500L71`0030L300031`07008700<01`L00`L300031`070087
00<01`L03PL01P071`L01`<01@L00`071`021`0300L000802`L00`071`021`0300L700L700D01`L7
00101`00:PL00`071`0?1`@00`L00`071`041`@010L00`071`0=1`0300L7008700<01`L01`L01@07
1`L000T70`041`0500L71`000PL300@700D01`L7000@1`0300L700<020L010071`L300h700<01`L0
0PL00`071`071`0500L71`00@0L002X700<01`L02`L400<700D01`L700031`<00`L00`071`021`03
00L700d700<01`L00PL00`071`071`0500L71`001PL300L700@01`L70`071`0500L71`0040L30003
1`0700P710000`L01`0>1`0300L7008700<01`L01`L01@071`L000l70P0<1`808@L002X700<01`L0
20L300L700@01`L710061`0300L7008700<01`L03@L00`071`021`0300L700L700D01`L700031`<0
2PL500T700D01`L7000=1`@00`L00`071`051`<010L00`071`0=1`0300L7008700<01`L01`L01@07
1`L000`70`000`L01`081`<000<700L080L002X700<01`L01@L300X71@091`0300L7008700<01`L0
3@L00`071`021`0300L700L700@01`L7100;1`<00`L00`071`071`0500L71`002PL300<700D01`L7
00041`<00PL00`071`021`0300L700d700<01`L00PL00`071`071`0500L71`0020L400@700<01`L0
10L300@700<01`L07`L002X700<01`L00PL300/70`031`0300L700L700<01`L00PL00`071`0=1`03
00L7008700<01`L01`L00`07000200`70P021`0500L71`002@L01@071`L000L70`061`0600L71`07
0`051`0300L7008700<01`L03@L00`071`021`0300L700L700D01`L700051`<020L00`071`0400L7
00<01`L07`L002X700<01`000P0;1`<00PL01@071`L000T700<01`L00PL00`071`0=1`0300L70087
00<01`L01PL3008700<01`L01`L300@700D01`L700091`0500L71`0010L300T700<01`L00`081`03
00L7008700<01`L03@L00`071`021`0300L700L700D01`L700021`<02`L300/700<01`L07`L002P7
100;1`<01@L01@071`L000T700<01`L00PL00`071`0=1`0300L7008700<01`L00`L300031`070087
00<01`L010L300L700D01`L700091`0500L71`000PL200`70`000`L01`081`0300L7008700<01`L0
3@L00`071`021`0300L700L700<01`L0100;1`@03@L00`071`0O1`009@L3008700<01`L01PL400P7
00D01`L700091`0300L7008700<01`L03@L00`071`021`0300L700<010L01@071`L000<70`0:1`05
00L71`002@L010071`L300/710031`0300L700L700<01`L00PL00`071`0=1`0300L7008700<01`L0
1`L300031`0700T70`031`0300L700/700<01`L07`L002870`051`0300L700<70`0<1`0500L71`00
2@L00`071`021`0300L700d700<01`L00PL300L700@01`L7100=1`0500L71`002@L500X70`031`05
00L71`002@L00`071`021`0300L700d700<01`L00PL00`071`041`@00`L00`071`051`<01PL00`07
1`0;1`0300L701l7000P1`8020L010071`L200l700D01`L700091`0300L7008700<01`L03@L00`07
000300T700<01`000P0@1`0500L71`001`L300<700<01`L01@L300H700D01`L700091`0300L70087
00<01`L03@L00`071`021`0400L71`<00`L01@071`L000<710091`0300L700/700<01`L07`L00207
00<01`L01`L01@071`L0010700D01`L700091`0300L7008700<01`L030L300<700<01`L01PL30087
00<01`L03PL01@071`L000@70`021`0500L71`0010L300T700D01`L700091`0300L7008700<01`L0
3@L00`071`021`@01PL010071`L400d700<01`L02`L00`071`0O1`0080L00`071`071`0500L71`00
40L01@071`L000T700<01`L00PL00`071`091`<000<700L00`L00`071`031`<000<700L00PL00`07
1`0>1`0600L71`070`051`0600L71`070`0<1`0500L71`002@L00`071`021`0300L700d700<01`00
0`091`0300L0008040L00`071`0;1`0300L701l7000P1`0300L700L700D01`L7000@1`0500L71`00
2@L00`071`021`0300L700H70`041`0300L7008700<01`000`041`0500L71`0040L00`071`0300P7
00<01`L00`0?1`0500L71`002@L00`071`021`0300L700`70`031`0300L700H70`021`0300L700h7
00<01`L02`L00`071`0O1`0080L00`071`071`0500L71`0040L01@071`L000T700<01`L00PL00`07
1`021`@01`L010071`L300P700D01`L7000@1`<000<700L020L300031`0700l700D01`L700091`03
00L7008700<01`L02@L300031`0700<700<01`L00`L300031`07008700<01`L03PL00`071`0;1`03
00L701l7000P1`0300L700L700D01`L7000@1`0500L71`002@L00`071`021`0300L000802`L40003
1`0700P700D01`L7000=1`@00`L00`071`041`@00`L00`071`0>1`0500L71`002@L00`071`021`03
00L700H70`041`0300L7008700<01`L00`041`0500L71`0040L00`071`0200T700<01`L00P0M1`00
80L00`071`071`0500L71`0040L01@071`L000T700@01`L70`0;1`@010L00`071`071`0500L71`00
2@L400<700D01`L700021`@00`L01@071`L0010700D01`L700091`0300L7008700<01`L00`L300L7
00<01`L00PL300L700D01`L7000@1`<000<700L020L300031`0701`7000P1`0300L700L700D01`L7
000@1`0500L71`002@L400031`0700P70`031`0300L7008700<01`L01`L01@071`L000H70`071`04
00L71`<01`L01@071`L0010700D01`L700091`0300L7008700<01`L00`0:1`0300L000<02@L01@07
1`L000d710031`0300L700@710031`0300L701/7000P1`0300L700L700D01`L7000@1`0500L71`00
1`L300@700<01`L010L300H700<01`L00PL00`071`071`0500L71`000`L300X71@091`0500L71`00
40L01@071`L000T700<01`L00PL300`70`031`0300L700L700D01`L7000:1`<00`L01@071`L000<7
0`031`0500L71`007@L0020700<01`L01`L01@071`L0010700D01`L700031`@00PL00`071`021`04
00L71`<02@L00`071`021`0300L700L700@01`L7100;1`<00`L00`071`071`0500L71`0040L01@07
1`L000T700<01`L00`0;1`<000<700L00`L00`071`071`0500L71`001`L300H700@01`L710061`05
00L71`007@L0020700<01`L01`L01@071`L0010700@01`L710061`0300L70087100<1`0300L70087
00<01`L01`L00`07000200/70`021`0500L71`002@L01@071`L0010700D01`L700091`<00PL00`07
1`061`<010L00`071`021`0300L700L700D01`L700041`<02@L00`07000200T700D01`L7000M1`00
80L00`071`071`0500L71`0040L00`07000200T700<01`000`0?1`0300L7008700<01`L01@L40087
00<01`L01@L400D700D01`L700091`0500L71`0040L01@071`L000H710041`0300L700<70`071`03
00L7008700<01`L01`L01@071`L000870P0<1`800PL00`071`071`0500L71`007@L0020700<01`L0
1`L01@071`L000l70`021`0300L700H70`031`0300L700d700<01`L00PL00`071`021`<00PL01@07
1`L000@70`091`0500L71`002@L01@071`L0010700D01`L700031`<00`L00`071`021`0300L700<0
2PL00`071`021`0300L700L700@01`L70`0;1`@00`L00`071`071`0500L71`007@L0020700<01`L0
1`L01@071`L000`70`000`L01`021`0300L700<70`000`L01`031`0300L700d700<01`L00PL00`07
000200D700H01`L700L300`700D01`L700091`0500L71`0040L010071`L400H700<01`L00PL300d7
00<01`L00PL00`071`071`D02PL300<700D01`L700091`0500L71`007@L0020700<01`L01`L01@07
1`L000T70`041`0500L71`000PL300@700<01`L00PL00`071`0=1`0400L71`<020L00`071`0300l7
00D01`L700091`0500L71`0040L00`07000200T700<01`000`0?1`0300L7008700<01`L01@L300<7
00<01`L01@L300H700D01`L700091`0500L71`007@L0020700<01`L01`L01@071`L000H70`071`04
00L71`<01`L00`071`021`0300L700d710000`L01`081`<000<700L03`L01@071`L000T700D01`L7
000?1`<00PL00`071`061`<00`L00`071`0=1`0300L7008700<01`L00PL3008700D01`L700041`<0
2@L01@071`L000T700D01`L7000M1`0080L00`071`071`0500L71`000`L300X71@091`0300L70087
00<01`L02`L300@700<01`L010L400<700<01`L03PL01@071`L000T700D01`L7000<1`<000<700L0
0PL00`071`031`<000<700L00`L00`071`0=1`0300L7008700<01`000P051`0600L71`070`0<1`05
00L71`002@L01@071`L001d7000P1`0300L700L700@01`L7100;1`<00`L00`071`071`0300L70087
00<01`L020L3008700<01`L00PL010071`L300<700D01`L7000@1`0500L71`002@L01@071`L000T7
0`041`0500L71`000PL300@700<01`L00PL00`071`0=1`0400L71`<020L00`071`0300l700D01`L7
00091`0500L71`007@L0020700<01`L01`L00`071`0200`70P021`0500L71`002@L00`071`021`03
00L700D70`051`0300L7008710061`0500L71`0040L01@071`L000T700D01`L700051`@01`L00`07
1`0400L700<01`L00PL00`071`0=1`@000<700L020L300031`0700l700D01`L700091`0500L71`00
7@L0020700<01`L01`L300031`0700P70`041`0500L71`002@L00`071`021`0300L700870`081`03
00L700<02@L01@071`L0010700D01`L700091`0500L71`000PL300/70`000`L01`081`0300L70087
00<01`L02PL400@700<01`L010L400<700<01`L03PL01@071`L000T700D01`L7000M1`0080L00`07
1`041`@00`L00`071`041`<01`L01@071`L000T700<01`L00PL00`07000200/70`021`0300L700L7
00D01`L7000@1`0500L71`002@L010071`L300/710031`0300L700L700<01`L00PL00`071`071`<0
0`L00`071`021`0300L700@00`L01@071`L0010700D01`L700091`0500L71`007@L0020700@01`L7
0`031`0500L71`000`L300X700D01`L700091`0400L71`<030L300@700<01`L01`L01@071`L00107
00D01`L700091`D02PL300<700D01`L700091`0300L7008700<01`L010L300H700<01`L00PL300L7
00D01`L7000@1`0500L71`002@L01@071`L001d7000P1`@01PL010071`L400d700D01`L700091`@0
00<700L02@L3008700<01`L00PL00`071`071`0500L71`0040L01@071`L000L70`031`0300L700D7
0`061`0500L71`002@L00`071`021`0300L700@02@L00`07000300T700D01`L7000@1`0500L71`00
2@L01@071`L001d7000N1`<02@L00`070002010700D01`L700071`<010L00`071`051`<01@L00`07
1`021`0300L700L700D01`L7000@1`0500L71`000`L4008700D01`L700031`@02@L01@071`L000T7
00<01`L00PL300`70`031`0300L700L700D01`L7000@1`0500L71`002@L01@071`L001d7000L1`80
0PL00`071`061`<00PL00`071`0>1`0500L71`0010L3008700<01`L00PL00`071`021`<020L00`07
1`021`0300L700L700D01`L7000@1`0400L71`@01PL010071`L400d700D01`L700091`0300L000<0
2`L300031`0700<700<01`L01`L01@071`L0010700D01`L700091`0500L71`007@L001`700D01`L7
00051`<000<700L00PL00`071`0>1`0600L71`070`051`0300L7008700<01`000P0;1`0300L70087
00<01`L01`L01@071`L0010700<01`000P091`0300L0008040L01@071`L000P70`031`0300L700D7
10041`0300L7008700<01`L01`L01@071`L0010700D01`L700091`0500L71`007@L001`700H01`L7
00L400@700D01`L7000@1`0300L700<020L010071`L300h700<01`L00PL00`071`071`0500L71`00
3`L3008700<01`L01PL3008700<01`L03PL01@071`L000@710000`L01`031`0300L700870`081`03
00L7008700<01`L01`L01@071`L0010700D01`L700091`0500L71`007@L001`700<01`L00`081`05
00L71`0040L300031`0700P710000`L01`0>1`0300L7008700<01`L01`L01@071`L000`70`000`L0
1`021`0300L700<70`000`L01`021`0300L700h700H01`L700L300D700<01`L00PL00`07000200/7
00<01`L00PL00`071`071`0500L71`0040L01@071`L000T700D01`L7000M1`0070L300031`0700P7
00D01`L7000=1`@00`L00`071`041`@010L00`071`0=1`0300L7008700<01`L01`L01@071`L000T7
0`041`0500L71`000PL300@700D01`L7000@1`0300L700<020L010071`L300h700<01`L00PL00`07
1`071`0500L71`0040L01@071`L000T700D01`L7000M1`0060L500<700<01`L01`L01@071`L000T7
10031`0500L71`000`L300<700<01`L00PL00`071`0=1`0300L7008700<01`L01`L01@071`L000H7
0`071`0400L71`<01`L01@071`L001070`000`L01`081`@000<700L03PL00`071`021`0300L700L7
00D01`L7000?1`800`L00`071`061`800`L00`071`0K1`005@L300@700D01`L700091`0500L71`00
1PL300L700@01`L710061`0300L7008700<01`L03@L00`071`021`0300L700L700D01`L700031`<0
2PL500T700D01`L7000=1`@00`L00`071`051`<010L00`071`0=1`0300L7008700<01`L01`L01@07
1`L000`70`000`L01`021`0300L700<70`000`L01`021`0300L701/7000B1`<01`L01@071`L000T7
00D01`L700031`<02PL500T700<01`L00PL00`071`0=1`0300L7008700<01`L01`L010071`L400/7
0`031`0300L700L700D01`L7000:1`<00`L01@071`L000@70`021`0300L7008700<01`L03@L00`07
1`021`0300L700L700D01`L700091`<010L01@071`L000870`041`0500L71`007@L000l70`0:1`05
00L71`002@L010071`L400/70`031`0300L700L700<01`L00PL00`071`0=1`0300L7008700<01`L0
1`L00`07000200`70P021`0500L71`002@L01@071`L000L70`061`0600L71`070`051`0300L70087
00<01`L03@L00`071`021`0300L700L700D01`L700061`<01`L010071`L300L700D01`L7000M1`00
2`L400d700D01`L700091`0300L000802`L3008700D01`L700091`0300L7008700<01`L03@L00`07
1`021`0300L700H70`021`0300L700L70`041`0500L71`002@L01@071`L000@70`091`0300L700<0
20L00`071`021`0300L700d700<01`L00PL00`071`071`0500L71`000`L300X71@091`0500L71`00
7@L000P70`0A1`0500L71`001`L4008700<01`L01PL300D700D01`L700091`0300L7008700<01`L0
3@L00`071`021`0300L700<70`000`L01`021`0300L700@70`071`0500L71`002@L01@071`L00087
0P0<1`<000<700L020L00`071`021`0300L700d700<01`L00PL00`071`071`0400L71`@02`L300<7
00<01`L01`L01@071`L001d700061`8050L01@071`L000@70`021`0500L71`0010L400P700D01`L7
00091`0300L7008700<01`L03@L00`071`021`0300L700<010L01@071`L000<70`0:1`0500L71`00
2@L010071`L300/710031`0300L700L700<01`L00PL00`071`0=1`0300L7008700<01`L01`L00`07
000200`70P021`0500L71`002@L01@071`L001d700061`0300L701<700H01`L700L300D700H01`L7
00L300`700D01`L700091`0300L7008700<01`L03@L00`071`021`<01`L010071`L400d700D01`L7
00091`D02PL300<700D01`L700091`0300L7008700<01`L03@L00`071`021`0300L700H70`021`03
00L700L70`041`0500L71`002@L01@071`L001d700061`0300L701<700@01`L70P081`0300L700<0
3`L01@071`L000T700<01`L00PL00`071`0=1`0300L000<02@L00`070002010700D01`L700071`<0
0`L00`071`051`<01PL01@071`L000T700<01`L00PL00`071`0=1`0300L7008700<01`L00`L30003
1`07008700<01`L010L300L700D01`L700091`0500L71`007@L000H700<01`L04`L01@071`L000T7
0`000`L01`0?1`0500L71`002@L00`071`021`0300L700`70`031`0300L700H70`021`0300L700h7
00D01`L700041`<00PL01@071`L000@70`091`0500L71`002@L00`071`021`0300L700d700<01`L0
0PL00`071`0300@700D01`L700031`<02PL01@071`L000T700D01`L7000M1`001PL00`071`0C1`05
00L71`001PL400<700<01`L03PL01@071`L000T700<01`L00PL00`071`091`<000<700L00`L00`07
1`031`<000<700L00PL00`071`0>1`0600L71`070`051`0600L71`070`0<1`0500L71`002@L00`07
1`021`0300L700d700<01`L00PL300L700@01`L7100=1`0500L71`002@L01@071`L001d700061`03
00L701<700D01`L700031`<00`L01@071`L0010700D01`L700091`0300L7008700<01`L01PL300@7
00<01`L00PL00`07000300@700D01`L7000@1`0300L700<020L00`071`0300l700D01`L700091`03
00L7008700<01`L03@L00`07000300T700<01`000P0@1`0500L71`002@L01@071`L001d700061`03
00L701<700@01`L710061`0500L71`0040L01@071`L000T700<01`L00PL00`071`021`@01`L01007
1`L300P700D01`L7000@1`<000<700L020L300031`0700l700D01`L700091`0300L7008700<01`L0
30L300<700<01`L01PL3008700<01`L03PL01@071`L000T700D01`L7000M1`001PL00`071`0C1`03
00L000802@L01@071`L0010700D01`L700091`0300L7008700<01`000P0;1`@000<700L020L01@07
1`L000d710031`0300L700@710031`0300L700h700D01`L700091`0300L7008700<01`L02@L30003
1`0700<700<01`L00`L300031`07008700<01`L03PL01@071`L000T700D01`L7000M1`001PL00`07
1`0C1`800PL00`071`071`0500L71`0040L01@071`L000T700@01`L70`0;1`@010L00`071`071`05
00L71`002@L400<700D01`L700021`@00`L01@071`L0010700D01`L700091`0300L7008700<01`L0
1PL300@700<01`L00PL00`07000300@700D01`L7000@1`0300L700802@L00`071`0201d700061`03
00L7010710031`0300L700L700D01`L7000@1`0500L71`002@L400031`0700P70`031`0300L70087
00<01`L01`L01@071`L000H70`071`0400L71`<01`L01@071`L0010700D01`L700091`0300L70087
00<01`L00PL400L700@01`L70`081`0500L71`0040L300031`0700P70`000`L01`0L1`001PL00`07
1`0=1`<00`L01@071`L000T700D01`L7000@1`0500L71`001`L300@700<01`L010L300H700<01`L0
0PL00`071`071`0500L71`000`L300X71@091`0500L71`0040L01@071`L000T700<01`L00PL00`07
000200/710000`L01`081`0500L71`003@L400<700<01`L010L400<700<01`L06`L000H700<01`L0
2PL300H700D01`L700091`0500L71`0040L01@071`L000<710021`0300L7008700@01`L70`091`03
00L7008700<01`L01`L010071`L400/70`031`0300L700L700D01`L7000@1`0500L71`002@L01007
1`L300/710041`0300L700L700D01`L700091`@00`L01@071`L0008710031`0500L71`007@L000H7
00<01`L01`L300T700D01`L700091`0500L71`0040L010071`L400H700<01`L00PL400`700<01`L0
0PL00`071`071`0300L000802`L3008700D01`L700091`0500L71`0040L01@071`L000T710000`L0
1`081`<00`L00`071`021`0300L700L700D01`L700061`<01`L010071`L300L700D01`L7000M1`00
1PL00`071`041`<030L01@071`L000T700D01`L7000@1`0300L000802@L00`07000300l700<01`L0
0PL00`071`051`@00PL00`071`051`@01@L01@071`L000T700D01`L7000@1`0500L71`001`L300@7
00<01`L010L300H700<01`L00PL00`071`071`0500L71`000`L300X71@091`0500L71`007@L000H7
00<01`L00PL200l700D01`L700091`0500L71`003`L3008700<01`L01PL300<700<01`L03@L00`07
1`021`0300L700870`021`0500L71`0010L300T700D01`L700091`0500L71`0040L01@071`L000<7
10021`0300L7008700@01`L70`091`0300L7008700<01`L01`L010071`L400/70`031`0300L700L7
00D01`L7000M1`001PL00`071`021`0300L700h700D01`L700091`0500L71`0030L300031`070087
00<01`L00`L300031`0700<700<01`L03@L00`071`021`0300L000801@L01P071`L01`<030L01@07
1`L000T700D01`L7000@1`0400L71`@01PL00`071`021`@030L00`071`021`0300L700L700<01`00
0P0;1`<00PL01@071`L000T700D01`L7000M1`001PL00`071`021`0300L700h700D01`L700091`05
00L71`002@L300@700D01`L700021`<010L00`071`021`0300L700d700@01`L70`081`0300L700<0
3`L01@071`L000T700D01`L7000@1`0300L000802@L00`07000300l700<01`L00PL00`071`051`@0
0PL00`071`051`@01@L01@071`L000T700D01`L7000M1`001PL00`071`021`0300L700h700D01`L7
00091`0500L71`001PL300L700@01`L70`071`0300L7008700<01`L03@L400031`0700P70`000`L0
1`0?1`0500L71`002@L01@071`L000l70`021`0300L700H70`031`0300L700d700<01`L00PL00`07
1`021`<00PL01@071`L000@70`091`0500L71`002@L01@071`L001d700061`0300L7008700<01`L0
3PL01@071`L000T700D01`L700031`<02PL500T700<01`L00PL00`071`0;1`<010L00`071`041`@0
0`L00`071`0>1`0500L71`002@L01@071`L000`70`000`L01`021`0300L700<70`000`L01`031`03
00L700d700<01`L00PL00`07000200D700H01`L700L300`700D01`L700091`0500L71`007@L000H7
00<01`L00PL00`071`0>1`0500L71`002@L010071`L400/70`031`0300L700L700<01`L00PL00`07
1`081`<00PL00`071`021`0400L71`<00`L01@071`L0010700D01`L700091`0500L71`002@L300@7
00D01`L700021`<010L00`071`021`0300L700d700@01`L70`081`0300L700<03`L01@071`L000T7
00D01`L7000M1`001PL00`071`021`0300L700h700D01`L700091`0300L7008030L2008700D01`L7
00091`0300L7008700<01`L01@L300D700<01`L00PL400H700D01`L7000@1`0500L71`002@L01@07
1`L000H70`071`0400L71`<01`L00`071`021`0300L700d710000`L01`081`<000<700L03`L01@07
1`L000T700D01`L7000?1`8030L000H700<01`L00PL00`071`0>1`0500L71`002@L300031`0700P7
0`041`0500L71`002@L00`071`021`0300L700870`081`0300L700<02@L01@071`L0010700D01`L7
00091`0500L71`000`L300X71@091`0300L7008700<01`L02`L300@700<01`L010L400<700<01`L0
3PL01@071`L000T700D01`L7000<1`<000<700L02`L000H700<01`L00PL00`071`0>1`0500L71`00
1PL400<700<01`L010L300L700D01`L700091`0300L7008700<01`000P0;1`<00PL00`071`071`05
00L71`0040L01@071`L000T700@01`L7100;1`<00`L00`071`071`0300L7008700<01`L020L30087
00<01`L00PL010071`L300<700D01`L7000@1`0500L71`002@L01@071`L000T70`041`0300L700X7
00061`0300L7008700<01`L03PL01@071`L000<70`031`0500L71`000`L300X700D01`L700091`04
00L71`<030L300@700<01`L01`L01@071`L0010700D01`L700091`0300L7008030L2008700D01`L7
00091`0300L7008700<01`L01@L300D700<01`L00PL400H700D01`L7000@1`0500L71`002@L01@07
1`L000D710071`0300L700X700061`0300L7008700<01`L03PL010071`L400H700@01`L7100=1`05
00L71`002@L400031`0700T70`021`0300L7008700<01`L01`L01@071`L0010700D01`L700091`<0
00<700L020L300@700D01`L700091`0300L7008700<01`L00PL300P700<01`L00`091`0500L71`00
40L01@071`L000T700D01`L700021`<02`L00`071`0:1`001PL00`071`021`0300L700h700<01`00
0P091`0300L0008040L01@071`L000L70`041`0300L700D70`051`0300L7008700<01`L01`L01@07
1`L0010700D01`L700061`@00`L00`071`041`<01`L01@071`L000T700<01`L00PL00`07000200/7
0`021`0300L700L700D01`L7000@1`0500L71`002@L010071`L300h700<01`L02PL000H700<01`L0
0PL00`071`0>1`800PL00`071`061`<00PL00`071`0>1`0500L71`0010L3008700<01`L00PL00`07
1`021`<020L00`071`021`0300L700L700D01`L7000@1`0500L71`000`L300<700D01`L700031`<0
2PL01@071`L000T700@01`L70`0<1`<010L00`071`071`0500L71`0040L01@071`L000T71@0@1`03
00L700X700061`0300L7008700<01`L03PL01@071`L000D70`000`L01`021`0300L700h700H01`L7
00L300D700<01`L00PL00`07000200/700<01`L00PL00`071`071`0500L71`0040L010071`L400H7
00@01`L7100=1`0500L71`002@L400031`0700T70`021`0300L7008700<01`L01`L01@071`L00107
00D01`L700071`<00`L00`071`0>1`0300L700X700061`0300L7008700<01`L03PL01P071`L01`@0
10L01@071`L0010700<01`L00`081`0400L71`<03PL00`071`021`0300L700L700D01`L7000@1`03
00L000802@L00`070002010700D01`L700071`<010L00`071`051`<01@L00`071`021`0300L700L7
00D01`L7000@1`0500L71`000`L4008700D01`L7000@1`0300L700X700061`0300L7008700<01`L0
3PL00`071`0300P700D01`L7000@1`<000<700L020L400031`0700h700<01`L00PL00`071`071`05
00L71`003`L3008700<01`L01PL3008700<01`L03PL01@071`L000@70`021`0300L7008700<01`L0
0PL300P700<01`L00PL00`071`071`0500L71`0040L010071`L400H700D01`L7000@1`0300L700X7
00061`0300L7008700<01`L03PL300031`0700P700D01`L7000=1`@00`L00`071`041`@010L00`07
1`0=1`0300L7008700<01`L01`L01@071`L000`70`000`L01`021`0300L700<70`000`L01`021`03
00L700h700H01`L700L300D700<01`L00PL00`07000200/700<01`L00PL00`071`071`0500L71`00
40L00`07000200T700D01`L7000@1`0300L700X700061`0300L7008700<01`L02PL500<700<01`L0
1`L01@071`L000T710031`0500L71`000`L300<700<01`L00PL00`071`0=1`0300L7008700<01`L0
1`L01@071`L000P710041`0500L71`000PL300@700D01`L7000@1`0300L700<020L010071`L300h7
00<01`L00PL00`071`071`0500L71`003`L3008700<01`L01PL200<700<01`L03PL00`071`0:1`00
1PL00`071`021`0300L700L70`041`0500L71`002@L01@071`L000H70`071`0400L71`@01PL00`07
1`021`0300L700d700<01`L00PL00`071`071`0500L71`001@L300P700<01`L010071`0500L71`00
40L300031`0700P710000`L01`0>1`0300L7008700<01`L01`L01@071`L000`70`000`L01`021`03
00L700<70`000`L01`021`0300L700h700<01`L02PL000H700<01`L00PL00`071`041`<01`L01@07
1`L000T700D01`L700031`<02PL500T700<01`L00PL00`071`0=1`0300L7008700<01`L01`L01@07
1`L000870`0;1`<000<700L020L01@071`L000d710031`0300L700@710041`0300L700d700<01`L0
0PL00`071`071`0500L71`002@L300@700D01`L700021`<010L01@071`L0010700@01`L70P071`00
1PL00`071`021`0400L71`<02PL01@071`L000T700@01`L7100;1`<00`L00`071`071`0300L70087
00<01`L03@L00`071`021`0300L700L700<01`L0100;1`@00`L00`071`071`0500L71`002@L400<7
00D01`L700031`<00`L00`071`021`0300L700d700<01`L00PL00`071`071`0500L71`001PL300L7
00@01`L70`071`0500L71`0040L400031`0700H700061`0300L70087100=1`0500L71`002@L00`07
000200/70`021`0500L71`002@L00`071`021`0300L700d700<01`L00PL00`071`071`<000<700L0
2@L300<700D01`L700091`0500L71`001PL300L700@01`L710061`0300L7008700<01`L03@L00`07
1`021`0300L700L700D01`L700031`<02PL500T700D01`L7000>1`<010L00`071`051`001PL00`07
0003010700D01`L700071`@00PL00`071`061`<01@L01@071`L000T700<01`L00PL00`071`0=1`03
00L7008700<01`L010L400<700<01`L01@L300H700D01`L700091`0500L71`000`L300X71@091`03
00L7008700<01`L03@L00`071`021`0300L700L700@01`L7100;1`<00`L00`071`071`0500L71`00
2`L3008700<01`L00PL00`071`051`001PL200<700<01`L03PL01@071`L000@70`021`0500L71`00
10L400P700D01`L700091`0300L7008700<01`L03@L00`071`021`0400L71`<00`L01@071`L000<7
10091`0500L71`002@L010071`L400/70`031`0300L700L700<01`L00PL00`071`0=1`0300L70087
00<01`L01`L00`07000200`70P021`0500L71`002@L01@071`L000P70`051`0300L7008700<01`L0
1@L000/700<01`L03PL01P071`L01`<01@L01P071`L01`<030L01@071`L000T700<01`L00PL00`07
1`0=1`0300L7008710061`0400L71`@03@L01@071`L000T700<01`000P0;1`<00PL01@071`L000T7
00<01`L00PL00`071`0=1`0300L7008700<01`L01PL3008700<01`L01`L300@700D01`L700091`05
00L71`001@L300P700<01`L00PL00`071`051`002`L00`071`0>1`0400L71`8020L00`071`0300l7
00D01`L700091`0300L7008700<01`L03@L00`07000300T700<01`000P0@1`0500L71`001`L40087
00<01`L01PL300D700D01`L700091`0300L7008700<01`L03@L00`071`021`0300L700<70`000`L0
1`021`0300L700@70`071`0500L71`002@L01@071`L000870`0;1`0300L7008700<01`L01@L000/7
00<01`L03PL01@071`L000T70`000`L01`0?1`0500L71`002@L00`071`021`0300L700`70`031`03
00L700H70`021`0300L700h700D01`L700041`<00PL01@071`L000@710081`0500L71`002@L00`07
1`021`0300L700d700<01`L00PL00`071`0300@700D01`L700031`<02PL01@071`L000T700@01`L7
0`0>1`0300L7008700<01`L01@L000/700<01`L03PL01@071`L000H710031`0300L700h700D01`L7
00091`0300L7008700<01`L02@L300031`0700<700<01`L00`L300031`07008700<01`L03PL01P07
1`L01`<01@L01P071`L01`<030L01@071`L000T700<01`L00PL00`071`0=1`0300L700870`071`04
00L71`@03@L01@071`L000T71@0@1`0300L7008700<01`L01@L000/700<01`L03PL01@071`L000<7
0`031`0500L71`0040L01@071`L000T700<01`L00PL00`071`061`<010L00`071`021`0300L700<0
10L01@071`L0010700<01`L00`081`0300L700<03`L01@071`L000T700<01`L00PL00`071`0=1`03
00L000<02@L00`070002010700D01`L700071`<00`L00`071`0>1`0300L7008700<01`L01@L000/7
00<01`L03PL010071`L400H700D01`L7000@1`0500L71`002@L00`071`021`0300L700<70`071`03
00L700870`071`0500L71`0040L300031`0700P70`000`L01`0?1`0500L71`002@L00`071`021`03
00L700`70`031`0300L700H70`021`0300L700h700D01`L700041`<00PL01@071`L0010700<01`L0
0PL00`071`051`002`L00`071`0>1`0300L000802@L01@071`L0010700D01`L700091`0300L70087
00<01`L00`0:1`0300L000<02@L01@071`L000d710031`0300L700@710031`0300L700h700D01`L7
00091`0300L7008700<01`L02@L300031`0700<700<01`L00`L300031`07008700<01`L03PL01P07
1`L01`<01@L01@071`L0010700<01`L00PL00`071`051`002`L00`071`0>1`800PL00`071`071`05
00L71`0040L01@071`L000T700<01`L00PL300`70`031`0300L700L700D01`L7000:1`<00`L01@07
1`L000<70`031`0500L71`0040L01@071`L000T700<01`L00PL00`071`061`<010L00`071`021`03
00L000<010L01@071`L0010700<01`L00`081`0300L7008040L00`071`021`0300L700D7000;1`03
00L700/710031`0300L700L700D01`L7000@1`0500L71`002@L00`071`0300/70`000`L01`031`03
00L700L700D01`L700071`<01PL010071`L400H700D01`L7000@1`0500L71`002@L00`071`021`03
00L7008710071`0400L71`<020L01@071`L001070`000`L01`081`<000<700L03`L00`071`021`03
00L700D7000;1`0300L700P70`031`0500L71`002@L01@071`L0010700D01`L700091`<00PL00`07
1`061`<010L00`071`021`0300L700L700D01`L700041`<02@L00`07000200T700D01`L7000@1`05
00L71`002@L00`071`021`0300L000802`L400031`0700P700D01`L7000=1`@00`L00`071`041`@0
0`L00`071`0>1`0300L7008700<01`L01@L000/700<01`L01@L300H700D01`L700091`0500L71`00
40L01@071`L000H710041`0300L700<70`071`0300L7008700<01`L01`L01@071`L000870P0<1`80
0PL00`071`071`0500L71`0040L01@071`L000T700@01`L70`0;1`@010L00`071`071`0500L71`00
2@L400<700D01`L700021`@00`L01@071`L0010700<01`L00PL00`071`051`002`L00`071`021`<0
2@L01@071`L000T700D01`L7000@1`0500L71`000`L300<700<01`L00PL00`071`0300X700<01`L0
0PL00`071`071`0400L71`<02`L400<700<01`L01`L01@071`L0010700D01`L700091`@000<700L0
20L300<700<01`L00PL00`071`071`0500L71`001PL300L700@01`L70`071`0500L71`0040L00`07
1`021`0300L700D7000;1`0300L0008030L01@071`L000T700D01`L7000@1`0400L71`@01PL00`07
1`021`<03@L00`071`021`0300L700L71@0:1`<00`L01@071`L000T700D01`L7000@1`0500L71`00
1`L300@700<01`L010L300H700<01`L00PL00`071`071`0500L71`000`L300X71@091`0500L71`00
40L00`071`021`0300L700D7000;1`803`L01@071`L000T700D01`L7000@1`0300L000802@L00`07
000300l700<01`L00PL00`071`051`<00`L00`071`051`<01PL01@071`L000T700D01`L7000@1`05
00L71`000`L4008700<01`L00PL010071`L300T700<01`L00PL00`071`071`0400L71`@02`L300<7
00<01`L01`L01@071`L0010700<01`L00PL00`071`051`0070L01@071`L000T700D01`L7000?1`<0
0PL00`071`061`<00`L00`071`0=1`0300L7008700<01`L00PL3008700D01`L700041`<02@L01@07
1`L000T700D01`L7000@1`0400L71`@01PL00`071`021`@030L00`071`021`0300L700L700<01`00
0P0;1`<00PL01@071`L000T700D01`L7000@1`0300L7008700<01`L01@L001`700D01`L700091`05
00L71`0030L300031`07008700<01`L00`L300031`0700<700<01`L03@L00`071`021`0300L00080
1@L01P071`L01`<030L01@071`L000T700D01`L7000@1`0300L000802@L00`07000300l700<01`L0
0PL00`071`051`@00PL00`071`051`@01@L01@071`L000T700D01`L7000@1`0300L7008700<01`L0
1@L001`700D01`L700091`0500L71`002@L300@700D01`L700021`<010L00`071`021`0300L700d7
00@01`L70`081`0300L700<03`L01@071`L000T700D01`L7000?1`<00PL00`071`061`<00`L00`07
1`0=1`0300L7008700<01`L00PL3008700D01`L700041`<02@L01@071`L000T700D01`L7000@1`03
00L7008700<01`L01@L001`700D01`L700091`0500L71`001@L400L700<01`L010071`0300L70087
00<01`L03@L400031`0700P70`000`L01`0?1`0500L71`002@L01@071`L000`70`000`L01`021`03
00L700<70`000`L01`031`0300L700d700<01`L00PL00`07000200D700H01`L700L300`700D01`L7
00091`0500L71`0040L00`071`021`0300L700D7000L1`0500L71`002@L01@071`L000870`0;1`<0
00<700L020L00`071`021`0300L700X710041`0300L700@710031`0300L700h700D01`L700091`05
00L71`002@L300@700D01`L700021`<010L00`071`021`0300L700d700@01`L70`081`0300L700<0
3`L01@071`L000T700D01`L7000@1`0300L7008700<01`L01@L001`700D01`L700091`0400L71`<0
2`L400<700<01`L01`L00`071`021`0300L700L70`031`0300L7008700<01`L010031`0500L71`00
40L01@071`L000T700D01`L700061`<01`L010071`L300L700<01`L00PL00`071`0=1`@000<700L0
20L300031`0700l700D01`L700091`0500L71`003`L200@700<01`L01@L001`700D01`L700091`D0
2PL300<700D01`L700091`0300L7008700<01`L010L300H700<01`L00PL300L700D01`L7000@1`05
00L71`002@L01@071`L000<70`0:1`D02@L00`071`021`0300L700/70`041`0300L700@710031`03
00L700h700D01`L700091`0500L71`0030L300H700<01`L01@L001`700D01`L700071`<00`L00`07
1`051`<01PL01@071`L000T700<01`L00PL00`071`0400T700<01`000`091`0500L71`0040L01@07
1`L000T700@01`L7100;1`<00`L00`071`071`0300L7008700<01`L020L3008700<01`L00PL01007
1`L300<700D01`L7000@1`0500L71`002@L01@071`L000T70`091`0300L700D7000L1`0500L71`00
0`L4008700D01`L700031`@02@L01@071`L000T700<01`L00PL300`70`031`0300L700L700D01`L7
000@1`0500L71`002@L00`071`0200`70P021`0500L71`002@L00`071`021`0300L700D70`051`03
00L7008710061`0500L71`0040L01@071`L000T700D01`L700061`<030L00`071`051`0070L01007
1`L400H700@01`L7100=1`0500L71`002@L00`07000300/70`000`L01`031`0300L700L700D01`L7
000@1`0500L71`002@L300031`0700P70`041`0500L71`002@L00`071`021`0300L700870`081`03
00L700<02@L01@071`L0010700D01`L700091`0500L71`000`L300l700<01`L01@L001`700<01`00
0P091`0300L0008040L01@071`L000P70`031`0300L700D710041`0300L7008700<01`L01`L01@07
1`L0010700D01`L700061`@00`L00`071`041`<01`L01@071`L000T700<01`L00PL00`07000200/7
0`021`0300L700L700D01`L7000@1`0500L71`002@L010071`L4018700<01`L01@L001`70P021`03
00L700L70P021`0300L700h700D01`L700041`@000<700L00`L00`071`021`<020L00`071`021`03
00L700L700D01`L7000@1`0500L71`000`L300<700D01`L700031`<02PL01@071`L000T700@01`L7
0`0<1`<010L00`071`071`0500L71`0040L01@071`L000T700<01`L00P0E1`0300L700D7000L1`05
00L71`002@L01@071`L0010700H01`L700L300D700<01`L00PL00`07000200/700<01`L00PL00`07
1`071`0500L71`0040L010071`L400H700@01`L7100=1`0500L71`002@L400031`0700T70`021`03
00L7008700<01`L01`L01@071`L0010700D01`L700091`<000<700L050L00`071`051`0070L01@07
1`L000T700D01`L7000@1`0300L700<020L010071`L300h700<01`L00PL00`071`071`0500L71`00
40L00`07000200T700<01`000P0@1`0500L71`001`L300@700<01`L01@L300D700<01`L00PL00`07
1`071`0500L71`0040L01@071`L000H710031`0300L701<700<01`L01@L001`700D01`L700091`05
00L71`0040L300031`0700P710000`L01`0>1`0300L7008700<01`L01`L01@071`L000l70`021`03
00L700H70`021`0300L700h700D01`L700041`<00PL00`071`021`0300L700870`081`0300L70087
00<01`L01`L01@071`L0010700D01`L700031`<00`L01@071`L001D700<01`L01@L001`700D01`L7
00091`0500L71`003@L400<700<01`L01@L300@700<01`L03@L00`071`021`0300L700L700D01`L7
000<1`<000<700L00PL00`071`031`<000<700L00PL00`071`0>1`0600L71`070`051`0300L70087
00<01`000P0;1`0300L7008700<01`L01`L01@071`L0010700@01`L710061`0500L71`005@L00`07
1`051`0070L01@071`L000T700D01`L7000:1`<00`L01@071`L000@70`021`0300L7008700<01`L0
3@L00`071`021`0300L700L700D01`L700081`@010L01@071`L000870`041`0500L71`0040L00`07
1`0300P700@01`L70`0>1`0300L7008700<01`L01`L01@071`L0010700<01`000P091`0500L71`00
5@L00`071`051`0070L01@071`L000T700D01`L700071`<01PL01P071`L01`<01@L00`071`021`03
00L700d700<01`L00PL00`071`071`0500L71`001@L300P700<01`L010071`0500L71`0040L30003
1`0700P710000`L01`0>1`0300L7008700<01`L01`L01@071`L000l70`021`0300L700H70P031`03
00L701<700<01`L01@L001`700D01`L700091`0500L71`0010L300T700<01`L00`081`0300L70087
00<01`L03@L00`071`021`0300L700L700D01`L700021`<02`L300031`0700P700D01`L7000=1`@0
0`L00`071`041`@010L00`071`0=1`0300L7008700<01`L01`L01@071`L000`70`000`L01`021`03
00L700<70`000`L01`021`0300L701<700<01`L01@L001`700D01`L700091`0500L71`000PL200`7
0`000`L01`081`0300L7008700<01`L03@L00`071`021`0300L700L700<01`L0100;1`@00`L00`07
1`071`0500L71`002@L400<700D01`L700031`<00`L00`071`021`0300L700d700<01`L00PL00`07
1`071`0500L71`0020L400@700D01`L700021`<010L01@071`L001@70P071`0070L01@071`L000T7
00@01`L70`0;1`@00`L00`071`071`0300L7008700<01`L03@L00`071`021`0300L700L70`000`L0
1`091`<00`L01@071`L000T700D01`L700061`<01`L010071`L400H700<01`L00PL00`071`0=1`03
00L7008700<01`L01`L01@071`L000D70`081`0300L700@01`L01@071`L001470`091`0070L01@07
1`L000T71@0:1`<00`L01@071`L000T700<01`L00PL00`071`0=1`0300L7008700<01`L010L400<7
00<01`L01@L300H700D01`L700091`0500L71`000`L300X71@091`0300L7008700<01`L03@L00`07
1`021`0300L700L700D01`L700021`<02`L300031`0700P700D01`L7000=1`@030L001`700D01`L7
00071`<00`L00`071`051`<01PL01@071`L000T700<01`L00PL00`071`0=1`0300L7008700@01`L7
0`031`0500L71`000`L400T700D01`L700091`0400L71`@02`L300<700<01`L01`L00`071`021`03
00L700d700<01`L00PL00`071`071`0300L700@02`L400<700<01`L01`L01@071`L000X70`0@1`00
70L01@071`L000@70`021`0500L71`0010L300T700D01`L700091`0300L7008700<01`L03@L00`07
1`021`@01PL010071`L400d700D01`L700091`0300L000802`L3008700D01`L700091`0300L70087
00<01`L03@L00`071`021`0300L700L70`000`L01`091`<00`L01@071`L000T700D01`L700071`<0
4`L001`700H01`L700L300D700H01`L700L300`700D01`L700091`0300L7008700<01`L03@L00`07
000300T700<01`000P0@1`0500L71`001`L4008700<01`L01PL300D700D01`L700091`0300L70087
00<01`L03@L00`071`021`0300L700@710031`0300L700D70`061`0500L71`002@L01@071`L000<7
100F1`0070L010071`L200P700@01`L70P0?1`0500L71`002@L00`071`021`0300L700`70`031`03
00L700H70`021`0300L700h700D01`L700041`<00PL01@071`L000@710081`0500L71`002@L00`07
1`021`0300L700d700<01`L00PL010071`L300<700D01`L700031`@02@L01@071`L000T700@01`L7
100J1`0070L01@071`L000T700D01`L7000@1`0500L71`002@L00`071`021`0300L700T70`000`L0
1`031`0300L700<70`000`L01`021`0300L700h700H01`L700L300D700H01`L700L300`700D01`L7
00091`0300L7008700<01`L03@L00`071`021`@01PL010071`L400d700D01`L700091`0300L00080
7@L001`700D01`L700091`0500L71`0040L01@071`L000T700<01`L00PL00`071`061`<010L00`07
1`021`0300L700<010L01@071`L0010700<01`L00`081`0300L700<03`L01@071`L000T700<01`L0
0PL00`071`0=1`0300L000<02@L00`070002010700D01`L700081`<00PL00`071`0K1`0070L01@07
1`L000T700D01`L7000@1`0500L71`002@L00`071`021`0300L700<70`071`0300L700870`071`05
00L71`0040L300031`0700P70`000`L01`0?1`0500L71`002@L00`071`021`0300L700`70`031`03
00L700H70`021`0300L700h700D01`L700041`@000<700L00PL00`071`0K1`0070L01@071`L000T7
00D01`L7000@1`0500L71`002@L00`071`021`0300L700<02PL00`07000300T700D01`L7000=1`@0
0`L00`071`041`@00`L00`071`0>1`0500L71`002@L00`071`021`0300L700T70`000`L01`031`03
00L700<70`000`L01`021`0300L700h700H01`L700L300D700D01`L7000M1`0070L01@071`L000T7
00D01`L7000@1`0500L71`002@L00`071`021`<030L300<700<01`L01`L01@071`L000X70`031`05
00L71`000`L300<700D01`L7000@1`0500L71`002@L00`071`021`0300L700H70`041`0300L70087
00<01`L00`041`0500L71`0040L00`071`0300P700<01`L00P0M1`0070L01@071`L000T700D01`L7
000@1`0500L71`002@L00`071`0300/70`000`L01`031`0300L700L700D01`L700071`<01PL01007
1`L400H700D01`L7000@1`0500L71`002@L00`071`021`0300L700<70`071`0300L700870`071`05
00L71`0040L300031`0700P70`0O1`0070L01@071`L000T700D01`L7000@1`0500L71`002@L30087
00<01`L01PL300@700<01`L00PL00`071`071`0500L71`0010L300T700<01`000P091`0500L71`00
40L01@071`L000T700<01`L00PL00`071`0300X700<01`000`091`0500L71`003@L400<700<01`L0
10L40247000L1`0500L71`002@L01@071`L0010700D01`L700061`@010L00`071`031`<01`L00`07
1`021`0300L700L700D01`L700021`8030L2008700<01`L01`L01@071`L0010700D01`L700091`03
00L700870`0<1`<00`L00`071`071`0500L71`002PL300<700D01`L700031`<00`L00`071`0O1`00
70L01@071`L000T700D01`L7000@1`0500L71`000`L300<700<01`L00PL00`071`0300X700<01`L0
0PL00`071`071`0400L71`<02`L400<700<01`L01`L01@071`L0010700D01`L700091`0300L700<0
2`L300031`0700<700<01`L01`L01@071`L000L70`061`0400L71`@01PL00`071`0O1`0070L01@07
1`L000T700D01`L7000@1`0400L71`@01PL00`071`021`<03@L00`071`021`0300L700L71@0:1`<0
0`L01@071`L000T700D01`L7000@1`0500L71`002@L3008700<01`L01PL300@700<01`L00PL00`07
1`071`0500L71`0010L300T700<01`000P091`0300L701l7000L1`0500L71`002@L01@071`L00107
00<01`000P091`0300L000<03`L00`071`021`0300L700D70`031`0300L700D70`061`0500L71`00
2@L01@071`L0010700D01`L700061`@010L00`071`031`<01`L00`071`021`0300L700L700D01`L7
00021`8030L2008700<01`L01`L00`071`0O1`0070L01@071`L000T700D01`L7000?1`<00PL00`07
1`061`<00`L00`071`0=1`0300L7008700<01`L00PL3008700D01`L700041`<02@L01@071`L000T7
00D01`L7000@1`0500L71`000`L300<700<01`L00PL00`071`0300X700<01`L00PL00`071`071`04
00L71`<02`L400<700<01`L01`L00`071`0O1`0070L01@071`L000T700D01`L7000<1`<000<700L0
0PL00`071`031`<000<700L00`L00`071`0=1`0300L7008700<01`000P051`0600L71`070`0<1`05
00L71`002@L01@071`L0010700@01`L710061`0300L700870`0=1`0300L7008700<01`L01`L500X7
0`031`0500L71`002@L00`071`0O1`0070L01@071`L000T700D01`L700091`<010L01@071`L00087
0`041`0300L7008700<01`L03@L010071`L300P700<01`L00`0?1`0500L71`002@L01@071`L00107
00<01`000P091`0300L000<03`L00`071`021`0300L700D70`031`0300L700D70`061`0500L71`00
2@L00`071`0O1`0070L01@071`L000T700D01`L700051`@01`L00`071`0400L700<01`L00PL00`07
1`0=1`@000<700L020L300031`0700l700D01`L700091`0500L71`003`L3008700<01`L01PL300<7
00<01`L03@L00`071`021`0300L700870`021`0500L71`0010L300T700D01`L700091`0300L701l7
000L1`0500L71`002@L01@071`L000870`0;1`<000<700L020L00`071`021`0300L700X710041`03
00L700@710031`0300L700h700D01`L700091`0500L71`0030L300031`07008700<01`L00`L30003
1`0700<700<01`L03@L00`071`021`0300L000801@L01P071`L01`<030L01@071`L000T700<01`L0
7`L001`700D01`L700091`0400L71`<02`L400<700<01`L01`L00`071`021`0300L700L70`031`03
00L7008700<01`L010031`0500L71`0040L01@071`L000T700D01`L700091`<010L01@071`L00087
0`041`0300L7008700<01`L03@L010071`L300P700<01`L00`0?1`0500L71`002@L00`071`0O1`00
70L01@071`L000T71@0:1`<00`L01@071`L000T700<01`L00PL00`071`041`<01PL00`071`021`<0
1`L01@071`L0010700D01`L700091`0500L71`001@L400L700<01`L010071`0300L7008700<01`L0
3@L400031`0700P70`000`L01`0?1`0500L71`002@L00`071`0O1`0070L01@071`L000L70`031`03
00L700D70`061`0500L71`002@L00`071`021`0300L700@02@L00`07000300T700D01`L7000@1`05
00L71`002@L01@071`L000870`0;1`<000<700L020L00`071`021`0300L700X710041`0300L700@7
10031`0300L700h700D01`L700091`0300L701l7000L1`0500L71`000`L4008700D01`L700031`@0
2@L01@071`L000T700<01`L00PL300`70`031`0300L700L700D01`L7000@1`0500L71`002@L01007
1`L300/710031`0300L700L700<01`L00PL00`071`071`<00`L00`071`021`0300L700@00`L01@07
1`L0010700D01`L700091`0300L701l7000L1`0400L71`@01PL010071`L400d700D01`L700091`03
00L000<02`L300031`0700<700<01`L01`L01@071`L0010700D01`L700091`D02PL300<700D01`L7
00091`0300L7008700<01`L010L300H700<01`L00PL300L700D01`L7000@1`0500L71`002@L00`07
1`0O1`0070L00`07000200T700<01`000P0@1`0500L71`0020L300<700<01`L01@L400@700<01`L0
0PL00`071`071`0500L71`0040L01@071`L000L70`031`0300L700D70`061`0500L71`002@L00`07
1`021`0300L700@02@L00`07000300T700D01`L7000@1`0500L71`002@L00`071`0O1`0070L20087
00<01`L01`L2008700<01`L03PL01@071`L000@710000`L01`031`0300L700870`081`0300L70087
00<01`L01`L01@071`L0010700D01`L700031`@00PL01@071`L000<710091`0500L71`002@L00`07
1`021`<030L300<700<01`L01`L01@071`L0010700D01`L700091`0300L701l7000P1`0300L700/7
00<01`L03PL01P071`L01`<01@L00`071`021`0300L000802`L00`071`021`0300L700L700D01`L7
000@1`0400L71`@01PL010071`L400d700D01`L700091`0300L000<02`L300031`0700<700<01`L0
1`L01@071`L0010700D01`L700091`0300L701l7000P1`0300L700/700<01`L03PL00`071`0300P7
00@01`L70`0>1`0300L7008700<01`L01`L01@071`L0010700<01`000P091`0300L0008040L01@07
1`L000P70`031`0300L700D710041`0300L7008700<01`L01`L01@071`L0010700D01`L700091`03
00L701l7000P1`0300L700/700<01`L03PL300031`0700P710000`L01`0>1`0300L7008700<01`L0
1`L01@071`L000l70`021`0300L700H70`021`0300L700h700D01`L700041`@000<700L00`L00`07
1`021`<020L00`071`021`0300L700L700D01`L7000@1`0500L71`002@L00`071`0O1`0080L00`07
1`0;1`0300L700/710031`0300L700D70`041`0300L700d700<01`L00PL00`071`071`0500L71`00
30L300031`07008700<01`L00`L300031`07008700<01`L03PL01P071`L01`<01@L00`071`021`03
00L000802`L00`071`021`0300L700L700D01`L7000@1`0500L71`002@L00`071`0O1`0080L00`07
1`0;1`0300L700P70`031`0500L71`0010L3008700<01`L00PL00`071`0=1`0300L7008700<01`L0
1`L01@071`L000T70`041`0500L71`000PL300@700D01`L7000@1`0300L700<020L010071`L300h7
00<01`L00PL00`071`071`0500L71`0040L01@071`L000T700<01`L07`L0020700<01`L02`L00`07
1`051`<01PL01P071`L01`<01@L00`071`021`0300L700d700<01`L00PL00`071`071`0500L71`00
1PL300L700@01`L70`071`0500L71`0040L300031`0700P710000`L01`0>1`0300L7008700<01`L0
1`L01@071`L000l70P031`0300L700H70P0Q1`0080L00`071`0;1`0300L700870`091`0300L700<0
20L00`071`021`0300L700d700<01`L00PL00`071`071`0500L71`000`L300X71@091`0500L71`00
3@L400<700<01`L01@L300@700<01`L03@L00`071`021`0300L700L700D01`L7000<1`<01@L00`07
1`031`<08`L0020700<01`L02`L00`071`0200`70`000`L01`081`0300L7008700<01`L03@L00`07
1`021`0300L700L700@01`L7100;1`<00`L00`071`071`0500L71`002PL300<700D01`L700041`<0
0PL00`071`021`0300L700d700<01`L00PL00`071`071`0500L71`0020L400P700<01`L00`0V1`00
80L00`071`0;1`<02`L400<700<01`L01`L00`071`021`0300L700d700<01`L00PL00`071`071`03
00L0008030L2008700D01`L700091`0500L71`001`L300H700H01`L700L300D700<01`L00PL00`07
1`0=1`0300L7008700<01`L01`L01@071`L000D70`0;1`@0:@L0020700<01`L020L400X70`031`05
00L71`002@L00`071`021`0300L700d700<01`L00PL00`071`061`<00PL00`071`071`<010L01@07
1`L000T700D01`L700041`<02@L00`071`0300P700<01`L00PL00`071`0=1`0300L7008700<01`L0
1`L01@071`L000870`0;1`<000<700L0:PL0020700<01`L01@L300<700<01`L01@L300H700D01`L7
00091`0300L7008700<01`L03@L00`071`021`0300L700<70`000`L01`021`0300L700@70`071`05
00L71`002@L01@071`L000870P0<1`<000<700L020L00`071`021`0300L700d700<01`L00PL00`07
1`071`0300L700@02`L300@700<01`L0:@L0020700<01`L00PL300H700<01`L00PL300T700D01`L7
00091`0300L7008700<01`L03@L00`071`021`0300L700<010L01@071`L000<70`0:1`0500L71`00
2@L010071`L300/710031`0300L700L700<01`L00PL00`071`0=1`0300L7008700<01`L01`L30003
1`0700T70`071`0300L702T7000P1`0300L000802@L00`07000200`700D01`L700091`0300L70087
00<01`L03@L00`071`021`<01`L010071`L400d700D01`L700091`D02PL300<700D01`L700091`03
00L7008700<01`L03@L00`071`021`0300L700@710031`0300L700D70`0:1`0300L702T7000P1`80
30L200l700D01`L700091`0300L7008700<01`L03@L00`07000300T700<01`000P0@1`0500L71`00
1`L300<700<01`L01@L300H700D01`L700091`0300L7008700<01`L03@L00`071`021`0400L71`<0
0`L01@071`L000<7100=1`0300L702T7000o1`0500L71`002@L00`071`021`0300L700`70`031`03
00L700H70`021`0300L700h700D01`L700041`<00PL01@071`L000@70`091`0500L71`002@L00`07
1`021`0300L700d700<01`L00PL400H700@01`L7100A1`0300L702T7000o1`0500L71`002@L00`07
1`021`0300L700T70`000`L01`031`0300L700<70`000`L01`021`0300L700h700H01`L700L300D7
00H01`L700L300`700D01`L700091`0300L7008700<01`L03@L00`07000300T700<01`000P0D1`03
00L702T7000o1`0500L71`002@L00`071`021`0300L700H70`041`0300L7008700<01`000`041`05
00L71`0040L00`071`0300P700<01`L00`0?1`0500L71`002@L00`071`021`0300L700`70`031`03
00L700H70`021`0300L7018700<01`L0:@L003l700D01`L700091`0300L7008700<01`L00PL400L7
00@01`L70`081`0500L71`0040L300031`0700P70`000`L01`0?1`0500L71`002@L00`071`021`03
00L700T70`000`L01`031`0300L700<70`000`L01`021`0300L7018700<01`L0:@L003l700D01`L7
00091`0300L7008700<01`000P0;1`@000<700L020L01@071`L000d710031`0300L700@710031`03
00L700h700D01`L700091`0300L7008700<01`L01PL300@700<01`L00PL00`071`0300@700D01`L7
000C1`80:`L003l700D01`L700091`0400L71`<02`L400@700<01`L01`L01@071`L000T710031`05
00L71`000PL400<700D01`L7000@1`0500L71`002@L00`071`021`0300L700<70`071`0300L70087
0`071`0500L71`0040L302d7000o1`0500L71`002@L400031`0700P70`031`0300L7008700<01`L0
1`L01@071`L000H70`071`0400L71`<01`L01@071`L0010700D01`L700091`0300L7008700<01`L0
0`0:1`0300L000<02@L01@071`L000d70`0`1`00?`L01@071`L000L70`041`0300L700@70`061`03
00L7008700<01`L01`L01@071`L000<70`0:1`D02@L01@071`L0010700D01`L700091`0300L70087
0`0<1`<00`L00`071`071`0500L71`002PL303<7000o1`0500L71`000`L4008700<01`L00PL01007
1`L300T700<01`L00PL00`071`071`0400L71`@02`L300<700<01`L01`L01@071`L0010700D01`L7
00091`0300L700<02`L300031`0700<700<01`L01`L01@071`L000L70`0f1`00?`L010071`L400H7
00<01`L00PL400`700<01`L00PL00`071`071`0300L000802`L3008700D01`L700091`0500L71`00
40L01@071`L000T70`021`0300L700H70`041`0300L7008700<01`L01`L01@071`L000@70`0i1`00
?`L00`07000200T700<01`000`0?1`0300L7008700<01`L01@L4008700<01`L01@L400D700D01`L7
00091`0500L71`0040L01@071`L000H710041`0300L700<70`071`0300L7008700<01`L01`L01@07
1`L000870P0l1`00?`L2008700<01`L01`L200<700<01`L03@L00`071`021`0300L700870`021`05
00L71`0010L300T700D01`L700091`0500L71`0040L01@071`L000<70`031`0300L7008700<01`L0
0`0:1`0300L7008700<01`L01`L010071`L303h700131`0300L700`700<01`L03@L00`071`021`03
00L000801@L01P071`L01`<030L01@071`L000T700D01`L7000@1`0400L71`@01PL00`071`021`<0
3@L00`071`021`0300L700L71@101`00@`L00`071`0<1`0300L700d700@01`L70`081`0300L700<0
3`L01@071`L000T700D01`L7000@1`0300L000802@L00`07000300l700<01`L00PL00`071`051`<0
0`L00`071`0n1`00@`L00`071`0<1`0300L700d710000`L01`081`<000<700L03`L01@071`L000T7
00D01`L7000?1`<00PL00`071`061`<00`L00`071`0=1`0300L7008700<01`L00PL3008700D01`L7
00101`00@`L00`071`0<1`0300L700/70`041`0300L700@710031`0300L700h700D01`L700091`05
00L71`0030L300031`07008700<01`L00`L300031`0700<700<01`L03@L00`071`021`0300L00080
1@L01@071`L0040700131`0300L700`700<01`L020L3008700<01`L00PL010071`L300<700D01`L7
000@1`0500L71`002@L01@071`L000T70`041`0500L71`000PL300@700<01`L00PL00`071`0=1`04
00L71`<020L00`071`02040700131`0300L700`700<01`L01@L300D700<01`L00PL400H700D01`L7
000@1`0500L71`002@L01@071`L000D710071`0300L700@01`L00`071`021`0300L700d7100;1`<0
@PL004<700<01`L030L00`071`021`<020L00`071`0300T700D01`L7000@1`0500L71`002@L01@07
1`L000870`0;1`<000<700L020L00`071`021`0300L700X7100;1`@0A0L004<700<01`L030L00`07
000200/70`021`0300L700L700D01`L7000@1`0500L71`002@L010071`L300/710031`0300L700L7
00<01`L00PL00`071`071`<00`L00`071`051`@00`L00`071`121`00@`L00`071`0;1`<030L300@7
00<01`L01`L01@071`L0010700D01`L700091`D02PL300<700D01`L700091`0300L7008700<01`L0
10L300H700<01`L00PL300L700<01`L0@PL004<700<01`L020L300031`0700T70`021`0300L70087
00<01`L01`L01@071`L0010700D01`L700071`<00`L00`071`051`<01PL01@071`L000T700<01`L0
0PL00`071`0400T700<01`000P0:1`0300L7048700131`0300L700D70`041`0300L700D70`051`03
00L7008700<01`L01`L01@071`L0010700D01`L700031`@00PL01@071`L000<710091`0500L71`00
2@L00`071`021`<030L300d700<01`L0@PL004<700<01`L00PL300L700<01`L00PL300P700<01`L0
0PL00`071`071`0500L71`0040L010071`L400H700@01`L7100=1`0500L71`002@L00`07000300/7
0`000`L01`0=1`0300L7048700131`0300L000802PL00`07000200/700<01`L00PL00`071`071`05
00L71`0040L00`07000200T700<01`000P0@1`0500L71`0020L300<700<01`L01@L400@700<01`L0
30L00`071`121`00@`L200d70P0>1`0300L7008700<01`L01`L01@071`L000l70`021`0300L700H7
0`021`0300L700h700D01`L700041`@000<700L00`L00`071`021`<020L00`071`0<1`0300L70487
001R1`0300L7008700<01`L01`L01@071`L000`70`051`0300L700<70`051`0300L700h700H01`L7
00L300D700<01`L00PL00`07000200/700<01`L030L00`071`121`00HPL00`071`021`0300L700L7
00D01`L700091`<020L00`071`0300P700<01`L03PL00`071`0300P700@01`L70`0>1`0300L700`7
00<01`L0@PL0068700<01`L00PL00`071`071`0500L71`001PL300/70`0;1`0300L700h70`0;1`@0
4@L00`071`0<1`0300L70487001R1`0300L7008700<01`L01`L01@071`L000<70`0;1`@03@L00`07
1`0;1`@02`L301@700<01`L030L00`071`121`00HPL00`071`021`0300L700L700@01`L7100;1`<0
0`L00`071`0;1`0300L700P70`031`0300L700H70`021`0300L7018700<01`L030L00`071`121`00
HPL00`071`021`0300L700L700<01`000P0<1`801PL00`071`0;1`0300L700D70`061`0300L700<7
0`051`0300L7018700<01`L030L00`071`121`00HPL00`071`021`0300L700H70`021`0300L700L7
0`081`0300L700/700<01`L00PL300T700<01`L00`081`0300L7018700<01`L030L00`071`121`00
HPL00`071`021`0300L700<70`000`L01`021`0300L700@70`0;1`0300L700/700<01`L00P0<1`<0
2`L00`071`0B1`0300L700`700<01`L0@PL0068700<01`L00PL00`071`0300@700D01`L700031`<0
3PL00`071`0;1`<02`L400d700<01`L04PL00`071`0<1`0300L70487001R1`0300L700870`071`04
00L71`@04@L00`071`081`@02PL300<700<01`L02`L00`071`0B1`0300L700`700<01`L0@PL00687
00<01`000`091`0300L0008050L00`071`051`<00`L00`071`051`<01PL00`071`0;1`0300L70187
00<01`L030L00`071`121`00HPL200<700<01`L01`L2008700<01`L04PL00`071`021`<01PL00`07
1`021`<02@L00`071`0;1`0300L7018700<01`L030L00`071`121`00I`L00`071`0;1`0300L70187
00<01`000P091`0300L0008030L00`071`0;1`0300L7018700<01`L030L00`071`121`00I`L00`07
1`0;1`0300L701470`0;1`<03`L00`071`0;1`0300L701470P0=1`80A0L006L700<01`L02`L00`07
1`0>1`<02`L3018700<01`L02`L00`071`0>1`<030L304H7001W1`0300L700/700<01`L02`L300/7
0`0E1`0300L700/700<01`L02`L300`70`191`00I`L00`071`0;1`0300L700L7100:1`@060L00`07
1`0;1`0300L700P70`0<1`<0C0L006L700<01`L02`L00`071`041`<02`L301`700<01`L02`L00`07
1`051`<030L304l7001W1`0300L700/700@01`L70`0;1`<07`L00`071`0;1`0300L700870`0<1`<0
DPL006L700<01`L02`L400/70`0R1`0300L700/700<01`L00P0<1`<0E@L006L700<01`L02@L300/7
0`0U1`0300L700/70`0;1`<0F0L006L700<01`L01@L4008700<01`L01@L402P700<01`L020L400X7
0`1K1`00I`L00`071`021`<01PL00`071`021`<0;0L00`071`051`<00`L00`071`051`<0GPL006L7
00<01`000P091`0300L00080;`L00`071`021`<01PL00`071`021`<0H@L006L70P0<1`80<PL00`07
000200T700<01`000P1T1`00Z@L200`70P1W1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00
o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {274.188, 0}} -> {-10.1406, -9.68787, \
0.0706688, 0.0706688}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["j = 3, k =1", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AL031, Axes \[Rule] True, Prolog \[Rule] PointSize[0.025], 
      PlotRange \[Rule] \ {{\(-20\), 20}, {\(-20\), 20}}, \ 
      AspectRatio\  \[Rule] \ Automatic]\)], "Input",
  CellLabel->"In[138]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.5 0.025 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -9 -9 ]
[.125 .4875 9 0 ]
[.25 .4875 -9 -9 ]
[.25 .4875 9 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -6 -9 ]
[.75 .4875 6 0 ]
[.875 .4875 -6 -9 ]
[.875 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -12 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -12 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-20)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-15)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-10)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(10)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(15)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(20)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-20)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-15)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-10)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(10)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(15)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(20)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.025 w
.56012 .04698 Mdot
.62262 .13301 Mdot
.68512 .21903 Mdot
.74762 .30506 Mdot
.81012 .39108 Mdot
.49762 .06729 Mdot
.56012 .15332 Mdot
.62262 .23934 Mdot
.68512 .32536 Mdot
.74762 .41139 Mdot
.81012 .49741 Mdot
.37262 .00158 Mdot
.43512 .0876 Mdot
.49762 .17362 Mdot
.56012 .25965 Mdot
.62262 .34567 Mdot
.68512 .43169 Mdot
.74762 .51772 Mdot
.81012 .60374 Mdot
.31012 .02188 Mdot
.37262 .10791 Mdot
.43512 .19393 Mdot
.49762 .27995 Mdot
.56012 .36598 Mdot
.62262 .452 Mdot
.68512 .53803 Mdot
.74762 .62405 Mdot
.81012 .71007 Mdot
.24762 .04219 Mdot
.31012 .12821 Mdot
.37262 .21424 Mdot
.43512 .30026 Mdot
.49762 .38629 Mdot
.56012 .47231 Mdot
.62262 .55833 Mdot
.68512 .64436 Mdot
.74762 .73038 Mdot
.81012 .8164 Mdot
.18512 .0625 Mdot
.24762 .14852 Mdot
.31012 .23455 Mdot
.37262 .32057 Mdot
.43512 .40659 Mdot
.49762 .49262 Mdot
.56012 .57864 Mdot
.62262 .66466 Mdot
.68512 .75069 Mdot
.74762 .83671 Mdot
.81012 .92274 Mdot
.18512 .16883 Mdot
.24762 .25485 Mdot
.31012 .34088 Mdot
.37262 .4269 Mdot
.43512 .51292 Mdot
.49762 .59895 Mdot
.56012 .68497 Mdot
.62262 .771 Mdot
.68512 .85702 Mdot
.74762 .94304 Mdot
.18512 .27516 Mdot
.24762 .36118 Mdot
.31012 .44721 Mdot
.37262 .53323 Mdot
.43512 .61926 Mdot
.49762 .70528 Mdot
.56012 .7913 Mdot
.62262 .87733 Mdot
.68512 .96335 Mdot
.18512 .38149 Mdot
.24762 .46752 Mdot
.31012 .55354 Mdot
.37262 .63956 Mdot
.43512 .72559 Mdot
.49762 .81161 Mdot
.56012 .89763 Mdot
.62262 .98366 Mdot
.18512 .48782 Mdot
.24762 .57385 Mdot
.31012 .65987 Mdot
.37262 .74589 Mdot
.43512 .83192 Mdot
.49762 .91794 Mdot
.18512 .59415 Mdot
.24762 .68018 Mdot
.31012 .7662 Mdot
.37262 .85223 Mdot
.43512 .93825 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[138]:=",
  ImageSize->{221.562, 221.562},
  ImageMargins->{{41, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M0000g@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc=d7003M1`00g@L00=d7003M1`00HPL400<7
0P1b1`00E0L400X700<01`L00`L010071`1a1`00E0L400/700<01`L00PL010071`031`<0J`L005@7
10041`@010L01@071`L0008700D01`L7001]1`00E0L400d700@01`L00PL01@071`L006d700171`@0
5`L010071`021`0400L700<700<01`L0J`L004L7100H1`8010L200@700<01`L0J`L004L7100T1`03
00L706/700171`@090L206`7000j1`@0<@L00`071`1[1`00>PL4034700<01`L02@L405h7000j1`@0
<@L00`071`091`@0GPL003X7100a1`0300L700T7101N1`00;@L403h70P0:1`@0GPL002d7100m1`@0
J`L002d7100m1`@0J`L002d7100m1`@0J`L006h7101[1`00K`L206`7001Q1`@02PL00`071`1[1`00
H@L400X700<01`L0J`L00647100:1`0300L706/7001Q1`@02PL00`071`1[1`00E0L401L70P1/1`00
E0L401L700<01`L0J`L005@7100G1`0300L706/7001D1`@02PL400870`041`0300L706/700171`@0
6@L00`071`041`0500L71`00K@L004L7100I1`0300L700@700@01`L70`0E1`@0DPL004L7100A1`@0
10L010071`L300@700<01`L05@L4058700171`@06@L01@071`L000H700<01`L05@L40587000j1`@0
90L300<700<01`L010L00`071`0E1`@0DPL003X7100V1`0400L71`@00`L00`071`091`@0GPL003X7
100a1`802PL405h7000j1`@0<@L00`071`091`@0GPL002d7100n1`0300L700T7101N1`00;@L403d7
101[1`00;@L403d7101[1`00;@L403d7101[1`00KPL406/7001Q1`@02PL00`071`1[1`00H@L400X7
00<01`L0J`L00647100:1`0300L706/7001Q1`@02PL00`071`1[1`00K`L206`7001D1`@05`L00`07
1`1[1`00E0L401L700<01`L08PL404D7001D1`@05`L00`071`0R1`@0A@L005@7100G1`0300L70287
10151`00A`L402@70P0S1`@0A@L004L7100T1`0300L701D7101B1`00A`L402@700<01`L05@L40587
00171`@05`L400<70P041`0300L701D7101B1`00>PL402H700D01`L700021`0500L71`005`L40587
000j1`@09PL01@071`L0008700@01`L70`091`@0GPL003X7100N1`@010L01@071`L0008700D01`L7
000;1`@0GPL003X7100V1`0500L71`000PL01@071`L000/7101N1`00;@L403470`031`0400L700<7
00<01`L02@L405h7000]1`@0<`L00`071`021`800`L406/7000]1`@0?@L406/7000]1`@0?@L406/7
001^1`@0J`L00647100:1`0300L706/7001Q1`@02PL00`071`0_1`@0>0L00647100:1`80<0L403P7
001Q1`@02PL00`071`0_1`@0>0L005@7100G1`0300L702l7100h1`00E0L401L700<01`L08PL404D7
001D1`@05`L00`071`0R1`@0A@L005@7100G1`808`L404D7001_1`0300L7028710151`00A`L402@7
00<01`L0J`L004L7100T1`0300L701D7101B1`00A`L402@700<01`L05@L4058700171`@090L201H7
101B1`00>PL4034700<01`L05@L40587000j1`@0<@L00`071`091`@0GPL003X7100a1`0300L700T7
101N1`00>PL402X70`041`0300L700T7101N1`00;@L403X700D01`L7000;1`@0GPL002d7100j1`03
00L700@0J`L002d7100a1`@00PL300<7100l1`@0:`L002d7100g1`0300L700<7100l1`@0:`L006P7
00<01`L00`L403`7100[1`00H@L400<710031`0300L703`7100[1`00H@L400X70P0`1`@0>0L00647
100:1`0300L702l7100h1`00H@L400X700<01`L0;`L403P7001D1`@05`L00`071`0_1`@0>0L005@7
100G1`0300L7028710151`00E0L401L70P0S1`@0A@L005@7100G1`0300L7028710151`00A`L402@7
00<01`L08PL404D700171`@090L00`071`0E1`@0DPL004L7100T1`0300L701D7101B1`00A`L402@7
0P0F1`@0DPL000L710031`8040L400870`0A1`@00`L201@70`0E1`0300L701D7100C1`@00`L20107
10021`<04@L400<70P031`001`L00`071`031`0400L7014700<01`L010L00`071`0>1`@00PL01007
1`0F1`0300L7018700<01`L060L00`071`0C1`0500L71`000PL00`071`0?1`0300L700@700<01`L0
3PL00`071`031`0400L7008700081`0300L7008700@01`L04@L00`071`041`0300L700h710021`04
00L701H700<01`L04PL00`071`091`@02`L00`071`0C1`0500L71`000PL00`071`0?1`0300L700@7
00<01`L03`L00`071`021`0400L7008700000`L0000200@700D01`L700021`0300L700L710041`04
00L71`<02`L4008710021`0400L700d710021`<05@L00`071`091`@020L301H700D01`L700021`03
00L700l700@01`L70`0C1`0500L71`000PL100470@L000X700@01`L00PL00`071`0?1`0500L71`00
4`L4008700@01`L04`L00`071`0E1`802PL400P700<01`L05PL01@071`L0008700<01`L03`L01@07
1`L001H700@01`L00PL100470@L000L700@01`L00PL010071`0?1`<00`L00`071`041`@02@L300<7
00@01`L04`L00`071`0E1`0300L700T710081`0300L701@70`031`0400L700l70`031`0300L70147
00@01`L00PL010071`021`0020L200@70P0B1`0400L71`@00`L400/700<01`L00PL201@7100C1`@0
5@L401D700<01`L00PL2018700@01`L7100A1`8010L200<7000]1`@0?@L403`7100[1`00;@L403d7
100l1`@0:`L000T7cP061`002@L00`071`021`0300L7008700<01`L00PL00`071`021`0300L70087
00<01`L00PL00`071`021`0300L700<700<01`L00PL00`071`021`0300L7008700<01`L00PL00`07
1`021`0300L7008700<01`L00`L00`071`021`0300L700871P041`0300L7008700<01`L00PL00`07
1`031`0300L7008700<01`L00PL00`071`021`0300L7008700<01`L00PL00`071`021`0300L700<7
00<01`L00PL00`071`021`0300L700871P041`0300L7008700<01`L00`L00`071`021`0300L70087
00<01`L00PL00`071`021`0300L700@700091`0300L701H700<01`L05`L00`071`0G1`0300L700P7
100:1`0300L701L700<01`L05@L401L700<01`L05`L00`071`041`00H@L400X700<01`L0;`L403P7
001Q1`@02PL00`071`0_1`@0>0L005@7100G1`80<0L403P7001D1`@05`L00`071`0R1`@0A@L005@7
100G1`0300L7028710151`00E0L401L700<01`L08PL404D700171`@090L00`071`0R1`@0A@L004L7
100T1`805PL4058700171`@090L00`071`0E1`@0DPL004L7100T1`0300L701D7101B1`00>PL40347
00<01`L05@L40587000j1`@0<@L00`071`091`@0GPL003X7100a1`0300L700T7101N1`00>PL40347
0P0:1`@0GPL006l700<01`L02@L405h7000]1`@0?PL00`071`1[1`00;@L403d7101[1`00;@L403d7
100l1`@0:`L002d7100m1`@0?0L402/7001^1`@0?0L402/7001Q1`@02PL00`071`0l1`@0:`L00647
10031`<010L00`071`0_1`@0>0L0064710061`0500L71`00<@L403P7001Q1`@01PL010071`L302l7
100h1`00E0L401070`041`0300L702l7100h1`00E0L4010700<01`L010L00`071`0R1`@0A@L005@7
100@1`0300L700@700<01`L08PL404D7001D1`@040L400<700<01`L08PL404D700171`@090L202<7
10151`00A`L402@700<01`L05@L4058700171`@090L00`071`0E1`@0DPL004L7100T1`0300L701D7
101B1`00>PL4034700<01`L05@L40587000j1`@0<@L200X7101N1`00>PL4034700<01`L02@L405h7
000j1`@0<@L00`071`091`@0GPL006l700<01`L02@L405h7001^1`@0J`L006h7100l1`@0:`L006h7
100l1`@0:`L006h7100l1`@0:`L006l700<01`L0?0L402/7001Q1`@02PL00`071`1[1`00H@L400X7
0P0`1`@0>0L00647100:1`0300L702l7100h1`00H@L400X700<01`L0;`L403P7001D1`@05`L00`07
1`0_1`@0>0L005@7100:1`@00`L200@700<01`L08PL404D7001D1`@030L01@071`L0008700D01`L7
000T1`@0A@L005@7100<1`0500L71`000PL010071`L3028710151`00A`L401T700D01`L700021`05
00L71`0090L404D700171`@06@L01@071`L0008700D01`L7000G1`@0DPL004L7100G1`<00`L01007
1`031`0300L701D7101B1`00A`L401T700<01`L00PL200@700<01`L05@L40587001_1`805PL40587
001_1`0300L700T7101N1`00K`L00`071`091`@0GPL006l700<01`L02@L405h7001_1`0300L700T7
101N1`00KPL406/7001^1`@0?0L402/7001^1`@0?0L402/7001^1`@0?0L402/7001_1`0300L703`7
100[1`00H@L400X70P0`1`@0>0L00647100:1`0300L702l7100h1`00H@L400X700<01`L0;`L403P7
001Q1`@02PL00`071`0_1`@0>0L005@7100G1`0300L706/7001D1`@05`L202<710151`00E0L401L7
00<01`L08PL404D7001D1`@05`L00`071`0R1`@0A@L0068710021`<010L00`071`0R1`@0A@L006@7
00<01`L010L01@071`L001L7101B1`00I0L00`071`041`0400L71`<05@L40587001T1`0400L71`<0
10L00`071`0E1`@0DPL006@700D01`L700061`0300L701D7101B1`00HPL300<700<01`L010L00`07
1`091`@0GPL006@700@01`L710031`0300L700T7101N1`00K`L200X7101N1`00K`L00`071`091`@0
GPL006h7101[1`00KPL403`7100[1`00KPL403`7100[1`00KPL403`7100[1`00H@L400X70P0m1`@0
:`L00647100:1`0300L702l7100h1`00H@L400X700<01`L0;`L403P7001Q1`@02PL00`071`0_1`@0
>0L006l700<01`L0;`L403P7001_1`80K0L006l700<01`L08PL404D7001_1`0300L7028710151`00
K`L00`071`0R1`@0A@L006l700<01`L08PL404D7001_1`805PL40587001_1`0300L701D7101B1`00
K`L00`071`0E1`@0DPL0068710031`8010L00`071`0E1`@0DPL0068700<01`L00`L010071`031`03
00L706/7001S1`0300L7008700@01`L00`L306/7001T1`0500L71`000PL00`071`1_1`00I@L01007
1`021`0300L706l7001R1`0400L7008700@01`L0L@L006<70P041`80LPL00=d7003M1`00g@L00001
\
\>"],
  ImageRangeCache->{{{0, 220.562}, {220.562, 0}} -> {-21.7515, -21.4596, \
0.19459, 0.19459}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[138]="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(basis31 = 
      FullSimplify[{A[3, 1, \[Alpha]] /. {m \[Rule] 1, n \[Rule] 0}, 
          A[3, 1, \[Alpha]] /. {m \[Rule] 0, 
              n \[Rule] 1}}]\), "\[IndentingNewLine]", 
    \(orig\  = \ 
      FullSimplify[
        A[3, 1, \[Alpha]] /. {m \[Rule] 0, n \[Rule] 0}]\)}], "Input",
  CellLabel->"In[139]:="],

Cell[BoxData[
    \({{\(-0.09508699431533885`\), 3.957926255168263`}, {2.4049130056846613`, 
        3.145627014585997`}}\)], "Output",
  CellLabel->"Out[139]="],

Cell[BoxData[
    \({\(-0.09508699431533882`\), \(-0.29532778659193704`\)}\)], "Output",
  CellLabel->"Out[140]="]
}, Open  ]],

Cell[BoxData[
    \(\(rad31\  = \ 
        N[\@\(\((basis31[\([1]\)]\  - \ orig)\) . \((basis31[\([1]\)]\  - \ \
orig)\)\)];\)\)], "Input",
  CellLabel->"In[141]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AppendTo[basis31, orig], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-10\), 10}, {\(-10\), 10}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[142]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.49525 .6979 Mdot
.62025 .65728 Mdot
.49525 .48523 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[142]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L0088710031`80U@L008@700D01`L700021`0300L7098700241`0500L71`000PL00`07
1`031`80S@L007`710041`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`07
1`031`0300L708`700221`<00`L010071`051`0300L708`700241`0300L700870P061`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L007d700<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<7
00<01`L0S0L007h700<01`L02PL00`071`031`80S@L007H710041`0300L700L70`061`0300L708`7
001o1`0300L700H700<01`L01PL00`071`2<1`00O0L010071`081`0300L700H700<01`L0S0L007`7
10081`@01@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`700281`<01PL00`071`2<1`00R`L00`071`031`0300L708`7
002;1`0300L700<70P2=1`00PPL400870`061`0300L708`700281`0300L700H700<01`L0S0L008P7
00<01`L01PL00`071`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00O0L400<700<01`L00PL300H7
00<01`L0S0L007`700<01`L030L00`071`031`0300L708`7001m1`0300L700/700<01`L00`L208d7
001f1`@010L00`071`071`<01PL00`071`2<1`00O`L00`071`061`0300L700H700<01`L0S0L007`7
00@01`L020L00`071`061`0300L708`7001m1`802@L400D700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L000L710031`805`L00`071`031`0300L700870`0I1`<06@L400<7
00<01`L00PL301@71P0H1`@00`L00`071`021`<06@L301X700<01`L00`L00`071`021`<05PL400<7
0P031`002@L01@071`L0008700<01`L050L00`071`0;1`0300L701T700<01`L05PL00`071`0<1`03
00L700l72P0F1`0300L700`700<01`L06@L00`071`0G1`0300L700/700<01`L05@L01@071`L00087
0@011`4700091`0500L71`000PL00`071`0E1`0300L700X700<01`L06@L00`071`0G1`0300L700/7
00<01`L03`L:01L700<01`L02`L00`071`0I1`0300L701P700<01`L02PL00`071`0E1`0500L71`00
0PL100470@L000031`00008010L01@071`L0008700<01`L03@L400@700<01`L01`L301<710021`<0
4`L400@700<01`L01`L30147300G1`0300L700L70`0I1`<06`L00`071`071`<060L01@071`L00087
0@011`4700091`0500L71`000PL00`071`0F1`0300L700H700<01`L06@L00`071`0L1`0300L700H7
00<01`L04@L<01P700<01`L01PL00`071`0I1`0300L701`700<01`L01PL00`071`0H1`0500L71`00
0PL100470@L000L70`031`0400L701D700@01`L020L00`071`0I1`0300L701T700@01`L020L00`07
1`0A1``05@L010071`081`0300L701T700<01`L06@L010071`081`0300L701H70`031`0400L70087
00091`0300L700870P0F1`@020L401P7100I1`802@L40107300F1`802@L401P7100H1`@020L401L7
00<01`L00PL200<7002:1``0RPL008X7302:1`00R`L:08/700091ol04P061`002@L00`071`031`03
00L700@700<01`L010L00`071`041`0300L700@700<01`L00`L00`071`041`0300L700@700<01`L0
10L00`071`041`0300L700<700<01`L010L00`071`041`0300L700@700<01`L010L00`071`031`03
00L700@700<01`L010L00`071`041`0300L700H010L00`071`041`0300L700@700<01`L010L00`07
1`041`0300L700<700<01`L010L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@7
00<01`L010L00`071`041`0300L700@700<01`L00`L00`071`041`0300L700@700<01`L010L00`07
1`041`0300L700@700091`0300L701l700<01`L07`L00`071`0O1`0300L701l700<01`L07`L00`07
1`0O1`0300L701l700<01`L07`L00`071`041`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
001l1`@00`L00`071`021`<01PL00`071`2<1`00O0L00`071`0<1`0300L700<700<01`L0S0L007d7
00<01`L02`L00`071`031`80S@L007h700<01`L01`L300H700<01`L0S0L007l700<01`L01PL00`07
1`061`0300L708`7001l1`0400L700P700<01`L01PL00`071`0K1`H0J`L007d70P091`@01@L00`07
1`0I1`X0J@L0094700<01`L06@L:06T7002A1`0300L701P7301X1`00T@L201T7301X1`00T@L00`07
1`0H1``0J0L0094700<01`L060L<06P7002A1`0300L701P7301X1`00T@L00`071`0H1``0J0L00947
00<01`L06@L:06T7002A1`0300L701T72P1Y1`00S@L601`71P1[1`00R`L:08/7002;1`X0R`L008X7
302:1`00RPL<08X7002:1``0RPL008X7302:1`00RPL<08X7002:1``0RPL008/72P2;1`00R`L:08/7
002=1`H0S@L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00R0L300H700<01`L0S0L008/700<01`L00`L00`071`2<1`00R`L00`07
1`031`80S@L008P70`061`0300L708`700281`0300L700H700<01`L0S0L008P700<01`L01PL00`07
1`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00O@L00`071`031`0300L700870`061`0300L708`7
001m1`0300L700/700<01`L00`L00`071`2<1`00OPL00`071`0:1`0300L700<70P2=1`00OPL00`07
1`071`<01PL00`071`2<1`00O`L00`071`061`0300L700H700<01`L0S0L007`700@01`L020L00`07
1`061`0300L708`7001l1`@020L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00PPL400<70P061`0300L708`7
00241`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`071`031`80S@L008@7
00D01`L700021`0300L7098700241`0500L71`000PL00`071`2B1`00PPL300<700@01`L0U0L008@7
00<01`L00PL209D7003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.6619, -10.5516, 0.0735301, \
0.0735301}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[142]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice031\  = tiling2D[SphericalCut[N[AL031], 10], rad31]\)], "Input",
  CellLabel->"In[143]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.06501 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.437148 0.0544218 0.548576 0.0544218 [
[ 0 0 0 0 ]
[ 1 1.06501 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.06501 L
0 1.06501 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.56803 .02536 m
.70408 .21262 L
s
.56803 .02536 m
.56803 .25683 L
s
.70408 .21262 m
.84014 .39988 L
s
.70408 .21262 m
.70408 .44409 L
s
.84014 .39988 m
.97619 .58715 L
s
.84014 .39988 m
.84014 .63135 L
s
.43197 .06956 m
.56803 .25683 L
s
.43197 .06956 m
.43197 .30103 L
s
.56803 .25683 m
.70408 .44409 L
s
.56803 .25683 m
.56803 .4883 L
s
.70408 .44409 m
.84014 .63135 L
s
.70408 .44409 m
.70408 .67556 L
s
.84014 .63135 m
.84014 .86282 L
s
.29592 .11377 m
.43197 .30103 L
s
.29592 .11377 m
.29592 .34524 L
s
.43197 .30103 m
.56803 .4883 L
s
.43197 .30103 m
.43197 .5325 L
s
.56803 .4883 m
.70408 .67556 L
s
.56803 .4883 m
.56803 .71977 L
s
.70408 .67556 m
.84014 .86282 L
s
.70408 .67556 m
.70408 .90703 L
s
.15986 .15798 m
.29592 .34524 L
s
.15986 .15798 m
.15986 .38945 L
s
.29592 .34524 m
.43197 .5325 L
s
.29592 .34524 m
.29592 .57671 L
s
.43197 .5325 m
.56803 .71977 L
s
.43197 .5325 m
.43197 .76397 L
s
.56803 .71977 m
.70408 .90703 L
s
.56803 .71977 m
.56803 .95124 L
s
.02381 .20218 m
.15986 .38945 L
s
.02381 .20218 m
.02381 .43365 L
s
.15986 .38945 m
.29592 .57671 L
s
.15986 .38945 m
.15986 .62092 L
s
.29592 .57671 m
.43197 .76397 L
s
.29592 .57671 m
.29592 .80818 L
s
.43197 .76397 m
.56803 .95124 L
s
.43197 .76397 m
.43197 .99544 L
s
.02381 .43365 m
.15986 .62092 L
s
.02381 .43365 m
.02381 .66512 L
s
.15986 .62092 m
.29592 .80818 L
s
.15986 .62092 m
.15986 .85239 L
s
.29592 .80818 m
.43197 .99544 L
s
.29592 .80818 m
.29592 1.03965 L
s
.02381 .66512 m
.15986 .85239 L
s
.02381 .66512 m
.02381 .89659 L
s
.15986 .85239 m
.29592 1.03965 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[143]:=",
  ImageSize->{288, 306.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001<PP10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00:<700<01`L0NPL00:<70P1k1`00X`L207/7002S1`0300L007X7002S1`04
00L707T7002S1`0500L71`00N0L00:<700D01`L7001h1`00X`L00`071`021`0300L707D7002S1`03
00L700<700<01`L0M0L00:<700<01`L00`L00`071`1d1`00X`L00`071`041`0300L707<7002S1`03
00L700D700<01`L0LPL00:<700<01`L01PL00`071`1a1`00N`L00`071`0U1`0300L700H700<01`L0
L@L007/70P0V1`0300L700L700<01`L0L0L007/70P0V1`0300L700P700<01`L0K`L007/700<01`00
9@L00`071`091`0300L706h7001k1`0400L702@700<01`L02@L00`071`1^1`00N`L01@071`L002<7
00<01`L02PL00`071`1]1`00N`L01@071`L002<700<01`L02`L00`071`1/1`00N`L00`071`021`03
00L7020700<01`L02`L00`071`1/1`00N`L00`071`031`0300L701l700<01`L030L00`071`1[1`00
N`L00`071`041`0300L701h700<01`L03@L00`071`1Z1`00N`L00`071`041`0300L701h700<01`L0
3PL00`071`1Y1`00N`L00`071`051`0300L701d700<01`L03PL00`071`1Y1`00E0L00`071`0T1`03
00L700H700<01`L070L00`071`0?1`0300L706P7001D1`809@L00`071`071`0300L701/700<01`L0
40L00`071`1W1`00E0L202D700<01`L01`L00`071`0K1`0300L7010700<01`L0I`L005@700<01`00
90L00`071`081`0300L701X700<01`L04@L00`071`1V1`00E0L010071`0S1`0300L700T700<01`L0
6@L00`071`0B1`0300L706D7001D1`0500L71`008PL00`071`0:1`0300L701P700<01`L04`L00`07
1`1T1`00E0L01@071`L0028700<01`L02PL00`071`0H1`0300L701<700<01`L0I0L005@700<01`L0
0PL00`071`0O1`0300L700/700<01`L05`L00`071`0D1`0300L706<7001D1`0300L700<700<01`L0
7PL00`071`0<1`0300L701H700<01`L05@L00`071`1R1`00E0L00`071`031`0300L701h700<01`L0
3@L00`071`0E1`0300L701H700<01`L0H@L005@700<01`L010L00`071`0M1`0300L700d700<01`L0
5@L00`071`0F1`0300L70647001D1`0300L700D700<01`L070L00`071`0>1`0300L701@700<01`L0
5`L00`071`1P1`00E0L00`071`061`0300L701/700<01`L03`L00`071`0C1`0300L701P700<01`L0
G`L002d700<01`L090L00`071`061`0300L701/700<01`L040L00`071`0B1`0300L701P700<01`L0
G`L002d70P0U1`0300L700L700<01`L06PL00`071`0@1`0300L7018700<01`L06@L00`071`1N1`00
;@L202D700<01`L020L00`071`0I1`0300L7014700<01`L04@L00`071`0J1`0300L705d7000]1`03
00L002@700<01`L02@L00`071`0H1`0300L7018700<01`L040L00`071`0K1`0300L705`7000]1`04
00L702<700<01`L02@L00`071`0H1`0300L7018700<01`L040L00`071`0K1`0300L705`7000]1`05
00L71`008PL00`071`0:1`0300L701L700<01`L04`L00`071`0?1`0300L701`700<01`L0F`L002d7
00D01`L7000R1`0300L700/700<01`L05PL00`071`0D1`0300L700h700<01`L07@L00`071`1J1`00
;@L00`071`021`0300L701l700<01`L02`L00`071`0F1`0300L701D700<01`L03@L00`071`0M1`03
00L705X7000]1`0300L700<700<01`L07PL00`071`0<1`0300L701D700<01`L05@L00`071`0=1`03
00L701h700<01`L0F@L002d700<01`L00`L00`071`0N1`0300L700d700<01`L050L00`071`0F1`03
00L700`700<01`L07`L00`071`1H1`00;@L00`071`041`0300L701d700<01`L03PL00`071`0C1`03
00L701L700<01`L02`L00`071`0P1`0300L705L7000]1`0300L700D700<01`L070L00`071`0>1`03
00L701<700<01`L060L00`071`0:1`0300L7020700<01`L0E`L002d700<01`L01PL00`071`0K1`03
00L700l700<01`L04PL00`071`0H1`0300L700X700<01`L08@L00`071`1F1`001PL00`071`0T1`03
00L700H700<01`L06`L00`071`0@1`0300L7014700<01`L06@L00`071`091`0300L7028700<01`L0
E@L000H70P0U1`0300L700L700<01`L06PL00`071`0@1`0300L7014700<01`L06PL00`071`081`03
00L702<700<01`L0E0L000H70P0U1`0300L700P700<01`L06@L00`071`0A1`0300L7010700<01`L0
6`L00`071`071`0300L702<700<01`L0E0L000H700<01`0090L00`071`091`0300L701P700<01`L0
4PL00`071`0?1`0300L701/700<01`L01`L00`071`0T1`0300L705<700061`0400L702<700<01`L0
2@L00`071`0H1`0300L701<700<01`L03PL00`071`0L1`0300L700H700<01`L090L205@700061`05
00L71`008PL00`071`0:1`0300L701L700<01`L04`L00`071`0>1`0300L701d700<01`L01@L00`07
1`0T1`80E0L000H700D01`L7000R1`0300L700/700<01`L05PL00`071`0D1`0300L700d700<01`L0
7PL00`071`041`0300L702@700<01`00D`L000H700<01`L00PL00`071`0O1`0300L700/700<01`L0
5PL00`071`0E1`0300L700`700<01`L07PL00`071`041`0300L702@700@01`L0DPL000H700<01`L0
0`L00`071`0N1`0300L700`700<01`L05@L00`071`0F1`0300L700/700<01`L07`L00`071`031`03
00L702@700D01`L7001A1`001PL00`071`031`0300L701h700<01`L03@L00`071`0D1`0300L701H7
00<01`L02`L00`071`0P1`0300L7008700<01`L090L01@071`L0054700061`0300L700@700<01`L0
7@L00`071`0>1`0300L701<700<01`L05`L00`071`0:1`0300L7024700D01`L7000V1`0300L70087
00<01`L0CPL000H700<01`L01@L00`071`0L1`0300L700h700<01`L04`L00`071`0H1`0300L700T7
00<01`L08@L01@071`L002H700<01`L00`L00`071`1=1`001PL00`071`061`0300L701/700<01`L0
3`L00`071`0B1`0300L701P700<01`L02@L00`071`0R1`0400L702H700<01`L00`L00`071`1=1`00
1PL00`071`061`0300L701/700<01`L040L00`071`0A1`0300L701T700<01`L020L00`071`0S1`03
00L002H700<01`L010L00`071`1<1`001PL00`071`071`0300L701X700<01`L040L00`071`0A1`03
00L701X700<01`L01`L00`071`0T1`809PL00`071`051`0300L704/700061`0300L700P700<01`L0
6@L00`071`0A1`0300L7010700<01`L06`L00`071`061`0300L702@70P0V1`0300L700H700<01`L0
BPL000H700<01`L02@L00`071`0H1`0300L7018700<01`L03`L00`071`0K1`0300L700H700<01`L0
9@L00`071`0T1`0300L700H700<01`L0BPL000H700<01`L02@L00`071`0H1`0300L701<700<01`L0
3PL00`071`0L1`0300L700D700<01`L09@L202D700<01`L01`L00`071`191`001PL00`071`0:1`03
00L701L700<01`L04`L00`071`0>1`0300L701d700<01`L010L00`071`0U1`809@L00`071`081`03
00L704P700061`0300L700/700<01`L05PL00`071`0D1`0300L700d700<01`L07@L00`071`041`03
00L702D700<01`0090L00`071`091`0300L704L700061`0300L700/700<01`L05PL00`071`0E1`03
00L700`700<01`L07PL00`071`031`0300L702D700@01`L08`L00`071`091`0300L704L700061`03
00L700`700<01`L05@L00`071`0F1`0300L700/700<01`L07`L00`071`021`0300L702D700D01`L7
000R1`0300L700X700<01`L0APL000H700<01`L03@L00`071`0D1`0300L701H700<01`L02`L00`07
1`0P1`0500L71`009`L01@071`L0028700<01`L02`L00`071`151`001PL00`071`0>1`0300L701<7
00<01`L05`L00`071`0:1`0300L7020700D01`L7000W1`0300L7008700<01`L07`L00`071`0;1`03
00L704D700061`0300L700h700<01`L04`L00`071`0H1`0300L700T700<01`L08@L010071`0W1`03
00L700<700<01`L07PL00`071`0<1`0300L704@700061`0300L700l700<01`L04PL00`071`0H1`03
00L700T700<01`L08PL00`07000W1`0300L700@700<01`L07@L00`071`0=1`0300L704<700061`03
00L7010700<01`L04@L00`071`0I1`0300L700P700<01`L08`L202L700<01`L010L00`071`0M1`03
00L700h700<01`L0@PL000H700<01`L040L00`071`0A1`0300L701X700<01`L01`L00`071`0S1`80
9`L00`071`051`0300L701`700<01`L03PL00`071`121`001PL00`071`0A1`0300L7010700<01`L0
6`L00`071`061`0300L702@700<01`L09@L00`071`061`0300L701/700<01`L03`L00`071`111`00
1PL00`071`0B1`0300L700l700<01`L06`L00`071`061`0300L702@70P0V1`0300L700L700<01`L0
6PL00`071`0@1`0300L7040700061`0300L701<700<01`L03PL00`071`0L1`0300L700D700<01`L0
90L202H700<01`L01`L00`071`0J1`0300L7010700<01`L0@0L000H700<01`L04`L00`071`0>1`03
00L701d700<01`L010L00`071`0T1`0300L002D700<01`L020L00`071`0I1`0300L7014700<01`L0
?`L000H700<01`L050L00`071`0=1`0300L701d700<01`L010L00`071`0T1`0400L702@700<01`L0
2@L00`071`0H1`0300L7018700<01`L0?PL000H700<01`L05@L00`071`0<1`0300L701h700<01`L0
0`L00`071`0T1`0500L71`008`L00`071`0:1`0300L701L700<01`L04`L00`071`0m1`001PL00`07
1`0F1`0300L700/700<01`L07`L00`071`021`0300L702@700D01`L7000S1`0300L700X700<01`L0
5`L00`071`0C1`0300L703d700061`0300L701H700<01`L02`L00`071`0P1`0500L71`009PL00`07
1`021`0300L7020700<01`L02`L00`071`0F1`0300L701@700<01`L0?0L000H700<01`L05`L00`07
1`0:1`0300L7020700D01`L7000V1`0300L700<700<01`L07`L00`071`0<1`0300L701D700<01`L0
5@L00`071`0k1`001PL00`071`0H1`0300L700T700<01`L08@L010071`0V1`0300L700@700<01`L0
7PL00`071`0<1`0300L701D700<01`L05PL00`071`0j1`001PL00`071`0H1`0300L700T700<01`L0
8PL00`07000V1`0300L700@700<01`L07PL00`071`0=1`0300L701@700<01`L05PL00`071`0j1`00
1PL00`071`0I1`0300L700P700<01`L08`L202H700<01`L01@L00`071`0M1`0300L700h700<01`L0
4`L00`071`0G1`0300L703T700061`0300L701X700<01`L01`L00`071`0S1`809PL00`071`061`03
00L701`700<01`L03`L00`071`0B1`0300L701P700<01`L0>0L000H700<01`L06`L00`071`061`03
00L702@700<01`L090L00`071`071`0300L701/700<01`L03`L00`071`0B1`0300L701P700<01`L0
>0L000H700<01`L06`L00`071`061`0300L702@70P0U1`0300L700L700<01`L06`L00`071`0@1`03
00L7014700<01`L06@L00`071`0g1`001PL00`071`0L1`0300L700D700<01`L090L202D700<01`L0
20L00`071`0J1`0300L7014700<01`L040L00`071`0J1`0300L703H700061`0300L701d700<01`L0
10L00`071`0T1`0300L002@700<01`L02@L00`071`0I1`0300L7018700<01`L03`L00`071`0K1`03
00L703D700061`0300L701d700<01`L010L00`071`0T1`0400L702<700<01`L02PL00`071`0H1`03
00L7018700<01`L03`L00`071`0K1`0300L703D700061`0300L701h700<01`L00`L00`071`0T1`05
00L71`008PL00`071`0:1`0300L701P700<01`L04`L00`071`0>1`0300L701`700<01`L0=0L000H7
00<01`L07`L00`071`021`0300L702@700D01`L7000R1`0300L700/700<01`L05`L00`071`0D1`03
00L700d700<01`L07@L00`071`0c1`001PL00`071`0P1`0500L71`009PL00`071`021`0300L701l7
00<01`L030L00`071`0F1`0300L701D700<01`L030L00`071`0M1`0300L703<700061`0300L70207
00D01`L7000V1`0300L700<700<01`L07PL00`071`0=1`0300L701D700<01`L05@L00`071`0<1`03
00L701h700<01`L0<PL000H700<01`L08@L010071`0V1`0300L700<700<01`L07PL00`071`0=1`03
00L701D700<01`L05PL00`071`0;1`0300L701l700<01`L0<@L000H700<01`L08PL00`07000V1`03
00L700@700<01`L07@L00`071`0>1`0300L701@700<01`L05`L00`071`0:1`0300L7020700<01`L0
<0L000H700<01`L08`L202H700<01`L01@L00`071`0L1`0300L700l700<01`L04`L00`071`0G1`03
00L700X700<01`L080L00`071`0`1`001PL00`071`0S1`809PL00`071`061`0300L701/700<01`L0
40L00`071`0B1`0300L701P700<01`L02@L00`071`0Q1`0300L702l700061`0300L702@700<01`L0
90L00`071`061`0300L701/700<01`L040L00`071`0B1`0300L701T700<01`L020L00`071`0R1`03
00L702h700061`0300L702@70P0U1`0300L700L700<01`L06PL00`071`0A1`0300L7014700<01`L0
6PL00`071`071`0300L702<700<01`L0;@L000H700<01`L090L202D700<01`L020L00`071`0I1`03
00L7018700<01`L040L00`071`0J1`0300L700L700<01`L08`L00`071`0]1`001PL00`071`0T1`03
00L002@700<01`L02@L00`071`0H1`0300L7018700<01`L040L00`071`0K1`0300L700H700<01`L0
90L00`071`0/1`001PL00`071`0T1`0400L702<700<01`L02@L00`071`0H1`0300L701<700<01`L0
3`L00`071`0L1`0300L700D700<01`L090L202d700061`0300L702@700D01`L7000R1`0300L700X7
00<01`L05`L00`071`0D1`0300L700h700<01`L07@L00`071`041`0300L702@70P0]1`001PL00`07
1`0T1`0500L71`008PL00`071`0;1`0300L701H700<01`L05@L00`071`0=1`0300L701d700<01`L0
10L00`071`0T1`0300L002`700061`0300L702@700<01`L00PL00`071`0O1`0300L700/700<01`L0
5PL00`071`0E1`0300L700d700<01`L07PL00`071`031`0300L702@700@01`L0:`L000H700<01`L0
90L00`071`031`0300L701h700<01`L030L00`071`0E1`0300L701H700<01`L030L00`071`0O1`03
00L7008700<01`L090L01@071`L002X700061`0300L702@700<01`L010L00`071`0M1`0300L700d7
00<01`L050L00`071`0G1`0300L700/700<01`L080L01@071`L002H700D01`L7000Z1`001PL00`07
1`0T1`0300L700@700<01`L07@L00`071`0>1`0300L701<700<01`L060L00`071`0:1`0300L70207
00D01`L7000V1`0300L7008700<01`L09`L000H700<01`L090L00`071`051`0300L701`700<01`L0
3PL00`071`0C1`0300L701P700<01`L02PL00`071`0Q1`0400L702H700<01`L00`L00`071`0V1`00
1PL00`071`0T1`0300L700H700<01`L06`L00`071`0?1`0300L7018700<01`L06@L00`071`091`03
00L7028700<01`009PL00`071`041`0300L702D700061`809@L00`071`071`0300L701X700<01`L0
40L00`071`0A1`0300L701X700<01`L020L00`071`0S1`809PL00`071`041`0300L702D700061`80
9@L00`071`071`0300L701X700<01`L040L00`071`0A1`0300L701/700<01`L01`L00`071`0S1`80
9PL00`071`051`0300L702@700061`0300L002@700<01`L020L00`071`0I1`0300L7014700<01`L0
40L00`071`0K1`0300L700L700<01`L090L00`071`0T1`0300L700H700<01`L08`L000H700@01`L0
8`L00`071`091`0300L701P700<01`L04PL00`071`0?1`0300L701`700<01`L01PL00`071`0T1`80
9@L00`071`071`0300L7028700061`0500L71`008PL00`071`0:1`0300L701L700<01`L04`L00`07
1`0>1`0300L701d700<01`L01@L00`071`0T1`809@L00`071`071`0300L7028700061`0500L71`00
8PL00`071`0:1`0300L701L700<01`L04`L00`071`0>1`0300L701h700<01`L010L00`071`0T1`03
00L002@700<01`L020L00`071`0Q1`001PL00`071`021`0300L701l700<01`L02`L00`071`0F1`03
00L701@700<01`L03@L00`071`0N1`0300L700@700<01`L090L010071`0S1`0300L700T700<01`L0
80L000H700<01`L00`L00`071`0N1`0300L700`700<01`L05@L00`071`0E1`0300L700`700<01`L0
7`L00`071`031`0300L702@700D01`L7000R1`0300L700X700<01`L07`L000H700<01`L00`L00`07
1`0N1`0300L700`700<01`L05@L00`071`0F1`0300L700/700<01`L080L00`071`021`0300L702@7
00D01`L7000R1`0300L700X700<01`L07`L000H700<01`L010L00`071`0M1`0300L700d700<01`L0
50L00`071`0F1`0300L700/700<01`L08@L01@071`L002H700<01`L00PL00`071`0O1`0300L700/7
00<01`L07PL000H700<01`L01@L00`071`0L1`0300L700h700<01`L04`L00`071`0G1`0300L700X7
00<01`L08@L01@071`L002H700<01`L00`L00`071`0N1`0300L700`700<01`L07@L000H700<01`L0
1PL00`071`0K1`0300L700l700<01`L04PL00`071`0H1`0300L700T700<01`L08PL010071`0V1`03
00L700<700<01`L07PL00`071`0<1`0300L701d700061`0300L700H700<01`L06`L00`071`0?1`03
00L7018700<01`L060L00`071`091`0300L702<700<01`009PL00`071`041`0300L701d700<01`L0
3@L00`071`0L1`001PL00`071`071`0300L701X700<01`L040L00`071`0A1`0300L701T700<01`L0
20L00`071`0T1`809PL00`071`051`0300L701`700<01`L03PL00`071`0K1`001PL00`071`081`03
00L701T700<01`L04@L00`071`0@1`0300L701X700<01`L01`L00`071`0T1`809PL00`071`061`03
00L701/700<01`L03`L00`071`0J1`001PL00`071`091`0300L701P700<01`L04PL00`071`0?1`03
00L701/700<01`L01PL00`071`0U1`0300L702@700<01`L01PL00`071`0K1`0300L700l700<01`L0
6PL000H700<01`L02@L00`071`0H1`0300L7018700<01`L03`L00`071`0K1`0300L700H700<01`L0
9@L202D700<01`L01`L00`071`0J1`0300L7010700<01`L06@L000H700<01`L02PL00`071`0G1`03
00L701<700<01`L03PL00`071`0L1`0300L700D700<01`L09@L202D700<01`L020L00`071`0I1`03
00L7014700<01`L060L000H700<01`L02`L00`071`0F1`0300L701@700<01`L03@L00`071`0M1`03
00L700@700<01`L09@L00`07000T1`0300L700T700<01`L060L00`071`0B1`0300L701L700061`03
00L700/700<01`L05PL00`071`0E1`0300L700`700<01`L07@L00`071`041`0300L702D700@01`L0
8`L00`071`091`0300L701P700<01`L04PL00`071`0G1`001PL00`071`0<1`0300L701D700<01`L0
5@L00`071`0<1`0300L701h700<01`L00`L00`071`0U1`0500L71`008PL00`071`0:1`0300L701L7
00<01`L04`L00`071`0F1`001PL00`071`0=1`0300L701@700<01`L05PL00`071`0;1`0300L701l7
00<01`L00PL00`071`0U1`0500L71`008PL00`071`0;1`0300L701H700<01`L050L00`071`0E1`00
1PL00`071`0>1`0300L701<700<01`L05`L00`071`0:1`0300L7020700D01`L7000W1`0300L70087
00<01`L07`L00`071`0;1`0300L701H700<01`L05@L00`071`0D1`001PL00`071`0>1`0300L701<7
00<01`L05`L00`071`0:1`0300L7020700D01`L7000W1`0300L700<700<01`L07PL00`071`0<1`03
00L701D700<01`L05@L00`071`0D1`001PL00`071`0?1`0300L7018700<01`L060L00`071`091`03
00L7024700@01`L09`L00`071`031`0300L701h700<01`L03@L00`071`0D1`0300L701H700<01`L0
4`L000H700<01`L040L00`071`0A1`0300L701T700<01`L020L00`071`0R1`0300L002L700<01`L0
10L00`071`0M1`0300L700h700<01`L04`L00`071`0G1`0300L7018700061`0300L7010700<01`L0
4@L00`071`0J1`0300L700L700<01`L08`L202L700<01`L01@L00`071`0L1`0300L700h700<01`L0
4`L00`071`0G1`0300L7018700061`0300L7014700<01`L040L00`071`0J1`0300L700L700<01`L0
8`L202L700<01`L01PL00`071`0K1`0300L700l700<01`L04PL00`071`0H1`0300L7014700061`03
00L7018700<01`L03`L00`071`0K1`0300L700H700<01`L090L00`071`0U1`0300L700H700<01`L0
6`L00`071`0@1`0300L7014700<01`L06@L00`071`0@1`001PL00`071`0C1`0300L700h700<01`L0
70L00`071`051`0300L702@70P0V1`0300L700L700<01`L06PL00`071`0@1`0300L7014700<01`L0
6PL00`071`0?1`001PL00`071`0C1`0300L700h700<01`L07@L00`071`041`0300L702@700<01`00
9@L00`071`081`0300L701T700<01`L04@L00`071`0@1`0300L701X700<01`L03`L000H700<01`L0
50L00`071`0=1`0300L701d700<01`L010L00`071`0T1`0300L002D700<01`L02@L00`071`0H1`03
00L7018700<01`L03`L00`071`0K1`0300L700h700061`0300L701D700<01`L030L00`071`0N1`03
00L700<700<01`L090L010071`0T1`0300L700T700<01`L060L00`071`0C1`0300L700h700<01`L0
70L00`071`0=1`001PL00`071`0F1`0300L700/700<01`L07`L00`071`021`0300L702@700D01`L7
000S1`0300L700X700<01`L05`L00`071`0C1`0300L700h700<01`L07@L00`071`0<1`001PL00`07
1`0F1`0300L700/700<01`L080L01@071`L002H700<01`L00PL00`071`0P1`0300L700/700<01`L0
5PL00`071`0D1`0300L700d700<01`L07@L00`071`0<1`001PL00`071`0G1`0300L700X700<01`L0
80L01@071`L002H700<01`L00PL00`071`0P1`0300L700/700<01`L05PL00`071`0E1`0300L700`7
00<01`L07PL00`071`0;1`001PL00`071`0H1`0300L700T700<01`L08@L010071`0V1`0300L700<7
00<01`L07`L00`071`0<1`0300L701D700<01`L05PL00`071`0;1`0300L701l700<01`L02PL000H7
00<01`L060L00`071`091`0300L7028700<01`009PL00`071`041`0300L701h700<01`L03@L00`07
1`0D1`0300L701H700<01`L02`L00`071`0P1`0300L700T700061`0300L701T700<01`L020L00`07
1`0S1`809PL00`071`051`0300L701d700<01`L03PL00`071`0C1`0300L701L700<01`L02PL00`07
1`0P1`0300L700T700061`0300L701X700<01`L01`L00`071`0S1`809PL00`071`051`0300L701d7
00<01`L03PL00`071`0C1`0300L701P700<01`L02@L00`071`0Q1`0300L700P700061`0300L701/7
00<01`L01PL00`071`0T1`0300L702@700<01`L01PL00`071`0L1`0300L700l700<01`L04PL00`07
1`0H1`0300L700T700<01`L08PL00`071`071`001PL00`071`0K1`0300L700H700<01`L090L202D7
00<01`L01`L00`071`0K1`0300L7010700<01`L04@L00`071`0I1`0300L700P700<01`L08`L00`07
1`061`001PL00`071`0L1`0300L700D700<01`L090L202D700<01`L020L00`071`0J1`0300L70107
00<01`L04@L00`071`0J1`0300L700L700<01`L08`L00`071`061`001PL00`071`0M1`0300L700@7
00<01`L090L00`07000T1`0300L700P700<01`L06PL00`071`0A1`0300L7010700<01`L06`L00`07
1`061`0300L702@700<01`L01@L000H700<01`L07@L00`071`041`0300L702@700@01`L08`L00`07
1`091`0300L701T700<01`L04PL00`071`0?1`0300L701/700<01`L01PL00`071`0/1`001PL00`07
1`0N1`0300L700<700<01`L090L01@071`L0028700<01`L02PL00`071`0H1`0300L701<700<01`L0
3PL00`071`0L1`0300L700D700<01`L0;0L000H700<01`L07`L00`071`021`0300L702@700D01`L7
000R1`0300L700/700<01`L05`L00`071`0C1`0300L700h700<01`L07@L00`071`041`0300L702`7
00061`0300L7020700D01`L7000V1`0300L7008700<01`L07`L00`071`0;1`0300L701L700<01`L0
50L00`071`0=1`0300L701d700<01`L010L00`071`0/1`001PL00`071`0P1`0500L71`009PL00`07
1`031`0300L701h700<01`L030L00`071`0F1`0300L701D700<01`L030L00`071`0N1`0300L700<7
00<01`L0;0L000H700<01`L08@L010071`0V1`0300L700<700<01`L07PL00`071`0=1`0300L701D7
00<01`L05PL00`071`0;1`0300L701l700<01`L00PL00`071`0/1`001PL00`071`0R1`0300L002H7
00<01`L010L00`071`0M1`0300L700h700<01`L050L00`071`0F1`0300L700/700<01`L080L01@07
1`L002h700061`0300L702<70P0V1`0300L700D700<01`L070L00`071`0>1`0300L701@700<01`L0
5`L00`071`0:1`0300L7020700D01`L7000^1`001PL00`071`0S1`809PL00`071`061`0300L701/7
00<01`L03`L00`071`0C1`0300L701P700<01`L02@L00`071`0Q1`0400L702h700061`0300L702@7
00<01`L090L00`071`061`0300L701/700<01`L040L00`071`0B1`0300L701P700<01`L02@L00`07
1`0R1`0300L002h700061`0300L702@70P0U1`0300L700L700<01`L06PL00`071`0A1`0300L70147
00<01`L06@L00`071`081`0300L702<70P0^1`001PL00`071`0T1`809@L00`071`081`0300L701T7
00<01`L04@L00`071`0A1`0300L701X700<01`L01`L00`071`0S1`80;PL000H700<01`L090L00`07
000T1`0300L700T700<01`L060L00`071`0B1`0300L7010700<01`L06`L00`071`061`0300L702@7
00<01`L0;0L000H700<01`L090L010071`0S1`0300L700T700<01`L060L00`071`0C1`0300L700l7
00<01`L06`L00`071`061`0300L702@700<01`L0;0L000H700<01`L090L01@071`L0028700<01`L0
2PL00`071`0G1`0300L701@700<01`L03PL00`071`0L1`0300L700D700<01`L090L00`071`0/1`00
1PL00`071`0T1`0500L71`008PL00`071`0;1`0300L701H700<01`L050L00`071`0>1`0300L701d7
00<01`L010L00`071`0T1`0300L702`700061`0300L702@700<01`L00PL00`071`0O1`0300L700/7
00<01`L05PL00`071`0E1`0300L700d700<01`L07@L00`071`041`0300L702@700<01`L0;0L000H7
00<01`L090L00`071`031`0300L701h700<01`L030L00`071`0E1`0300L701H700<01`L030L00`07
1`0N1`0300L700<700<01`L090L00`071`0/1`001PL00`071`0T1`0300L700<700<01`L07PL00`07
1`0=1`0300L701@700<01`L05`L00`071`0;1`0300L701l700<01`L00PL00`071`0T1`0300L702`7
00061`0300L702@700<01`L010L00`071`0M1`0300L700h700<01`L04`L00`071`0G1`0300L700/7
00<01`L080L01@071`L002H700<01`L0;0L000H700<01`L090L00`071`051`0300L701`700<01`L0
3PL00`071`0C1`0300L701P700<01`L02PL00`071`0P1`0500L71`009PL00`071`0/1`001PL00`07
1`0T1`0300L700H700<01`L06`L00`071`0?1`0300L7018700<01`L06@L00`071`091`0300L70247
00@01`L09PL00`071`0/1`001PL00`071`0T1`0300L700H700<01`L06`L00`071`0@1`0300L70147
00<01`L06PL00`071`081`0300L7028700<01`009PL00`071`0/1`001PL202D700<01`L01`L00`07
1`0J1`0300L7010700<01`L04@L00`071`0J1`0300L700P700<01`L08`L202H700<01`L0;0L000H7
0P0U1`0300L700P700<01`L06@L00`071`0A1`0300L7010700<01`L06`L00`071`071`0300L702<7
0P0V1`0300L702`700061`0300L002@700<01`L02@L00`071`0H1`0300L7018700<01`L03`L00`07
1`0L1`0300L700H700<01`L090L00`071`0T1`0300L702`700061`0400L702<700<01`L02@L00`07
1`0H1`0300L701<700<01`L03PL00`071`0M1`0300L700D700<01`L090L202D700<01`L0;0L000H7
00D01`L7000R1`0300L700X700<01`L05`L00`071`0C1`0300L700h700<01`L07@L00`071`051`03
00L702@70P0U1`0300L702`700061`0500L71`008PL00`071`0;1`0300L701H700<01`L050L00`07
1`0=1`0300L701h700<01`L010L00`071`0T1`0300L002@700<01`L0;0L000H700<01`L00PL00`07
1`0O1`0300L700/700<01`L05PL00`071`0E1`0300L700`700<01`L07`L00`071`031`0300L702@7
00@01`L08`L00`071`0/1`001PL00`071`031`0300L701h700<01`L030L00`071`0E1`0300L701H7
00<01`L02`L00`071`0P1`0300L7008700<01`L090L01@071`L0028700<01`L0;0L000H700<01`L0
10L00`071`0M1`0300L700d700<01`L050L00`071`0F1`0300L700/700<01`L080L00`071`021`03
00L702@700D01`L7000R1`0300L702`700061`0300L700@700<01`L07@L00`071`0>1`0300L701<7
00<01`L05`L00`071`0:1`0300L7024700D01`L7000V1`0300L7008700<01`L07`L00`071`0/1`00
1PL00`071`051`0300L701`700<01`L03PL00`071`0C1`0300L701P700<01`L02@L00`071`0R1`04
00L702H700<01`L00`L00`071`0N1`0300L702`700061`0300L700H700<01`L06`L00`071`0?1`03
00L7018700<01`L060L00`071`091`0300L702<700<01`009PL00`071`041`0300L701d700<01`L0
;0L000H700<01`L01`L00`071`0J1`0300L7010700<01`L04@L00`071`0I1`0300L700P700<01`L0
8`L00`07000V1`0300L700@700<01`L07@L00`071`0/1`001PL00`071`071`0300L701X700<01`L0
40L00`071`0A1`0300L701X700<01`L01`L00`071`0T1`809PL00`071`051`0300L701`700<01`L0
;0L000H700<01`L020L00`071`0I1`0300L7014700<01`L040L00`071`0K1`0300L700H700<01`L0
9@L00`071`0T1`0300L700H700<01`L06`L00`071`0/1`001PL00`071`091`0300L701P700<01`L0
4PL00`071`0?1`0300L701/700<01`L01PL00`071`0U1`809@L00`071`071`0300L701X700<01`L0
;0L000H700<01`L02PL00`071`0G1`0300L701<700<01`L03PL00`071`0L1`0300L700D700<01`L0
9@L202D700<01`L01`L00`071`0J1`0300L702`700061`0300L700X700<01`L05`L00`071`0C1`03
00L700h700<01`L07@L00`071`041`0300L702D700<01`0090L00`071`081`0300L701T700<01`L0
;0L000H700<01`L02`L00`071`0F1`0300L701@700<01`L03@L00`071`0M1`0300L700@700<01`L0
9@L010071`0S1`0300L700T700<01`L060L00`071`0/1`001PL00`071`0<1`0300L701D700<01`L0
5@L00`071`0<1`0300L701h700<01`L00`L00`071`0U1`0500L71`008PL00`071`0:1`0300L701L7
00<01`L0;0L000H700<01`L030L00`071`0E1`0300L701H700<01`L02`L00`071`0O1`0300L70087
00<01`L09@L01@071`L0028700<01`L02PL00`071`0G1`0300L702`700061`0300L700d700<01`L0
50L00`071`0F1`0300L700/700<01`L080L01@071`L002L700<01`L00PL00`071`0O1`0300L700/7
00<01`L05PL00`071`0/1`001PL00`071`0>1`0300L701<700<01`L05`L00`071`0:1`0300L70207
00D01`L7000W1`0300L700<700<01`L07PL00`071`0<1`0300L701D700<01`L0;0L000H700<01`L0
3`L00`071`0B1`0300L701P700<01`L02@L00`071`0Q1`0400L702L700<01`L00`L00`071`0N1`03
00L700`700<01`L05@L00`071`0/1`001PL00`071`0?1`0300L7018700<01`L060L00`071`091`03
00L7028700<01`009`L00`071`041`0300L701d700<01`L03@L00`071`0D1`0300L702`700061`03
00L7010700<01`L04@L00`071`0I1`0300L700P700<01`L08`L202L700<01`L01@L00`071`0L1`03
00L700h700<01`L04`L00`071`0/1`001PL00`071`0A1`0300L7010700<01`L06PL00`071`071`03
00L702<70P0W1`0300L700H700<01`L06`L00`071`0?1`0300L7018700<01`L0;0L000H700<01`L0
4PL00`071`0?1`0300L701/700<01`L01PL00`071`0T1`0300L702D700<01`L01PL00`071`0K1`03
00L700l700<01`L04PL00`071`0/1`001PL00`071`0B1`0300L700l700<01`L06`L00`071`061`03
00L702@70P0V1`0300L700L700<01`L06PL00`071`0@1`0300L7014700<01`L0;0L000H700<01`L0
4`L00`071`0>1`0300L701`700<01`L01@L00`071`0T1`809PL00`071`081`0300L701T700<01`L0
4@L00`071`0@1`0300L702`700061`0300L701@700<01`L03@L00`071`0M1`0300L700@700<01`L0
90L00`07000U1`0300L700T700<01`L060L00`071`0B1`0300L700l700<01`L0;0L000H700<01`L0
5@L00`071`0<1`0300L701d700<01`L010L00`071`0T1`0400L702@700<01`L02@L00`071`0H1`03
00L7018700<01`L03`L00`071`0/1`001PL00`071`0E1`0300L700`700<01`L07PL00`071`031`03
00L702@700D01`L7000S1`0300L700X700<01`L05`L00`071`0C1`0300L700h700<01`L0;0L000H7
00<01`L05PL00`071`0;1`0300L701l700<01`L00PL00`071`0T1`0500L71`008`L00`071`0;1`03
00L701H700<01`L050L00`071`0=1`0300L702`700061`0300L701L700<01`L02PL00`071`0P1`05
00L71`009PL00`071`021`0300L7020700<01`L02`L00`071`0F1`0300L701D700<01`L030L00`07
1`0/1`001PL00`071`0G1`0300L700X700<01`L080L01@071`L002H700<01`L00`L00`071`0O1`03
00L700`700<01`L05@L00`071`0E1`0300L700`700<01`L0;0L000H700<01`L060L00`071`091`03
00L7024700@01`L09PL00`071`041`0300L701h700<01`L03@L00`071`0D1`0300L701H700<01`L0
2`L00`071`0/1`001PL00`071`0I1`0300L700P700<01`L08PL00`07000V1`0300L700@700<01`L0
7PL00`071`0>1`0300L701<700<01`L05`L00`071`0:1`0300L702`700061`0300L701X700<01`L0
1`L00`071`0S1`809PL00`071`051`0300L701d700<01`L03PL00`071`0C1`0300L701L700<01`L0
2PL00`071`0/1`001PL00`071`0J1`0300L700L700<01`L08`L202H700<01`L01PL00`071`0L1`03
00L700l700<01`L04PL00`071`0H1`0300L700T700<01`L0;0L000H700<01`L06`L00`071`061`03
00L702@700<01`L090L00`071`071`0300L701/700<01`L040L00`071`0A1`0300L701T700<01`L0
20L00`071`0/1`001PL00`071`0L1`0300L700D700<01`L090L202D700<01`L01`L00`071`0K1`03
00L7010700<01`L04@L00`071`0J1`0300L700L700<01`L0;0L000H700<01`L07@L00`071`041`03
00L702@70P0U1`0300L700P700<01`L06PL00`071`0A1`0300L7010700<01`L06PL00`071`071`03
00L702`700061`0300L701d700<01`L010L00`071`0T1`0300L002@700<01`L02@L00`071`0I1`03
00L7018700<01`L03`L00`071`0K1`0300L700H700<01`L0;0L000H700<01`L07PL00`071`031`03
00L702@700@01`L08`L00`071`0:1`0300L701P700<01`L04`L00`071`0>1`0300L701`700<01`L0
1@L00`071`0/1`001PL00`071`0O1`0300L7008700<01`L090L01@071`L0028700<01`L02PL00`07
1`0H1`0300L701<700<01`L03PL00`071`0M1`0300L700@700<01`L0;0L000H700<01`L080L01@07
1`L002H700D01`L7000R1`0300L700/700<01`L05`L00`071`0D1`0300L700d700<01`L07@L00`07
1`041`0300L702`700061`0300L7020700D01`L7000V1`0300L7008700<01`L07`L00`071`0<1`03
00L701H700<01`L05@L00`071`0<1`0300L701h700<01`L00`L00`071`0/1`001PL00`071`0Q1`04
00L702H700<01`L00`L00`071`0N1`0300L700d700<01`L05@L00`071`0F1`0300L700/700<01`L0
7`L00`071`021`0300L702`700061`0300L7028700<01`009PL00`071`031`0300L701h700<01`L0
3@L00`071`0E1`0300L701H700<01`L02`L00`071`0P1`0500L71`00;PL000H700<01`L08`L202H7
00<01`L010L00`071`0M1`0300L700h700<01`L050L00`071`0G1`0300L700X700<01`L080L01@07
1`L002h700061`0300L702<70P0V1`0300L700D700<01`L070L00`071`0?1`0300L701<700<01`L0
60L00`071`091`0300L7024700@01`L0;PL000H700<01`L090L00`071`0T1`0300L700H700<01`L0
6`L00`071`0@1`0300L7018700<01`L060L00`071`091`0300L7028700<01`00;PL000H700<01`L0
9@L00`071`0S1`0300L700H700<01`L06`L00`071`0@1`0300L7018700<01`L06@L00`071`081`03
00L702<70P0^1`001PL00`071`0U1`0300L702<700<01`L01`L00`071`0J1`0300L7014700<01`L0
4@L00`071`0J1`0300L700L700<01`L08`L202h700061`0300L702H700<01`L08PL00`071`081`03
00L701T700<01`L04PL00`071`0@1`0300L701/700<01`L01PL00`071`0T1`0300L702`700061`03
00L702L700<01`L08@L00`071`091`0300L701P700<01`L04PL00`071`0@1`0300L701/700<01`L0
1PL00`071`1C1`001PL00`071`0X1`0300L7020700<01`L02@L00`071`0H1`0300L701<700<01`L0
3`L00`071`0L1`0300L700D700<01`L0D`L000H700<01`L0:0L00`071`0P1`0300L700X700<01`L0
5`L00`071`0D1`0300L700h700<01`L07@L00`071`041`0300L705<700061`0300L702T700<01`L0
7`L00`071`0;1`0300L701H700<01`L05@L00`071`0=1`0300L701d700<01`L010L00`071`1C1`00
1PL00`071`0Z1`0300L701h700<01`L02`L00`071`0F1`0300L701D700<01`L03@L00`071`0N1`03
00L700<700<01`L0D`L000H700<01`L0:PL00`071`0N1`0300L700`700<01`L05@L00`071`0F1`03
00L700`700<01`L07`L00`071`021`0300L705<700061`0300L702/700<01`L07@L00`071`0=1`03
00L701@700<01`L05`L00`071`0;1`0300L7020700D01`L7001E1`001PL00`071`0/1`0300L701`7
00<01`L03PL00`071`0C1`0300L701P700<01`L02PL00`071`0P1`0500L71`00E@L000H700<01`L0
;@L00`071`0K1`0300L700h700<01`L04`L00`071`0H1`0300L700X700<01`L08@L010071`1E1`00
1PL00`071`0]1`0300L701/700<01`L03`L00`071`0B1`0300L701T700<01`L02@L00`071`0R1`03
00L005D7000g1`0300L701X700<01`L040L00`071`0A1`0300L701X700<01`L020L00`071`0S1`80
E@L003P700<01`L06@L00`071`0@1`0300L7014700<01`L06`L00`071`071`0300L702<70P1E1`00
>@L00`071`0H1`0300L7014700<01`L040L00`071`0K1`0300L700L700<01`L090L00`071`1C1`00
>@L00`071`0H1`0300L7018700<01`L03`L00`071`0L1`0300L700H700<01`L0NPL003X700<01`L0
5`L00`071`0C1`0300L700h700<01`L07@L00`071`051`0300L707X7000k1`0300L701H700<01`L0
4`L00`071`0>1`0300L701h700<01`L010L00`071`1j1`00>`L00`071`0F1`0300L701@700<01`L0
3@L00`071`0N1`0300L700@700<01`L0NPL003`700<01`L05@L00`071`0E1`0300L700`700<01`L0
7`L00`071`031`0300L707X7000m1`0300L701@700<01`L05PL00`071`0;1`0300L7020700<01`L0
0PL00`071`1j1`00?PL00`071`0C1`0300L701H700<01`L02`L00`071`0Q1`0500L71`00O0L003h7
00<01`L04`L00`071`0G1`0300L700X700<01`L08@L01@071`L007`7000o1`0300L7018700<01`L0
60L00`071`091`0300L7028700@01`L0O0L0040700<01`L04@L00`071`0H1`0300L700T700<01`L0
8`L00`07001l1`00@0L00`071`0A1`0300L701T700<01`L020L00`071`0T1`80O0L0044700<01`L0
40L00`071`0J1`0300L700L700<01`L090L207`700121`0300L700l700<01`L06`L00`071`061`03
00L702D700<01`L0NPL004<700<01`L03PL00`071`0K1`0300L700H700<01`L0XPL004<700<01`L0
3PL00`071`0L1`0300L700D700<01`L0XPL004@700<01`L03@L00`071`0M1`0300L700@700<01`L0
XPL004D700<01`L030L00`071`0M1`0300L700@700<01`L0XPL004H700<01`L02`L00`071`0N1`03
00L700<700<01`L0XPL004H700<01`L02`L00`071`0O1`0300L7008700<01`L0XPL004L700<01`L0
2PL00`071`0P1`0500L71`00Y0L004P700<01`L02@L00`071`0P1`0500L71`00Y0L004P700<01`L0
2@L00`071`0Q1`0400L70:@700191`0300L700P700<01`L08PL00`07002T1`00BPL00`071`071`03
00L702<70P2T1`00B`L00`071`061`0300L702<70P2T1`00B`L00`071`061`0300L702@700<01`L0
XPL004`700<01`L01@L00`071`391`00C@L00`071`041`0300L70<T7001=1`0300L700@700<01`L0
b@L004h700<01`L00`L00`071`391`00C`L00`071`021`0300L70<T7001@1`0500L71`00b`L00507
00D01`L7003;1`00D@L010071`3;1`00DPL00`07003;1`00D`L20</7001C1`80b`L005@700<01`L0
b@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {305.688, 0}} -> {-8.03268, -10.0811, \
0.064025, 0.064025}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[143]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice31\  = 
      tiling2D[SphericalCut[N[Join[AL031, \ AL131, \ AL231, \ AL331]], 10], \ 
        rad31]\)], "Input",
  CellLabel->"In[144]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97054 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499981 0.0480782 0.485338 0.0480782 [
[ 0 0 0 0 ]
[ 1 .97054 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .97054 L
0 .97054 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.6156 .02311 m
.7358 .18854 L
s
.6156 .02311 m
.6156 .2276 L
s
.6156 .02311 m
.42329 .10122 L
s
.7358 .18854 m
.856 .35398 L
s
.7358 .18854 m
.7358 .39303 L
s
.7358 .18854 m
.54349 .26665 L
s
.856 .35398 m
.97619 .51941 L
s
.856 .35398 m
.856 .55847 L
s
.856 .35398 m
.66368 .43209 L
s
.97619 .51941 m
.78388 .59752 L
s
.49541 .06216 m
.6156 .2276 L
s
.49541 .06216 m
.49541 .26665 L
s
.49541 .06216 m
.3031 .14027 L
s
.6156 .2276 m
.7358 .39303 L
s
.6156 .2276 m
.6156 .43209 L
s
.6156 .2276 m
.8171 .17775 L
s
.6156 .2276 m
.42329 .3057 L
s
.7358 .39303 m
.856 .55847 L
s
.7358 .39303 m
.7358 .59752 L
s
.7358 .39303 m
.93729 .34318 L
s
.7358 .39303 m
.54349 .47114 L
s
.856 .55847 m
.856 .76295 L
s
.856 .55847 m
.66368 .63657 L
s
.37521 .10122 m
.49541 .26665 L
s
.37521 .10122 m
.37521 .3057 L
s
.37521 .10122 m
.57671 .05137 L
s
.37521 .10122 m
.1829 .17932 L
s
.49541 .26665 m
.6156 .43209 L
s
.49541 .26665 m
.49541 .47114 L
s
.49541 .26665 m
.6969 .2168 L
s
.49541 .26665 m
.3031 .34476 L
s
.6156 .43209 m
.7358 .59752 L
s
.6156 .43209 m
.6156 .63657 L
s
.6156 .43209 m
.8171 .38224 L
s
.6156 .43209 m
.42329 .51019 L
s
.7358 .59752 m
.856 .76295 L
s
.7358 .59752 m
.7358 .80201 L
s
.7358 .59752 m
.93729 .54767 L
s
.7358 .59752 m
.54349 .67563 L
s
.856 .76295 m
.66368 .84106 L
s
.25502 .14027 m
.37521 .3057 L
s
.25502 .14027 m
.25502 .34476 L
s
.25502 .14027 m
.45651 .09042 L
s
.37521 .3057 m
.49541 .47114 L
s
.37521 .3057 m
.37521 .51019 L
s
.37521 .3057 m
.57671 .25586 L
s
.37521 .3057 m
.1829 .38381 L
s
.49541 .47114 m
.6156 .63657 L
s
.49541 .47114 m
.49541 .67563 L
s
.49541 .47114 m
.6969 .42129 L
s
.49541 .47114 m
.3031 .54925 L
s
.6156 .63657 m
.7358 .80201 L
s
.6156 .63657 m
.6156 .84106 L
s
.6156 .63657 m
.8171 .58673 L
s
.6156 .63657 m
.42329 .71468 L
s
.7358 .80201 m
.54349 .88012 L
s
.13482 .17932 m
.25502 .34476 L
s
.13482 .17932 m
.13482 .38381 L
s
.13482 .17932 m
.33632 .12948 L
s
.25502 .34476 m
.37521 .51019 L
s
.25502 .34476 m
.25502 .54925 L
s
.25502 .34476 m
.45651 .29491 L
s
.25502 .34476 m
.06271 .42287 L
s
.37521 .51019 m
.49541 .67563 L
s
.37521 .51019 m
.37521 .71468 L
s
.37521 .51019 m
.57671 .46034 L
s
.37521 .51019 m
.1829 .5883 L
s
.49541 .67563 m
.6156 .84106 L
s
.49541 .67563 m
.49541 .88012 L
s
.49541 .67563 m
.6969 .62578 L
s
.49541 .67563 m
.3031 .75374 L
s
.6156 .84106 m
.8171 .79121 L
s
.6156 .84106 m
.42329 .91917 L
s
.13482 .38381 m
.25502 .54925 L
s
.13482 .38381 m
.13482 .5883 L
s
.13482 .38381 m
.33632 .33396 L
s
.25502 .54925 m
.37521 .71468 L
s
.25502 .54925 m
.25502 .75374 L
s
.25502 .54925 m
.45651 .4994 L
s
.25502 .54925 m
.06271 .62735 L
s
.37521 .71468 m
.49541 .88012 L
s
.37521 .71468 m
.37521 .91917 L
s
.37521 .71468 m
.57671 .66483 L
s
.37521 .71468 m
.1829 .79279 L
s
.49541 .88012 m
.6969 .83027 L
s
.13482 .5883 m
.25502 .75374 L
s
.13482 .5883 m
.13482 .79279 L
s
.13482 .5883 m
.33632 .53845 L
s
.25502 .75374 m
.37521 .91917 L
s
.25502 .75374 m
.45651 .70389 L
s
.37521 .91917 m
.57671 .86932 L
s
.13482 .79279 m
.33632 .74294 L
s
.8171 .17775 m
.93729 .34318 L
s
.8171 .17775 m
.8171 .38224 L
s
.8171 .17775 m
.62479 .25586 L
s
.93729 .34318 m
.93729 .54767 L
s
.93729 .34318 m
.74498 .42129 L
s
.57671 .05137 m
.6969 .2168 L
s
.57671 .05137 m
.57671 .25586 L
s
.57671 .05137 m
.3844 .12948 L
s
.6969 .2168 m
.8171 .38224 L
s
.6969 .2168 m
.6969 .42129 L
s
.6969 .2168 m
.50459 .29491 L
s
.8171 .38224 m
.93729 .54767 L
s
.8171 .38224 m
.8171 .58673 L
s
.8171 .38224 m
.62479 .46034 L
s
.93729 .54767 m
.74498 .62578 L
s
.45651 .09042 m
.57671 .25586 L
s
.45651 .09042 m
.45651 .29491 L
s
.45651 .09042 m
.2642 .16853 L
s
.57671 .25586 m
.6969 .42129 L
s
.57671 .25586 m
.57671 .46034 L
s
.57671 .25586 m
.3844 .33396 L
s
.6969 .42129 m
.8171 .58673 L
s
.6969 .42129 m
.6969 .62578 L
s
.6969 .42129 m
.50459 .4994 L
s
.8171 .58673 m
.8171 .79121 L
s
.8171 .58673 m
.62479 .66483 L
s
.33632 .12948 m
.45651 .29491 L
s
.33632 .12948 m
.33632 .33396 L
s
.33632 .12948 m
.144 .20758 L
s
.45651 .29491 m
.57671 .46034 L
s
.45651 .29491 m
.45651 .4994 L
s
.45651 .29491 m
.2642 .37302 L
s
.57671 .46034 m
.6969 .62578 L
s
.57671 .46034 m
.57671 .66483 L
s
.57671 .46034 m
.3844 .53845 L
s
.6969 .62578 m
.8171 .79121 L
s
.6969 .62578 m
.6969 .83027 L
s
.6969 .62578 m
.50459 .70389 L
s
.8171 .79121 m
.62479 .86932 L
s
.21612 .16853 m
.33632 .33396 L
s
.21612 .16853 m
.21612 .37302 L
s
.33632 .33396 m
.45651 .4994 L
s
.33632 .33396 m
.33632 .53845 L
s
.33632 .33396 m
.144 .41207 L
s
.45651 .4994 m
.57671 .66483 L
s
.45651 .4994 m
.45651 .70389 L
s
.45651 .4994 m
.2642 .57751 L
s
.57671 .66483 m
.6969 .83027 L
s
.57671 .66483 m
.57671 .86932 L
s
.57671 .66483 m
.3844 .74294 L
s
.6969 .83027 m
.50459 .90838 L
s
.21612 .37302 m
.33632 .53845 L
s
.21612 .37302 m
.21612 .57751 L
s
.21612 .37302 m
.02381 .45113 L
s
.33632 .53845 m
.45651 .70389 L
s
.33632 .53845 m
.33632 .74294 L
s
.33632 .53845 m
.144 .61656 L
s
.45651 .70389 m
.57671 .86932 L
s
.45651 .70389 m
.45651 .90838 L
s
.45651 .70389 m
.2642 .782 L
s
.57671 .86932 m
.3844 .94743 L
s
.09593 .41207 m
.21612 .57751 L
s
.09593 .41207 m
.09593 .61656 L
s
.21612 .57751 m
.33632 .74294 L
s
.21612 .57751 m
.21612 .782 L
s
.33632 .74294 m
.45651 .90838 L
s
.09593 .61656 m
.21612 .782 L
s
.78388 .18854 m
.90407 .35398 L
s
.78388 .18854 m
.78388 .39303 L
s
.90407 .35398 m
.90407 .55847 L
s
.54349 .06216 m
.66368 .2276 L
s
.54349 .06216 m
.54349 .26665 L
s
.66368 .2276 m
.78388 .39303 L
s
.66368 .2276 m
.66368 .43209 L
s
.66368 .2276 m
.86518 .17775 L
s
.78388 .39303 m
.90407 .55847 L
s
.78388 .39303 m
.78388 .59752 L
s
.42329 .10122 m
.54349 .26665 L
s
.42329 .10122 m
.42329 .3057 L
s
.42329 .10122 m
.62479 .05137 L
s
.54349 .26665 m
.66368 .43209 L
s
.54349 .26665 m
.54349 .47114 L
s
.54349 .26665 m
.74498 .2168 L
s
.66368 .43209 m
.78388 .59752 L
s
.66368 .43209 m
.66368 .63657 L
s
.66368 .43209 m
.86518 .38224 L
s
.78388 .59752 m
.78388 .80201 L
s
.3031 .14027 m
.42329 .3057 L
s
.3031 .14027 m
.3031 .34476 L
s
.3031 .14027 m
.50459 .09042 L
s
.42329 .3057 m
.54349 .47114 L
s
.42329 .3057 m
.42329 .51019 L
s
.42329 .3057 m
.62479 .25586 L
s
.54349 .47114 m
.66368 .63657 L
s
.54349 .47114 m
.54349 .67563 L
s
.54349 .47114 m
.74498 .42129 L
s
.66368 .63657 m
.78388 .80201 L
s
.66368 .63657 m
.66368 .84106 L
s
.66368 .63657 m
.86518 .58673 L
s
.1829 .17932 m
.3031 .34476 L
s
.1829 .17932 m
.1829 .38381 L
s
.1829 .17932 m
.3844 .12948 L
s
.3031 .34476 m
.42329 .51019 L
s
.3031 .34476 m
.3031 .54925 L
s
.3031 .34476 m
.50459 .29491 L
s
.42329 .51019 m
.54349 .67563 L
s
.42329 .51019 m
.42329 .71468 L
s
.42329 .51019 m
.62479 .46034 L
s
.54349 .67563 m
.66368 .84106 L
s
.54349 .67563 m
.54349 .88012 L
s
.54349 .67563 m
.74498 .62578 L
s
.66368 .84106 m
.86518 .79121 L
s
.1829 .38381 m
.3031 .54925 L
s
.1829 .38381 m
.1829 .5883 L
s
.1829 .38381 m
.3844 .33396 L
s
.3031 .54925 m
.42329 .71468 L
s
.3031 .54925 m
.3031 .75374 L
s
.3031 .54925 m
.50459 .4994 L
s
.42329 .71468 m
.54349 .88012 L
s
.42329 .71468 m
.42329 .91917 L
s
.42329 .71468 m
.62479 .66483 L
s
.54349 .88012 m
.74498 .83027 L
s
.06271 .42287 m
.1829 .5883 L
s
.06271 .42287 m
.06271 .62735 L
s
.06271 .42287 m
.2642 .37302 L
s
.1829 .5883 m
.3031 .75374 L
s
.1829 .5883 m
.1829 .79279 L
s
.1829 .5883 m
.3844 .53845 L
s
.3031 .75374 m
.42329 .91917 L
s
.3031 .75374 m
.50459 .70389 L
s
.42329 .91917 m
.62479 .86932 L
s
.06271 .62735 m
.1829 .79279 L
s
.06271 .62735 m
.2642 .57751 L
s
.1829 .79279 m
.3844 .74294 L
s
.86518 .17775 m
.86518 .38224 L
s
.62479 .05137 m
.74498 .2168 L
s
.62479 .05137 m
.62479 .25586 L
s
.74498 .2168 m
.86518 .38224 L
s
.74498 .2168 m
.74498 .42129 L
s
.86518 .38224 m
.86518 .58673 L
s
.50459 .09042 m
.62479 .25586 L
s
.50459 .09042 m
.50459 .29491 L
s
.62479 .25586 m
.74498 .42129 L
s
.62479 .25586 m
.62479 .46034 L
s
.74498 .42129 m
.86518 .58673 L
s
.74498 .42129 m
.74498 .62578 L
s
.86518 .58673 m
.86518 .79121 L
s
.3844 .12948 m
.50459 .29491 L
s
.3844 .12948 m
.3844 .33396 L
s
.50459 .29491 m
.62479 .46034 L
s
.50459 .29491 m
.50459 .4994 L
s
.62479 .46034 m
.74498 .62578 L
s
.62479 .46034 m
.62479 .66483 L
s
.74498 .62578 m
.86518 .79121 L
s
.74498 .62578 m
.74498 .83027 L
s
.2642 .16853 m
.3844 .33396 L
s
.2642 .16853 m
.2642 .37302 L
s
.3844 .33396 m
.50459 .4994 L
s
.3844 .33396 m
.3844 .53845 L
s
.50459 .4994 m
.62479 .66483 L
s
.50459 .4994 m
.50459 .70389 L
s
.62479 .66483 m
.74498 .83027 L
s
.62479 .66483 m
.62479 .86932 L
s
.144 .20758 m
.2642 .37302 L
s
.144 .20758 m
.144 .41207 L
s
.2642 .37302 m
.3844 .53845 L
s
.2642 .37302 m
.2642 .57751 L
s
.3844 .53845 m
.50459 .70389 L
s
.3844 .53845 m
.3844 .74294 L
s
.50459 .70389 m
.62479 .86932 L
s
.50459 .70389 m
.50459 .90838 L
s
.144 .41207 m
.2642 .57751 L
s
.144 .41207 m
.144 .61656 L
s
.2642 .57751 m
.3844 .74294 L
s
.2642 .57751 m
.2642 .782 L
s
.3844 .74294 m
.50459 .90838 L
s
.3844 .74294 m
.3844 .94743 L
s
.02381 .45113 m
.144 .61656 L
s
.144 .61656 m
.2642 .782 L
s
.2642 .782 m
.3844 .94743 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[144]:=",
  ImageSize->{288, 279.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00015`P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00:l70P1_1`00[@L200031`0006h7002Z1`<00`L206h7002X1`801PL00`07
001]1`00Y@L300P700@01`L0K0L00:<70P0;1`0500L71`00J`L00:070`0=1`0500L71`00J`L009h7
0P0@1`0300L7008700<01`L0J0L009/70`051`<02PL4008700<01`L0I`L009T70P041`D000<70000
1PL400870P021`0300L706H7002F1`<00PL700<70P021`@00`L00`071`02008700<01`L0IPL008d7
0P051`8000<700000`000`L000061`@01`L01P071`07008700<01`L0I@L008/70P0010L000L600<7
0`041`D00PL00`071`051`0400L7008700@01`L0IPL008P70`031`D01@L200031`0000@010L01@07
1`L000H700@01`L00`L010071`1U1`00QPL200<710000`L01`031`<000<700000`071`0500L71`00
1PL010071`031`0400L706D700231`T00PL01@071`0700H00PL010071`061`0300L7008700<01`L0
0`L010071`041`0400L706@700211`D000@7000010L00`07000300L700D01`L700051`0300L700<7
00<01`L00PL010071`051`0400L706<7001n1`@00`L200D710021`0300L700H700D01`L700051`03
00L700@700D01`L700021`0300L700@700@01`L0HPL007X710041`<00`L700@700<01`L01@L00`07
1`021`0300L7008700<01`L010L01@071`L0008700<01`L010L010071`1R1`00MPL600@720000`L0
00031`<00`L00`071`041`0300L700<700D01`L700071`0400L7008700<01`L01@L010071`1Q1`00
LPL400031`0000@720001@L0000700D000<700000`L00`071`031`0300L700@700@01`L020L00`07
00021`0300L700H700@01`L0H0L006h710021`<00PL700<71`041`0400L000<700<01`L00`L00`07
1`041`0400L700T70P021`0300L700H700D01`L7001O1`00JPL400@70P000`L0000600@71@081`05
00L01`000`L00`071`021`0300L700D700<01`002@L2008700<01`L01`L010071`1O1`00J0L20003
1`0000871P031`<00`L400051`071`001`L00`0700021`0500L71`000`L00`071`061`802PL01007
1`0:1`0400L705h7001U1`<00`L600@70`000`L0000400@700D01`L700061`0300L000<700@01`L0
0`L00`071`071`0300L700P70P000`L01`0:1`0400L705d7001S1`8010L500D70P000`L0000400L7
00D01`L700061`0300L000<700D01`L700021`0300L700L700<01`L020L01007000;1`0500L71`00
G0L006070`000`L0000400061`071`071P0010L000021`0300L700@700<01`L00PL00`071`031`03
00L000@700L01`L700L000T70P091`0400L000`700@01`L0G0L005h71P0010L000031`0300L700@0
0`L2008700D01`L700051`0300L700<700<01`L00PL00`0700051`0400L71`802@L00`0700081`04
00L700d700@01`L0F`L005/71@031`801@L400041`071`<010L01@071`L000D700<01`L010L01`07
1`L01`001PL00`071`0200T700@01`L01`L00`071`0200`700D01`L7001J1`00F0L400@70`031`H0
10L200L700<01`L00PL00`071`021`0300L700@700L01`L700L000H700D01`L700091`0400L700L7
00H01`L01`0<1`0500L71`00F@L005@71@051`<000<700001@021`D000<700L01PL00`071`031`05
00L71`001`L01P071`0700L700<01`L00P081`0500L71`001PL01P071`0700d700@01`L0F@L00507
1P041`P00PL2008710021`800PL00`071`041`0300L700<700D01`L700081`0500L01`0020L01007
00081`0300L7008700<01`L00`L010071`021`0300L700/700@01`L0F0L004`7100010L000021`P0
0PL800<700<01`L00P021`0300L700@700<01`L010L010071`081`0500L01`002@L200031`0700H7
00<01`L00`L00`071`021`0400L700<700<01`L02PL01@071`L005L700191`<00`L200031`000080
00<700000P041`D01`L01P071`07008700<01`L00`L00`071`051`0300L000T70P000`L01`081`80
0PL00`071`041`0300L700<700<01`L00PL010071`041`0300L700X700D01`L7001F1`00B@L20003
1`0000@010L300<71@021`0300L700D700@01`L00PL010071`041`0300L700D700<01`002PL00`07
000:1`0500L71`001@L00`071`041`0500L71`000PL00`071`021`0300L700/700@01`L0EPL004T7
1@051`<000<700000`041`0500L71`001PL010071`031`0300L000@700<01`L01PL200X70`0:1`80
0PL00`071`031`0300L700D700@01`L00PL00`071`031`0300L700/700@01`L0E@L004H710000`L0
1`041`8000<7000010061`0500L71`001PL010071`031`0400L700<700<01`L01`L00`071`081`<0
2PL00`0700021`0300L7008700<01`L01PL00`0700021`0300L700@700<01`L02PL01@071`L005@7
00111`H00PL010071`021`T00PL00`071`031`0300L7008700<01`L00`L010071`041`0400L70087
00<01`L01`L200T700<01`002PL00`0700031`0500L71`0020L00`0700021`0300L700D700<01`L0
2PL01@071`L005<7000m1`@000@7000010L00`07000300<70P031`0500L71`0010L00`071`031`03
00L7008700@01`L01@L01P071`0700T70P091`0400L000T700@01`L00`L010071`091`800PL00`07
1`051`0300L700/700@01`L0D`L003T710031`801@L500031`0700<01@L01@071`L000@700<01`L0
10L01@071`L0008700<01`L00`L01P071`0700T700<01`0020L0100700091`0500L71`000PL01007
1`0:1`0400L700P700<01`L02PL01@071`L00587000e1`@010L300<71`031`8020L00`071`021`05
00L71`001PL01@071`L0008700<01`L010L00`071`0200T700@01`L01`L01@0700L000P700<01`L0
0PL01P071`0700X70P000`L01`081`0300L700X700D01`L7001A1`00<@L400H70P000`L000030087
0P021`0400L0008700<01`L01@L00`071`031`0400L700L700@01`L00PL00`071`051`0400L700T7
00@01`L01`L00`0700021`0300L700D700<01`L00PL010071`L200X70P000`L01`091`0300L700X7
00D01`L7001@1`00;@L400L720031`8010L0100700021`0300L700D700<01`L00`L010071`081`03
00L0008700<01`L01@L00`071`0200P700D01`L700061`0300L000<700<01`L010L00`071`031`03
00L700802PL01007000:1`0300L700/700@01`L0D0L002T710091`D00`L500H700@01`000`L00`07
1`041`0300L700@700<01`0020L00`0700021`0300L700H700@01`0020L00`071`021`0300L700<7
00<01`000`L00`071`041`0300L700@700@01`L02PL010071`0;1`0300L700X700D01`L7001?1`00
9PL300/70`071`<020L01@0700L000<700<01`L00`L00`071`051`802@L2008700<01`L01`L20003
1`0700H700<01`L00`L00`071`021`0300L000@700<01`L00`L00`071`051`0400L000T700<01`L0
0P0;1`0300L700X700D01`L7000F1`<02`L302L7000V1`8030L200D710021`0300L700D700<01`00
0PL010071`051`0300L700D70P0:1`0400L700X700@01`L01PL00`071`031`0300L7008700<01`00
1@L00`071`021`0300L700D700D01`0700081`0300L7008030L00`071`0:1`0500L71`004@L50003
1`0000H710021`0300L702D7000V1`8030L200<70P031`0500L71`001PL00`0700031`0400L700@7
00<01`L01PL00`071`081`8000<700L02@L010071`061`0300L700@700L01`L700L000H700D01`L7
00081`8000<700L01`L01P071`0700/700<01`L02PL01@071`L000d71`031`800PL400H700<01`L0
9@L002H700<01`002`L00`07000200D700D01`L700061`0300L000<700D01`L700031`0300L700H7
0P091`8000<700L02@L2008700<01`L00`L00`071`051`0600L700L01PL01@071`L000T700@01`L0
1`L010071`021`0300L700T700<01`L02PL00`071`0200P71@000`L000061`@02PL00`071`0U1`00
9PL010071`0:1`@01PL00`071`021`0300L700<700<01`0010L01@071`L0008700<01`L01PL00`07
00081`0400L000X700<01`000PL00`071`021`0300L700D700H01`L01`071`0400L700T70P021`03
00L700@700@01`L00`L00`071`091`0300L700X70P000`L000031`@00`L300@71@021`0300L700P7
00<01`L09@L002H700D01`L700071`<00`L00`071`031`0300L700<700<01`L00PL00`0700051`04
00L7008700<01`L01PL00`0700081`0400L700X700<01`000`L01@071`L000P700D01`0700081`03
00L000T70P021`0300L700@700@01`L00`L00`071`0:1`0300L700H70`000`L01`0500D70P000`L0
000400@700D01`L700091`0300L702D7000V1`0500L71`0010L3008700D01`L700051`0300L700<7
00<01`L00PL00`0700061`0600L700L020L010071`071`0300L700802@L010071`021`0500L71`00
2@L200031`0700L700<01`002@L00`0700021`0300L700<700@01`L010L00`071`091`0300L700@7
0P031`@000<700L00`L300031`0000<01`L01@071`L000T700<01`L09@L002H700<01`L00PL01007
00051`0300L7008700<01`L00PL00`071`041`0700L71`0700061`0400L71`8020L01@071`L000H7
00<01`L00P091`0500L71`000PL010071`0:1`0300L000T70P091`0400L7008700<01`L00PL01007
1`051`0300L700T700@01`L71`021`800PL00`070005008700@01`L01PL00`071`021`0300L700H7
00<01`L09@L002H700<01`L00PL200L700<01`L00`L01@071`L000L700H01`L01`071`0300L70080
20L01@071`L000H700H01`L01`081`0300L7008700H01`L01`0:1`0300L000X700<01`L01`L01@07
1`L0008700D01`L700021`0300L700@700<01`L02@L500P700<01`000`071`0500L71`001@L00`07
1`031`0300L700D700<01`L09@L002H700<01`L00P021`0300L700@700<01`L010L010071`071`06
00L700L020L010071`081`0300L7008700<01`L00`L010071`021`0300L700D700<01`L00PL01007
1`L200X70`0:1`8020L01@071`L0008700D01`L700021`0300L700@700<01`L01PL500T710021`03
00L700H700D01`L700051`0300L700@700<01`L010L00`071`0U1`009PL00`071`02008700<01`L0
10L00`071`041`0400L700P700D01`0700081`0300L700801`L00`071`031`0300L7008700@01`L0
0PL00`071`051`0300L700<700<01`L00P0:1`0300L000X70P081`0300L7008700@01`L00PL01007
1`071`0400L71`D00`L00`071`031`P00`L00`071`051`0300L7008700<01`L00PL00`071`041`03
00L700@700<01`L09@L002H700<01`L00P031`0300L700<700<01`L01@L00`0700091`8000<700L0
20L01@0700L000H700<01`L010L01@071`L0008700D01`L700061`0300L700@700@01`L02PL00`07
000:1`0300L000L700<01`L00`L01P071`07008700<01`L01@L600H71P000`L000031`<00`L00`07
1`041`0300L700<700D01`L700071`0300L700<700<01`L09@L002H700H01`L01`031`0300L70087
00<01`L01PL200X700<01`002PL200031`0700D700<01`L010L01@071`L0008700<01`L00PL00`07
1`031`0300L700@700<01`L00P091`0400L000T700@01`L01PL00`071`041`0300L700800PL01007
1`L400041`0000@71`0010L000021`@000<700000PL00`071`041`0300L700@700@01`L020L00`07
1`021`0300L702D7000V1`0400L7008700@01`L010L00`071`061`802PL00`07000;1`0400L700D7
00<01`L01@L010071`021`0300L700<700<01`L00PL00`071`051`0500L01`0020L01@0700L000P7
00@01`L01PL00`071`041`0300L700800PL400<70P000`L01`0600<70`000`L0000200<700@01`00
0`L00`071`031`0300L700@700@01`L020L00`071`021`0300L702D7000V1`0400L700<700@01`L0
0`L00`071`071`0300L700P70`0;1`0500L71`0010L00`071`061`0300L0008700<01`L00`L00`07
1`021`0300L700H70P000`L01`071`0500L01`0020L01@071`L000D700<01`L01@L00`07000400<7
0`000`L0000500@71P071`0500L01`000`L00`071`021`0300L700D700<01`002@L01@071`L002L7
000V1`0400L700<700D01`L700021`0300L700L70P091`0300L000/70P021`0300L7008700<01`L0
1PL00`0700021`0300L700@700D01`L700091`0400L700L700<01`000PL00`071`051`0300L70087
00<01`L00PL00`071`051`8000H7000700L600<70P041`D00PL00`071`051`0300L0008700@01`L0
10L00`071`061`802PL010071`0W1`009PL010071`041`0700L71`0700091`0300L000P700<01`00
2`L00`0700021`0500L71`002@L2008700<01`L01@L010071`091`0500L71`001PL00`0700031`03
00L700@700<01`L00`L01@071`L000D70P021`<000<700000P041`T010L01@071`L000H700<01`00
0`L010071`031`0300L700H70P0;1`0300L002L7000V1`0400L700D700H01`L01`091`0300L000P7
00@01`002PL010071`021`0400L700X700@01`L020L00`0700091`800PL00`071`041`0300L000@7
00<01`L00`L00`071`031`0500L71`000PL300@71@051`8000<700000`071`0500L71`001PL00`07
00031`0500L71`000PL00`071`071`0300L700T700<01`009`L002H700@01`L01PL00`071`0200T7
00@01`L01`L01@0700L000T700@01`L00`L00`07000:1`8000<700L01`L00`0700091`0300L00087
00<01`L00`L00`0700041`0300L700<700<01`L010L00`071`0300<71P021`0300L700T00PL00`07
1`041`0300L7008700<01`L00`L00`0700041`0700L71`0700091`802`L202L7000V1`0400L700H7
00D01`L700091`0500L71`001PL00`0700021`0300L700H700D01`L700021`0300L000X70P000`L0
1`081`802@L00`0700031`0300L7008700<01`001@L00`071`021`0300L700D70`021`H00PL20003
1`0000<00PL2008700D01`L700051`0300L700<700<01`L00PL00`0700051`0600L700L02@L00`07
000;1`0300L702D7000V1`0400L700L700<01`L00P081`0300L7008700<01`L00`L00`0700021`03
00L700H700<01`L00PL00`071`0200X700@01`002PL00`071`071`0400L700<700L01`L700L000H7
00D01`L700051`8000<700000P000`L000051`D00PL300@700D01`L700051`0300L700<700<01`L0
0PL00`0700061`0300L700802@L00`07000;1`0300L702D7000V1`0400L700P700@01`0020L00`07
1`021`0300L700<700<01`000`L00`071`051`0300L7008700D01`L7000:1`0400L700X70P081`05
00L71`000PL01`071`L01`001PL01@071`L000<72P041`@000@700070P071`0300L7008700<01`L0
0PL00`071`041`0700L71`0700061`0500L71`002@L010071`0:1`809PL002H700@01`L020L01@07
00L000L700<01`L00`L00`071`021`0300L000@700<01`L010L00`071`031`0400L700X700@01`L0
2PL200P700D01`L700031`0600L700L01`L00`071`0500@70P031`H000<700L00`000`L01`061`03
00L700<700D01`L700071`0600L700L01`L010071`091`0500L71`002@L00`07000U1`009PL01007
1`091`800PL00`071`041`0300L700@700L01`L700L000@700<01`L010L00`071`041`0400L000T7
00<01`L00P091`0300L000L700<01`L00PL02@071`L01`0700071`@010L400031`00008000<70000
0PL400031`00008700<01`L010L00`071`031`0500L71`001`L01P071`0700P700@01`0020L00`07
1`021`0300L700H700@01`L090L002H700@01`L02PL010071`061`0300L700@700L01`L700L000D7
00<01`L00`L00`071`051`8000<700L01`L01P071`0700P700@01`L01PL00`071`031`0400L71`80
00<700L00PLC00031`0000@00PL00`071`02008700<01`L010L00`071`041`0400L700P700D01`07
00081`0500L01`001`L00`071`021`0300L700H700@01`L090L002H700@01`L02PL2008700<01`L0
0`L00`071`051`0600L700L01PL00`071`021`0300L700D70P000`L01`071`0600L700L020L01007
1`061`0300L700@700<01`L00P000`L0000200041`001`@000<700000P041`D01PL01P071`070087
00<01`L00`L00`071`051`0300L000T70P000`L01`081`800PL00`071`041`0300L700<700<01`L0
1@L01@071`L002<7000V1`0400L700X70P031`0300L7008700<01`L01PL01@0700L000L700D01`L7
00081`0400L700L700@01`L00PL00`071`051`0500L71`001@L00`071`041`0300L700@00PL500<7
0P051`@00PL00`071`051`0400L7008700@01`L010L00`071`051`0300L000X700<01`002PL01007
1`061`0300L700@700<01`L010L00`071`021`0300L70207000V1`0400L700X700<01`000`L01@07
1`L000T70P000`L01`061`0500L71`0020L2008700<01`L010L010071`031`0300L700@700<01`L0
0PL00`071`021`0300L700D70P000`L0000400@71@000`L00003008700D01`L700061`0400L700<7
00<01`0010L00`071`061`802PL00`07000:1`800PL00`071`031`0300L700@700<01`L010L00`07
1`031`0300L701l7000V1`0400L700X700@01`L00PL01@071`L000T70P000`L01`071`0400L700P7
00<01`000PL00`071`031`0400L700@700<01`L00`L00`071`031`0500L71`0010L300031`0000<0
1@L200871P051`0500L71`001PL010071`031`0400L700<700<01`L01`L00`071`081`<02PL200<7
00<01`L00PL00`071`051`0300L700<700<01`L00`L00`071`0O1`009PL010071`0:1`0400L700<7
00@01`L02PL00`0700091`0300L000P700<01`000PL00`071`031`0400L700@700<01`L00`L00`07
1`031`0500L71`000PL900031`0700871P0010L000071`0300L7008700<01`L00`L010071`041`04
00L7008700<01`L01`L200T700<01`002PL00`0700021`0300L7008700<01`L01PL00`071`021`03
00L700@700<01`L07PL002H700@01`L02PL01@071`L000<700<01`002PL300T700<01`0020L01007
1`021`0300L7008700@01`L01@L00`071`021`0300L700@700<01`L01@000`L000021`8000<70000
10031`<00PL00`071`041`0300L700<700<01`L00PL010071`051`0600L700L02@L200T700<01`00
2PL010071`021`0500L71`002@L01@071`L000L700<01`L07@L002H700@01`L02PL00`071`021`04
00L71`802PL00`07000:1`8020L01@071`L0008700D01`L700021`0300L700@700D01`L700071`@0
0PL200D71@041`800PL01@071`L000D700<01`L010L01@071`L0008700<01`L00`L01P071`0700T7
00<01`0020L0100700091`0500L71`000PL010071`091`0500L71`001`L00`071`0M1`009PL01007
1`0:1`0300L700<700<01`L00P0:1`0300L000/700<01`L01PL00`071`021`0300L000<700@01`L0
1PL01@071`L000<710000`L0000300@71P000`L01`0300@700D01`L700051`0300L700@700D01`L7
00021`0300L700@700<01`L00P091`0400L700L700D01`0700081`0500L71`000`L00`07000:1`04
00L700P700<01`L070L002H700@01`L02PL00`071`031`0500L71`002PL01007000:1`0300L700H7
00<01`L00PL010071`021`0400L700L700<01`L01@041`800`L500870`000`L000071`0300L70087
00<01`L00PL00`071`051`0400L7008700<01`L01@L010071`091`0400L700L700<01`000PL00`07
1`051`0300L7008700H01`L01`0;1`0300L000T700<01`L06`L002H700@01`L02PL00`071`041`03
00L700802@L01@0700L000T70P071`0300L700<700H01`L01`021`0300L700@71`031`P000<70000
10L4008700<01`L010L00`071`031`0500L71`0020L00`0700021`0300L700D700<01`L00P081`05
00L71`001PL00`0700021`0300L700D700<01`L00`L00`071`0200`70P0:1`0300L701X7000V1`04
00L700X700<01`L01@L01@0700L000P700<01`000PL00`071`061`0300L000H700<01`L010L00`07
1`02008700<01`L010021`<00`L;00871@000`L000031`0300L700<700<01`L010L010071`081`03
00L0008700<01`L01PL0100700081`0300L7008700<01`L00`L00`0700031`0300L700@700<01`L0
0`L01@071`L000`70P0:1`0300L701X7000V1`0400L700X700<01`L01PL200031`0700L700<01`00
0PL00`071`061`0400L700D700<01`L010L00`071`0200031`0000800`L300031`0000H00`L20003
1`00008010L0100700031`0300L700<700<01`L010L010071`091`800PL00`071`071`8000<700L0
1PL00`071`031`0300L7008700<01`0010L00`071`031`0300L700@700@01`L03@L00`071`091`03
00L701T7000V1`0400L700X700<01`L01PL2008700<01`L01@L00`0700031`0300L700D700@01`L0
1@L00`071`051`0300L0008000<700L00PL200031`0000H00`L600P700D01`0700031`0300L70087
00<01`L01@L00`07000:1`0400L700X700@01`L01PL00`071`031`0300L7008700<01`0010L00`07
1`031`0300L700D700@01`0030L200/700<01`L060L002H700@01`L02PL00`071`071`0500L71`00
1PL00`0700041`0300L700@700D01`L700041`0300L700D70P0010L000L700<70`031`@000D700L7
00071`0300L0008700D01`L700031`0300L700H70P0:1`8000<700L02@L010071`061`0300L700@7
00L01`L700L000D700<01`L00PL00`071`061`8000<700L02PL00`07000:1`0300L701P7000V1`04
00L700X700<01`L01`L2008700<01`L010L00`0700041`0300L700@700<01`L00PL01@071`L000@7
0`021`L010L300031`0000<01@L01@071`L000H700<01`000`L010071`031`0300L700L700<01`L0
20L200031`0700T70P021`0300L700<700<01`L01@L01P071`0700H700D01`L700081`8000<700L0
2PL00`07000;1`0300L701L7000V1`0400L700X700<01`L01`L200<700<01`L00`L00`0700051`03
00L700<700<01`L00PL01@071`L000870P041`H010L200031`0000@01`L01@071`L000H700<01`00
0`L01@071`L0008700<01`L01`L00`071`081`0400L000X700<01`000PL00`071`021`0300L700D7
00H01`L01`071`0400L700T700@01`L02PL010071`0;1`0300L701H7000V1`0400L700X700<01`L0
1`L00`0700031`0300L7008700<01`001PL00`071`021`0300L700<700<01`L00`000`L000040006
1`071`071P0010L000021`0300L700@700<01`L00PL00`071`031`0300L000@700L01`L700L000T7
0P091`0400L700X700<01`000`L01@071`L000P700D01`0700071`0400L700T70P021`0300L700L7
00D01`L7000;1`0300L701D7000V1`0400L700X700<01`L01`L010071`031`0700L71`0700071`05
00L71`001PL600041`0000<70P000`L0000200870`021`0500L71`001@L00`071`031`0300L70087
00<01`001@L010071`L200T700<01`0020L00`071`0200T700@01`L00PL01@071`L000T70P000`L0
1`071`0300L000T700<01`000PL00`071`061`0500L71`002`L00`071`0E1`009PL010071`0:1`03
00L700L700D01`L700021`0700L71`0700071`0500L71`000`L600870P051`H00PL200D700D01`L7
00051`0300L700@700L01`L700L000H700<01`L00P091`0400L700L700<01`L00P091`0500L71`00
0PL010071`0:1`0300L000T70P091`0300L0008700<01`L01PL00`071`021`0300L700T700<01`L0
50L002H700@01`L02PL00`071`071`0500L71`000`L01P071`0700P700<01`L01@031`@00`L60004
1`001`801`L00`071`021`0300L7008700<01`L010L01`071`L01`001PL01@071`L000T700@01`L0
1`L01P071`0700P700<01`L00PL01P071`0700X700<01`002@L200T700@01`L00PL00`071`051`03
00L700<700<01`L02@L00`071`0C1`009PL010071`0:1`0300L700L700<01`L00PL02@071`L01`07
00081`D01@L300031`0000D00PL500031`0700H700<01`L00`L01@071`L000L700H01`L01`071`03
00L7008020L01@071`L000H700@01`L00PL00`071`051`0300L7008700@01`L70P0:1`<02PL00`07
1`071`0500L71`000PL00`071`041`0300L700@700<01`L02@L00`071`0B1`009PL010071`0:1`03
00L700L700<01`L00`L010071`L200031`0700<720021`P00PL2008710021`800PL00`071`041`03
00L700@700@01`L020L01@0700L000P700@01`0020L00`071`021`0300L700<700@01`L00PL00`07
1`051`0300L700<700<01`L00P0:1`0300L000X70P081`0300L7008700<01`001PL00`071`041`03
00L700T700<01`L04PL002H700@01`L02PL00`071`071`0300L700<700@01`L70P000`L000030004
1`00008720021`P00`L00`071`02008700<01`L010L00`071`041`0400L700P700D01`0700091`80
00<700L01PL00`071`031`0300L7008700@01`L00`L00`071`041`0300L700@700@01`L02PL00`07
000:1`8020L00`071`021`0400L700D700<01`L01@L00`071`081`804`L002H700@01`L02PL00`07
1`071`0300L700@700<01`L010031`8000<700000P0010L000051`D01`L01P071`07008700<01`L0
0`L00`071`051`0300L000T70P000`L01`081`800PL00`071`041`0300L700<700<01`L00PL01007
1`041`0300L700<700<01`L010L00`071`0200T700@01`002@L00`0700071`0300L700<700@01`L0
10L00`071`061`0300L700<710000`L01`0B1`009PL010071`0:1`0300L700L700<01`L01@L20003
1`0000L00`L400<71@021`0300L700D700@01`L00PL010071`041`0300L700H70P0:1`0300L000X7
00D01`L700051`0300L700@700D01`L700021`0300L700<700<01`L00PL00`071`051`0500L01`00
20L01@0700L000P700@01`L01PL00`071`041`0400L700<700<01`L01`L700<700<01`L04@L002H7
00@01`L02PL00`071`071`0300L700870`000`L01`0500D70P021`D010L01@071`L000H700@01`L0
0`L010071`031`0300L700H70P0:1`<02PL2008700<01`L00`L00`071`051`0400L7008700<01`L0
0`L00`071`021`0300L700H70P000`L01`071`0500L01`0020L01@071`L000D700<01`L010L01007
1`031`0300L700@7100010L000051`0300L70147000V1`0400L700X700<01`L01`L00`071`0200<7
10000`L01`031`<000<7000010061`0500L71`001PL010071`031`0400L700<700<01`L01`L00`07
1`081`<02PL00`0700021`0300L7008700<01`L01PL00`0700021`0300L700@700D01`L700091`04
00L700L700<01`000PL00`071`051`0500L71`001@L00`071`051`0400L0008700<01`L010031`80
20L00`071`0A1`009PL010071`0:1`0300L700L72@0010L000L200031`0000P00PL00`071`031`03
00L7008700<01`L00`L010071`041`0400L7008700<01`L01`L200T700<01`002PL00`0700031`05
00L71`0020L00`0700021`0300L700D700@01`L02@L01@071`L000H700<01`000`L00`071`041`03
00L7008700<01`L00PL00`071`051`8000@700070`041`<000<700L01`L00`071`0A1`009PL01007
1`0:1`0300L700D71@0010L000041`0300L000<00`L200<700D01`L700041`0300L700<700<01`L0
0PL010071`051`0600L700L02@L00`0700081`0400L000T700@01`L00`L010071`091`800PL00`07
1`061`0300L000T70P021`0300L700@700<01`0010L00`071`031`0300L700<700D01`L700041`<0
0PL500@70P041`0300L700H700<01`L04@L002H700@01`L02PL00`071`021`@000<700L00P051`D0
00<700L00`051`0500L71`0010L00`071`041`0500L71`000PL00`071`041`0300L700802@L00`07
00081`0400L000T700D01`L700021`0400L700X700@01`L020L00`0700091`0300L0008700<01`L0
0`L00`0700041`0300L700<700<01`L00`L01@071`L000870P000`L0000400031`0000870P061`03
00L700H700<01`L04@L002H700@01`L02PL500@70`031`T000<7000020L00`071`021`0500L71`00
1PL01@071`L0008700<01`L010L00`071`0200T700@01`L01`L01@0700L000P700<01`L00PL01P07
1`0700X70P000`L01`081`802@L00`0700031`0300L7008700<01`001@L00`071`021`0300L700@7
00<01`L01P051`0300L700<020L00`071`061`0300L70147000V1`0400L700L71P041`P000<70000
0`L4008700<01`L01@L00`071`031`0400L700L700@01`L00PL00`071`051`0400L700T700D01`L7
00061`0300L0008700<01`L01@L00`071`021`0400L71`802PL200031`0700T700<01`L01`L01007
1`031`0700L71`0700061`0500L71`001`L400T71@091`0300L700H700<01`L04@L002H700@01`L0
0`L400041`0000<720001@L0000700D000<700000`L00`071`041`0300L700@700<01`0020L00`07
00021`0300L700H700@01`0020L01@071`L000H700<01`000`L00`071`041`0300L700<700<01`L0
0P0:1`0400L000X70P081`0500L71`000PL01`071`L01`001PL01@071`L000@70`000`L000081`<0
00@700002@L00`071`061`0300L70147000V1`0300L700@00PL3008700<01`0010031`L010L01007
00031`0300L700@700<01`L010L00`0700091`800PL00`071`061`0500L01`001`L00`071`021`03
00L700<700<01`000`L00`071`041`0300L700@700@01`L02PL010071`0:1`8020L01@071`L000<7
00H01`L01`071`0300L700D010L200H70P021`0600L000L020L00`071`061`0300L70147000V1`@0
0`L200D710041`D020L01@0700L000<700<01`L00`L00`071`051`802@L2008700<01`L01`L20003
1`0700H700<01`L00`L00`071`021`0300L000@700<01`L00`L00`071`051`0400L000T700<01`L0
0P091`0300L000L700<01`L00PL02@071`L01`0700071`H01@L300@70P041`@00PL00`071`051`03
00L700H700<01`L04@L002H70P000`L0000200H70`031`@000D700L700071`0300L0008700D01`L7
00041`0300L700H700<01`L020L010071`0:1`0400L700H700<01`L010L01`071`L01`001@L00`07
1`021`0300L700D700D01`0700081`0300L700802@L010071`061`0300L700<700@01`L70P000`L0
1`021`@000@700000`L500031`0000<00`L4008700D01`L700061`0300L700H700<01`L04@L002H7
10061`<000<7000010041`0500L71`001PL00`0700031`0400L700@700<01`L01PL00`071`081`80
00<700L02@L2008700<01`L00`L00`071`041`0700L71`0700061`0500L71`0020L200031`0700L7
00H01`L01`081`0400L700H700<01`L010L00`071`0200031`0000800PL300031`0000H00`L20087
10031`0400L700<700<01`L010L00`071`061`0300L70147000U1`D010L200031`0000@01`L01@07
1`L000H700<01`000`L01@071`L000<700<01`L01PL200T700@01`002PL200<700<01`L00PL00`07
1`051`0600L700L01PL01@071`L000T700@01`L01`L010071`021`0300L700D700D01`L700051`03
00L700@700<01`L010031`8000<700000`000`L000031`L01`L010071`041`0300L700<700<01`L0
1PL00`071`0A1`008`L200061`071`071P0010L000021`0300L700@700<01`L00PL00`071`031`03
00L000@700D01`L700021`0300L700H700<01`0020L01007000:1`0300L0008700<01`L00PL00`07
1`061`0500L01`001`L010071`091`800PL00`071`041`0400L700<700<01`L010L00`071`021`03
00L7008700<01`L01@L200031`0000L00`L300<71P021`0300L700D700@01`L01@L00`071`021`03
00L700H700<01`L04@L002070`031`0300L700@00`L2008700D01`L700051`0300L700<700<01`L0
0PL00`0700051`0700L71`0700081`0400L700L700@01`L02PL010071`021`0500L71`002@L20003
1`0700L700<01`002@L2008700<01`L010L010071`031`0300L700@700<01`L00`L01@071`L000@7
0`000`L01`0500D70P000`L0000400@700D01`L700061`0400L700H700D01`L700081`0300L70147
000N1`801@L600870`041`0500L71`001@L00`071`031`0300L7008700<01`001PL01P071`0700P7
00@01`L01`L00`071`0200T700@01`L00`L010071`091`8000<700L01`L00`0700091`0300L00087
00<01`L00`L010071`041`0300L700<700<01`L00`L01@071`L000870P031`@000<700L00`L30003
1`0000<01`L01@071`L000H700@01`L01PL01@071`L000P700<01`L04@L001/70`031`H00PL01007
00071`0300L7008700<01`L00PL00`071`041`0700L71`0700061`0400L71`8020L01@071`L000H7
00H01`L01`081`0500L71`000`L00`07000:1`0300L000T70P091`0400L7008700<01`L00PL01007
1`051`0300L7008700<01`L010L00`071`0900041`001`8000<700001`021`0300L700@700<01`L0
0PL00`071`031`0400L700L700@01`L020L00`071`0A1`006@L300031`0000D00PL00`071`020003
1`0700H700<01`L00`L01@071`L000L700H01`L01`071`0500L71`0020L00`071`021`0300L700<7
00H01`L01`081`0300L7008700H01`L01`0:1`<02PL00`071`071`0500L71`000PL01@071`L00087
00<01`L010L01@071`L000H71P0010L000041`0300L000<00PL3008700D01`L700051`0300L700<7
00<01`L00PL010071`081`0300L000P700<01`L04@L001H71`021`801@L00`071`02008700<01`L0
10L00`071`041`0400L700L700H01`L01`081`0400L700P700<01`L00PL00`071`031`0400L70087
00<01`L01@L00`071`031`0300L700802PL300X70P081`0500L71`000PL01@071`L0008700<01`L0
10L01@071`L000@71P000`L000051`D000<700L00P051`0500L71`001@L00`071`041`0500L71`00
0PL00`071`071`8020L00`071`0A1`0050L5008710071`0300L700800PL00`071`041`0300L700@7
00@01`L020L01@0700L000P700<01`L00P071`0300L700<700<01`L00PL010071`031`0300L700@7
00<01`L00`L01@071`L000X700<01`002PL200P700<01`L00PL010071`021`0400L700L700<01`L0
1@041`<00`L900031`0000L700<01`L00PL00`071`021`0300L700@700D01`L700021`0300L700L7
0P081`0300L70147000B1`<01@L200031`0700L700H01`L01`021`0300L700<700<01`L01@L00`07
00091`8000<700L020L01@0700L000H700<01`L010L01@071`L0008700<01`L00PL00`071`031`03
00L700@700<01`L00P091`0400L000T700<01`001`L00`071`031`0600L700L00PL00`071`051`D0
1@L800031`0000<710021`0300L700@700<01`L00`L01@071`L000L700@01`L00PL00`071`081`03
00L700H700<01`L04@L001870P031`<000D700L700071`0400L7008700@01`L010L00`071`061`80
2PL00`07000:1`800PL00`071`031`0300L700D700@01`L00PL00`071`021`0300L700<700<01`L0
1@L0100700091`0500L01`0020L010071`061`0300L700@700<01`L00P021`0400L71`P00`L80005
1`0000L01@000`L000031`0300L700<700<01`L010L010071`081`0300L0008700<01`L020L200L7
00<01`L04@L001871@041`0500L71`001PL010071`031`0300L000@700<01`L01PL200X700<01`00
2`L010071`051`0300L700D700@01`L00PL00`071`031`0300L7008700<01`L01PL200031`0700L7
00D01`0700081`0400L700H700<01`L010L00`071`02008710021`800PL800<71`041`0400L000<7
00<01`L00`L00`071`041`0400L700P700<01`000PL00`071`081`0300L000H700<01`L04@L00187
0`061`0500L71`001PL010071`031`0400L700<700<01`L01`L00`071`081`<02`L01@071`L000@7
00<01`L01PL00`0700021`0300L700@700D01`L700081`800PL00`071`051`0300L0008700<01`L0
1@L01@071`L000D700<01`L01@L00`07000400870`000`L0000600@71@081`0500L01`000`L00`07
1`021`0300L700D700<01`002@L2008700<01`L020L00`0700061`0300L70147000?1`@00PL00`07
1`031`0300L7008700<01`L00`L010071`041`0400L7008700<01`L01`L200T700<01`002`L200<7
00D01`L700091`800PL00`071`051`0400L700T700D01`L700061`0300L000<700<01`L010L00`07
1`021`0300L7008700<01`L01@L200041`001`L00`L300<710001@L01`L000L700<01`000PL01@07
1`L000<700<01`L01PL200X700@01`L02PL010071`051`0300L70147000=1`800`L01@071`L000@7
00<01`L00`L00`071`021`0400L700D700H01`L01`091`0300L000P700<01`002`L00`0700031`04
00L700X700@01`L01`L010071`091`800PL00`071`041`0300L000<700<01`L010L00`071`031`05
00L71`0010L300871`041`<000<7000010041`0500L71`001PL00`0700031`0400L700<700<01`L0
1`L00`071`081`8000<700L02@L01@071`L000@700<01`L04@L000X70`051`0500L71`0010L00`07
1`041`0500L71`000PL00`071`031`0600L700L02@L00`0700081`0400L000X700@01`L00PL01007
1`0:1`0400L700P700<01`002@L200<700<01`L00`L00`0700041`0300L700<700<01`L00`L01@07
1`L000870P041`H010L200031`0000@01`L01@071`L000H700<01`000`L01@071`L0008700<01`L0
1`L00`071`081`8000<700L02@L00`071`021`0500L71`004`L000P70P081`0300L7008700D01`L7
00061`0500L71`000PL00`071`041`0300L700802@L010071`071`0500L01`002@L010071`031`03
00L000X70P000`L01`081`802@L00`0700031`0300L7008700<01`001@L00`071`021`0300L700@7
00<01`L00`000`L0000400061`071`071P0010L000021`0300L700@700<01`L00PL00`071`031`03
00L000@700L01`L700L000T70P091`0400L000X700<01`L00PL01@071`L001<700061`802PL00`07
1`031`0400L700L700@01`L00PL00`071`051`0400L700T700D01`L700061`0300L0008700<01`L0
1PL01@071`L000<70P0:1`0400L000X700<01`L01`L010071`031`0700L71`0700061`0500L71`00
1`L900@71P041`800PL01@071`L000D700<01`L00`L00`071`021`0300L000D700@01`L70P091`03
00L000P700@01`L02PL00`071`031`0400L701<700071`0300L700P700<01`L00`L010071`081`03
00L0008700<01`L01@L00`071`0200P700<01`L00PL00`071`031`0300L0008700<01`L01PL00`07
1`021`0300L700802PL01007000:1`0300L700L700D01`L700021`0700L71`0700061`0500L71`00
10L600031`0000D71`021`<010L01@071`L000D700<01`L010L01`071`L01`001PL00`071`0200T7
00@01`L01`L010071`0:1`0300L700@700<01`004`L000L700<01`L020L00`071`041`0300L000P7
00<01`000PL00`071`061`0400L000P700<01`L00PL00`071`031`0300L000<700<01`L01@L00`07
1`021`0500L71`002PL010071`0:1`8020L01@071`L000<700H01`L01`071`0500L700L010031`<0
0`L700041`001`801`L00`071`021`0300L7008700<01`L010L01`071`L01`001PL01@071`L000T7
00@01`L01`L00`071`0200T700<01`L01@L201<700081`0300L700L700<01`L01@L200T70P021`03
00L700L70P000`L01`061`0300L700<700<01`L00PL00`0700041`0300L700@700<01`L00`L00`07
1`0200T700<01`L00P091`0300L000L700<01`L00PL02@071`L01`0700081`D010L800041`000087
1@000`L01`061`0300L700<700D01`L700071`0600L700L01`L00`071`0200P700D01`L700061`06
00L700L020L00`071`051`804`L000T700<01`L01PL00`071`051`802PL010071`0:1`0400L700H7
00<01`L010L01`071`L01`0010L00`071`041`0300L700@700D01`0700081`0600L700L020L01007
1`061`0300L700<700@01`L70P000`L01`031`L00`L800870P021`@00PL2008700<01`L010L00`07
1`041`0400L700P700D01`0700081`0400L000P700<01`L00PL00`071`031`0400L7008700<01`L0
1@L00`071`061`0300L70147000:1`0300L700D700<01`L01PL00`071`081`8000<700L02@L01007
1`061`0300L700@700L01`L700L000D700<01`L00`L00`071`051`8000<700L01`L01P071`0700P7
00@01`L01PL00`071`031`0400L71`8000<700000`001@L0000700P00`L800<700<01`L00P021`03
00L700@700<01`L010L010071`081`0500L01`002@L200031`0700H700<01`L00`L00`071`021`04
00L7008700<01`L01@L00`071`061`804PL000X700<01`L01@L00`071`061`802@L200031`0700T7
0P021`0300L700<700<01`L01@L01P071`0700H700<01`L00PL00`071`051`800PL00`071`051`04
00L7008700<01`L01@L01@071`L000D700<01`L010L00`071`0400<70P000`L0000700@71@071`06
00L700L00PL00`071`031`0300L700D700<01`002@L200031`0700P70P021`0300L700@700<01`L0
0`L00`071`021`0400L700<700<01`L010L00`071`061`0300L00147000;1`0300L700@700<01`L0
1PL00`0700081`0400L000X700<01`000PL00`071`021`0300L700H700D01`0700071`0500L71`00
20L01@071`L000H700@01`L00`L00`071`041`0300L7008700<01`L00PL00`071`051`8000<70000
1`041`8010L5008700<01`L01@L010071`021`0400L700@700<01`L01PL200X700<01`002PL01@07
1`L000D700<01`L010L01@071`L0008700<01`L00PL00`071`031`0300L700H700<01`004@L000`7
00<01`L00`L00`071`061`0300L000P700@01`L02PL00`0700031`0500L71`002@L200031`0700H7
00D01`L700081`800PL00`071`041`0400L700<700<01`L010L00`071`031`0500L71`001@L20003
1`0700D01@L900@700D01`L700061`0400L700<700@01`L00`L00`071`061`802PL300X70P021`03
00L700<700<01`L01@L010071`021`0300L700<700<01`L00PL00`071`061`0400L70107000=1`03
00L7008700<01`L01PL010071`071`0300L700802@L010071`021`0500L71`002@L200031`0700L7
00@01`L020L00`0700021`0300L700<700@01`L010L00`071`031`0300L700<700D01`L700021`<0
0PL400031`0700@70P000`L0000300L700D01`L700061`0400L700<700@01`L00`L00`071`071`03
00L700P70`0:1`0300L0008700<01`L00PL00`071`061`0300L0008700<01`L00`L00`071`021`03
00L700H700D01`L7000?1`003@L00`071`021`0300L700H700D01`L700061`0300L700802@L01@07
1`L0008700@01`L02PL00`0700091`0300L000P700<01`000`L00`071`021`0400L700D700<01`L0
0PL00`071`041`0300L700T000@700070P021`P00PL00`071`041`0300L7008700<01`L00`L01007
1`041`0400L7008700<01`L01`L200T700<01`002PL00`0700031`0500L71`0020L00`0700021`03
00L700@700D01`L700081`0300L7008700<01`L030L000h700D01`L700081`0500L71`001PL01P07
1`0700P700<01`L00PL01P071`0700X70`091`0300L000P700@01`L00`L01@071`L0008700<01`L0
10L01@071`L000L71@0010L000041`0300L000<00`L2008700D01`L700051`0300L700<700<01`L0
0PL010071`051`0600L700L02@L00`0700081`0400L000T700@01`L00`L010071`091`800PL00`07
1`051`0400L700P700<01`L00PL00`071`0<1`003`L010071`081`0300L7008700<01`L00`L01007
1`021`0300L700D700<01`L00PL010071`L200X700<01`002PL200P700D01`L700021`0500L71`00
0PL00`071`041`0500L71`0010L600031`0000D71@000`L01`0300@700D01`L700051`0300L700@7
00D01`L700021`0300L700<700@01`L70P091`0300L000P700@01`002@L01@071`L0008700@01`L0
2PL010071`071`0400L700P700<01`L00`L00`071`0;1`003`L010071`081`0300L700<700<01`L0
0PL010071`021`0300L700D700<01`L00`L00`071`0200X700<01`002`L00`071`061`0300L70087
00@01`L00PL010071`071`0300L700H00`L300<72@000`L000071`0300L7008700<01`L00PL00`07
1`041`0500L71`000PL00`071`041`0300L700802@L010071`071`0500L01`0020L00`071`021`06
00L700L02PL200031`0700L700<01`0020L00`071`041`0300L700X7000@1`0300L000P700<01`L0
10L01@071`L0008700D01`L700061`0300L700@700@01`L02PL01007000:1`0300L700H700<01`L0
0PL01`071`L01`000PL00`071`051`L00`L800870P021`@00PL00`071`041`0300L700<700D01`L7
00071`0400L7008700<01`L01@L010071`091`0500L71`001PL00`0700021`0300L700D700<01`L0
0PL010071`L200X70P000`L01`081`8020L00`071`051`0300L700T7000A1`8020L00`071`041`05
00L71`000PL00`071`021`0300L700<700<01`L010L00`071`0200T700D01`0700091`801`L00`07
1`031`0400L71`800PL010071`L400870P031`P00`L200031`00008000<700000PL00`071`041`03
00L700@700@01`L020L00`0700021`0300L700D700<01`L00P081`0500L71`001PL00`0700031`03
00L700@700<01`L00`L00`071`0200X700@01`002PL00`071`061`0300L700D700<01`L02@L00187
00<01`L01PL00`071`051`0400L7008700<01`L00`L00`071`021`0300L700D700D01`0700081`03
00L0008700<01`L01PL00`0700061`0300L700@700<01`L00P021`@00`L;00<720031`0400L000<7
00<01`L00`L00`071`041`0400L700P700<01`000PL00`071`061`0500L01`001`L00`071`021`03
00L700<700<01`000`L00`071`041`0300L700@700@01`L02PL010071`0:1`0300L700H700<01`L0
1PL00`071`081`004PL00`071`061`0300L700H700<01`000PL00`071`031`0300L7008700<01`L0
1PL200031`0700L700<01`000PL00`071`061`0400L700D700<01`L010L00`071`0500@70P000`L0
000500H710071`0500L01`000`L00`071`021`0300L700D700<01`002@L2008700<01`L01`L20003
1`0700H700<01`L00`L00`071`021`0300L000@700<01`L00`L00`071`051`0400L000T700<01`L0
0P091`801`L00`071`071`0300L700L7000B1`801`L00`071`061`0300L0008700<01`L010L01@07
1`L000T700@01`L01`L00`0700031`0300L700D700@01`L01@L00`071`051`8000D7000700021`D0
0`L200@71@021`0300L700D700<01`000PL010071`041`0300L700H70P0:1`0400L700X700@01`L0
1PL00`071`041`0700L71`0700051`0300L7008700<01`L01@L01@0700L000P700<01`L00P091`03
00L000H700<01`L020L00`071`061`004PL00`0700061`0300L700L70P021`0300L700D700@01`L0
2@L01@071`L000H700<01`0010L00`071`041`0500L71`0010L00`071`031`8000<700L00P000`L0
000200@71@000`L0000200<700D01`L700061`0300L000<700@01`L00`L00`071`061`802PL20003
1`0700T700D01`L700051`0300L700@700L01`L700L000H700D01`L700081`8000<700L01`L01P07
1`0700P700<01`001PL00`071`081`0300L700H7000B1`0400L700D700<01`L020L010071`081`03
00L000T70P021`0300L700@700<01`0010L00`071`041`0300L7008700D01`L700021`<010L500D7
0P021`H01@L01@071`L000H700<01`000`L01@071`L0008700<01`L01`L00`071`081`8000<700L0
2@L200<700<01`L00PL00`071`051`0600L700L01PL01@071`L000T700@01`L01`L010071`021`03
00L700D700@01`L01@L00`071`081`801`L0018700@01`L01@L00`071`081`8000<700L01`L00`07
00091`0300L0008700<01`L00`L00`0700051`0300L700<700<01`L00PL010071`L300<71P021`03
00L700L000<700000P061`0300L7008700<01`L00`L00`0700041`0700L71`0700091`802@L01007
000:1`0300L0008700<01`L00PL00`071`061`0500L01`001`L010071`091`800PL00`071`041`04
00L700<700<01`L010L01@071`L000@700<01`L01PL200T7000B1`0500L71`0010L00`071`081`80
00<700L020L200T700<01`000`L00`071`021`0300L000H700<01`L00PL00`071`031`@00PL30003
1`00008700<01`L01P031`<00`L00`071`031`0300L700<700<01`L00PL00`0700051`0600L700L0
2@L00`0700081`0400L700X700<01`000`L01@071`L000T70P000`L01`071`0300L000T70P021`03
00L700@700@01`L00`L00`071`041`0300L7008700D01`L700051`<02`L0018700<01`L00PL01@07
1`L000X700@01`002PL00`071`071`0400L700<700L01`L700L000L700D01`L700041`L00PL200@7
1@041`<00PL01@071`L000D700<01`L00`L00`071`021`0300L000H700<01`L00P091`0300L000P7
00<01`L00P091`0400L700<700@01`L02@L200031`0700L700<01`002@L00`0700021`0300L700<7
00@01`L010L00`071`031`0300L7008700D01`L700031`803PL0018700<01`L00PL01@071`L000X7
00@01`L02PL200P700D01`L700021`0700L71`0700071`0500L71`000PL700041`0000@70`001PL0
00L01`801@L00`071`021`0300L7008700<01`L010L01`071`L01`001PL01@071`L000T700@01`L0
1`L00`071`0200T700D01`L700031`0300L000X700<01`002@L200T700@01`L00PL00`071`021`04
00L700D700<01`L00PL00`071`031`0300L700@040L0018700<01`L00`L010071`0:1`0400L700X7
0P081`0500L71`000`L01P071`0700P700<01`L010041`<00`L500031`07008000<700001`L00`07
1`031`0500L71`001`L01P071`0700L700@01`L02@L01@071`L000H700H01`L01`081`0300L70087
00H01`L01`0:1`<02PL00`071`071`0500L71`000PL01@071`L0008700<01`L010L01@071`L000H7
0`0C1`004PL00`071`041`0300L000X700<01`L00P091`0300L000L700<01`L00PL02@071`L01`07
00071`D01@L:00@71@021`0300L700@700<01`L00`L01@071`L000L700H01`L01`081`0400L000P7
00<01`L00PL00`071`031`0400L7008700<01`L01@L00`071`021`0400L71`802PL300X70P081`05
00L71`000PL01@071`L0008700<01`L010L01@071`L000@70P000`L0000C1`004PL00`071`051`80
2PL01P071`0700P700@01`L01PL00`071`031`0400L71`8000<700L00PL600031`00008720000`L0
00031`@00PL2008700<01`L010L00`071`041`0400L700P700D01`0700081`0500L01`001`L00`07
1`021`0300L700<700@01`L00PL00`071`051`0300L700<700D01`L7000:1`0300L000X70P081`03
00L7008700@01`L00PL010071`071`0500L700L00`031`804`L0018700<01`L01@L200X700H01`L0
1`081`0400L700H700<01`L010L00`071`0200031`00008000<7000010L700<70`000`L0000200<7
00<01`L00P031`0300L700<700<01`L01@L00`0700091`8000<700L020L2008700<01`L010L00`07
1`031`0300L7008700@01`L00`L00`071`041`0300L700@700<01`L00P091`0400L000T700<01`00
1`L00`071`031`0600L700L00PL00`071`061`0400L000D70`0C1`004PL00`071`061`0300L700P7
00@01`L00PL00`071`051`0500L71`001@L00`071`041`0300L700@00PL20087100010L000041`H0
1`L01P071`0700<700<01`L00PL00`071`051`0300L000X700<01`002PL010071`061`0300L700@7
00D01`L700021`0300L7008700<01`L00`L00`071`041`0300L700802@L01@0700L000P700@01`L0
1PL00`071`041`0300L700800PL00`071`051`@00PL501D7000B1`0300L700H70P091`0400L700<7
00<01`L010L00`071`021`0300L7008700<01`L01@L200031`0000L00`L400871P021`0300L700D7
00@01`L00PL010071`041`0300L700H70P0:1`0300L000X70P021`0300L700<700<01`L010L01@07
1`L0008700<01`L00`L00`071`021`0300L700D700D01`0700081`0500L01`0020L010071`061`03
00L700@700<01`L00P021`0300L700<70P021`@000<700005`L0018700<01`L01PL00`0700081`04
00L700@700<01`L00`L00`071`031`0500L71`0010L300031`0700D01@L200871@041`0500L71`00
1PL010071`031`0400L700<700<01`L01`L00`071`081`<02PL200<700<01`L00PL00`071`051`04
00L7008700<01`L00`L00`071`021`0300L700H70P021`0300L700D700<01`000PL00`071`051`05
00L71`001@L00`071`051`0400L0008700<01`L01`000`L0000201T7000B1`0300L700H700<01`00
20L010071`041`0300L700<700<01`L00`L01@071`L000870P031`@000<700L00`L300031`0000@0
1PL01@071`L000H700@01`L00`L01@071`L0008700<01`L01`L200T700<01`002PL00`0700021`03
00L7008700<01`L01PL00`0700021`0300L700@700D01`L700091`0500L71`001PL00`0700031`03
00L700@700<01`L00PL00`071`021`0300L700D70P0010L01`L600@70P0L1`004PL00`071`061`04
00L700L700@01`L01@L00`071`021`0300L700@700<01`L020021`8000@7000720001@L01`L000D7
00<01`L00PL00`071`031`0400L700@700L01`L700L000T70P091`0300L000X700@01`L00PL01@07
1`L000T70P021`0300L700D700@01`L02@L01@071`L000H700<01`000`L00`071`041`0300L700<7
00D01`L700051`800PL600D70`0N1`004PL00`071`061`0500L71`001PL010071`061`0500L71`00
1`L500031`0000D700<01`000`031`800`L01@071`L000@700<01`L00`L00`071`021`0400L700D7
00H01`L01`091`0300L000P700@01`002@L01@071`L0008700@01`L02@L2008700<01`L01PL00`07
00091`800`L00`071`031`0300L000@700<01`L00`L00`071`031`0500L71`000PL3008710021`03
00L700870P0Q1`004PL00`071`061`0300L7008700<01`L00`L010071`061`0500L71`0010L900D7
1@000`L01`0300D700D01`L700041`0300L700@700D01`L700021`0300L700@700<01`L00P091`04
00L700L700D01`0700081`0500L71`000`L00`07000:1`0400L700P700<01`002@L00`0700031`03
00L7008700<01`001@L00`071`021`0300L700@700<01`L00`000`L0000400051`071`000PL202<7
000B1`0300L700H700<01`L00PL00`071`031`0400L700L700<01`L01@041`8010L900031`0000P7
00<01`L00PL01@071`L000H700D01`L700021`0300L700@700D01`L700091`0400L700L700<01`00
0PL00`071`051`0300L7008700H01`L01`0:1`8000<700L020L200T700<01`0010L01`071`L01`00
1PL01@071`L000L72@041`8000@700009@L0018700<01`L01PL00`071`031`0300L7008700@01`L0
1`L600<70`000`L0000300031`0000<710021`0300L700D700<01`L00`L010071`071`0400L70087
00<01`L01@L00`071`0200P700D01`L700061`0300L0008700<01`L01@L00`071`031`0300L70080
2PL01007000:1`0300L700L700@01`L00`L01`071`L01`001PL01@071`L000D71@000`L000071`@0
9`L0018700<01`L01PL00`071`041`0500L71`000PL010071`L400041`0000<70P000`L000030005
1`0000L01@000`L000031`0300L700@700<01`L010L00`0700081`0300L0008700<01`L01PL01007
00081`0300L7008700<01`L00`L00`0700031`0300L700@700<01`L00`L01@071`L000X700@01`00
2PL200P700D01`L700031`0600L700L01`L01@071`0700@00`L300L70`000`L0000W1`004PL00`07
1`061`0300L700@700D01`L700021`@00PL300041`001`D00`L700@700@01`000`L00`071`041`03
00L700@700<01`002@L2008700<01`L01PL01@0700L000L700<01`L00`L00`071`021`0300L000@7
00<01`L00`L00`071`041`0400L700X700@01`L02PL200P700D01`L700041`0500L01`0020L600<7
10061`800PL01007000W1`004PL00`071`061`0300L700D700<01`L010031`801@L300D71@081`05
00L01`000`L00`071`031`0300L700D70P091`800PL00`071`071`800PL00`071`041`0300L700<7
00<01`L00PL00`0700041`0300L700<700<01`L01@L0100700091`0300L700802@L00`0700071`03
00L7008700<01`L00PL200031`0700<710000`L000031`D000<700L00`L2008710000`L01`0V1`00
4PL00`071`061`0300L700H700D01`001`0400L70P031`@000D700L700071`0300L0008700D01`L7
00041`0300L700H700<01`L020L010071`0:1`0400L700H700<01`L010L01`071`L01`001@L00`07
1`021`0300L700H70P000`L01`071`0600L700L020L010071`061`0300L700<700@01`L70P000`L0
000300872`031`0300L000H00PL010071`0W1`004PL00`071`061`0300L700L71@0:1`H010L01@07
1`L000H700<01`000`L010071`041`0300L700H700<01`L020L200031`0700T70P021`0300L700<7
00<01`L01@L01P071`0700H700D01`L700081`8000<700L01`L01P071`0700P700@01`L01PL00`07
1`041`0300L700@010L200031`0000H01@L500H700@01`L09`L0018700<01`L01PL00`071`071`D0
1`L600L700D01`L700061`0300L000<700D01`L700031`0300L700H70P091`0400L000X70P031`03
00L7008700<01`L01@L01P071`0700L700@01`L02@L010071`071`0400L7008700<01`L01@L01@07
1`L000D700<01`L010L300041`0000871@031`801@L400X700@01`L09`L0018700<01`L01PL00`07
1`051`8000D700L700031`@000@700000PL00`071`041`0300L7008700<01`L00`L00`0700041`05
00L71`000PL00`071`061`0300L000P700@01`002PL00`0700031`0500L71`0020L01@0700L000L7
00@01`L02@L2008700<01`L010L010071`031`0300L700@700<01`L00PL00`071`021`0300L70087
10021`H010L4008710031`0300L700P700@01`L09`L0018700<01`L01PL00`071`021`<00`L20003
1`0000800`L2008700D01`L700051`0300L700<700<01`L00PL00`0700051`0700L71`0700081`04
00L700L700@01`L02PL010071`021`0500L71`002@L200031`0700L700<01`002@L00`0700021`03
00L700<700@01`L00`L00`071`041`0300L700<700D01`L700021`8010L500D70P021`H01@L00`07
1`081`0400L702L7000B1`0300L700H700<01`L00P051`H00PL300@700D01`L700051`0300L700@7
00L01`L700L000H700H01`L01`081`0400L700L700<01`L00P091`0400L700<700@01`L02PL00`07
00091`802@L00`0700021`0300L700<700@01`L010L00`071`031`0300L700<700@01`L70`021`L0
00<700000PL600041`0000L700<01`L020L010071`0W1`004PL00`071`061`<00`L400031`070080
00<700001`L00`071`021`0300L7008700<01`L010L01`071`L01`001PL010071`L200P700D01`L7
00061`0600L700L020L01@071`L000<700<01`002PL00`0700091`802@L010071`021`0300L70087
00@01`L01@L00`071`021`0300L700@710001@L0000700800PL200031`0000@00`L300T700<01`L0
20L010071`0W1`004PL00`071`041`<000<700000P051`0300L7008000<700L01PL00`071`031`05
00L71`001`L01P071`0700L700D01`L700081`0300L7008700<01`L00`L01P071`0700P700<01`L0
0PL010071`L200X70`0:1`0300L700L700D01`L700021`0500L71`000PL00`071`041`0500L71`00
1@L600870P051`D00`L3008700<01`L01`L00`071`081`0400L702L7000B1`0400L71`L02@L01@07
1`L0008700<01`L010L00`071`041`0400L700P700D01`0700081`0400L700P700<01`L00PL00`07
1`031`0400L7008700<01`L01@L00`071`031`0300L700802PL00`07000:1`8020L00`071`021`03
00L000<700@01`L01PL01@071`L000871@000`L0000300@71P021`<01@L00`071`071`0300L700P7
00@01`L09`L0018700<01`0010031`0300L700L700D01`L700021`0300L700@700<01`L010L01007
1`081`0500L01`002@L0100700071`0300L700<700<01`L00PL010071`031`0300L700@700<01`L0
0`L01@071`L000X700<01`002PL200P700<01`L00PL010071`021`0400L700L700<01`L010051`80
0`L500870`0010L000061`0300L700L700<01`L020L010071`0W1`004PL300P700<01`L01PL00`07
1`021`0400L700D700<01`L01@L00`0700091`8000<700L020L01@0700L000H700<01`L010L01@07
1`L0008700<01`L00PL00`071`031`0300L700@700<01`L00P091`0400L000T700<01`001`L00`07
1`031`0600L700L00PL00`071`041`D01@L800031`0000@710021`0300L700@700<01`L01`L00`07
1`081`0400L702L7000C1`0300L700P700<01`L01@L00`071`031`0400L700@700<01`L01PL200X7
00<01`002PL2008700<01`L00`L00`071`051`0400L7008700<01`L00PL00`071`031`0300L700D7
00D01`0700081`0500L01`0020L010071`061`0300L700@700<01`L00P021`0300L700H000<70000
0`L;00871@000`L000031`0300L700<700<01`L01`L00`071`081`0400L702L7000C1`0300L700T7
00<01`L010L00`071`041`0400L700<700<01`L01`L00`071`081`<02`L010071`051`0300L700D7
00@01`L00PL00`071`031`0300L7008700<01`L01PL200031`0700L700D01`0700081`0500L71`00
1@L00`071`041`0300L7008000<700000P0010L000031`P00`L200031`00008010L0100700041`03
00L7008700<01`L01`L00`071`081`0400L702L7000D1`0300L700P700<01`L010L00`071`041`04
00L700<700<01`L01`L00`071`081`<02`L2008700<01`L00PL00`071`061`0300L0008700<01`L0
10L01@071`L000P70P021`0300L700D700<01`000PL00`071`051`0500L71`001@L00`071`051`03
00L0008000<700L00P031`P00`L600P700D01`0700031`0300L7008700<01`L01`L00`071`081`04
00L702L7000E1`0300L700P700<01`L00`L00`071`051`0400L7008700<01`L01`L200T700<01`00
2`L200<700D01`L700091`800PL00`071`051`0400L700T700D01`L700061`0300L000<700<01`L0
10L00`071`021`0300L7008700<01`L01@L200041`001`8000<700000P031`<00`L400051`071`00
1`L00`0700021`0500L71`000`L00`071`071`0300L700P700@01`L09`L001H700<01`L020L00`07
1`021`0300L700H700H01`L01`091`0300L000P700@01`002PL00`0700031`0400L700X700@01`L0
1`L010071`091`800PL00`071`041`0300L000@700<01`L00`L00`071`031`0500L71`0010L30087
1`041`<000<700000`051`0500L71`001PL00`0700031`0500L71`000PL00`071`071`0300L700P7
00@01`L09`L001H700<01`L02@L01@071`L000T700<01`L00P091`0400L700L700@01`002PL01007
1`021`0400L700X700@01`L020L00`0700091`800`L00`071`031`0300L000@700<01`L00`L00`07
1`031`0500L71`000PL200@71P041`8000<7000010071`0500L71`001PL00`0700031`0300L70087
00<01`002@L00`071`081`0400L702L7000G1`0300L700P700D01`L700091`0300L700802@L01007
1`071`0500L01`002@L01@071`L0008700<01`002PL200031`0700P70P091`0300L000<700<01`L0
0PL00`0700051`0300L7008700<01`L010L00`071`0300031`0000<00PL01@071`0700H000@70000
0PL00`071`041`0300L7008700<01`L00`L00`0700041`0700L71`0700091`0300L700P700@01`L0
9`L001P700<01`L020L010071`0:1`0400L700T700D01`L700061`0300L0008700<01`L01PL01@07
1`L000<70P0:1`0400L000X700<01`L01`L010071`031`0700L71`0700061`0500L71`001`L800D7
1P031`<00PL01@071`L000D700<01`L00`L00`071`021`0300L000D700@01`L70P091`0300L700P7
00@01`L09`L001T700<01`L020L00`07000;1`0400L000P700<01`L00PL00`071`031`0300L000<7
00<01`L01@L00`071`021`0300L700802PL01007000:1`0300L700L700D01`L700021`0700L71`07
00061`0500L71`0010L900D71`021`801@L01@071`L000D700<01`L010L01`071`L01`001PL01@07
1`L000T700<01`L020L010071`0W1`006@L00`071`091`802`L01@0700L000L700<01`L00`L00`07
1`021`0300L000<700<01`L01@L00`071`031`0400L700X700@01`L02PL200P700D01`L700031`06
00L700L01`L01@071`0700@00`L200@71`0010L000L200L700<01`L00PL00`071`021`0300L700@7
00L01`L700L000H700D01`L700091`0300L700P700@01`L09`L001X700<01`L020L200`70P000`L0
1`061`0300L700<700<01`L00PL00`0700041`0300L700@700<01`L010L0100700091`0300L70080
2@L00`0700071`0300L7008700T01`L700L01`0020L500@7200010L000021`D000<700L01PL00`07
1`031`0500L71`001`L01P071`0700L700<01`L00P081`0300L700P700@01`L09`L001/700<01`L0
20L00`071`0;1`0400L700H700<01`L010L01`071`L01`001@L00`071`031`0300L700@700D01`07
00081`0600L700L020L010071`061`0300L700<700@01`L70P000`L01`031`L00`L800870P021`@0
0PL2008700<01`L010L00`071`041`0400L700P700D01`0700081`0500L01`001`L00`071`081`04
00L702L7000K1`0300L700P70P0<1`800PL00`071`031`0300L700D700H01`L01`061`0300L70087
00<01`L01@L200031`0700L700H01`L01`081`0400L700H700<01`L00`L010071`L200031`0000<0
00D700001`0800<720031`0300L700800PL00`071`041`0300L700@700@01`L020L01@0700L000T7
0P021`0300L700@700<01`L020L010071`0W1`0070L00`071`071`0300L000/70P031`0300L70087
00<01`L01PL01@0700L000H700<01`L00PL00`071`061`0400L700L700@01`L00PL00`071`051`05
00L71`001@L00`071`041`0300L700@00`L200031`0000H01@L500L700H01`L01`021`0300L700<7
00<01`L01@L00`0700091`8000<700L020L2008700<01`L010L00`071`081`0400L702L7000M1`03
00L700H700<01`002`L00`0700021`0300L7008700<01`L01PL01@0700L000L700D01`L700081`80
0PL00`071`041`0400L700<700<01`L010L00`071`021`0300L7008700<01`L01@L200031`0000L0
0`L300@71@021`0300L700D700@01`L00PL010071`041`0300L700H70P0:1`0300L000X700D01`L7
00051`0300L700P700@01`L09`L001h700<01`L01@L010071`0:1`0400L7008700D01`L700091`80
00<700L01`L010071`081`800PL00`071`041`0400L700<700<01`L010L00`071`031`0500L71`00
10L300031`0700D01@L200031`0000@010L01@071`L000H700@01`L00`L010071`031`0300L700H7
0P0:1`<02PL200<700<01`L00PL00`071`081`0400L702L7000N1`0300L700D700D01`L700091`04
00L700<700@01`L02PL00`0700081`0400L700P700<01`000PL00`071`031`0400L700@700<01`L0
0`L00`071`031`0500L71`000PL200<710000`L01`031`<000<700000`071`0500L71`001PL01007
1`031`0400L700<700<01`L01`L00`071`081`<02PL00`0700021`0300L7008700<01`L020L01007
1`0W1`007`L00`071`041`0300L7008700<01`L01PL01@071`L000<700<01`002PL300T700<01`00
20L010071`021`0300L7008700@01`L01@L00`071`021`0300L700@700<01`L02@0010L000L20003
1`0000L00PL00`071`041`0300L7008700<01`L00`L010071`041`0400L7008700<01`L01`L200T7
00<01`002PL00`0700031`0500L71`002PL010071`0W1`0080L00`071`031`0300L7008700<01`L0
1PL00`071`021`0600L700L02PL300X70P081`0500L71`000PL01@071`L0008700<01`L010L01@07
1`L000L71@0010L000041`0300L000<00`L2008700D01`L700051`0300L700<700<01`L00PL01007
1`051`0600L700L02@L00`0700081`0400L000T700@01`L00`L010071`0:1`0400L702L7000P1`03
00L700<700<01`L00`L00`071`051`0300L700<700<01`L00P0:1`0300L000/700<01`L01PL01@07
1`L0008700D01`L700021`0300L700@700D01`L700041`H000<700001@L500031`0700<010L01@07
1`L000D700<01`L010L01@071`L0008700<01`L010L00`071`0200T700<01`0020L0100700091`05
00L71`000`L00`07000:1`0400L702L7000Q1`0300L7008700<01`L010L00`071`041`0300L700<7
00D01`L7000:1`0400L000X700<01`L01PL00`071`021`0400L7008700@01`L01`L00`071`0500@7
0`031`T000<700001`L00`071`021`0300L7008700<01`L010L01@071`L0008700<01`L010L00`07
1`0200T700@01`L01`L01@0700L000P700<01`L00PL01P071`0700X700@01`L09`L0028700D01`L7
00071`0300L700<700<01`L010L00`071`0200T700D01`0700091`801`L00`071`031`0600L700L0
0PL00`071`051`H010L800031`0000<710021`0300L700@700<01`L00`L01@071`L000L700@01`L0
0PL00`071`051`0400L700T700D01`L700061`0300L0008700<01`L01@L00`071`021`0400L71`80
2PL010071`0W1`008`L010071`071`0300L700<700<01`L01@L0100700091`0500L01`002@L00`07
00061`0300L700@700<01`L00P021`0400L71`@000@700000`L800051`0000L01@000`L000031`03
00L700<700<01`L010L010071`081`0300L0008700<01`L01PL0100700081`0500L71`001PL00`07
00031`0300L700@700<01`L00`L01@071`L000X700@01`L09`L002<700@01`L020L00`071`021`03
00L700H70P000`L01`071`0300L0008700<01`L01PL00`0700061`0300L700@700<01`L00P021`@0
0PL300031`0000H00`L700@700@01`000`L00`071`031`0300L700@700@01`L02@L2008700<01`L0
1PL01@0700L000L700<01`L00PL00`071`031`0300L000<700<01`L010L00`071`041`0400L700X7
00@01`L09`L002@700<01`002@L01@071`L000P70P021`0300L700D700<01`000`L00`071`051`04
00L700D700<01`L01@L00`07000400<70P000`L0000600@71@081`0500L01`000`L00`071`021`03
00L700D700<01`002@L2008700<01`L01`L200031`0700H700<01`L00`L00`071`021`0300L000@7
00<01`L00`L00`071`051`0400L000T700@01`L09`L002D70P0:1`0400L700T700D01`L700061`03
00L000@700<01`L010L01@071`L000@700<01`L01@L200041`001`L00`L300<710001@L01`L000L7
00<01`000PL01@071`L000<700<01`L01PL200X700@01`L02PL010071`061`0300L700@700L01`L7
00L000D700<01`L00PL00`071`051`0500L01`0020L010071`0W1`009PL00`071`081`0400L700T7
0P021`0300L700@700<01`0010L00`071`041`0300L7008700D01`L700041`<00PL700@70`000`L0
000400@700D01`L700061`0300L000<700@01`L00`L00`071`071`0300L700P70P000`L01`091`80
0PL00`071`031`0300L700@700L01`L700L000H700D01`L700081`8000<700L01`L010071`0W1`00
9PL00`071`091`0300L000T70P031`0300L700<700<01`001@L00`071`031`0300L7008700D01`L7
00021`8010L600@70P000`L0000400L700D01`L700061`0300L000<700D01`L700021`0300L700L7
00<01`L020L01007000:1`800`L00`071`021`0300L700D700H01`L01`061`0500L71`002@L01007
1`071`0400L702L7000V1`802`L200T700<01`000`L00`071`021`0300L000H700<01`L00PL00`07
1`031`0300L700<000<7000010001PL01`L01`H000@700000PL00`071`041`0300L7008700<01`L0
0`L00`0700041`0700L71`0700091`802@L01007000:1`0300L0008700<01`L00PL00`071`061`05
00L01`001`L010071`091`800PL00`071`041`0400L702L7000V1`0300L000/700<01`L01`L01007
1`031`0700L71`0700071`0500L71`001PL600041`0000<70P000`L0000200<70P021`0500L71`00
1@L00`071`031`0300L7008700<01`001@L010071`L200T700<01`0020L010071`0:1`0400L70087
00D01`L700091`8000<700L01`L00`0700091`800`L00`071`031`0400L702L7000V1`0300L000/7
00<01`L01`L01@071`L0008700L01`L700L000L700D01`L700031`H00PL200D71P021`<010L01@07
1`L000D700<01`L010L01`071`L01`001PL00`071`0200T700@01`L01`L00`071`0200T700@01`L0
0`L010071`091`8000<700L01`L00`0700091`0300L0008700<01`L00`L010071`0W1`009PL01007
1`0:1`8020L01@071`L000<700H01`L01`081`0300L700D00`L400<71P0010L000L200L700<01`L0
0PL00`071`021`0300L700@700L01`L700L000H700D01`L700091`0400L700L700H01`L01`081`05
00L71`000`L00`07000:1`0300L000T70P091`0400L7008700<01`L00PL010071`0W1`009PL01@07
1`L000T700<01`001`L00`071`021`0900L71`0700L000P71@051`<000<700001@021`D000<700L0
1PL00`071`031`0500L71`001`L01P071`0700L700<01`L00P081`0500L71`001PL01P071`0700P7
00<01`L00PL01P071`0700X70`0:1`0300L700L700D01`L700021`0500L71`000PL00`071`0U1`00
9PL00`071`021`0300L700H700@01`L01PL00`071`031`0400L71`8000<700L00`L8008720021`80
0PL400870P021`0300L700@700<01`L00`L01@071`L000P700D01`0700081`0400L000P700<01`L0
0PL00`071`031`0400L7008700<01`L01@L00`071`031`0300L700802PL300X70P081`0500L71`00
0PL01@071`L0008700<01`L09@L002H700<01`L00PL00`071`061`0400L700H700<01`L00`L01007
1`L200031`0000<000@700000PL800<71`031`0300L700800PL00`071`041`0300L700@700@01`L0
20L01@0700L000T70P000`L01`061`0300L700<700<01`L00PL010071`031`0300L700@700<01`L0
0`L01@071`L000X700<01`002PL200P700<01`L00PL010071`021`0400L702L7000V1`0300L700<7
00<01`L01@L01@071`L000D700<01`L010L010071`L300<70P000`L0000200041`0000D71@071`06
00L700L00PL00`071`031`0300L700D700<01`002@L200031`0700P70P021`0300L700@700<01`L0
0`L00`071`021`0400L700@700<01`L00`L00`071`041`0300L700802@L0100700091`0300L000L7
00<01`L00`L01P071`07008700<01`L09@L002H700<01`L010L00`071`041`0300L7008700<01`L0
0PL00`071`051`0400L71`P01PL010071`L400<700<01`L01@L010071`021`0400L700@700<01`L0
1@L00`07000:1`0300L000X700D01`L700051`0300L700@700D01`L700021`0300L7008700<01`L0
0`L00`071`051`0400L000T700D01`0700081`0400L700H700<01`L010L00`071`02008700<01`L0
9@L002H700<01`L010L00`071`041`0300L700<700D01`L700081`0300L700@02PL400P700<01`L0
10L010071`031`0300L000@700<01`L01PL200X70`0:1`800PL00`071`031`0300L700D700@01`L0
0PL00`071`031`0300L7008700<01`L01PL200031`0700L700D01`0700081`0400L700H700<01`L0
10L00`071`02008700<01`L09@L002H700<01`L01@L00`071`031`0300L700<700D01`L700071`@0
00<700L01`L600X700<01`L010L010071`031`0400L700<700<01`L01`L00`071`081`<02PL00`07
00021`0300L7008700<01`L01PL00`0700021`0300L700@700D01`L700081`800PL00`071`051`03
00L0008700<01`L01@L01@071`L000D700<01`L01@L0100700021`0300L702D7000V1`0300L700H7
00<01`L00PL00`071`041`0400L700871P0010L01`L2008720031`0300L700P700<01`L00`L01007
1`041`0400L7008700<01`L01`L200T700<01`002PL00`0700031`0500L71`0020L00`0700021`03
00L700D700@01`L02@L01@071`L000H700<01`000`L00`071`041`0300L7008700<01`L00PL00`07
1`051`8010L00`071`0U1`009PL00`071`071`0500L71`001`L500041`0000@700<01`000`031`80
1`L00`071`081`0300L7008700@01`L01@L01P071`0700T70P091`0400L000T700@01`L00`L01007
1`091`800PL00`071`051`0400L700T70P021`0300L700@700<01`000`L00`071`041`0300L700<7
00D01`L700041`<00PL01@071`L002L7000V1`0300L700L700D01`L700041`H000<700001@L50003
1`0700<02@L00`071`091`0500L71`000PL00`071`031`0600L700L02@L00`0700081`0400L000T7
00D01`L700021`0400L700X700@01`L020L00`0700091`800`L00`071`031`0300L000@700<01`L0
0`L00`071`031`0500L71`000PL200D700D01`L7000W1`009PL00`071`081`0300L700D010L300<7
10031`8000<700003@L00`071`081`0500L71`000PL00`071`041`0300L700802@L010071`071`05
00L01`0020L00`071`021`0600L700L02PL200031`0700P70P091`0300L000<700<01`L00PL00`07
00051`0300L7008700<01`L010L00`071`0300P700@01`L09`L002H700<01`L020L400H70P000`L0
000300P70P021`0300L700/700<01`L020L010071`021`0300L700D700@01`L02@L010071`071`03
00L0008700<01`L01@L00`071`021`0400L71`802PL200031`0700T700<01`L01`L010071`031`07
00L71`0700061`0500L71`001`L300/700<01`009`L002H700<01`L010L400870P031`L03@L01007
1`0=1`0300L700T700<01`000PL00`071`051`0300L7008020L01@071`L000H700<01`000`L00`07
1`041`0300L700<700<01`L00P0:1`0400L000X700<01`L01`L01@071`L0008700L01`L700L000H7
00D01`L700041`<000<7000030L202L7000V1`0300L700@01PL200031`0000<04@L01@071`L000d7
00<01`L020L00`0700021`0300L700H700@01`0020L00`071`021`0300L700<700<01`000`L00`07
1`041`0300L700@700@01`L02PL010071`0:1`8020L01@071`L000<700H01`L01`071`0400L70087
0P041`8030L202L7000V1`<02`L301H700D01`L7000=1`0300L700P70P021`0300L700L70P000`L0
1`061`0300L700<700<01`L00PL00`0700041`0300L700<700<01`L01@L0100700091`0300L70080
2@L00`0700071`0300L7008700T01`L700L01`0020L00`07000200D70`0;1`<09`L004h700@01`L0
3@L00`071`091`0400L700X700@01`L01PL00`071`031`0300L7008700<01`001@L00`071`021`03
00L700D700D01`0700081`0300L700802@L010071`061`0300L700<700@01`L70P000`L01`071`<0
0`L500T7100Z1`00C`L010071`0=1`0300L700P70P000`L01`091`0400L700H700<01`L010L01`07
1`L01`001PL01@071`L000P70P000`L01`071`0600L700L020L010071`061`0300L700<700@01`L7
0P000`L01`041`<000<700001P071`@0;PL004l700D01`L7000=1`0300L700L70P000`L01`091`80
0PL00`071`031`0300L700D700H01`L01`061`0500L71`002@L010071`071`0400L7008700<01`L0
1@L01@071`L000D700<01`L010L00`071`0200031`0700870P000`L0000300031`0000H7100b1`00
D0L01@071`L000d700<01`L01PL01007000:1`0300L0008700<01`L00PL00`071`051`0600L700L0
1`L010071`091`800PL00`071`041`0400L700<700<01`L010L00`071`021`0300L7008700<01`L0
1@L200<71`031`<010L403H7001A1`0400L700d700<01`L01PL010071`0:1`0300L000<700D01`L7
00081`0500L01`0020L00`0700091`800PL00`071`041`0400L700<700<01`L010L00`071`031`05
00L71`0010L300041`071`@01@L200<7100j1`00DPL010071`0=1`0300L700D700<01`L00P091`04
00L7008700D01`L700091`8000<700L01`L00`0700091`0300L0008700<01`L00`L010071`041`03
00L700<700<01`L00`L01@071`L000870P031`@000<700L00`L300031`000080?PL0058700D01`L7
000=1`0300L700@700<01`L00P091`0500L71`000PL010071`0:1`0300L000T70P091`0400L70087
00<01`L00PL010071`051`0300L7008700<01`L010L00`071`0900051`071`000PL60487001C1`04
00L700d700<01`L010L01P071`0700P700<01`L00PL01P071`0700X700<01`002PL00`071`071`05
00L71`000PL01@071`L0008700<01`L010L01@071`L000L71@0010L000041`0300L000<0A`L005@7
00@01`L03@L00`071`031`0400L7008700<01`L01@L00`071`021`0400L71`802PL300X70P081`05
00L71`000PL01@071`L0008700<01`L010L01@071`L000@71P000`L000051`D0BPL005@700D01`L7
000=1`0300L7008700@01`L00PL00`071`051`0300L700<700<01`L00P0:1`0300L000X70P081`03
00L7008700@01`L00PL010071`071`0300L700H00`L300<71P000`L0001:1`00E@L01@071`L000d7
00D01`L700021`0500L71`001PL00`071`041`0400L700X700<01`002PL00`0700071`0300L700<7
00H01`L01`021`0300L700D71P041`P000<7000010L204X7001F1`0400L700d700D01`L700021`03
00L7008700<01`L00`L00`071`041`0300L700802@L0100700091`0400L700H700<01`L010L00`07
1`02008700@01`L7100010L000031`L00PL30087101<1`00E`L010071`0=1`0400L7008700<01`L0
0`L00`071`021`0300L700D700D01`0700081`0500L01`0020L010071`061`0300L700@700<01`L0
0P021`@00`L200031`0000H010L200031`000080D0L005L700D01`L7000=1`0300L0008700<01`L0
0`L00`071`021`0300L700H70P000`L01`071`0500L01`0020L01@071`L000D700<01`L01@L00`07
000400<70`000`L0000500@71P1D1`00F0L010071`0=1`0300L0008700<01`L010L01@071`L000T7
00@01`L01`L00`0700021`0300L700D700<01`L00PL00`071`021`0300L700D70P041`0300L000D0
0`L200@7101H1`00F@L010071`0=1`800PL00`071`051`0400L700T700D01`L700061`0300L000<7
00<01`L010L00`071`031`0500L71`001@L2008700@01`L710041`<00PL405`7001J1`0400L700d7
00@01`L020L00`0700091`800PL00`071`041`0300L000@700<01`L00`L00`071`031`0500L71`00
0PL300@71@051`8000<700000`1O1`00FPL01@071`L000`70P000`L01`071`0300L000T700<01`00
0PL00`071`031`0300L000@700<01`L00`L00`071`041`0300L700<00`L6008700<01`L02@1Q1`00
F`L010071`0<1`8000<700L020L200T700<01`000`L00`071`021`0300L000D700<01`L00PL00`07
1`051`<00PL600<700<01`0010021`80I0L005`700@01`L02`L01007000:1`0300L700L700@01`L0
0`L01`071`L01`001PL01@071`L000D70P000`L0000200031`0000H710021`<0IPL005`700D01`L7
000:1`0400L700X70P081`0500L71`000PL01`071`L01`001PL01@071`L000<72P041`@000@70007
0P1Y1`00G@L010071`0:1`0400L700X70P081`0500L71`000`L01P071`0700L700<01`L01@041`80
0`L600<70`1[1`00GPL010071`091`0300L700802@L00`0700071`0300L7008700T01`L700L01`00
1`L400@710000`L0000200031`000087101^1`00G`L010071`081`0600L700L020L010071`061`03
00L700<700@01`L70P000`L01`021a400`L60787001O1`0400L700P700H01`L01`081`0400L700H7
00<01`L010L00`071`0200031`00008000@7000710000`L0000200@71@1f1`00H0L010071`071`04
00L7008700<01`L01@L01@071`L000D700<01`L010L010071`L300871@031`801@L407X7001Q1`04
00L700H700@01`L00`L00`071`041`0300L7008700<01`L00PL00`071`051`0300L7008710041`<0
0`L507d7001R1`0400L700D700@01`L010L00`071`031`0300L700<700D01`L700081`D01@L20087
1P201`00HPL010071`051`0400L700@700<01`L00`L00`071`031`0500L71`0010L6008700@01`L7
1P0010L000221`00H`L010071`041`0400L700D700<01`L00PL00`071`041`0500L700L00`000`L0
00021`0300L700H00`L208D7001T1`0400L700<700@01`L01PL01@071`L000L710021`801@L500@7
0P271`00I@L00`0700031`0400L700H700D01`L700031`@000<700000`041`H00`L308T7001U1`04
00L7008700@01`L01`L00`071`0400D70P031`D00`L200031`0008`7001V1`0600L700L00PL00`07
1`041`D01@L300031`00008000<700001PL208h7001W1`0300L700800PL00`071`0400<70P031`H0
0PL309P7001W1`0300L7008000<700000P071`8000<700000P041`80V`L006P700<01`L00P000`L0
1`091`801@L309d7001Y1`0300L7008700<01`L03@L20:07001Z1`0500L71`003@L20:87001Z1`05
00L71`002PL30:@7001[1`0400L700P70P2W1`00K0L00`0700051`<0Z@L006d70P031`80[0L006d7
0P000`L0002^1`00KPL20;07003o1b47003o1b47003o1b47003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {278.5, 0}} -> {-10.4011, -10.0949, 0.0724844, \
0.0724844}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[144]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["j = 3, k =2", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AL032, Axes \[Rule] True, Prolog \[Rule] PointSize[0.025], 
      PlotRange \[Rule] \ {{\(-20\), 20}, {\(-20\), 20}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[145]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.5 0.025 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -9 -9 ]
[.125 .4875 9 0 ]
[.25 .4875 -9 -9 ]
[.25 .4875 9 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -6 -9 ]
[.75 .4875 6 0 ]
[.875 .4875 -6 -9 ]
[.875 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -12 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -12 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-20)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-15)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-10)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(10)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(15)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(20)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-20)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-15)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-10)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(10)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(15)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(20)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.025 w
.62565 .1134 Mdot
.66428 .16656 Mdot
.70291 .21973 Mdot
.74153 .2729 Mdot
.78016 .32606 Mdot
.81879 .37923 Mdot
.85741 .43239 Mdot
.89604 .48556 Mdot
.93467 .53872 Mdot
.9733 .59189 Mdot
.56315 .13371 Mdot
.60178 .18687 Mdot
.64041 .24004 Mdot
.67903 .2932 Mdot
.71766 .34637 Mdot
.75629 .39954 Mdot
.79491 .4527 Mdot
.83354 .50587 Mdot
.87217 .55903 Mdot
.9108 .6122 Mdot
.94942 .66536 Mdot
.50065 .15401 Mdot
.53928 .20718 Mdot
.57791 .26035 Mdot
.61653 .31351 Mdot
.65516 .36668 Mdot
.69379 .41984 Mdot
.73241 .47301 Mdot
.77104 .52617 Mdot
.80967 .57934 Mdot
.8483 .63251 Mdot
.88692 .68567 Mdot
.43815 .17432 Mdot
.47678 .22749 Mdot
.51541 .28065 Mdot
.55403 .33382 Mdot
.59266 .38698 Mdot
.63129 .44015 Mdot
.66991 .49332 Mdot
.70854 .54648 Mdot
.74717 .59965 Mdot
.7858 .65281 Mdot
.82442 .70598 Mdot
.37565 .19463 Mdot
.41428 .24779 Mdot
.45291 .30096 Mdot
.49153 .35413 Mdot
.53016 .40729 Mdot
.56879 .46046 Mdot
.60741 .51362 Mdot
.64604 .56679 Mdot
.68467 .61995 Mdot
.7233 .67312 Mdot
.76192 .72629 Mdot
.31315 .21494 Mdot
.35178 .2681 Mdot
.39041 .32127 Mdot
.42903 .37443 Mdot
.46766 .4276 Mdot
.50629 .48077 Mdot
.54491 .53393 Mdot
.58354 .5871 Mdot
.62217 .64026 Mdot
.6608 .69343 Mdot
.69942 .74659 Mdot
.25065 .23524 Mdot
.28928 .28841 Mdot
.32791 .34158 Mdot
.36653 .39474 Mdot
.40516 .44791 Mdot
.44379 .50107 Mdot
.48241 .55424 Mdot
.52104 .6074 Mdot
.55967 .66057 Mdot
.5983 .71374 Mdot
.63692 .7669 Mdot
.18815 .25555 Mdot
.22678 .30872 Mdot
.26541 .36188 Mdot
.30403 .41505 Mdot
.34266 .46821 Mdot
.38129 .52138 Mdot
.41991 .57455 Mdot
.45854 .62771 Mdot
.49717 .68088 Mdot
.5358 .73404 Mdot
.57442 .78721 Mdot
.12565 .27586 Mdot
.16428 .32902 Mdot
.20291 .38219 Mdot
.24153 .43536 Mdot
.28016 .48852 Mdot
.31879 .54169 Mdot
.35741 .59485 Mdot
.39604 .64802 Mdot
.43467 .70118 Mdot
.4733 .75435 Mdot
.51192 .80752 Mdot
.06315 .29617 Mdot
.10178 .34933 Mdot
.14041 .4025 Mdot
.17903 .45566 Mdot
.21766 .50883 Mdot
.25629 .56199 Mdot
.29491 .61516 Mdot
.33354 .66833 Mdot
.37217 .72149 Mdot
.4108 .77466 Mdot
.44942 .82782 Mdot
.00065 .31647 Mdot
.03928 .36964 Mdot
.07791 .42281 Mdot
.11653 .47597 Mdot
.15516 .52914 Mdot
.19379 .5823 Mdot
.23241 .63547 Mdot
.27104 .68863 Mdot
.30967 .7418 Mdot
.3483 .79497 Mdot
.38692 .84813 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[145]:=",
  ImageSize->{239, 239},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003_0000k`P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc>l7003_1`00k`L00>l7003_1`00k`L006X7
10031`80O0L006X700<01`L00`L010071`1k1`00J`L00`071`021`0400L700@70P1e1`00I0L400@7
00D01`L700021`0300L7008700<01`L0M0L006d700@01`L00PL00`071`021`0300L707@7001Z1`04
00L7008700@01`L010L00`071`1d1`00J`L200@70P051`0300L707@7001h1`0300L707@7001h1`80
M@L007P700<01`L0M0L007P700<01`L0M0L007P700<01`L0M0L007P700<01`L0M0L007P70P1e1`00
N0L00`071`1d1`00N0L00`071`1d1`00N0L00`071`1d1`00N0L00`071`1d1`00N0L00`071`1d1`00
N0L207D7001h1`0300L707@7001h1`0300L707@7001h1`0300L707@7001h1`0300L707@7001h1`80
M@L007P700<01`L0M0L007P700<01`L060L405P7001h1`0300L701P7101H1`00JPL400870`051`03
00L701P7101H1`00K0L00`071`041`0300L7008700<01`L060L405P7001/1`0300L700@700<01`L0
0PL200/7101V1`00I0L400@700@01`L70`051`0300L700X7101V1`00K0L01@071`L000L700<01`L0
2PL406H7001Z1`<00`L00`071`051`0300L700X7101V1`00K0L010071`L400@700<01`L0M0L007L7
101d1`00M`L407@7001g1`@080L40507001g1`@080L40507001Y1`@02`L00`071`0P1`@0D0L006T7
100;1`0300L70207101@1`00J@L400/70P1e1`00J@L400/700<01`L04PL405h7001h1`0300L70187
101N1`00F`L401T700<01`L04PL405h7001K1`@06@L00`071`0B1`@0GPL005/7100I1`0300L700D7
101[1`00F`L401T70P061`@0J`L004d7100W1`0300L700D7101[1`00C@L402L700<01`L01@L40207
10171`00C@L402L700<01`L0:@L404L7001=1`@08@L4008700<01`L0:@L404L7001b1`@00PL202X7
10171`00?`L402l710021`0300L707@7000o1`@0;`L4008700<01`L06`L405D7000o1`@0=@L00`07
1`0K1`@0E@L003l7100Q1`@00PL400<70P051`0300L701/7101E1`00<@L402l710041`0500L71`00
0PL00`071`021`0300L701/7101E1`00<@L402l710041`0500L71`000PL00`071`021`803PL406<7
000a1`@0;`L400@700D01`L700021`0300L7008700<01`L03@L406<7000a1`@08@L4018700D01`L7
00021`0300L7008700<01`L03@L406<7001F1`@040L300<700@01`L010L00`071`0=1`@08@L403h7
000S1`@0;`L4018700<01`L00PL200D700<01`L0<PL403h7000S1`@0;`L401h71P0_1`@0?PL002<7
101A1`0300L000<0;`L403h7000S1`@08@L402`700<01`000`1a1`005@L402l7100/1`0300L000<0
8@L404`7000E1`@0;`L4020710081`0300L702@7101<1`005@L402l7100P1`@020L00`071`0T1`@0
C0L001D7100Q1`@0;PL400P70P0U1`@0C0L003X7100^1`@020L00`071`0F1`@0FPL000L7100_1`@0
>PL00`071`0F1`@0FPL000L7100_1`@080L401H700<01`L05PL405X700071`@0D`L401H700<01`L0
5PL40207100f1`001`L40247100^1`@05PL203/7100f1`00;0L402h7100F1`0300L700P7100^1`@0
=PL002`7100P1`@090L00`071`081`@0;PL403H7000/1`@080L402@700<01`L020L4020710141`00
7PL402h7100T1`0300L700P7100P1`@0A0L001h7100^1`@08@L402h710141`007PL405<71@0]1`@0
A0L001h7100P1`@0;`L407H700121`@0;`L40207101B1`0040L402h7100b1`0300L701h7101B1`00
40L402h7100Q1`@01@L300D700<01`L07PL40587000@1`@08@L402h710081`0300L7008700<01`L0
7PL40247100]1`0040L40247100^1`@020L00`071`021`80A0L402d7000e1`@0;PL700870`051`03
00L70107100_1`@0;@L003D7100P1`@04`L00`071`051`0300L70107100_1`@0;@L005T7100C1`03
00L700D700<01`L040L40247100k1`009`L402h7100C1`@010L00`071`0@1`@08@L403/7000W1`@0
;PL401/70P031`@0;`L403/7000W1`@0C@L00`071`021`@0;`L403/7000W1`@080L402T700<01`L0
0PL406h7001;1`@0:@L00`071`021`@08@L404T7000I1`@0;PL402T700<01`L09`L404T7000I1`@0
;PL4024710041`0300L702L710191`006@L40207100_1`@010L202P7100P1`@09@L001T7100P1`@0
;`L400@700<01`L06@L402h7100U1`00?@L402l710041`0300L701T7100^1`@09@L003d7100Q1`@0
4PL00`071`0I1`@0;PL402D7001R1`@04PL00`071`0I1`@08@L40387000_1`@0;`L401870P0o1`@0
<PL002l7100_1`@04PL00`071`0;1`@0;`L4038700071`@00`L2018710021`<010L400/710031`80
5PL301P700<01`L02`L400P70`0F1`@00`L200D7100:1`@00PL301<710031`800`L000L700<01`L0
0`L010071`0C1`0300L700@700@01`L7100=1`0500L71`000PL00`071`0:1`@020L00`071`0E1`03
00L700/7100;1`0300L701D700D01`L700021`0300L7018700<01`L010L00`071`0@1`0300L700<7
00@01`L00PL000P700<01`L00PL010071`0@1`@01PL00`071`0B1`0500L71`000PL00`071`0:1`@0
20L00`071`0E1`0300L700/7100;1`0300L701<710021`0400L701@700<01`L010L00`071`0A1`03
00L7008700@01`L00PL000031`00008010L01@071`L0008700<01`L02@L400031`0000800`L300d7
10041`0500L71`000PL00`071`0:1`L00PL301P7100F1`<05PL4008700@01`L050L010071`L301D7
00D01`L700021`400@L11`002PL010071`021`0300L700h710031`0300L701D700D01`L700021`03
00L700X710051`0300L701P7100F1`0300L701H710021`0400L701@700D01`L7000H1`0400L70087
0@011`4700071`0400L7008700@01`L040L400<700<01`L04`L300<700<01`000`0C1`0300L701P7
100F1`0300L701H710021`0400L701870`031`0300L000<040L010071`021`0400L7008700081`80
10L201@700@01`L7100D1`0300L700871@0C1`@05`L401H710071`@030L00`071`021`805@L01007
1`L601470P041`800`L004H7100^1`0300L70287100^1`@070L004H7100P1`@02PL00`071`0R1`@0
;PL401`700091n001PL000T700<01`L00PL00`071`031`0300L7008700<01`L00`L00`071`021`03
00L700<700<01`L00`L00`071`021`0300L700@010L00`071`031`0300L7008700<01`L00`L00`07
1`031`0300L7008700<01`L00`L00`071`021`0300L700@010L00`071`031`0300L700<700<01`L0
0PL00`071`031`0300L7008700<01`L00`L00`071`021`0300L700<700<01`L00`L00`071`021`03
00L700<700<01`L00PL00`071`031`0300L700871@000`L01`041`0300L7008700<01`L00`L00`07
1`021`0300L700<700<01`L00`L00`071`041`002@L00`071`0H1`0300L7014710041`0300L701T7
00<01`L02`L400X700<01`L050L400031`0701X700<01`L03PL400L700<01`L06@L00`071`041`00
>0L403`700<01`L050L402h7100Z1`00>0L40207100H1`0300L701@7101L1`00:PL402h7100H1`03
00L701@7100P1`@0>0L002X7100^1`@060L200L7100^1`@0>0L002X7100^1`@060L00`071`061`@0
;PL40247100C1`00:PL40207100V1`0300L700H7100^1`@08@L401<7001>1`@09PL00`071`061`@0
80L402l7100C1`00CPL402H700<01`L0:PL402l7100C1`00CPL4024710000`L01`0[1`@0APL007<7
10000`L0000[1`@08@L4024700101`@0;`L400031`070507100Q1`00@0L402l710000`L01`0M1`@0
;`L4024700101`@08@L400l700<01`L070L402l7100Q1`00@0L40247100?1`0300L701`7100Q1`@0
;`L00387100_1`@03`L201d7100Q1`@0;`L00387100_1`@03`L00`071`0>1`@0;`L402l7000b1`@0
@PL00`071`0>1`@0;`L40207100;1`00<PL40247100M1`0300L700h7101C1`@02`L005L7100M1`03
00L700h7100Q1`@0;PL400/7001G1`@07@L00`071`0c1`@0;PL400/7001G1`@07@L200031`000080
;`L403d700191`@0:`L00`071`0402l7100P1`@06@L004T7100[1`0300L700@08@L402h7100I1`00
B@L402<70`051`0300L700@08@L402h7100I1`00B@L4024710000`L01`031`0300L702D7100^1`@0
6@L006h710000`L01`031`809PL40207100W1`00>`L402l71@051`0300L704T7100W1`00>`L402l7
10061`0300L701L7100^1`@09`L003/7100a1`0300L700D700<01`L05`L402h7100W1`00>`L40247
100<1`@010L00`071`0G1`@0F@L00607100D1`0300L701L7100P1`@0=@L00607100D1`80?0L403D7
001P1`@050L00`071`091`@0;PL403D7001B1`@08PL00`071`091`@0;PL40247100@1`00DPL40287
00<01`L02@L40247100^1`@040L00587100R1`0300L700T7100Q1`@0;PL40107001B1`@080L402l7
100^1`@040L007H7100_1`@080L401h700141`@0;PL405<7100N1`00A0L402h7100Q1`@0;PL401h7
00141`@0<0L00`071`0P1`@0;PL401h700141`@080L400`700<01`L080L40507001X1`@030L20247
100P1`@0;0L006P7100<1`0300L70187100^1`@0;0L006P7100<1`0300L70187100^1`@0;0L005X7
100J1`0300L70187100^1`@0;0L005X7100J1`0300L70187100P1`@0>PL005X7100J1`0300L703H7
100j1`00FPL401X70P051`@0;PL403X7001h1`0300L700@7100^1`@0>PL004`7100X1`0300L700@7
101/1`00C0L401X710031`801@L00`071`041`@080L404P7001<1`@070L010071`L500<700<01`L0
:0L404P7001<1`@070L010071`L500<70P0Y1`@0B0L006`700@01`L71@031`0300L702P710181`00
K0L010071`L500<700<01`L06PL405H7001Z1`<00`L010071`041`0300L701X7101F1`00H`L400D7
00<01`L00PL200D700<01`L06PL405H7001S1`@04@L00`071`0J1`@0EPL006<7100A1`80M@L006<7
100A1`0300L700`7101T1`00N0L00`071`0<1`@0I0L005D7100O1`0300L700`7101T1`00E@L401l7
00<01`L030L406@7001E1`@07`L50787001E1`@07`L50787001h1`D0LPL007P71@1b1`00N0L00`07
1`1d1`00J`L400T700<01`L0M0L006/710091`80M@L006/710091`0300L707@7001[1`@02@L00`07
1`1d1`00GPL401H700<01`L0M0L005h7100F1`0300L707@7001N1`@05PL00`071`1d1`00GPL401H7
0P1e1`00N0L00`071`1d1`00N0L00`071`1d1`00JPL400870`051`0300L707@7001/1`0300L700@7
00<01`L00PL00`071`1d1`00K0L00`071`041`0300L700870P1e1`00K0L010071`L300D700<01`L0
M0L006`700D01`L700071`0300L707@7001Z1`<00`L00`071`051`0300L707@7001/1`0400L71`@0
10L00`071`1d1`00N0L00`071`1d1`00N0L207D7001h1`0300L707@7001h1`0300L707@7001h1`03
00L707@7001h1`0300L707@7001h1`80M@L007P700<01`L0M0L007P700<01`L0M0L007P700<01`L0
M0L007P700<01`L0M0L007P700<01`L0M0L007P70P1e1`00N0L00`071`1d1`00N0L00`071`1d1`00
N0L00`071`1d1`00N0L00`071`1d1`00N0L207D7001h1`0300L707@7001h1`0300L707@7001h1`03
00L707@7001Z1`@00`L200D700<01`L0M0L006X700<01`L00`L010071`041`0300L707@7001[1`03
00L7008700@01`L010L207D7001/1`0500L71`000PL00`071`1i1`00K@L010071`021`0300L707T7
001Z1`0400L7008700@01`L0N`L006/70P041`80O0L00>l7003_1`00k`L00001\
\>"],
  ImageRangeCache->{{{0, 238}, {238, 0}} -> {-21.6146, -21.3455, 0.179374, \
0.179374}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[145]="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(basis32 = 
      FullSimplify[{A[3, 2, \[Alpha]] /. {m \[Rule] 1, n \[Rule] 0}, 
          A[3, 2, \[Alpha]] /. {m \[Rule] 0, 
              n \[Rule] 1}}]\), "\[IndentingNewLine]", 
    \(orig\  = \ 
      FullSimplify[
        A[3, 2, \[Alpha]] /. {m \[Rule] 0, n \[Rule] 0}]\)}], "Input",
  CellLabel->"In[146]:="],

Cell[BoxData[
    \({{\(-2.2485364745084375`\), 
        0.04290080768728155`}, {1.7965484973662997`, 
        1.3572285879851154`}}\)], "Output",
  CellLabel->"Out[146]="],

Cell[BoxData[
    \({0.2514635254915625`, \(-0.7693984328949843`\)}\)], "Output",
  CellLabel->"Out[147]="]
}, Open  ]],

Cell[BoxData[
    \(\(rad32\  = \ \@\(\((basis32[\([1]\)]\  - \ orig)\) . \
\((basis32[\([1]\)]\  - \ orig)\)\);\)\)], "Input",
  CellLabel->"In[148]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AppendTo[basis32, orig], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-10\), 10}, {\(-10\), 10}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[149]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.38757 .50215 Mdot
.58983 .56786 Mdot
.51257 .46153 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[149]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L0088710031`80U@L008@700D01`L700021`0300L7098700241`0500L71`000PL00`07
1`031`80S@L007`710041`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`07
1`031`0300L708`700221`<00`L010071`051`0300L708`700241`0300L700870P061`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L007d700<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<7
00<01`L0S0L007h700<01`L02PL00`071`031`80S@L007H710041`0300L700L70`061`0300L708`7
001o1`0300L700H700<01`L01PL00`071`2<1`00O0L010071`081`0300L700H700<01`L0S0L007`7
10081`@01@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`700281`<01PL00`071`2<1`00R`L00`071`031`0300L708`7
002;1`0300L700<70P2=1`00PPL400870`061`0300L708`700281`0300L700H700<01`L0S0L008P7
00<01`L01PL00`071`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00O0L400<700<01`L00PL300H7
00<01`L0S0L007`700<01`L030L00`071`031`0300L708`7001m1`0300L700/700<01`L00`L208d7
001f1`@010L00`071`071`<01PL00`071`2<1`00O`L00`071`061`0300L700H700<01`L0S0L007`7
00@01`L020L00`071`061`0300L708`7001m1`802@L400D700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`L0R0L009072P261`00T0L:08H7002?1``0Q@L008l730251`00S`L<08D7
00071`@00`L201L700<01`L00`L00`071`021`<06@L301T710031`0300L700870`0F1``040L400<7
00<01`L00PL301T70`0J1`0300L700<700<01`L00PL301H710031`800`L000T700D01`L700021`03
00L701@700<01`L02`L00`071`0I1`0300L701H700<01`L030L00`071`0C1``040L00`071`0<1`03
00L701T700<01`L05`L00`071`0;1`0300L701D700D01`L700021`400@L11`002@L01@071`L00087
00<01`L05@L00`071`0:1`0300L701T700<01`L05`L00`071`0;1`0300L701<7300A1`0300L700/7
00<01`L06@L00`071`0H1`0300L700X700<01`L05@L01@071`L000870@011`4700000`L0000200@7
00D01`L700021`0300L700d710041`0300L700L70`0C1`@00PL301<710041`0300L700L70`0G1`X0
4`L00`071`071`<06@L301/700<01`L01`L301P700D01`L700021`400@L11`002@L01@071`L00087
00<01`L05PL00`071`061`0300L701T700<01`L070L00`071`061`0300L701L72P0D1`0300L700H7
00<01`L06@L00`071`0L1`0300L700H700<01`L060L01@071`L000870@011`4700071`<00`L01007
1`0E1`0400L700P700<01`L06@L00`071`0I1`0400L700871`0J1`L04`L010071`081`0300L701T7
00<01`L06@L010071`081`0300L701H70`031`0400L7008700091`0300L700870P0F1`@020L401P7
100I1`8000<700002P0G1`0300L701P70P091`@060L401P710081`@05`L00`071`021`800`L006h7
2P0I1`0300L708`7001]1``060L00`071`2<1`00K@L<01P700<01`L0S0L000T7o`0B00H700091`03
00L700<700<01`L010L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@700<01`L0
10L00`071`041`0300L700@700<01`L00`L00`071`041`0300L700@700<01`L010L00`071`021``0
0`L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@700<01`L010L00`071`041`03
00L700@700<01`L00`L00`071`041`0300L700@700<01`L010L00`071`041`0300L700<700<01`L0
10L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@700<01`L010L00`071`041`03
00L700@700<01`L010L000T700<01`L07`L00`071`0O1`0300L701d7300H1`0300L701l700<01`L0
7`L00`071`0O1`0300L701l700<01`L010L006d7300H1`0300L708`7001^1`X06@L00`071`2<1`00
KPL:01T700<01`L0S0L007071P0K1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L04`L607<7002A1`80
4PL:0747002A1`0300L701472P1a1`00T@L00`071`0@1``0L0L0094700<01`L040L<0707002A1`03
00L70107301`1`00T@L00`071`0@1``0L0L009470P0A1``0L0L0094700<01`L040L<0707002A1`03
00L701472P1a1`00T@L00`071`0A1`X0L@L0094700<01`L04`L607<7002A1`0300L708`7002A1`03
00L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L007`710031`0300L700870`061`0300L708`7001l1`0300L700`700<01`L00`L00`071`2<1`00
O@L00`071`0;1`0300L700<70P2=1`00OPL00`071`071`<01PL00`071`2<1`00O`L00`071`061`03
00L700H700<01`L0S0L007`700@01`L020L00`071`061`0300L708`7001m1`802@L400D700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80
S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00R0L300H700<01`L0S0L008/700<01`L00`L00`071`2<1`00R`L00`071`031`80
S@L008P70`061`0300L708`700281`0300L700H700<01`L0S0L008P700<01`L01PL00`071`2<1`00
R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00O@L00`071`031`0300L700870`061`0300L708`7001m1`03
00L700/700<01`L00`L00`071`2<1`00OPL00`071`0:1`0300L700<70P2=1`00OPL00`071`071`<0
1PL00`071`2<1`00O`L00`071`061`0300L700H700<01`L0S0L007`700@01`L020L00`071`061`03
00L708`7001l1`@020L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00PPL400<70P061`0300L708`700241`05
00L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`071`031`80S@L008@700D01`L7
00021`0300L7098700241`0500L71`000PL00`071`2B1`00PPL300<700@01`L0U0L008@700<01`L0
0PL209D7003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.6619, -10.5516, 0.0735301, \
0.0735301}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[149]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice032\  = 
      tiling2D[SphericalCut[N[AL032], 10], \ rad32\ ]\)], "Input",
  CellLabel->"In[150]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00251 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.486761 0.0526463 0.485782 0.0526463 [
[ 0 0 0 0 ]
[ 1 1.00251 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00251 L
0 1.00251 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.73216 .09306 m
.8135 .20502 L
s
.73216 .09306 m
.60055 .13583 L
s
.8135 .20502 m
.89485 .31698 L
s
.8135 .20502 m
.68189 .24779 L
s
.89485 .31698 m
.97619 .42894 L
s
.89485 .31698 m
.76323 .35975 L
s
.97619 .42894 m
.84457 .47171 L
s
.5192 .02387 m
.60055 .13583 L
s
.5192 .02387 m
.38759 .06663 L
s
.60055 .13583 m
.68189 .24779 L
s
.60055 .13583 m
.46893 .17859 L
s
.68189 .24779 m
.76323 .35975 L
s
.68189 .24779 m
.55027 .29055 L
s
.76323 .35975 m
.84457 .47171 L
s
.76323 .35975 m
.63162 .40251 L
s
.84457 .47171 m
.92592 .58366 L
s
.84457 .47171 m
.71296 .51447 L
s
.92592 .58366 m
.7943 .62643 L
s
.38759 .06663 m
.46893 .17859 L
s
.38759 .06663 m
.25597 .1094 L
s
.46893 .17859 m
.55027 .29055 L
s
.46893 .17859 m
.33731 .22136 L
s
.55027 .29055 m
.63162 .40251 L
s
.55027 .29055 m
.41866 .33332 L
s
.63162 .40251 m
.71296 .51447 L
s
.63162 .40251 m
.5 .44528 L
s
.71296 .51447 m
.7943 .62643 L
s
.71296 .51447 m
.58134 .55723 L
s
.7943 .62643 m
.87564 .73839 L
s
.7943 .62643 m
.66269 .66919 L
s
.87564 .73839 m
.74403 .78115 L
s
.25597 .1094 m
.33731 .22136 L
s
.25597 .1094 m
.12436 .15216 L
s
.33731 .22136 m
.41866 .33332 L
s
.33731 .22136 m
.2057 .26412 L
s
.41866 .33332 m
.5 .44528 L
s
.41866 .33332 m
.28704 .37608 L
s
.5 .44528 m
.58134 .55723 L
s
.5 .44528 m
.36838 .48804 L
s
.58134 .55723 m
.66269 .66919 L
s
.58134 .55723 m
.44973 .6 L
s
.66269 .66919 m
.74403 .78115 L
s
.66269 .66919 m
.53107 .71196 L
s
.74403 .78115 m
.61241 .82392 L
s
.12436 .15216 m
.2057 .26412 L
s
.2057 .26412 m
.28704 .37608 L
s
.2057 .26412 m
.07408 .30689 L
s
.28704 .37608 m
.36838 .48804 L
s
.28704 .37608 m
.15543 .41885 L
s
.36838 .48804 m
.44973 .6 L
s
.36838 .48804 m
.23677 .5308 L
s
.44973 .6 m
.53107 .71196 L
s
.44973 .6 m
.31811 .64276 L
s
.53107 .71196 m
.61241 .82392 L
s
.53107 .71196 m
.39945 .75472 L
s
.61241 .82392 m
.69376 .93588 L
s
.61241 .82392 m
.4808 .86668 L
s
.69376 .93588 m
.56214 .97864 L
s
.07408 .30689 m
.15543 .41885 L
s
.15543 .41885 m
.23677 .5308 L
s
.15543 .41885 m
.02381 .46161 L
s
.23677 .5308 m
.31811 .64276 L
s
.23677 .5308 m
.10515 .57357 L
s
.31811 .64276 m
.39945 .75472 L
s
.31811 .64276 m
.1865 .68553 L
s
.39945 .75472 m
.4808 .86668 L
s
.39945 .75472 m
.26784 .79749 L
s
.4808 .86668 m
.56214 .97864 L
s
.4808 .86668 m
.34918 .90945 L
s
.02381 .46161 m
.10515 .57357 L
s
.10515 .57357 m
.1865 .68553 L
s
.1865 .68553 m
.26784 .79749 L
s
.1865 .68553 m
.05488 .72829 L
s
.26784 .79749 m
.34918 .90945 L
s
.26784 .79749 m
.13622 .84025 L
s
.05488 .72829 m
.13622 .84025 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[150]:=",
  ImageSize->{288, 288.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L009@70P2:1`00T@L3008700<01`L0Q`L008h70`051`0300L708L7002:1`@0
2@L00`071`261`00Q`L300h700<01`L0Q@L008@70`0B1`0300L708@700211`<05@L00`071`241`00
OPL301T700<01`L0P`L007/70`0M1`0300L70887001g1`@080L00`071`221`00M0L302D700<01`L0
P@L007470`0Y1`0300L70807001^1`<0;@L00`071`1o1`00J`L3008700<01`L0:`L00`071`1o1`00
J0L300D700<01`L0;0L00`071`1n1`00I0L400T700<01`L0;0L00`071`1m1`00H@L300h700<01`L0
:`L00`071`1m1`00GPL3018700<01`L0:`L00`071`1l1`00F`L301D700<01`L0;0L00`071`1k1`00
F0L301T700<01`L0;0L00`071`1j1`00E@L301d700<01`L0:`L00`071`0[1`80C@L00547100P1`03
00L702`700<01`L09`L3008700<01`L0BPL004h70`0U1`0300L702`700<01`L08`L300D700<01`L0
BPL004/70`0Y1`0300L702`700<01`L07PL400T700<01`L0B@L004P70`0]1`0300L702/700<01`L0
6`L300h700<01`L0B0L004D70`021`0300L702/700<01`L0;0L00`071`0G1`<04PL00`071`171`00
@PL300D700<01`L0;0L00`071`0/1`0300L701<70`0E1`0300L704L7000n1`@02@L00`071`0/1`03
00L702/700<01`L040L301T700<01`L0APL003/70`0>1`0300L702/700<01`L0;0L00`071`0<1`<0
7@L00`071`151`00>0L3018700<01`L0:`L00`071`0/1`0300L700L7100P1`0300L704D7000e1`<0
5@L00`071`0/1`0300L702`700<01`L00`L302D700<01`L0A0L003870`0I1`0300L702`700<01`L0
:`L00`071`0302T700<01`L0@`L002l70`0M1`0300L702/700<01`L0:`L302d700<01`L0@PL002/7
100P1`0300L702`700<01`L09`L3008700<01`L0:`L00`071`121`00:0L302D700<01`L0;0L00`07
1`0S1`<01@L00`071`0/1`0300L70447000U1`<0:@L00`071`0/1`0300L701h710091`0300L702`7
00<01`L0@0L002<70P0]1`0300L702/700<01`L06`L300h700<01`L0:`L00`071`101`0090L00`07
1`0[1`0300L702`700<01`L05`L3018700<01`L0:`L00`071`0o1`0090L00`071`0/1`0300L702`7
00<01`L04`L301D700<01`L0;0L00`071`0n1`009@L00`071`0/1`0300L702/700<01`L040L301T7
00<01`L0;0L00`071`0m1`009PL00`071`0[1`0300L702`700<01`L030L301d700<01`L0:`L00`07
1`0m1`009`L00`071`0[1`0300L702`700<01`L01`L4020700<01`L0;0L00`071`0l1`009`L00`07
1`0/1`0300L702`700<01`L00`L302D700<01`L0;0L00`071`0k1`00:0L00`071`0/1`0300L702/7
00<01`L00`0Y1`0300L702`700<01`L0>PL002T700<01`L0:`L00`071`0[1`<0;@L00`071`0[1`03
00L703X7000Z1`0300L702/700<01`L09`L3008700<01`L0:`L00`071`0/1`0300L703T7000Z1`03
00L702`700<01`L08`L300D700<01`L0;0L00`071`0/1`0300L703P7000[1`0300L702`700<01`L0
7PL400T700<01`L0;0L00`071`0[1`0300L703P7000/1`0300L702/700<01`L06`L300h700<01`L0
:`L00`071`0/1`0300L703L7000/1`0300L702`700<01`L05`L3018700<01`L0:`L00`071`0/1`03
00L703H7000]1`0300L702`700<01`L04`L301D700<01`L0;0L00`071`0/1`0300L703D7000^1`03
00L702/700<01`L040L301T700<01`L0;0L00`071`0[1`0300L703D7000_1`0300L702/700<01`L0
30L301d700<01`L0:`L00`071`0[1`80=PL002l700<01`L0;0L00`071`071`@080L00`071`0/1`03
00L702L70`021`0300L703<7000`1`0300L702`700<01`L00`L302D700<01`L0;0L00`071`0S1`<0
1@L00`071`0c1`00<@L00`071`0[1`0300L700<0:@L00`071`0/1`0300L701h710091`0300L70387
000b1`0300L702X70`0]1`0300L702/700<01`L06`L300h700<01`L0<@L0038700<01`L09`L30087
00<01`L0:`L00`071`0/1`0300L701L70`0B1`0300L70307000c1`0300L702<70`051`0300L702`7
00<01`L0;0L00`071`0C1`<05@L00`071`0`1`00=0L00`071`0P1`802@L00`071`0/1`0300L702/7
00<01`L040L301T700<01`L0;`L003@700<01`L07@L300`700<01`L0:`L00`071`0/1`0300L700`7
0`0M1`0300L702h7000e1`0300L701T70`0@1`0300L702/700<01`L0;0L00`071`071`@080L00`07
1`0^1`00=PL00`071`0E1`<04`L00`071`0/1`0300L702`700<01`L00`L302D700<01`L0;@L003L7
00<01`L04@L301L700<01`L0;0L00`071`0[1`0300L700<0:@L00`071`0/1`00=`L00`071`0>1`<0
6`L00`071`0[1`0300L702/70`0]1`0300L702/7000h1`0300L700X70`0O1`0300L702/700<01`L0
9`L3008700<01`L0:`L00`071`0[1`00>@L00`071`071`808PL00`071`0/1`0300L702<70`051`03
00L702`700<01`L0:PL003X700<01`L00`L302D700<01`L0;0L00`071`0N1`@02@L00`071`0/1`03
00L702T7000j1`0300L700<0:@L00`071`0[1`0300L701/70`0>1`0300L702/700<01`L0:@L003X7
0`0]1`0300L702/700<01`L05`L3018700<01`L0:`L00`071`0X1`00=`L3008700<01`L0:`L00`07
1`0/1`0300L701<70`0E1`0300L702`700<01`L09`L003@70`051`0300L702`700<01`L0:`L00`07
1`0@1`<06@L00`071`0/1`0300L702H7000`1`@02@L00`071`0/1`0300L702/700<01`L030L301d7
00<01`L0:`L00`071`0V1`00;@L300h700<01`L0;0L00`071`0[1`0300L700L7100Q1`0300L702/7
00<01`L09@L002X70`0B1`0300L702/700<01`L0;0L00`071`031`<09@L00`071`0/1`0300L702@7
000W1`<05@L00`071`0/1`0300L702/700<01`L00`0Y1`0300L702`700<01`L08`L002@70`0I1`03
00L702`700<01`L0:PL302d700<01`L0:`L00`071`0S1`008@L301d700<01`L0;0L00`071`0V1`<0
0PL00`071`0/1`0300L702/700<01`L08PL001d7100P1`0300L702`700<01`L08`L300D700<01`L0
;0L00`071`0/1`0300L70247000J1`<09@L00`071`0/1`0300L701l70`091`0300L702`700<01`L0
:`L00`071`0Q1`005`L302T700<01`L0;0L00`071`0K1`<03@L00`071`0/1`0300L702/700<01`L0
80L001D70P0]1`0300L702`700<01`L05`L3014700<01`L0;0L00`071`0[1`0300L701l7000F1`03
00L702/700<01`L0;0L00`071`0C1`@050L00`071`0/1`0300L702`700<01`L07PL001H700<01`L0
;0L00`071`0/1`0300L700l70`0I1`0300L702`700<01`L0:`L00`071`0N1`005`L00`071`0/1`03
00L702`700<01`L02`L301d700<01`L0;0L00`071`0Z1`807`L001P700<01`L0:`L00`071`0]1`03
00L700L70`0Q1`0300L702`700<01`L09PL3008700<01`L070L001T700<01`L0:`L00`071`0/1`03
00L700@70`0T1`0300L702`700<01`L08`L300D700<01`L070L001T700<01`L0;0L00`071`0/1`03
00L700<0:0L00`071`0/1`0300L701l70`091`0300L701/7000J1`0300L702`700<01`L0:`L302`7
00<01`L0;0L00`071`0K1`<03@L00`071`0J1`006`L00`071`0[1`0300L702P70`021`0300L702/7
00<01`L0;0L00`071`0G1`<04@L00`071`0I1`006`L00`071`0/1`0300L702@70`051`0300L702/7
00<01`L0;0L00`071`0C1`@050L00`071`0I1`0070L00`071`0/1`0300L702070`091`0300L702/7
00<01`L0;0L00`071`0?1`<06@L00`071`0H1`007@L00`071`0/1`0300L701`70`0=1`0300L702/7
00<01`L0;0L00`071`0;1`<07@L00`071`0G1`007PL00`071`0[1`0300L701T70`0@1`0300L702`7
00<01`L0;0L00`071`071`<08@L00`071`0F1`007PL00`071`0/1`0300L701D70`0D1`0300L702/7
00<01`L0;0L00`071`041`<090L00`071`0F1`007`L00`071`0/1`0300L701870P0H1`0300L702/7
00<01`L0;0L00`071`0302P700<01`L05@L0020700<01`L0:`L00`071`0?1`<06`L00`071`0[1`03
00L702/70`0/1`0300L701@7000P1`0300L702`700<01`L02`L301h700<01`L0;0L00`071`0W1`<0
0PL00`071`0[1`0300L701<7000Q1`0300L702`700<01`L01`L3028700<01`L0:`L00`071`0T1`<0
1@L00`071`0[1`0300L701<7000R1`0300L702`700<01`L00`L302H700<01`L0:`L00`071`0O1`@0
2@L00`071`0[1`0300L70187000S1`0300L702/700<01`L00`0Y1`0300L702`700<01`L06`L300h7
00<01`L0:`L00`071`0A1`008`L00`071`0[1`<0;@L00`071`0/1`0300L701L70`0B1`0300L702/7
00<01`L040L002@700<01`L09`L3008700<01`L0;0L00`071`0[1`0300L701@70`0E1`0300L702/7
00<01`L040L002D700<01`L08`L300D700<01`L0;0L00`071`0/1`0300L701070`0I1`0300L702/7
00<01`L03`L002H700<01`L07PL400T700<01`L0;0L00`071`0/1`0300L700`70`0M1`0300L702/7
00<01`L03PL002H700<01`L06`L300h700<01`L0;0L00`071`0/1`0300L700L7100P1`0300L702`7
00<01`L03@L002L700<01`L05`L3018700<01`L0;0L00`071`0[1`0300L700@70`0U1`0300L702/7
00<01`L03@L002P700<01`L04`L301D700<01`L0;0L00`071`0/1`0300L700<0:@L00`071`0[1`03
00L700`7000X1`0300L701070`0I1`0300L702`700<01`L0:`L302d700<01`L0:`L00`071`0;1`00
:@L00`071`0<1`<07@L00`071`0/1`0300L702L70`021`0300L702/700<01`L0;0L00`071`0:1`00
:PL00`071`071`@080L00`071`0/1`0300L702@70`051`0300L702`700<01`L0:`L00`071`0:1`00
:`L00`071`031`<09@L00`071`0/1`0300L702070`091`0300L702`700<01`L0:`L00`071`091`00
:`L00`071`0302T700<01`L0;0L00`071`0L1`<03@L00`071`0[1`0300L702`700<01`L020L002/7
0`0]1`0300L702/700<01`L06@L3014700<01`L0:`L00`071`0/1`0300L700L7000X1`<00PL00`07
1`0[1`0300L702`700<01`L05@L301@700<01`L0;0L00`071`0[1`0300L700L7000U1`<01@L00`07
1`0/1`0300L702`700<01`L04PL201P700<01`L0;0L00`071`0[1`0300L700H7000Q1`@02@L00`07
1`0/1`0300L702`700<01`L03PL301/700<01`L0:`L00`071`0[1`801`L001h70`0>1`0300L702/7
00<01`L0;0L00`071`0;1`<07PL00`071`0/1`0300L702L70`091`006`L3018700<01`L0:`L00`07
1`0/1`0300L700L70`0R1`0300L702`700<01`L08`L300`7000H1`<05@L00`071`0/1`0300L702`7
00<01`L00`L302H700<01`L0;0L00`071`0N1`@03`L001D70`0I1`0300L702`700<01`L0:`L00`07
1`0302X700<01`L0:`L00`071`0K1`<04`L001870`0M1`0300L702/700<01`L0:`L302d700<01`L0
;0L00`071`0G1`<05PL000h7100P1`0300L702`700<01`L09`L3008700<01`L0;0L00`071`0/1`03
00L701<70`0I1`002`L302D700<01`L0;0L00`071`0S1`<01@L00`071`0]1`0300L702/700<01`L0
40L301`700081`<0:@L00`071`0/1`0300L701h710091`0300L702`700<01`L0;0L00`071`0<1`<0
7`L000H70P0]1`0300L702/700<01`L06`L300h700<01`L0;0L00`071`0/1`0300L700L7100R1`00
1`L00`071`0[1`0300L702`700<01`L05`L3018700<01`L0;0L00`071`0/1`0300L700<70`0V1`00
1`L00`071`0/1`0300L702`700<01`L04`L301D700<01`L0;@L00`071`0[1`0300L700<0:@L000P7
00<01`L0;0L00`071`0[1`0300L701070`0I1`0300L702`700<01`L0:`L302`700091`0300L702/7
00<01`L0;0L00`071`0<1`<07@L00`071`0/1`0300L702L70`021`0300L702X7000:1`0300L702/7
00<01`L0;0L00`071`071`@080L00`071`0]1`0300L702<70`051`0300L702X7000:1`0300L702`7
00<01`L0;0L00`071`031`<09@L00`071`0]1`0300L701h710091`0300L702T7000;1`0300L702`7
00<01`L0:`L00`071`0302T700<01`L0;0L00`071`0K1`<03PL00`071`0X1`0030L00`071`0[1`03
00L702/70`0]1`0300L702`700<01`L05`L3018700<01`L09`L000d700<01`L0:`L00`071`0W1`<0
0PL00`071`0[1`0300L702d700<01`L04`L301D700<01`L09`L000d700<01`L0;0L00`071`0S1`<0
1@L00`071`0/1`0300L702`700<01`L040L301T700<01`L09PL000h700<01`L0;0L00`071`0N1`@0
2@L00`071`0/1`0300L702`700<01`L030L301d700<01`L09@L000l700<01`L0:`L00`071`0K1`<0
3PL00`071`0[1`0300L702d700<01`L01`L4020700<01`L09@L0010700<01`L0:`L00`071`0G1`<0
4PL00`071`0[1`0300L702d700<01`L00`L302D700<01`L090L0010700<01`L0;0L00`071`0C1`<0
5@L00`071`0/1`0300L702`700<01`L00`0Y1`0300L702<7000A1`0300L702/700<01`L040L301T7
00<01`L0;0L00`071`0[1`<0;@L00`071`0R1`004PL00`071`0[1`0300L700`70`0M1`0300L702/7
00<01`L0:0L3008700<01`L0:`L00`071`0R1`004`L00`071`0[1`0300L700L7100Q1`0300L702/7
00<01`L090L300D700<01`L0;0L00`071`0Q1`004`L00`071`0/1`0300L700<70`0U1`0300L702`7
00<01`L080L300T700<01`L0;0L00`071`0P1`0050L00`071`0[1`0300L700<0:@L00`071`0/1`03
00L701`70`0=1`0300L702/700<01`L080L001D700<01`L0:PL302d700<01`L0:`L00`071`0I1`<0
40L00`071`0/1`0300L701l7000F1`0300L702H70`021`0300L702`700<01`L0:`L00`071`0E1`<0
50L00`071`0/1`0300L701h7000F1`0300L702<70`051`0300L702`700<01`L0;0L00`071`0B1`80
60L00`071`0/1`0300L701d7000G1`0300L701l70`091`0300L702`700<01`L0:`L00`071`0?1`<0
6`L00`071`0[1`0300L701d7000H1`0300L701/70`0=1`0300L702`700<01`L0:`L00`071`0;1`<0
7PL00`071`0/1`0300L701`7000I1`0300L701L70`0A1`0300L702`700<01`L0:`L00`071`071`<0
8PL00`071`0/1`0300L701/7000I1`0300L701<7100D1`0300L702`700<01`L0;0L00`071`031`<0
9PL00`071`0/1`0300L701X7000J1`0300L700l70`0I1`0300L702`700<01`L0:`L00`071`0302T7
00<01`L0;0L00`071`0J1`006`L00`071`0;1`<07@L00`071`0/1`0300L702X70`0]1`0300L702`7
00<01`L06@L001`700<01`L01`L3024700<01`L0;0L00`071`0V1`<00PL00`071`0/1`0300L702`7
00<01`L060L001`700<01`L010L302@700<01`L0;0L00`071`0S1`<01@L00`071`0/1`0300L702`7
00<01`L060L001d700<01`L00`0X1`0300L702`700<01`L07`L300T700<01`L0;0L00`071`0/1`03
00L701L7000N1`80;0L00`071`0/1`0300L701/70`0=1`0300L702`700<01`L0;0L00`071`0F1`00
7`L00`071`0[1`0300L702`700<01`L05`L3014700<01`L0;0L00`071`0/1`0300L701D7000O1`03
00L702/700<01`L0;0L00`071`0C1`@050L00`071`0/1`0300L702`700<01`L05@L0020700<01`L0
:`L00`071`0/1`0300L700l70`0I1`0300L702`700<01`L0:`L201H7000Q1`0300L702/700<01`L0
;0L00`071`0;1`<07@L00`071`0/1`0300L702L70`0H1`008@L00`071`0/1`0300L702`700<01`L0
1`L3024700<01`L0:`L00`071`0T1`<06`L0028700<01`L0:`L00`071`0/1`0300L700@70`0T1`03
00L702`700<01`L080L301h7000S1`0300L702/700<01`L0;0L00`071`0302P700<01`L0;0L00`07
1`0L1`<08@L002@700<01`L0:`L00`071`0[1`<0;0L00`071`0[1`0300L701T70`0T1`0090L00`07
1`0/1`0300L702L70`021`0300L702/700<01`L0:`L00`071`0E1`<09`L002D700<01`L0:`L00`07
1`0T1`<01@L00`071`0[1`0300L702`700<01`L04PL202X7000V1`0300L702/700<01`L07`L400T7
00<01`L0:`L00`071`0/1`0300L700h70`0/1`009PL00`071`0/1`0300L701/70`0>1`0300L702/7
00<01`L0:`L00`071`0;1`<0;`L002L700<01`L0;0L00`071`0G1`<04PL00`071`0[1`0300L702/7
00<01`L01`L30387000X1`0300L702/700<01`L050L301D700<01`L0:`L00`071`0/1`0300L700<7
0`0e1`00:0L00`071`0/1`0300L701070`0I1`0300L702/700<01`L0:`L00`071`0303P7000Y1`03
00L702`700<01`L030L301d700<01`L0:`L00`071`0Z1`<0>`L002X700<01`L0;0L00`071`071`@0
80L00`071`0/1`0300L702H70`021`0300L703T7000[1`0300L702/700<01`L010L302D700<01`L0
:`L00`071`0S1`<01@L00`071`0i1`00:`L00`071`0/1`0300L700<0:@L00`071`0[1`0300L701l7
0`091`0300L703P7000/1`0300L702/70`0]1`0300L702/700<01`L06`L300d700<01`L0=`L002d7
00<01`L09`L3008700<01`L0:`L00`071`0/1`0300L701L70`0A1`0300L703H7000]1`0300L702@7
0`051`0300L702`700<01`L0:`L00`071`0C1`@050L00`071`0f1`00;PL00`071`0P1`<02@L00`07
1`0/1`0300L702/700<01`L03`L301T700<01`L0=@L002l700<01`L070L300d700<01`L0:`L00`07
1`0/1`0300L700/70`0M1`0300L703@7000_1`0300L701T70`0A1`0300L702/700<01`L0;0L00`07
1`071`<08@L00`071`0c1`00<0L00`071`0E1`<050L00`071`0/1`0300L702/700<01`L010L302@7
00<01`L0<`L0034700<01`L04PL201P700<01`L0;0L00`071`0[1`0300L700<0:0L00`071`0b1`00
<PL00`071`0>1`<06`L00`071`0[1`0300L702/70`0/1`0300L70347000b1`0300L700/70`0N1`03
00L702`700<01`L09`L3008700<01`L0:`L00`071`0`1`00<`L00`071`071`<08PL00`071`0/1`03
00L702<70`051`0300L702/700<01`L0<0L003@700<01`L00`L302H700<01`L0;0L00`071`0N1`@0
2@L00`071`0[1`0300L702l7000d1`0300L700<0:PL00`071`0[1`0300L701/70`0>1`0300L702/7
00<01`L0;PL003@70`0]1`0300L702`700<01`L05`L3018700<01`L0:`L00`071`0]1`00<@L30087
00<01`L0;0L00`071`0/1`0300L701<70`0E1`0300L702/700<01`L0;@L002h70`051`0300L702d7
00<01`L0:`L00`071`0@1`<06@L00`071`0[1`0300L702`7000Z1`@02@L00`071`0/1`0300L702`7
00<01`L030L301d700<01`L0:`L00`071`0[1`009`L300h700<01`L0;0L00`071`0/1`0300L700L7
100P1`0300L702`700<01`L0:PL002@70`0B1`0300L702`700<01`L0;0L00`071`031`<09@L00`07
1`0[1`0300L702X7000Q1`<05@L00`071`0]1`0300L702/700<01`L00`0Y1`0300L702/700<01`L0
:@L001h70`0I1`0300L702`700<01`L0:`L302d700<01`L0:`L00`071`0X1`006`L301d700<01`L0
;0L00`071`0W1`<00PL00`071`0[1`0300L702`700<01`L09`L001L7100P1`0300L702d700<01`L0
8`L300D700<01`L0;0L00`071`0[1`0300L702L7000D1`<09@L00`071`0]1`0300L701h710091`03
00L702`700<01`L0:`L00`071`0V1`004@L302T700<01`L0;0L00`071`0K1`<03PL00`071`0[1`03
00L702`700<01`L09@L000l70P0]1`0300L702`700<01`L05`L3018700<01`L0:`L00`071`0/1`03
00L702@7000@1`0300L702/700<01`L0;@L00`071`0C1`<05@L00`071`0/1`0300L702/700<01`L0
90L0010700<01`L0;0L00`071`0/1`0300L701070`0I1`0300L702`700<01`L0:`L00`071`0S1`00
4@L00`071`0/1`0300L702`700<01`L030L301d700<01`L0:`L00`071`0[1`8090L0018700<01`L0
:`L00`071`0]1`0300L700L7100P1`0300L702`700<01`L09`L302H7000C1`0300L702/700<01`L0
;@L00`071`031`<09@L00`071`0/1`0300L702<70`0Y1`004`L00`071`0/1`0300L702`700<01`L0
0`0Y1`0300L702`700<01`L07PL402`7000D1`0300L702`700<01`L0:`L302d700<01`L0:`L00`07
1`0K1`<0<0L001D700<01`L0:`L00`071`0X1`<00PL00`071`0[1`0300L702`700<01`L05`L303<7
000F1`0300L702/700<01`L090L300D700<01`L0;0L00`071`0/1`0300L701<70`0f1`005PL00`07
1`0/1`0300L702070`091`0300L702`700<01`L0:`L00`071`0@1`<0>@L001L700<01`L0;0L00`07
1`0L1`<03@L00`071`0[1`0300L702`700<01`L030L303`7000H1`0300L702/700<01`L06@L30107
00<01`L0;0L00`071`0/1`0300L700L7100o1`006@L00`071`0[1`0300L701D70`0D1`0300L702`7
00<01`L0;0L00`071`031`<0@`L001T700<01`L0;0L00`071`0B1`8060L00`071`0/1`0300L702/7
00<01`L00`161`006PL00`071`0[1`0300L700l70`0K1`0300L702/700<01`L0:`L304T7000K1`03
00L702/700<01`L02`L301h700<01`L0;0L00`071`0W1`<0C0L001`700<01`L0:`L00`071`071`<0
8PL00`071`0/1`0300L702<70`1?1`0070L00`071`0/1`0300L700<70`0V1`0300L702`700<01`L0
7PL40587000M1`0300L702/700<01`L00`0Y1`0300L702`700<01`L06`L305H7000N1`0300L702X7
0`0]1`0300L702`700<01`L05`L305T7000O1`0300L702H70`021`0300L702`700<01`L0;0L00`07
1`0C1`<0G0L001l700<01`L08`L300D700<01`L0;0L00`071`0/1`0300L701070`1O1`0080L00`07
1`0O1`<02@L00`071`0/1`0300L702`700<01`L030L30687000Q1`0300L701/70`0=1`0300L702`7
00<01`L0;0L00`071`071`@0I@L0028700<01`L05`L3014700<01`L0;0L00`071`0/1`0300L700<7
0`1Y1`008PL00`071`0C1`@050L00`071`0/1`0300L702`700<01`L00`1/1`008`L00`071`0?1`<0
6@L00`071`0/1`0300L702/70`1_1`0090L00`071`0;1`<07@L00`071`0/1`0300L702L70`021`03
00L706d7000U1`0300L700L70`0Q1`0300L702/700<01`L090L300D700<01`L0K@L002D700<01`L0
10L302@700<01`L0;0L00`071`0P1`<02@L00`071`1/1`009PL00`071`0302P700<01`L0;0L00`07
1`0L1`<03@L00`071`1[1`009`L202`700<01`L0:`L00`071`0I1`<04@L00`071`1Z1`00EPL00`07
1`0[1`0300L701D70`0D1`0300L706X7001F1`0300L702`700<01`L04PL201P700<01`L0J@L005L7
00<01`L0;0L00`071`0>1`<06`L00`071`1X1`00F0L00`071`0[1`0300L700/70`0O1`0300L706L7
001I1`0300L702/700<01`L01`L3028700<01`L0I`L005T700<01`L0;0L00`071`031`<09PL00`07
1`1V1`00FPL00`071`0[1`0300L700<0:PL00`071`1U1`00F`L00`071`0Z1`<0;PL00`071`1T1`00
G0L00`071`0V1`<00PL00`071`0/1`0300L706@7001L1`0300L702<70`051`0300L702d700<01`L0
H`L005d700<01`L07`L300T700<01`L0;@L00`071`1R1`00GPL00`071`0K1`<03@L00`071`0]1`03
00L70647001O1`0300L701L70`0A1`0300L702`700<01`L0H@L005l700<01`L04`L401@700<01`L0
;@L00`071`1P1`00H0L00`071`0?1`<06@L00`071`0]1`0300L705l7001Q1`0300L700/70`0M1`03
00L702d700<01`L0GPL0068700<01`L01`L3024700<01`L0;0L00`071`1N1`00HPL00`071`041`<0
90L00`071`0]1`0300L705d7001S1`0300L700<0:0L00`071`0]1`0300L705`7001T1`80;0L00`07
1`0]1`0300L705/7002C1`0300L702`700<01`L0F`L009<700<01`L0;@L00`071`1J1`00U0L00`07
1`0]1`0300L705T7002E1`0300L702d700<01`L0F0L009H700<01`L0;0L00`071`1H1`00UPL00`07
1`0]1`0300L705L7002G1`0300L702`70P1H1`00V0L00`071`0X1`<0FPL009T700<01`L090L305d7
002I1`0300L702470`1P1`00VPL00`071`0M1`<0H`L009/700<01`L06@L306H7002L1`0300L701D7
0`1Y1`00W0L00`071`0C1`80K0L009d700<01`L03`L306h7002N1`0300L700/70`1a1`00W`L00`07
1`071`<0M0L009l700<01`L010L307L7002P1`0300L700<0NPL00:470P1m1`00o`LQ1`00o`LQ1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287.688, 0}} -> {-9.24705, -9.22737, \
0.0661918, 0.0661918}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[150]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice32\  = 
      tiling2D[SphericalCut[N[Join[AL032, \ AL132, \ AL232, \ AL332]], 10], \ 
        rad32]\)], "Input",
  CellLabel->"In[151]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03596 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499927 0.049582 0.517979 0.049582 [
[ 0 0 0 0 ]
[ 1 1.03596 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.03596 L
0 1.03596 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.73104 .14812 m
.80765 .25356 L
s
.73104 .14812 m
.60709 .1884 L
s
.80765 .25356 m
.88426 .359 L
s
.80765 .25356 m
.6837 .29384 L
s
.88426 .359 m
.96087 .46445 L
s
.88426 .359 m
.76031 .39928 L
s
.96087 .46445 m
.83691 .50472 L
s
.53048 .08295 m
.60709 .1884 L
s
.53048 .08295 m
.40653 .12323 L
s
.60709 .1884 m
.6837 .29384 L
s
.60709 .1884 m
.48313 .22867 L
s
.6837 .29384 m
.76031 .39928 L
s
.6837 .29384 m
.55974 .33411 L
s
.76031 .39928 m
.83691 .50472 L
s
.76031 .39928 m
.63635 .43956 L
s
.83691 .50472 m
.91352 .61016 L
s
.83691 .50472 m
.71296 .545 L
s
.91352 .61016 m
.78957 .65044 L
s
.40653 .12323 m
.48313 .22867 L
s
.40653 .12323 m
.28257 .1635 L
s
.48313 .22867 m
.55974 .33411 L
s
.48313 .22867 m
.35918 .26895 L
s
.55974 .33411 m
.63635 .43956 L
s
.55974 .33411 m
.43579 .37439 L
s
.63635 .43956 m
.71296 .545 L
s
.63635 .43956 m
.5124 .47983 L
s
.71296 .545 m
.78957 .65044 L
s
.71296 .545 m
.589 .58527 L
s
.78957 .65044 m
.86618 .75588 L
s
.78957 .65044 m
.66561 .69072 L
s
.86618 .75588 m
.74222 .79616 L
s
.28257 .1635 m
.35918 .26895 L
s
.28257 .1635 m
.15862 .20378 L
s
.35918 .26895 m
.43579 .37439 L
s
.35918 .26895 m
.23522 .30922 L
s
.43579 .37439 m
.5124 .47983 L
s
.43579 .37439 m
.31183 .41466 L
s
.5124 .47983 m
.589 .58527 L
s
.5124 .47983 m
.38844 .52011 L
s
.589 .58527 m
.66561 .69072 L
s
.589 .58527 m
.46505 .62555 L
s
.66561 .69072 m
.74222 .79616 L
s
.66561 .69072 m
.54166 .73099 L
s
.74222 .79616 m
.61827 .83643 L
s
.15862 .20378 m
.23522 .30922 L
s
.23522 .30922 m
.31183 .41466 L
s
.23522 .30922 m
.11127 .3495 L
s
.31183 .41466 m
.38844 .52011 L
s
.31183 .41466 m
.18788 .45494 L
s
.38844 .52011 m
.46505 .62555 L
s
.38844 .52011 m
.26449 .56038 L
s
.46505 .62555 m
.54166 .73099 L
s
.46505 .62555 m
.34109 .66582 L
s
.54166 .73099 m
.61827 .83643 L
s
.54166 .73099 m
.4177 .77127 L
s
.61827 .83643 m
.69487 .94188 L
s
.61827 .83643 m
.49431 .87671 L
s
.69487 .94188 m
.57092 .98215 L
s
.11127 .3495 m
.18788 .45494 L
s
.18788 .45494 m
.26449 .56038 L
s
.18788 .45494 m
.06392 .49521 L
s
.26449 .56038 m
.34109 .66582 L
s
.26449 .56038 m
.14053 .60066 L
s
.34109 .66582 m
.4177 .77127 L
s
.34109 .66582 m
.21714 .7061 L
s
.4177 .77127 m
.49431 .87671 L
s
.4177 .77127 m
.29375 .81154 L
s
.49431 .87671 m
.57092 .98215 L
s
.49431 .87671 m
.37036 .91698 L
s
.06392 .49521 m
.14053 .60066 L
s
.14053 .60066 m
.21714 .7061 L
s
.21714 .7061 m
.29375 .81154 L
s
.21714 .7061 m
.09318 .74637 L
s
.29375 .81154 m
.37036 .91698 L
s
.29375 .81154 m
.16979 .85182 L
s
.09318 .74637 m
.16979 .85182 L
s
.81489 .13699 m
.89149 .24243 L
s
.81489 .13699 m
.69093 .17726 L
s
.89149 .24243 m
.76754 .28271 L
s
.61432 .07182 m
.69093 .17726 L
s
.61432 .07182 m
.49037 .1121 L
s
.69093 .17726 m
.76754 .28271 L
s
.69093 .17726 m
.56698 .21754 L
s
.76754 .28271 m
.84415 .38815 L
s
.76754 .28271 m
.64358 .32298 L
s
.84415 .38815 m
.92076 .49359 L
s
.84415 .38815 m
.72019 .42842 L
s
.92076 .49359 m
.7968 .53387 L
s
.49037 .1121 m
.56698 .21754 L
s
.49037 .1121 m
.36641 .15237 L
s
.56698 .21754 m
.64358 .32298 L
s
.56698 .21754 m
.44302 .25781 L
s
.64358 .32298 m
.72019 .42842 L
s
.64358 .32298 m
.51963 .36326 L
s
.72019 .42842 m
.7968 .53387 L
s
.72019 .42842 m
.59624 .4687 L
s
.7968 .53387 m
.87341 .63931 L
s
.7968 .53387 m
.67285 .57414 L
s
.87341 .63931 m
.74945 .67958 L
s
.36641 .15237 m
.44302 .25781 L
s
.36641 .15237 m
.24246 .19265 L
s
.44302 .25781 m
.51963 .36326 L
s
.44302 .25781 m
.31907 .29809 L
s
.51963 .36326 m
.59624 .4687 L
s
.51963 .36326 m
.39567 .40353 L
s
.59624 .4687 m
.67285 .57414 L
s
.59624 .4687 m
.47228 .50897 L
s
.67285 .57414 m
.74945 .67958 L
s
.67285 .57414 m
.54889 .61442 L
s
.74945 .67958 m
.82606 .78503 L
s
.74945 .67958 m
.6255 .71986 L
s
.82606 .78503 m
.70211 .8253 L
s
.24246 .19265 m
.31907 .29809 L
s
.24246 .19265 m
.1185 .23292 L
s
.31907 .29809 m
.39567 .40353 L
s
.31907 .29809 m
.19511 .33837 L
s
.39567 .40353 m
.47228 .50897 L
s
.39567 .40353 m
.27172 .44381 L
s
.47228 .50897 m
.54889 .61442 L
s
.47228 .50897 m
.34833 .54925 L
s
.54889 .61442 m
.6255 .71986 L
s
.54889 .61442 m
.42494 .65469 L
s
.6255 .71986 m
.70211 .8253 L
s
.6255 .71986 m
.50154 .76013 L
s
.70211 .8253 m
.57815 .86558 L
s
.1185 .23292 m
.19511 .33837 L
s
.19511 .33837 m
.27172 .44381 L
s
.19511 .33837 m
.07116 .37864 L
s
.27172 .44381 m
.34833 .54925 L
s
.27172 .44381 m
.14776 .48408 L
s
.34833 .54925 m
.42494 .65469 L
s
.34833 .54925 m
.22437 .58953 L
s
.42494 .65469 m
.50154 .76013 L
s
.42494 .65469 m
.30098 .69497 L
s
.50154 .76013 m
.57815 .86558 L
s
.50154 .76013 m
.37759 .80041 L
s
.57815 .86558 m
.65476 .97102 L
s
.57815 .86558 m
.4542 .90585 L
s
.65476 .97102 m
.53081 1.01129 L
s
.07116 .37864 m
.14776 .48408 L
s
.14776 .48408 m
.22437 .58953 L
s
.14776 .48408 m
.02381 .52436 L
s
.22437 .58953 m
.30098 .69497 L
s
.22437 .58953 m
.10042 .6298 L
s
.30098 .69497 m
.37759 .80041 L
s
.30098 .69497 m
.17703 .73524 L
s
.37759 .80041 m
.4542 .90585 L
s
.37759 .80041 m
.25363 .84069 L
s
.4542 .90585 m
.53081 1.01129 L
s
.4542 .90585 m
.33024 .94613 L
s
.02381 .52436 m
.10042 .6298 L
s
.10042 .6298 m
.17703 .73524 L
s
.17703 .73524 m
.25363 .84069 L
s
.25363 .84069 m
.33024 .94613 L
s
.66976 .08983 m
.74637 .19528 L
s
.66976 .08983 m
.5458 .13011 L
s
.74637 .19528 m
.82297 .30072 L
s
.74637 .19528 m
.62241 .23555 L
s
.82297 .30072 m
.89958 .40616 L
s
.82297 .30072 m
.69902 .34099 L
s
.89958 .40616 m
.97619 .5116 L
s
.89958 .40616 m
.77563 .44644 L
s
.97619 .5116 m
.85224 .55188 L
s
.46919 .02467 m
.5458 .13011 L
s
.46919 .02467 m
.34524 .06494 L
s
.5458 .13011 m
.62241 .23555 L
s
.5458 .13011 m
.42185 .17038 L
s
.62241 .23555 m
.69902 .34099 L
s
.62241 .23555 m
.49846 .27583 L
s
.69902 .34099 m
.77563 .44644 L
s
.69902 .34099 m
.57506 .38127 L
s
.77563 .44644 m
.85224 .55188 L
s
.77563 .44644 m
.65167 .48671 L
s
.85224 .55188 m
.92884 .65732 L
s
.85224 .55188 m
.72828 .59215 L
s
.92884 .65732 m
.80489 .6976 L
s
.34524 .06494 m
.42185 .17038 L
s
.42185 .17038 m
.49846 .27583 L
s
.42185 .17038 m
.29789 .21066 L
s
.49846 .27583 m
.57506 .38127 L
s
.49846 .27583 m
.3745 .3161 L
s
.57506 .38127 m
.65167 .48671 L
s
.57506 .38127 m
.45111 .42154 L
s
.65167 .48671 m
.72828 .59215 L
s
.65167 .48671 m
.52772 .52699 L
s
.72828 .59215 m
.80489 .6976 L
s
.72828 .59215 m
.60433 .63243 L
s
.80489 .6976 m
.8815 .80304 L
s
.80489 .6976 m
.68093 .73787 L
s
.8815 .80304 m
.75754 .84331 L
s
.29789 .21066 m
.3745 .3161 L
s
.29789 .21066 m
.17394 .25093 L
s
.3745 .3161 m
.45111 .42154 L
s
.3745 .3161 m
.25055 .35638 L
s
.45111 .42154 m
.52772 .52699 L
s
.45111 .42154 m
.32715 .46182 L
s
.52772 .52699 m
.60433 .63243 L
s
.52772 .52699 m
.40376 .56726 L
s
.60433 .63243 m
.68093 .73787 L
s
.60433 .63243 m
.48037 .6727 L
s
.68093 .73787 m
.75754 .84331 L
s
.68093 .73787 m
.55698 .77815 L
s
.75754 .84331 m
.63359 .88359 L
s
.17394 .25093 m
.25055 .35638 L
s
.25055 .35638 m
.32715 .46182 L
s
.25055 .35638 m
.12659 .39665 L
s
.32715 .46182 m
.40376 .56726 L
s
.32715 .46182 m
.2032 .50209 L
s
.40376 .56726 m
.48037 .6727 L
s
.40376 .56726 m
.27981 .60754 L
s
.48037 .6727 m
.55698 .77815 L
s
.48037 .6727 m
.35642 .71298 L
s
.55698 .77815 m
.63359 .88359 L
s
.55698 .77815 m
.43302 .81842 L
s
.63359 .88359 m
.50963 .92386 L
s
.12659 .39665 m
.2032 .50209 L
s
.2032 .50209 m
.27981 .60754 L
s
.2032 .50209 m
.07924 .54237 L
s
.27981 .60754 m
.35642 .71298 L
s
.27981 .60754 m
.15585 .64781 L
s
.35642 .71298 m
.43302 .81842 L
s
.35642 .71298 m
.23246 .75325 L
s
.43302 .81842 m
.50963 .92386 L
s
.43302 .81842 m
.30907 .8587 L
s
.50963 .92386 m
.38568 .96414 L
s
.07924 .54237 m
.15585 .64781 L
s
.15585 .64781 m
.23246 .75325 L
s
.23246 .75325 m
.30907 .8587 L
s
.23246 .75325 m
.10851 .79353 L
s
.30907 .8587 m
.38568 .96414 L
s
.30907 .8587 m
.18511 .89897 L
s
.10851 .79353 m
.18511 .89897 L
s
.83021 .18414 m
.90682 .28959 L
s
.83021 .18414 m
.70625 .22442 L
s
.90682 .28959 m
.78286 .32986 L
s
.62964 .11898 m
.70625 .22442 L
s
.62964 .11898 m
.50569 .15925 L
s
.70625 .22442 m
.78286 .32986 L
s
.70625 .22442 m
.5823 .26469 L
s
.78286 .32986 m
.85947 .4353 L
s
.78286 .32986 m
.65891 .37014 L
s
.85947 .4353 m
.93608 .54075 L
s
.85947 .4353 m
.73551 .47558 L
s
.93608 .54075 m
.81212 .58102 L
s
.42908 .05381 m
.50569 .15925 L
s
.42908 .05381 m
.30513 .09408 L
s
.50569 .15925 m
.5823 .26469 L
s
.50569 .15925 m
.38173 .19953 L
s
.5823 .26469 m
.65891 .37014 L
s
.5823 .26469 m
.45834 .30497 L
s
.65891 .37014 m
.73551 .47558 L
s
.65891 .37014 m
.53495 .41041 L
s
.73551 .47558 m
.81212 .58102 L
s
.73551 .47558 m
.61156 .51585 L
s
.81212 .58102 m
.88873 .68646 L
s
.81212 .58102 m
.68817 .6213 L
s
.88873 .68646 m
.76478 .72674 L
s
.30513 .09408 m
.38173 .19953 L
s
.38173 .19953 m
.45834 .30497 L
s
.38173 .19953 m
.25778 .2398 L
s
.45834 .30497 m
.53495 .41041 L
s
.45834 .30497 m
.33439 .34524 L
s
.53495 .41041 m
.61156 .51585 L
s
.53495 .41041 m
.411 .45069 L
s
.61156 .51585 m
.68817 .6213 L
s
.61156 .51585 m
.4876 .55613 L
s
.68817 .6213 m
.76478 .72674 L
s
.68817 .6213 m
.56421 .66157 L
s
.76478 .72674 m
.84138 .83218 L
s
.76478 .72674 m
.64082 .76701 L
s
.84138 .83218 m
.71743 .87246 L
s
.25778 .2398 m
.33439 .34524 L
s
.25778 .2398 m
.13382 .28008 L
s
.33439 .34524 m
.411 .45069 L
s
.33439 .34524 m
.21043 .38552 L
s
.411 .45069 m
.4876 .55613 L
s
.411 .45069 m
.28704 .49096 L
s
.4876 .55613 m
.56421 .66157 L
s
.4876 .55613 m
.36365 .59641 L
s
.56421 .66157 m
.64082 .76701 L
s
.56421 .66157 m
.44026 .70185 L
s
.64082 .76701 m
.71743 .87246 L
s
.64082 .76701 m
.51687 .80729 L
s
.71743 .87246 m
.59347 .91273 L
s
.13382 .28008 m
.21043 .38552 L
s
.21043 .38552 m
.28704 .49096 L
s
.21043 .38552 m
.08648 .4258 L
s
.28704 .49096 m
.36365 .59641 L
s
.28704 .49096 m
.16309 .53124 L
s
.36365 .59641 m
.44026 .70185 L
s
.36365 .59641 m
.23969 .63668 L
s
.44026 .70185 m
.51687 .80729 L
s
.44026 .70185 m
.3163 .74212 L
s
.51687 .80729 m
.59347 .91273 L
s
.51687 .80729 m
.39291 .84757 L
s
.59347 .91273 m
.46952 .95301 L
s
.08648 .4258 m
.16309 .53124 L
s
.16309 .53124 m
.23969 .63668 L
s
.16309 .53124 m
.03913 .57151 L
s
.23969 .63668 m
.3163 .74212 L
s
.23969 .63668 m
.11574 .67696 L
s
.3163 .74212 m
.39291 .84757 L
s
.3163 .74212 m
.19235 .7824 L
s
.39291 .84757 m
.46952 .95301 L
s
.39291 .84757 m
.26896 .88784 L
s
.03913 .57151 m
.11574 .67696 L
s
.11574 .67696 m
.19235 .7824 L
s
.19235 .7824 m
.26896 .88784 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[151]:=",
  ImageSize->{273.938, 283.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004A00016`P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l74PL00?l74PL00?l74PL00?l74PL00?l7
4PL00?l74PL007l70P2@1`00O0L3008700<01`L0S@L007T70`051`0300L708d7001f1`<02@L00`07
1`2<1`00L`L300d700<01`L0R`L006l7100@1`0300L708/7001/1`<05@L00`071`2:1`00J@L301T7
00<01`L0R@L006H70`0;1`8040L00`071`281`00H`L300/70`021`0300L700d700<01`L0R0L00607
0`0;1`<01@L00`071`0>1`0300L708L7001N1`802`L300T700<01`L03PL00`071`261`00G`L00`07
1`061`<03@L00`071`0=1`0300L708H7001O1`0300L70087100A1`0300L700d700<01`L06PL206T7
001P1`@05@L00`071`0>1`0300L701H70`021`0300L706H7001N1`@060L00`071`0=1`0300L701<7
0`051`0300L706H7001K1`<010L00`071`0F1`0300L700d700@01`L70P0<1`<02@L00`071`1U1`00
F0L300L700<01`L05`L00`071`0=1`<00PL00`071`061`<03@L00`071`1T1`00E@L300/700<01`L0
5PL00`071`0:1`@010L00`071`021`@04@L00`071`071`80FPL005<70P0?1`0300L701H700<01`L0
1PL300@700<01`L00PL401D700<01`L010L3008700<01`L0E`L005@700<01`L03PL00`071`0F1`03
00L700870`081`0300L000<060L00`071`0300D700<01`L0E`L005@700<01`L03PL00`071`0F1`D0
2PL300@700<01`L05@L300T700<01`L0EPL005D700<01`L03PL00`071`0C1`@02PL3008700<01`L0
0PL00`071`0B1`<00PL00`071`081`0300L705D7001F1`0300L700h700<01`L03`L300@700<01`L0
10L300H700<01`L00PL00`071`0=1`@01@L00`071`091`0300L705@7001G1`0300L700d700<01`L0
30L300P700<01`L00`0:1`0300L7008700<01`L02@L300X700<01`L020L00`071`1D1`00E`L00`07
1`0>1`0300L700P70`0;1`<00PL00`071`081`0300L700<700<01`L01@L300h700<01`L020L00`07
1`1C1`00F0L00`071`0>1`0300L700@70`0;1`<000<700L00PL00`071`091`0300L7008700<01`L0
0PL300/70P041`0300L700T700<01`L0DPL005T700<01`L03PL00`071`0300/70`051`0500L71`00
2`L00`071`021`@02`L3008700<01`L00PL00`071`091`0300L70547001J1`0300L700d70`021`03
00L700H70`081`0300L7008700<01`L020L00`071`0400X70`051`0300L700<700<01`L020L00`07
1`1A1`00FPL00`071`0:1`<000<700L00PL00`071`031`<030L00`071`021`0300L700L70`031`03
00L700D70`091`0300L700<700<01`L020L00`071`1@1`00F`L00`071`061`<01@L01P071`L01`<0
40L01@071`L000H70`021`0300L7008700@01`L70`0=1`0300L7008700<01`L02@L00`071`1?1`00
G0L00`071`021`<020L00`071`0301@700D01`L700021`<01@L00`071`031`<04@L00`071`021`03
00L700P700<01`L06`L20387001L1`0300L000802`L300<700<01`L04@L010071`L300T700<01`00
0P000`L01`0A1`0300L700<700<01`L020L00`071`0G1`<00PL00`071`0_1`00F`L300/70`021`05
00L71`0050L3008700<01`L01PL300@700<01`L04@L00`071`021`0300L700T700<01`L04`L300D7
00<01`L0;`L005P70`031`0300L700D70`061`0500L71`0040L300031`07008700<01`L00`L300<7
00<01`L00PL00`071`0A1`0300L7008700<01`L02@L010071`L200`70`091`0300L702h7001E1`<0
1`L010071`L300T700<01`L00PL00`071`0:1`<01@L01P071`L01`<01PL00`071`031`0300L70147
00<01`L00PL00`071`081`@00PL00`071`061`<03@L00`071`0]1`00DPL300X710021`0300L700P7
00<01`L00PL00`071`061`<020L00`071`0300X700<01`L00PL00`071`0A1`0300L700<700<01`L0
1@L400@700<01`L00PL4014700<01`L0;0L004l70`0;1`@010L00`071`091`0500L71`001@L300/7
0`021`0300L700T700<01`L00PL00`071`0A1`0300L7008700<01`L00PL300@700<01`L00PL401D7
00<01`L0;0L004`70`0;1`<010L00`071`021`0300L700T700H01`L700L300/70`021`0500L71`00
2`L00`071`021`0300L7014700<01`L00PL400L700<01`L0100H1`0300L702/700191`<00PL00`07
1`061`<01`L00`071`031`0300L700P700<01`L00`0;1`<01@L00`071`021`0300L700P700<01`L0
0`L00`071`0@1`0300L000@02@L300@700<01`L05PL00`071`0Z1`00APL300D700<01`L00PL400/7
00<01`L00PL00`071`081`<00PL00`071`061`<02@L00`071`021`0300L700P700<01`L00PL00`07
1`0?1`<01@L00`071`031`<00PL00`071`021`0300L701L700<01`L0:@L004<70`091`@040L00`07
1`021`0300L700@70`021`0500L71`0010L300d700D01`L7000;1`0300L7008700<01`L02`L300<7
00<01`L00PL00`071`0300H700<01`L00PL00`071`0F1`0300L702T700101`<02PL401<700<01`L0
0PL00`071`0300D700<01`L00PL4010700<01`L00PL00`071`081`0300L700<700<01`L01`L300L7
00@01`L70`091`0300L700<700<01`L05PL00`071`0X1`00?0L400X70`041`0300L7010700<01`L0
0PL300T710000`L01`0B1`0300L7008700<01`L020L00`071`031`0300L700<70`0:1`@00PL00`07
1`081`0300L700<700<01`L05PL00`071`0W1`00>@L300/70`071`0300L7014710000`L01`071`@0
0`L00`071`0B1`0500L71`002`L00`071`021`0300L700<02`L400@700<01`L02@L00`071`021`03
00L701070P041`0300L702L7000f1`<02`L300/700<01`L03@L500@700<01`L00PL300@700D01`L7
000D1`0500L71`002`L010071`L300/70`041`0300L7008700<01`L02@L00`071`021`0300L700`7
0`021`0300L7008700<01`L09PL003<70`0;1`<03`L00`071`091`<01@L00`071`021`@01`L00`07
1`021`0300L7014700<01`L00PL00`071`081`@00PL00`071`061`<01`L00`071`031`0300L700P7
00<01`L00`L00`071`081`<01@L00`071`031`0300L702D7000`1`<02`L3008700<01`L03PL00`07
1`051`<020L00`071`0300/700D01`L7000D1`0300L7008700<01`L01@L400@700<01`L00PL400/7
00<01`L00`L00`071`071`8010L00`071`051`<02@L00`071`031`0300L702@7000]1`<02`L300D7
00<01`L03PL00`071`021`<02`L300<700<01`L02@L01@071`L001@700D01`L700041`<010L00`07
1`021`@040L00`071`021`0300L700@70`021`0300L7008700@01`L70`0=1`0300L7008700<01`L0
90L002/70P0;1`<02@L00`071`0>1`@02`L3008700<01`L00PL00`071`091`0500L71`004`L00`07
1`021`@01`L00`071`0401<700<01`L00PL00`071`0300D700<01`L00PL4014700<01`L00PL00`07
1`0S1`00;0L00`071`061`<03@L00`071`0;1`@02PL300D700<01`L00PL00`071`091`0300L70087
00<01`L04@L600T70`041`0300L7010700<01`L00PL300T710021`0300L7010700<01`L00`L00`07
1`0R1`00;0L00`071`021`@04@L00`071`071`<00`L00`071`051`<02@L00`071`021`0300L700T7
00D01`L7000A1`@010L00`071`031`<00PL00`071`021`0300L7014710021`0300L700D710041`03
00L7014700<01`L00PL00`071`0R1`00;@L401D700<01`L010L3008700<01`L00PL010071`L300d7
00<01`L00PL00`071`091`0500L71`003@L300<700<01`L00PL00`071`0300H700<01`L00PL00`07
1`0=1`D010L00`071`021`<010L00`071`021`0300L7014700<01`L00PL00`071`0Q1`00:`L401P7
00<01`L00`051`0300L70087100A1`0500L71`002`L00`071`021`0300L700L70`071`0400L71`<0
2@L00`071`031`0300L700T70`051`0300L7008710071`0300L700<700<01`L04@L00`071`021`03
00L70207000X1`<010L00`071`0E1`<02@L4008700<01`L040L00`071`021`0300L700T700<01`L0
0PL00`071`031`<02`L3008700<01`L020L00`071`031`0300L700D70`081`0300L700@02PL00`07
1`021`0300L7014700<01`L00`L00`071`0O1`009@L300L700<01`L04PL3008700<01`L01@L400@7
00<01`L04@L00`071`021`0300L700T700D01`L700021`<02`L400@700<01`L02@L00`071`021`03
00L700870`0;1`<00`L00`071`091`0300L7008700<01`L04@L00`071`021`0300L701l7000R1`<0
2`L00`071`0=1`@01@L00`071`021`<010L00`071`021`0300L7014700D01`L7000<1`0300L700<0
2`L300@700<01`L00PL00`071`091`0300L70087100;1`<00PL00`071`021`0300L700T700<01`L0
0PL00`071`0A1`0300L7008700<01`L07PL002070P0?1`0300L700T70`0:1`@01`L00`071`031`03
00L7014700D01`L7000;1`<00PL00`071`061`<020L00`071`021`0300L700P700<01`L0100:1`<0
1@L00`071`031`0300L700P700<01`L00`L00`071`0@1`0300L700<700<01`L07@L0024700<01`L0
3PL00`071`051`<02`L400X700<01`L00PL00`071`0A1`0300L7008700<01`L01@L300031`070087
00<01`L00PL400/700<01`L00`L00`071`071`<00`L00`071`051`<02@L00`071`031`0300L700P7
00<01`L00PL00`071`0A1`0300L700<700<01`L070L0024700<01`L03PL00`071`021`<02`L300<7
00<01`L02@L00`071`021`0300L7014700<01`L00PL010071`L300D700@01`L7100@1`0300L70087
00<01`L010L3008700<01`L00PL010071`L300d700<01`L00PL00`071`091`0300L7008700<01`L0
4@L00`071`021`0300L701`7000R1`0300L700h7100;1`<00PL00`071`021`0300L700T700<01`L0
0PL00`071`0A1`0400L71`@020L00`07000301<700<01`L00PL00`071`0300D700<01`L00PL40147
00<01`L00PL00`071`081`0300L700<700<01`L04@L010071`L201d7000S1`0300L700/7100:1`<0
1@L00`071`031`0300L700P700<01`L00`L00`071`0@1`0300L000<02@L300@700<01`L04@L01007
1`L300T710021`0300L7010700<01`L00`L00`071`081`0300L700<700<01`L040L401l7000T1`03
00L700P70P031`0300L700D70`091`0300L700<700<01`L020L00`071`021`0300L700l70`041`03
00L700<70`031`0500L71`004`L4008700<01`L01@L400@700<01`L04@L00`071`021`0300L700T7
00<01`L00PL00`071`0>1`@08@L002@700<01`L02@L00`071`021`0400L71`<03@L00`071`021`03
00L700T700<01`L00PL00`071`0;1`<00`L01@071`L000870`071`0500L71`0040L400@700<01`L0
0PL300@700<01`L00PL00`071`0A1`0300L7008700<01`L02@L010071`L200`70`041`0300L701h7
000U1`0300L700P700<01`L00PL4014700<01`L00PL00`071`081`0300L700<700<01`L01`L300L7
00<01`L00`0:1`0300L7008700<01`L02PL300@700<01`L00PL400L700<01`L00`L00`071`0A1`03
00L7008700<01`L020L4008700<01`L01PL300L700<01`L07PL002H700<01`L020L4008700<01`L0
40L00`071`031`0300L700P700<01`L00`L00`071`031`<02PL3008700<01`L02@L00`071`021`03
00L700H70`071`0300L700@02PL00`071`021`0300L7014700<01`L00`L00`071`051`@010L00`07
1`021`@02`L00`071`0M1`009`L00`071`051`@010L00`071`0A1`0300L7008700<01`L02@L00`07
1`021`0300L700<02PL300031`07008700<01`L02PL01@071`L000D70`0:1`<00`L00`071`091`03
00L7008700<01`L04@L00`071`021`0300L700870`041`0300L70087100@1`0300L701`7000W1`03
00L700870`041`0300L7008700<01`L04@L00`071`021`0300L700T700@01`L70`0:1`<01@L01@07
1`L000`700H01`L700L300X70`021`0300L7008700<01`L02@L00`071`021`0300L7014700<01`L0
0PL400L700<01`L0100C1`0300L701/7000X1`@01`L00`071`031`0300L7014700<01`L00PL00`07
1`081`@00PL00`071`051`<020L00`071`021`0300L700T700<01`L00`0:1`<01@L00`071`031`03
00L700P700<01`L00`L00`071`0@1`0300L000@02@L300@700<01`L040L00`071`0K1`009PL400X7
00<01`L00PL00`071`0A1`0300L700<700<01`L01@L400@700<01`L00PL300`700<01`L00PL00`07
1`081`<00PL00`071`051`<02@L00`071`031`0300L700P700<01`L00PL00`071`0?1`<01@L00`07
1`031`<00PL00`071`021`0300L7014700<01`L06PL002@70P031`0300L700T700<01`L00PL00`07
1`0A1`0300L7008700<01`L00PL300@700<01`L00PL4010700D01`L700071`<00PL01@071`L000<7
0`0=1`0300L7008700<01`L02@L00`071`021`0300L700/70`031`0300L7008700<01`L00`061`03
00L7008700<01`L04@L00`071`0I1`009@L00`071`021`0300L700T700<01`L00PL00`071`0A1`03
00L7008710071`0300L700@04`L01@071`L000<70`051`0300L700870`0A1`0300L7008700<01`L0
20L00`071`031`0300L700L70`071`0400L71`<02@L00`071`031`0300L7014700<01`L060L002D7
00<01`L00`L00`071`081`0300L700<700<01`L040L00`07000400T70`031`0300L7014700<01`L0
0PL300T710000`L01`0A1`0300L700<700<01`L020L00`071`031`0300L700<70`0:1`@00PL00`07
1`081`0300L700<700<01`L040L00`071`0H1`009PL00`071`031`0300L700P700<01`L00PL00`07
1`0?1`<01@L00`071`031`<00PL00`071`021`0300L7014710000`L01`071`@00`L00`071`0A1`03
00L7008700<01`L02@L00`071`021`0300L700<02`L400@700<01`L02@L00`071`021`0300L70107
0P0I1`009`L00`071`021`0300L700T700<01`L00PL00`071`0;1`<00`L00`071`021`0300L700<0
1PL00`071`021`0300L700d71@031`0300L700<70`031`0300L7008700<01`L04@L00`071`021`03
00L700T700@01`L70`0;1`<010L00`071`021`0300L700T700<01`L00PL00`071`0<1`<06`L002P7
00<01`L00PL00`071`081`0300L700<700<01`L01`L300L700@01`L70`091`0300L700<700<01`L0
2@L300D700H01`L700L300L700<01`L00PL00`071`0A1`0300L7008700<01`L020L4008700<01`L0
1PL300L700<01`L00`L00`071`081`0300L700<700<01`L020L301h7000X1`0300L700<700<01`L0
20L00`071`031`0300L700<70`0:1`@00PL00`071`081`0300L7008700<01`L01PL300P700<01`L0
0`0;1`0500L71`004`L00`071`031`0300L700D710041`0300L70087100;1`0300L700<700<01`L0
1`L200@700<01`L01@L30247000Y1`0300L7008700<01`L02@L00`071`021`0300L700<02`L400@7
00<01`L02@L00`071`021`0300L700870`0;1`<00PL00`071`0:1`0500L71`004`L00`071`021`03
00L700870`041`0300L70087100@1`0300L7008700<01`L010L3008700<01`L00PL010071`L302@7
000Z1`0300L7008700<01`L02@L010071`L300/70`041`0300L7008700<01`L02@L00`071`021`@0
2`L3008700D01`L7000;1`0300L7008700<01`L04@L00`071`021`@01`L00`071`0401<700<01`L0
0PL00`071`0300D700<01`L00PL402L7000[1`0300L7008700<01`L020L4008700<01`L01PL300L7
00<01`L00`L00`071`081`0300L700<02`L300D700<01`L00PL00`071`091`0300L7008700<01`L0
40L00`07000400T70`041`0300L7010700<01`L00PL300T710021`0300L702H7000[1`0300L700<7
00<01`L01@L400@700<01`L00PL400/700<01`L00PL00`071`081`<00`L00`071`051`<02@L00`07
1`021`0300L700T700D01`L7000A1`<01@L00`071`031`<00PL00`071`021`0300L7014710021`03
00L700D710041`0300L702H7000/1`0300L7008700<01`L00PL300@700<01`L00PL4010700<01`L0
0PL00`071`041`<00PL00`071`021`0400L71`<03@L01@071`L000/700<01`L00PL00`071`0;1`<0
0`L00`071`021`0300L700<01PL00`071`021`0300L700d71@041`0300L700870`041`0300L70087
00<01`L09@L002d700<01`L00PL400L700<01`L0100C1`0300L7008700<01`L00`051`0300L70087
100A1`0500L71`002`L00`071`021`0300L700L70`071`0400L71`<02@L00`071`031`0300L700T7
0`051`0300L7008710071`0300L700<700<01`L090L002d700<01`0010091`<010L00`071`0@1`03
00L700870`091`@000<700L04PL00`071`021`0300L700T700<01`L00PL00`071`031`<02PL40087
00<01`L020L00`071`031`0300L700D70`081`0300L700@02PL00`071`021`0300L702@7000/1`<0
1@L00`071`031`<00PL00`071`021`0300L7014710000`L01`071`@010L00`071`0A1`0500L71`00
2`L00`071`021`0300L700<02`L400@700<01`L02@L00`071`021`0300L700870`0;1`<00`L00`07
1`091`0300L7008700<01`L08`L002T70`031`0300L7008700<01`L00`061`0300L7008700<01`L0
3@L500@700<01`L00PL300@700D01`L7000D1`0500L71`002`L010071`L300/70`041`0300L70087
00<01`L02@L00`071`021`@02`L3008700<01`L00PL00`071`091`0300L7008700<01`L08PL002H7
0`071`0400L71`<02@L00`071`031`0300L700T70`051`0300L7008710071`0300L7008700<01`L0
4PL01@071`L000/70`021`0300L700H70`071`0300L700<700<01`L020L00`071`0400X70`051`03
00L700<700<01`L020L00`071`031`0300L70247000S1`<02PL4008700<01`L020L00`071`031`03
00L700D70`081`0300L700<02`L00`071`021`0300L7014700<01`L00PL00`071`051`@010L00`07
1`021`@02`L00`071`031`0300L700L70`031`0300L700D70`091`0300L700<700<01`L020L00`07
1`021`0300L70247000P1`<02`L400@700<01`L02@L00`071`021`0300L700870`0;1`<00`L00`07
1`091`0500L71`0050L01@071`L000@70`041`0300L70087100@1`0300L7008700<01`L010L30087
00<01`L00PL010071`L300d700<01`L00PL00`071`091`0300L7008700<01`L080L001h70P0;1`<0
10L00`071`021`0300L700T700<01`L00PL400/70`021`0300L7008700<01`L02@L01@071`L001@7
00@01`L710081`0300L000<04`L00`071`021`0300L700<01@L00`071`021`@04@L00`071`021`03
00L700P700<01`L00`L00`071`0O1`007`L00`071`061`<01`L00`071`031`0300L700P700<01`L0
100:1`<01@L00`071`021`0300L700T700<01`L00PL00`071`0A1`H02@L300@700<01`L040L00`07
1`021`<02@L4008700<01`L040L00`071`031`0300L700P700<01`L00`L00`071`0N1`007`L00`07
1`021`@02`L00`071`031`0300L700L70`031`0300L700D70`091`0300L7008700<01`L02@L00`07
1`021`0300L700h710041`0300L700<70`021`0300L7008700<01`L04@L4008700<01`L01@L400@7
00<01`L04@L00`071`021`0300L700T700<01`L00PL00`071`0N1`0080L4010700<01`L00PL00`07
1`041`<00PL00`071`021`0400L71`<03@L00`071`021`0300L700T700D01`L7000=1`<010L01@07
1`L000870`061`0300L7008700<01`L03@L500@700<01`L00PL300@700<01`L00PL00`071`0A1`03
00L7008700<01`L02@L010071`L201l7000N1`@04`L00`071`021`0300L700<01@L00`071`021`@0
4@L01@071`L000/700<01`L00PL00`071`071`<020L00`071`0300X700<01`L00PL00`071`091`<0
1@L00`071`021`@01`L00`071`031`0300L7014700<01`L00PL00`071`081`@00PL00`071`0L1`00
6`L300@700<01`L040L00`071`021`<02@L4008700<01`L040L00`071`021`0300L700T700<01`L0
0PL00`071`031`<02`L3008700<01`L020L00`071`031`0300L700D70`081`0300L700@02PL00`07
1`021`0300L7014700<01`L00`L00`071`051`@010L00`071`0L1`0060L300L700<01`L04@L40087
00<01`L01@L400@700<01`L04@L00`071`021`0300L700T700D01`L700021`<02`L300031`070087
00<01`L02@L00`071`021`0300L700870`0;1`<00`L00`071`091`0300L7008700<01`L04@L00`07
1`021`0300L700870`041`0300L7008700<01`L06`L001D70`0;1`0300L700d71@041`0300L70087
0`041`0300L7008700<01`L04@L01@071`L000`700<01`L00`0;1`<01@L01@071`L000/700<01`L0
0PL400/70`021`0300L7008700<01`L02@L00`071`021`0300L7014700<01`L00PL400L700<01`L0
0`L00`071`0J1`004`L200l700<01`L02@L300D700<01`L00PL400L700<01`L00`L00`071`0A1`05
00L71`002`L3008700<01`L01PL300P700<01`L00PL00`071`081`0300L700@02PL300D700<01`L0
0`L00`071`081`0300L700<700<01`L040L00`07000400X700<01`L00`L00`071`0I1`0050L00`07
1`0>1`0300L700D70`081`0300L700@02PL00`071`021`0300L7014700<01`L00PL00`071`051`<0
00<700L00PL00`071`021`@030L00`071`021`0300L700L70`031`0300L700D70`091`0300L700<7
00<01`L020L00`071`021`0300L700l70`051`0300L700P700<01`L00PL00`071`0I1`0050L00`07
1`0>1`0300L700870`0;1`<00`L00`071`091`0300L7008700<01`L04@L00`071`021`0400L71`<0
1@L010071`L4014700D01`L700061`<00PL00`071`021`0400L71`<03@L00`071`021`0300L700T7
00<01`L00PL00`071`0;1`<00`L00`071`021`0300L700T700<01`L00PL00`071`0H1`005@L00`07
1`0>1`@02`L3008700<01`L00PL00`071`091`0300L7008700<01`L04@L010071`L400P700<01`00
0`0D1`0500L71`000PL300D700<01`L00`L3014700<01`L00PL00`071`081`0300L700<700<01`L0
1`L300L700@01`L70P0:1`0300L700<700<01`L05`L001H700<01`L02`L400X70`051`0300L700<7
00<01`L020L00`071`031`0300L7010700<01`000`091`<010L00`071`0A1`0400L71`<02@L00`07
000200031`07014700<01`L00`L00`071`081`0300L700<700<01`L00`L300X710021`0300L700P7
00<01`L00`L00`071`0F1`005`L00`071`081`800`L00`071`051`<02@L00`071`031`0300L700P7
00<01`L00PL00`071`0?1`<010L00`071`031`<00`L01@071`L001@70`021`0300L700H70`041`03
00L7014700<01`L00PL00`071`091`0300L7008700<01`L00`0;1`@010L00`071`091`0300L70087
00<01`L05PL001L700<01`L02@L00`071`021`0400L71`<03@L00`071`021`0300L700T700<01`L0
0PL00`071`0;1`<00`L01@071`L000870`071`0500L71`0040L300031`07008700<01`L00`L300<7
00<01`L00PL00`071`0A1`0300L7008700<01`L02@L010071`L300/70`041`0300L7008700<01`L0
2@L00`071`021`0300L701D7000H1`0300L700P700<01`L00PL4014700<01`L00PL00`071`081`03
00L700<700<01`L01`L300L700<01`L00`0:1`0300L7008700<01`L02PL300D700H01`L700L300H7
00<01`L00`L00`071`0A1`0300L7008700<01`L020L4008700<01`L01PL300L700<01`L00`L00`07
1`081`0300L700<700<01`L050L001T700<01`L020L4008700<01`L040L00`071`031`0300L700P7
00<01`L00`L00`071`031`<02PL3008700<01`L02@L00`071`021`0300L700H70`081`0300L700<0
2PL00`071`021`0300L7014700<01`L00`L00`071`051`@010L00`071`021`@02`L00`071`031`03
00L700L70P041`0300L701@7000J1`0300L700D710041`0300L7014700<01`L00PL00`071`091`03
00L7008700<01`L00`0:1`<000<700L00PL00`071`0:1`0500L71`001@L300/70`021`0300L700T7
00<01`L00PL00`071`0A1`0300L7008700<01`L00PL300@700<01`L00PL4010700<01`L00PL00`07
1`041`<00PL00`071`021`0300L701<7000J1`0300L700870`041`0300L7008700<01`L04@L00`07
1`021`0300L700T700@01`L70`0:1`<01@L01@071`L000`700H01`L700L300/70`021`0500L71`00
2`L00`071`021`0300L7014700<01`L00PL400L700<01`L0100C1`0300L7008700<01`L00`051`03
00L700<700<01`L04PL001/710071`0300L700<700<01`L04@L00`071`021`0300L700P710021`03
00L700D70`081`0300L7008700<01`L02@L00`071`0300/70`051`0300L7008700<01`L020L00`07
1`031`0300L7010700<01`0010091`<010L00`071`0@1`0300L700870`091`0300L700<700<01`L0
4@L001T7100:1`0300L7008700<01`L04@L00`071`031`0300L700D710041`0300L700870`0<1`03
00L7008700<01`L020L3008700<01`L01PL300T700<01`L00PL00`071`081`0300L7008700<01`L0
3`L300D700<01`L00`L3008700<01`L00PL00`071`0A1`@00PL00`071`081`0300L7008700<01`L0
4@L001L70P031`0300L700T700<01`L00PL00`071`0A1`0300L7008700<01`L00PL300@700<01`L0
0PL4010700D01`L700071`<00PL01@071`L000@70`0=1`0500L71`002`L00`071`021`0300L700/7
0`031`0300L7008700<01`L00`061`0300L7008700<01`L03@L500@700<01`L02@L00`071`021`03
00L70107000H1`0300L7008700<01`L02@L00`071`021`0300L7014700<01`L00PL400L700<01`L0
100C1`0500L71`000`L300D700<01`L00PL4010700<01`L00PL00`071`081`0300L700<700<01`L0
1`L300L700@01`L70`091`0300L700<700<01`L02@L300D700<01`L00PL00`071`081`0300L700<7
00<01`L03`L001P700<01`L00`L00`071`081`0300L700<700<01`L040L00`07000400T70`041`03
00L7010700<01`L00PL300T710000`L01`0B1`0300L7008700<01`L020L00`071`031`0300L700<7
0`0:1`@00PL00`071`081`0300L700<700<01`L01@L300P700<01`L00`L00`071`081`0300L70087
00<01`L03`L001T700<01`L00`L00`071`081`0300L7008700<01`L03`L300D700<01`L00`L30087
00<01`L00PL00`071`0A1`@000<700L01`L400<700<01`L04PL01@071`L000/700<01`L00PL00`07
1`0300/710041`0300L700T700<01`L00PL00`071`021`<02`L200D700<01`L020L00`071`021`03
00L700h7000J1`0300L7008700<01`L02@L00`071`021`0300L700/70`031`0300L7008700<01`L0
0`061`0300L7008700<01`L03@L500<700<01`L00`L300@700D01`L7000D1`0500L71`002`L01007
1`L300/70`041`0300L7008700<01`L02@L00`071`021`@02`L3008700<01`L00PL00`071`091`03
00L7008700<01`L03@L001/700<01`L00PL00`071`081`0300L700<700<01`L01`L300L700@01`L7
0`091`0300L700<700<01`L02@L300D700H01`L700L300L700<01`L00PL00`071`0A1`0300L70087
00<01`L020L4008700<01`L01PL300L700<01`L00`L00`071`081`0300L700@02PL300D700<01`L0
0`L00`071`081`0300L700<700<01`L030L001/700<01`L00`L00`071`081`0300L700<700<01`L0
0`L300X710021`0300L700P700<01`L00`L00`071`051`<020L00`071`0300/700D01`L7000D1`03
00L7008700<01`L01@L400@700<01`L00PL400/700<01`L00`L00`071`071`<00`L00`071`051`<0
2@L00`071`031`0300L700P700<01`L00PL00`071`0<1`0070L00`071`021`0300L700T700<01`L0
0PL00`071`0300/710041`0300L700T700<01`L00PL00`071`021`<02`L3008700<01`L02PL01@07
1`L001@700D01`L700041`<010L00`071`021`@040L00`071`021`0300L700@70`021`0300L70087
00@01`L70`0=1`0300L700<700<01`L020L00`071`021`0300L700/7000M1`0300L7008700<01`L0
2@L010071`L300/70`041`0300L7008700<01`L02@L00`071`021`@02`L3008700D01`L7000<1`05
00L71`004`L00`071`021`@01`L00`071`0401<700<01`L00PL00`071`0300D700<01`L00PL40147
00<01`L00PL00`071`091`0300L7008700<01`L02PL001h700<01`L00PL00`071`081`@00PL00`07
1`061`<01`L00`071`031`0300L700P700<01`L0100:1`<01@L00`071`021`0300L700T700<01`L0
0PL00`071`0A1`H02@L300@700<01`L040L00`071`021`<02@L4008700<01`L040L00`071`031`03
00L700P700<01`L00`L00`071`091`007PL00`071`031`0300L700D710041`0300L70087100;1`03
00L700<700<01`L01`L300<700<01`L01@L300T700<01`L00PL00`071`091`0500L71`004@L400@7
00<01`L00`L3008700<01`L00PL00`071`0A1`@00PL00`071`051`@010L00`071`0A1`0300L700<7
00<01`L020L00`071`021`0300L700T7000O1`0300L7008700<01`L00PL300@700<01`L00PL40107
00<01`L00PL00`071`041`<00PL00`071`021`0400L71`<03@L01@071`L000`700D01`L7000=1`<0
0`L00`071`021`0300L700<01PL00`071`021`0300L700d71@041`0300L700870`041`0300L70087
00<01`L04@L00`071`031`0300L700P700@01`L70P0:1`0080L00`071`021`@01`L00`071`0401<7
00<01`L00PL00`071`0300D700<01`L00PL4014700D01`L7000;1`0300L7008700<01`L01`L300L7
00@01`L70`091`0300L700<700<01`L02@L300D700<01`L00PL400L700<01`L00`L00`071`0A1`03
00L7008700<01`L02@L300`7000P1`0300L000@02@L300@700<01`L040L00`071`021`<02@L40087
00<01`L040L00`071`021`0300L700T700<01`L00PL00`071`031`<02`L3008700<01`L020L00`07
1`031`0300L700D70`081`0300L700@02PL00`071`021`0300L7014700<01`L00`L00`071`051`@0
3PL001l70`051`0300L700<70`021`0300L7008700<01`L04@L4008700<01`L01@L400@700<01`L0
4@L01@071`L000`700D01`L700021`<02`L400@700<01`L02@L00`071`021`0300L700870`0;1`<0
10L00`071`081`0300L7008700<01`L04@L00`071`031`0400L71`<010L00`071`0;1`0070L300<7
00<01`L00PL00`071`0300H700<01`L00PL00`071`0=1`D010L00`071`021`<010L00`071`021`03
00L7014700D01`L7000<1`0300L700<02`L300@700<01`L00PL00`071`091`0300L70087100;1`<0
0PL00`071`021`0300L700T700<01`L00PL00`071`0A1`0300L700<70`081`0300L700X7000I1`<0
1`L010071`L300T700<01`L00`L00`071`091`<01@L00`071`021`@01`L00`071`031`0300L70147
00D01`L7000;1`<00PL00`071`061`<020L00`071`021`0300L700P700<01`L0100:1`<01@L00`07
1`031`0300L700P700<01`L00`L00`071`0A1`H02`L00`071`091`005PL300X710021`0300L700P7
00<01`L00`L00`071`051`<020L00`071`0400X700<01`L00PL00`071`0A1`0300L7008700<01`L0
1@L300031`07008700<01`L00PL400/700<01`L00`L00`071`071`<010L00`071`041`<02@L00`07
1`031`0300L700P700<01`L00PL00`071`0?1`<01@L00`071`081`0300L700T7000C1`<02`L400@7
00<01`L02@L00`071`021`0300L700870`0;1`<00`L00`071`091`0300L7008700<01`L04@L01@07
1`L000@70`051`0400L71`@040L00`071`021`0300L700@70`021`0300L7008700@01`L70`0=1`03
00L700<700<01`L020L00`071`021`0300L700/70`031`0300L700870P0:1`0300L700P7000A1`80
2`L300@700<01`L00PL00`071`091`0300L70087100;1`<00PL00`071`021`0300L700T700<01`L0
0PL00`071`0A1`0400L71`@020L00`07000301<700<01`L00PL00`071`0300D700<01`L00PL40147
00<01`L00PL00`071`091`0300L7008700<01`L01`L300L7100=1`0300L700L7000B1`0300L700H7
0`071`0300L700<700<01`L020L00`071`0400X70`051`0300L700<700<01`L020L00`071`031`03
00L7010700<01`000`091`<010L00`071`0A1`0400L71`<02@L4008700<01`L040L00`071`031`03
00L700P700<01`L00`L00`071`031`<020L4010700<01`L01PL0018700<01`L00PL400/700<01`L0
0`L00`071`071`<00`L00`071`051`<02@L00`071`031`0300L700P700<01`L00PL00`071`0?1`<0
10L00`071`031`<00`L01@071`L001<710021`0300L700D710051`0300L7010700<01`L00`L00`07
1`081`0300L7008700<01`L00`081`<00`L00`071`0>1`0300L700H7000C1`@040L00`071`021`03
00L700@70`021`0300L7008700@01`L70`0=1`0300L7008700<01`L02@L00`071`021`0300L700/7
0`031`0500L71`000PL300L700D01`L7000@1`@010L00`071`021`<010L00`071`021`0300L70147
00<01`L00`L00`071`081`0400L71`<020L300L700<01`L03PL00`071`051`004@L401<700<01`L0
0PL00`071`0300D700<01`L00PL4014700<01`L00PL00`071`081`0300L700<700<01`L01`L300L7
00<01`L00`0:1`0300L7008700<01`L02PL300@700<01`L00PL400L700<01`L00`L00`071`0A1`03
00L7008700<01`L020L4008700<01`L00PL400/700<01`L03@L200H7000>1`<010L00`071`0@1`03
00L700870`091`@00PL00`071`0@1`0300L700<700<01`L020L00`071`031`0300L700<70`0:1`<0
0PL00`071`091`0300L7008700<01`L01PL300L700<01`L0100:1`0300L700<700<01`L040L00`07
1`031`0300L700@70`000`L01`031`0300L0008040L00`071`091`<020L000/70`071`0300L70147
10021`0300L700D710041`0300L7014700<01`L00PL00`071`091`0300L7008700<01`L00`0:1`<0
00<700L00PL00`071`0:1`0500L71`001@L300X70`041`0300L700P700<01`L00`L00`071`0@1`03
00L700<700<01`L00`051`0300L700<04`L00`071`061`<02`L000P70`0;1`0300L700d71@041`03
00L700870`041`0300L7008700<01`L04@L00`071`021`0300L700T700@01`L70`0:1`<01@L01@07
1`L000`700H01`L700L300X70`021`0300L7008700<01`L02@L00`071`021`0300L7014700@01`L7
10081`<00`L00`071`0A1`0300L700870`0>1`001PL200l700<01`L02@L300D700<01`L00PL400L7
00<01`L00`L00`071`0A1`0300L7008700<01`L020L4008700<01`L01@L300P700<01`L00PL00`07
1`091`0300L700<02PL300D700<01`L00`L00`071`081`0300L700<700<01`L04@L3008700<01`L0
10L3008700<01`L00PL00`071`0A1`@04@L000L700<01`L03PL00`071`051`<020L00`071`0400X7
00<01`L00PL00`071`0A1`0300L700<700<01`L01@L400@700<01`L00PL300`700<01`L00PL00`07
1`081`<00`L00`071`041`<02@L00`071`031`0300L700P700<01`L00`L00`071`0<1`D01@L00`07
1`0300D700<01`L00PL00`071`0>1`D04`L000L700<01`L03PL00`071`021`<02`L300<700<01`L0
2@L00`071`021`0300L7014700<01`L00PL00`071`021`<010L00`071`021`@040L01@071`L000L7
0`021`0500L71`000`L300d700<01`L00`L00`071`081`0300L700<700<01`L020L300D700<01`L0
0PL300T700<01`L00PL00`071`0:1`<010L00`071`0A1`0020L00`071`0>1`@02`L3008700<01`L0
0PL00`071`091`0300L7008700<01`L04@L00`071`021`@01`L00`071`0401<700D01`L700031`<0
1@L00`071`021`<04@L00`071`021`0300L700T700<01`L00PL00`071`051`<02@L4008700<01`L0
20L00`071`021`0300L700H70`081`0300L7010700091`0300L700/7100:1`<01@L00`071`031`03
00L700P700<01`L00`L00`071`0@1`0300L000@02@L300@700<01`L040L00`071`021`<02@L40003
1`07014700<01`L00`L00`071`081`0300L700<700<01`L0100:1`@010L00`071`091`0300L70087
00<01`L00PL300/70P0A1`002PL00`071`081`800`L00`071`051`<02@L00`071`031`0300L700P7
00<01`L00PL00`071`0?1`<01@L00`071`031`<00PL00`071`021`0300L7014710000`L01`071`@0
10L00`071`0@1`0300L700<700<01`L020L00`071`021`<02`L300<700<01`L00`L00`071`081`03
00L7008700<01`000P0;1`<04`L000X700<01`L02@L00`071`021`0400L71`<03@L00`071`021`03
00L700T700<01`L00PL00`071`0;1`<00`L00`071`021`0300L700<01PL00`071`021`0300L700d7
1@031`0300L700<70`041`0500L71`004`L00`071`031`0300L700P710021`0300L700H70`071`03
00L700<700<01`L020L00`071`0300/70`0F1`002`L00`071`081`0300L70087100A1`0300L70087
00<01`L020L00`071`031`0300L700L70`071`0400L71`<02@L00`071`031`0300L700T70`051`06
00L71`070`071`0300L7008700<01`L04@L00`071`021`0300L700H710041`0300L70087100;1`03
00L700<700<01`L01`L300<700<01`L01@L301T7000<1`0300L700P710021`0300L7010700<01`L0
0`L00`071`081`0300L700<700<01`L00`L300X710021`0300L700P700<01`L00PL00`071`061`<0
20L00`071`0300/700<01`L00PL00`071`0@1`0300L700<700<01`L00PL300<700<01`L00`L40107
00<01`L00PL00`071`041`<00PL00`071`021`0400L71`<070L000d700<01`L01@L400@700<01`L0
4@L00`071`021`0300L700T700<01`L00PL00`071`0300/710041`0300L700T700<01`L00PL00`07
1`021`<02`L300<700<01`L02@L00`071`021`0300L7010700<01`L00`L400L700<01`L0100B1`03
00L700<700<01`L00`051`0300L70087100O1`003@L00`071`021`<010L00`071`021`0300L70147
00<01`L00PL00`071`091`0400L71`<02`L300@700<01`L00PL00`071`091`0300L70087100;1`<0
0PL01@071`L000/700<01`L00PL00`071`0A1`0300L000@02@L300@700<01`L040L00`071`021`<0
2@L400031`070207000>1`@01`L00`071`031`0300L7014700<01`L00PL00`071`081`@00PL00`07
1`061`<01`L00`071`031`0300L700P700<01`L0100:1`<01@L00`071`021`0300L700T700<01`L0
0PL00`071`0?1`<010L00`071`041`<00PL00`071`021`0300L7014710021`0300L700D710041`03
00L701h7000<1`@02PL00`071`021`0300L7014700<01`L00`L00`071`051`@010L00`071`021`@0
2`L00`071`031`0300L700L70`031`0300L700D70`091`0300L7008700<01`L02@L00`071`021`03
00L700/70`021`0300L700<700<01`L00`051`0300L700<700<01`L03@L500@700<01`L00PL300@7
00<01`L00PL00`071`0M1`002PL200<700<01`L02@L00`071`021`0300L7014700<01`L00PL00`07
1`021`<010L00`071`021`@040L00`071`021`0300L700@70`021`0300L7008700@01`L70`0=1`03
00L7008700<01`L02@L00`071`021`0300L700L70`061`0300L700870`091`0300L700<700<01`L0
2@L300@700<01`L00`L400L700<01`L00PL00`071`0M1`002`L00`071`021`0300L700T700<01`L0
0PL00`071`0A1`0300L7008710071`0300L700@04`L00`071`021`0300L700<01@L00`071`021`@0
4@L01@071`L000/700<01`L00PL00`071`041`<02PL4008700<01`L020L00`071`031`0300L700D7
0`081`0300L700@02PL00`071`021`0300L701`7000;1`0300L700<700<01`L020L00`071`031`03
00L7010700<01`0010091`<010L00`071`0@1`0300L700870`091`@000<700L04PL00`071`021`03
00L700T700<01`L00PL00`071`0300/710041`0300L700T700<01`L00PL00`071`021`<02`L300<7
00<01`L02@L00`071`021`0300L701/7000<1`0300L700<700<01`L020L00`071`021`0300L700l7
0`051`0300L700<70`021`0300L7008700<01`L04@L400031`0700L710041`0300L7014700<01`L0
0PL00`071`091`0400L71`<02`L300<700<01`L00`L00`071`081`0300L700<7100;1`<00PL00`07
1`021`0300L700T700<01`L00PL00`071`0J1`003@L00`071`021`0300L700T700<01`L00PL00`07
1`0;1`<00`L00`071`021`0300L700<01PL00`071`021`0300L700d71@041`0300L700870`041`03
00L7008700<01`L04@L00`071`021`0300L700P710021`0300L700H70`071`0300L700<700<01`L0
20L00`071`0400X70`051`0300L700<700<01`L020L00`071`021`0300L701X7000>1`0300L70087
00<01`L020L00`071`031`0300L700L70`071`0400L71`<02@L00`071`031`0300L700T70`051`03
00L7008710071`0300L700<700<01`L040L00`071`021`0300L700H710041`0300L70087100;1`03
00L700<700<01`L01`L300<700<01`L01@L300T700<01`L00`L00`071`081`0300L7008700<01`L0
6@L000h700<01`L00`L00`071`081`0300L700<700<01`L00`L300X710021`0300L700P700<01`L0
0`L00`071`051`<020L00`071`0400X700<01`L00PL00`071`0A1`0300L7008700<01`L00PL300@7
00<01`L00PL4010700<01`L00PL00`071`041`<00PL00`071`021`0400L71`<03@L00`071`021`03
00L700T700<01`L00PL00`071`0H1`003`L00`071`021`0300L700T700<01`L00PL00`071`0300/7
10041`0300L700T700<01`L00PL00`071`021`<02`L300<700<01`L02@L00`071`021`0300L70147
00<01`L00PL400P700<01`000`0B1`0300L700<700<01`L00`051`0300L70087100A1`0300L70087
00<01`L020L00`071`031`0300L701L7000@1`0300L7008700<01`L02@L00`071`021`802`L300@7
00<01`L00PL00`071`091`0300L70087100;1`<00PL00`071`021`0300L700T700<01`L00PL00`07
1`0A1`H02@L300@700<01`L040L00`071`021`<02@L4008700<01`L040L00`071`031`0300L700P7
00<01`L00PL00`071`0G1`004@L00`071`021`0300L700P700<01`L00`L00`071`061`<01`L00`07
1`031`0300L700P700<01`L0100:1`<01@L00`071`031`0300L700P700<01`L00PL00`071`0?1`<0
10L00`071`041`<00PL00`071`021`0300L7014710021`0300L700D710041`0300L7014700<01`L0
0PL00`071`091`0300L7008700<01`L05PL0014700<01`L00`L00`071`081`0300L7008700<01`L0
0PL400/700<01`L00`L00`071`071`<010L00`071`041`<02@L00`071`021`0300L700T700<01`L0
0PL00`071`0;1`<00`L00`071`021`0300L700<01PL00`071`021`0300L700d71@041`0300L70087
0`041`0300L7008700<01`L04@L00`071`021`0300L700T700@01`L70P0G1`004PL00`071`021`03
00L700T700<01`L00PL4010700<01`L00PL00`071`041`<00PL00`071`021`0400L71`<03@L00`07
1`021`0300L700T700<01`L00PL00`071`071`<01`L010071`L300T700<01`L00`L00`071`091`<0
10L00`071`031`@01`L00`071`031`0300L7014700<01`L00PL00`071`081`@06@L001<700<01`L0
0PL00`071`081`0300L700@04`L00`071`021`0300L700<01@L00`071`021`@04@L00`071`021`03
00L700T700<01`L00PL00`071`031`<02PL4008700<01`L020L00`071`031`0300L700D70`081`03
00L700@02PL00`071`021`0300L7014700<01`L00`L00`071`051`@06`L001<700<01`L00`L00`07
1`071`<010L00`071`0@1`0300L700870`091`@00PL00`071`0@1`0300L700<700<01`L020L00`07
1`021`0300L700<02`L400@700<01`L02@L00`071`021`0300L700870`0;1`<00`L00`071`091`03
00L7008700<01`L04@L00`071`021`0300L700870`041`0300L701P7000D1`0300L700<700<01`L0
0`L3008700<01`L00PL00`071`0A1`@00PL00`071`051`@01@L00`071`0@1`0300L7008700<01`L0
2@L010071`L300/70`041`0300L7008700<01`L02@L00`071`021`@02`L3008700<01`L00PL00`07
1`091`0300L7008700<01`L04@L00`071`021`@01`L00`071`0H1`005@L00`071`021`0300L700<0
1PL00`071`021`0300L700d71@041`0300L700870`041`0300L7008700<01`L04@L00`071`021`03
00L700T70`021`0300L700H70`081`0300L7008700<01`L020L00`071`0400X70`051`0300L700<7
00<01`L020L00`071`031`0300L7010700<01`00100:1`0300L701L7000F1`0300L700870P091`03
00L700<700<01`L02@L300D700<01`L00PL400L700<01`L00`L00`071`0A1`0300L7008700<01`L0
1@L300031`07008700<01`L00PL400/700<01`L00`L00`071`071`<00`L00`071`051`<02@L00`07
1`031`0300L700P700<01`L00PL00`071`0?1`<01@L00`071`081`0300L701H7000F1`0300L700<7
00<01`L020L00`071`031`0300L700D70`081`0300L700@02PL00`071`031`0300L7010700<01`L0
0PL00`071`021`<010L00`071`021`@040L00`071`021`0300L700@70`021`0300L7008700@01`L7
0`0=1`0300L7008700<01`L02@L00`071`021`0300L700/70`031`0300L7008700<01`L02@L00`07
1`0E1`005`L00`071`021`0300L700T700<01`L00PL00`071`021`<02`L300@700<01`L020L00`07
1`031`0300L7010700<01`L00PL400P700<01`000`0C1`0300L7008700<01`L00`051`0300L70087
100A1`0300L7008700<01`L020L00`071`031`0300L700L70`071`0400L71`802PL00`071`0E1`00
60L00`071`021`0300L700T700<01`L00PL400/70`021`0300L7008700<01`L02@L00`071`021`03
00L7014700<01`000`091`<010L00`071`0@1`0300L700870`091`@00PL00`071`0@1`0300L700<7
00<01`L020L00`071`031`0300L700<70`0:1`@03@L00`071`0D1`0060L00`071`031`0300L700P7
00<01`L0100:1`<01@L00`071`031`0300L700P700<01`L00`L00`071`0?1`<010L00`071`031`<0
0`L01@071`L001<710021`0300L700D710041`0300L7014700<01`L00PL00`071`091`0300L70087
00<01`L00`0;1`@040L00`071`0C1`006@L00`071`031`0300L700P70P041`0300L700@70`091`03
00L700<700<01`L020L00`071`031`0300L700/70`021`0300L7008700<01`L00`061`0300L70087
00<01`L03PL400@700<01`L00PL300@700<01`L00PL00`071`0A1`0300L7008700<01`L02@L01007
1`L300/70`041`0300L700h700<01`L04PL001X700<01`L00PL00`071`091`0300L7008700@01`L7
0`0=1`0300L700<700<01`L020L00`071`031`0300L700L70`061`0400L71`<02PL00`071`021`03
00L700X70`041`0300L7008710071`0300L700<700<01`L04@L00`071`021`0300L700P710021`03
00L700H70`071`0300L700h700<01`L04PL001/700<01`L00PL00`071`081`0300L70087100A1`03
00L7008700<01`L02@L00`071`021`0300L700@70`0:1`<00PL00`071`091`0300L7008700<01`L0
1PL300L700<01`L0100:1`0300L7008700<01`L04@L00`071`031`0300L700D710041`0300L70087
100;1`0300L700d70P0C1`006`L00`071`031`0300L700P710021`0300L7010700<01`L00`L00`07
1`081`0300L700<700<01`L00`0:1`<000<700L00PL00`071`0:1`0500L71`001@L300X70`031`03
00L700T700<01`L00PL00`071`0A1`0300L7008700<01`L00PL300@700<01`L00PL4010700<01`L0
2@L301D7000L1`0300L700<700<01`L01@L400D700<01`L040L00`071`031`0300L700P700<01`L0
0PL300X70`041`0300L7008700<01`L02@L00`071`021`0300L000802PL3008700<01`L00PL00`07
1`091`0300L7008700<01`L04@L00`071`021`@01`L00`071`0401<700<01`L01@L301P7000M1`03
00L7008700<01`L00PL300@700<01`L00PL00`071`0A1`0300L700<700<01`L020L4008700<01`L0
1@L300P700<01`L00PL00`071`091`0300L700<02PL300D700<01`L00`L00`071`081`0300L700<7
00<01`L040L00`07000400T70`041`0300L7010700<01`L00PL301/7000N1`0300L7008710071`03
00L700<700<01`L04@L00`071`021`0300L700H710041`0300L700870`0<1`0300L7008700<01`L0
20L3008700<01`L01@L300T700<01`L00`L00`071`081`0300L7008700<01`L03`L300D700<01`L0
0`L3008700<01`L00PL00`071`0A1`@07PL001h700<01`L0100:1`0300L700<700<01`L040L00`07
1`031`0300L700870`031`0300L700<7100@1`0500L71`001`L3008700D01`L700031`<03@L00`07
1`021`0300L700T700<01`L00PL00`071`0;1`<00`L00`071`021`0300L700<01PL00`071`021`03
00L700d71@0P1`007`L200@700<01`L020L00`071`031`0300L7010700<01`L00`L400L700<01`L0
100B1`0300L7008700@01`L70`051`0300L700870`0A1`0300L7008700<01`L020L00`071`031`03
00L700L70`071`0400L71`<02@L00`071`031`0300L700T70`051`0300L701d7000P1`0300L70087
00<01`L02@L00`071`021`0300L7014700<01`0010091`<010L00`071`0@1`0300L700870`091`@0
00<700L04@L00`071`031`0300L700P700<01`L00`L00`071`031`<02PL4008700<01`L020L00`07
1`031`0300L700D70`081`0300L701d7000P1`0300L700<700<01`L020L00`071`031`0300L700l7
0`041`0300L700@70`021`0300L7008700<01`L04@L400031`0700L710031`0300L7014700<01`L0
0PL00`071`091`0300L7008700<01`L00`0;1`@010L00`071`091`0300L7008700<01`L00PL300/7
0P0N1`008@L00`071`031`0300L700P700<01`L00`L00`071`0;1`<00PL00`071`031`0300L700<0
1@L00`071`031`0300L700d71@031`0300L700<70`041`0500L71`004`L00`071`021`0300L700T7
00@01`L70`0;1`<010L00`071`021`0300L700T700<01`L00PL400/70`0P1`008PL00`071`031`03
00L700P700<01`L00`L00`071`071`<01PL00`071`021`<02@L00`071`031`0300L700T70`041`03
00L7008700<01`000P071`0300L7008700<01`L04@L00`071`021`0300L700P710021`0300L700H7
0`071`0300L700<700<01`L020L00`071`0400X70`0S1`008`L00`071`021`0300L700T700<01`L0
0PL00`071`041`<02PL4008700<01`L020L00`071`031`0300L700D70`081`0300L700<02`L01@07
1`L001<700<01`L00`L00`071`051`@010L00`071`021`@02`L00`071`031`0300L700L70`031`03
00L700D70`0V1`008`L00`071`031`0300L700P700<01`L00`L00`071`0300/710041`0300L700T7
00<01`L00PL00`071`021`<02`L3008700<01`L02PL01@071`L001<700<01`L00PL00`071`021`<0
10L00`071`021`@040L00`071`021`0300L700@70`021`0300L7008700@01`L70`0Y1`0090L00`07
1`031`0300L700P700<01`L00PL300/70`031`0300L700<700<01`L020L00`071`031`@02`L30087
00D01`L7000<1`0500L71`004`L00`071`021`@01`L00`071`0401<700<01`L00PL00`071`0300D7
00<01`L00PL402`7000U1`0300L700<700<01`L020L4008700<01`L01PL300L700<01`L00`L00`07
1`081`0300L700@02PL300D700<01`L00PL00`071`091`0300L7008700<01`L040L00`07000400T7
0`041`0300L7010700<01`L00PL300T710021`0300L702/7000V1`0300L7008700<01`L01PL400@7
00<01`L00PL400/700<01`L00`L00`071`071`<00`L00`071`051`<02@L00`071`021`0300L700T7
00D01`L7000A1`<01@L00`071`031`<00PL00`071`021`0300L7014710021`0300L700D710041`03
00L702/7000V1`0300L700<700<01`L00PL300<700<01`L00`L4010700<01`L00PL00`071`041`<0
0PL00`071`021`0400L71`<03@L01@071`L000`700D01`L7000=1`<00`L00`071`021`0300L700<0
1PL00`071`021`0300L700d71@041`0300L700870`041`0300L7008700<01`L0:PL002L700<01`L0
0`L400L700<01`L0100B1`0300L700<700<01`L00`051`0300L70087100A1`0500L71`002`L00`07
1`021`0300L700L70`071`0400L71`<02@L00`071`031`0300L700T70`051`0300L7008710071`03
00L700<700<01`L0:@L002P700<01`0010091`<010L00`071`0@1`0300L700870`091`@00PL00`07
1`0@1`0300L7008700<01`L02@L00`071`021`0300L700<70`0:1`@00PL00`071`081`0300L700<7
00<01`L01@L300P700<01`L0100:1`0300L7008700<01`L0:@L002L70`041`0300L700@70`021`03
00L7008700<01`L04@L4008700<01`L01@L400@700<01`L04@L01@071`L000`700D01`L700021`<0
2`L400@700<01`L02@L00`071`021`0300L700870`0;1`<00`L00`071`091`0300L7008700<01`L0
:0L002@70`021`0300L700<700<01`L00`051`0300L700<700<01`L03@L500@700<01`L00PL300@7
00<01`L00PL00`071`0A1`0500L71`0030L00`071`0300/70`041`0300L7008700<01`L02@L00`07
1`021`@02`L3008700<01`L00PL00`071`091`0300L7008700<01`L09`L002470`061`0300L700<7
0P091`0300L700<700<01`L02@L300@700<01`L00`L400L700<01`L00`L00`071`0A1`0500L71`00
2`L3008700<01`L01PL300L700<01`L00`L00`071`081`0300L700@02PL300D700<01`L00`L00`07
1`081`0300L700<700<01`L09PL001h70`0:1`0300L700<700<01`L020L00`071`031`0300L700D7
0`081`0300L700@02PL00`071`021`0300L7014700<01`L00PL00`071`051`<000<700L00PL00`07
1`021`@02`L00`071`031`0300L700L70`031`0300L700D70`091`0300L700<700<01`L020L00`07
1`021`0300L702H7000K1`<03PL00`071`021`0300L700T700<01`L00PL00`071`021`<02`L300<7
00<01`L02@L00`071`021`0300L7014700D01`L700041`<01@L010071`L4010700<01`L00PL00`07
1`041`<00PL00`071`021`0400L71`<03@L00`071`021`0300L700T700<01`L00PL00`071`0U1`00
6@L2014700<01`L00`L00`071`081`0300L700<7100;1`<00PL00`071`021`0300L700T700<01`L0
0PL00`071`0A1`0400L71`@020L00`07000301<700<01`L00PL00`071`0300D700<01`L00PL40147
00<01`L00PL00`071`081`0300L700<700<01`L090L001X700<01`L040L00`071`031`0300L700P7
00<01`L0100:1`<01@L00`071`031`0300L700P700<01`L00`L00`071`0@1`0300L000<02@L300@7
00<01`L040L00`071`021`<02@L4008700<01`L040L00`071`031`0300L700P700<01`L00`L00`07
1`0S1`006PL00`071`0A1`0300L700<700<01`L01`L300<700<01`L01@L300T700<01`L00`L00`07
1`081`0300L7008700<01`L03`L300@700<01`L00`L300<700D01`L7000C1`@00PL00`071`051`@0
10L00`071`0A1`0300L7008700<01`L02@L00`071`021`0300L702<7000K1`0300L7014700<01`L0
0PL00`071`041`<00PL00`071`021`0400L71`<03@L00`071`021`0300L700T700<01`L00PL00`07
1`0;1`<00`L01@071`L000870`071`0500L71`0040L400@700<01`L00PL300@700<01`L00PL00`07
1`0A1`0300L7008700<01`L02@L010071`L202@7000L1`0300L7010700<01`L00`L00`071`0300D7
00<01`L00PL4014700<01`L00PL00`071`081`0300L700<700<01`L01`L300L700<01`L00`0:1`03
00L7008700<01`L02PL300@700<01`L00PL400L700<01`L00`L00`071`0A1`0300L7008700<01`L0
20L402H7000M1`0300L7010700<01`L00PL300T710021`0300L7010700<01`L00`L00`071`081`03
00L700<700<01`L00`L300X70`021`0300L700T700<01`L00PL00`071`061`<01`L00`071`0400X7
00<01`L00PL00`071`0A1`0300L700<700<01`L01@L402P7000M1`0300L7014710021`0300L700D7
10041`0300L7014700<01`L00PL00`071`091`0300L7008700<01`L00`0:1`<000<700L00PL00`07
1`0:1`0500L71`001@L300X70`031`0300L700T700<01`L00PL00`071`0A1`0300L7008700<01`L0
0PL300@700<01`L09@L001h700<01`L03@L500@700<01`L00PL300@700<01`L00PL00`071`0A1`03
00L7008700<01`L02@L010071`L300X70`051`0500L71`0030L01P071`L01`<02PL3008700<01`L0
0PL00`071`091`0300L7008700<01`L04@L00`071`021`@01`L00`071`0U1`007`L00`071`091`<0
10L00`071`031`@01`L00`071`031`0300L7014700<01`L00PL00`071`081`@00PL00`071`051`<0
20L00`071`021`0300L700T700<01`L00`0:1`<01@L00`071`031`0300L700P700<01`L00`L00`07
1`0@1`0300L000@02PL00`071`0T1`0080L00`071`051`<020L00`071`0400X700<01`L00PL00`07
1`0A1`0300L700<700<01`L01@L400@700<01`L00PL300`700<01`L00PL00`071`081`<00PL00`07
1`051`<02@L00`071`031`0300L700P700<01`L00PL00`071`0?1`<01@L00`071`081`0300L702<7
000P1`0300L700870`0<1`800`L00`071`091`0300L7008700<01`L04@L00`071`021`0300L70087
0`041`0300L70087100@1`0500L71`001`L3008700D01`L700031`<03@L00`071`021`0300L700T7
00<01`L00PL00`071`0;1`<00`L00`071`021`0300L700T700<01`L08PL00247100@1`0300L70087
00<01`L02@L00`071`021`0300L7014700<01`L00PL400L700<01`L0100C1`0500L71`000`L300D7
00<01`L00PL3014700<01`L00PL00`071`081`0300L700<700<01`L01`L300L700@01`L70P0:1`03
00L70287000O1`@04PL00`071`031`0300L700P700<01`L00`L00`071`0@1`0300L000@02@L300<7
00<01`L04@L00`071`021`<02@L400031`07014700<01`L00`L00`071`081`0300L700<700<01`L0
0`L300X7100=1`0300L70247000M1`800`L00`071`0A1`0300L700<700<01`L020L00`071`021`03
00L700l70`051`0300L700<70`021`0300L7008700<01`L04@L400031`0700L710031`0300L70147
00<01`L00PL00`071`091`0300L7008700<01`L00`0;1`@040L00`071`0P1`007PL00`071`021`03
00L7014700<01`L00PL00`071`091`0300L7008700<01`L02`L300<700<01`L00PL00`071`0300H7
00<01`L00PL00`071`0=1`D00`L00`071`031`<00`L00`071`021`0300L7014700<01`L00PL00`07
1`091`0400L71`<02`L300@700<01`L03PL00`071`0O1`007PL00`071`031`0300L7014700<01`L0
0PL00`071`081`0300L700<700<01`L01`L300L700@01`L70`091`0300L700<700<01`L02@L300D7
00H01`L700L300L700<01`L00PL00`071`0A1`0300L7008700<01`L020L400/70`071`0300L700h7
00<01`L07`L001l700<01`L00`L00`071`0@1`0300L700<700<01`L020L00`071`031`0300L700<7
0`0:1`@00PL00`071`081`0300L7008700<01`L01PL300P700<01`L00`0;1`0500L71`004`L00`07
1`031`0300L700D710091`@02`L00`071`0=1`8080L0020700<01`L00PL00`071`0A1`0300L70087
00<01`L02@L00`071`021`0300L700<02`L400@700<01`L02@L00`071`021`0300L700870`0;1`<0
0PL00`071`0:1`0500L71`004`L00`071`021`0300L700870`041`0300L700<70`0@1`0300L700T7
0`0R1`008@L00`071`021`0300L7014700<01`L00PL00`071`091`0400L71`<02`L300@700<01`L0
0PL00`071`091`0300L70087100;1`<00PL01@071`L000/700<01`L00PL00`071`0A1`0300L70087
10071`0300L700<050L00`071`051`<09@L0024700<01`L00`L00`071`0A1`0300L7008700<01`L0
20L4008700<01`L01PL300L700<01`L00`L00`071`081`0300L700<02`L300D700<01`L00PL00`07
1`091`0300L7008700<01`L040L00`07000400T70`0G1`0300L700870`0X1`008PL00`071`021`03
00L7014700<01`L00`L00`071`051`@010L00`071`021`@02`L00`071`021`0300L700P70`031`03
00L700D70`091`0300L7008700<01`L02@L01@071`L001470`051`0300L700<70`021`0300L701H7
100[1`008`L00`071`021`0300L7014700<01`L00PL00`071`021`<010L00`071`021`@040L00`07
1`021`0300L700@70`021`0300L7008700@01`L70`0=1`0500L71`002`L00`071`021`0300L700/7
0`031`0300L7008700<01`L00`061`0300L701871@0]1`0090L00`071`021`0300L7014700<01`L0
0PL400L700<01`L0100C1`0300L7008700<01`L00`051`0300L70087100@1`0300L7008700<01`L0
2@L00`071`021`0300L700L70`071`0400L71`<02@L00`071`0?1`<01@L00`071`0Z1`0090L00`07
1`031`0300L7010700<01`0010091`<010L00`071`0@1`0300L700870`091`@000<700L04PL00`07
1`021`0300L700T700<01`L00PL00`071`031`<02PL400d700<01`L02`L300P700<01`L0:PL002D7
00<01`L00PL00`071`0?1`<01@L00`071`031`<00PL00`071`021`0300L7014710000`L01`071`@0
10L00`071`0A1`0500L71`002`L00`071`021`0300L700<02`L4010700<01`L01`L300/70P0[1`00
9PL00`071`021`0300L700/70`031`0300L7008700<01`L00`061`0300L7008700<01`L03@L500@7
00<01`L00PL300@700D01`L7000D1`0500L71`002`L010071`L300/70`041`0300L700h700<01`L0
0`L300/70`0]1`009PL00`071`031`0300L700L70`071`0300L700870P091`0300L700<700<01`L0
2@L300D700<01`L00PL400L700<01`L00PL00`071`0A1`0300L7008700<01`L02@L3008700<01`L0
1PL300L700<01`L03PL00`071`0300/70`0`1`009`L00`071`031`0300L700<70`0:1`0300L700<7
00<01`L020L00`071`031`0300L700D70`081`0300L700<02`L00`071`021`0300L7014700<01`L0
0PL00`071`051`@010L00`071`021`@02`L00`071`0=1`<02`L303<7000X1`0300L7008700<01`L0
0`0>1`0300L7008700<01`L02@L00`071`021`0300L700870`0;1`<00`L00`071`091`0500L71`00
50L01@071`L000@70`041`0300L70087100@1`0300L700T70`0;1`<0=PL002T700<01`L00PL20187
00<01`L00PL00`071`091`0300L70087100;1`<00PL00`071`021`0300L700T700D01`L7000C1`03
00L7008710081`0300L000<04`L00`071`051`<02PL403T7000Y1`0300L701H700<01`L00`L00`07
1`081`0300L700@02PL300D700<01`L00PL00`071`091`0300L7008700<01`L04@L600T70`041`03
00L7010700<01`L00PL300X70`0m1`00:PL00`071`0F1`0300L700<700<01`L01`L300<700<01`L0
1@L300T700<01`L00PL00`071`091`0300L7008700<01`L03PL400@700<01`L00`L3008700<01`L0
0PL00`071`0A1`@02PL30407000[1`0300L701H700<01`L00PL00`071`041`<00PL00`071`021`04
00L71`<03@L00`071`021`0300L700T700D01`L7000=1`<00`L00`071`021`0300L700<01PL00`07
1`021`0300L700d71@091`<0@`L002/700<01`L05`L00`071`021`0300L700<01@L00`071`021`@0
4@L01@071`L000/700<01`L00PL00`071`071`<01`L010071`L300X700<01`L00PL00`071`091`<0
1@L00`071`031`<0APL002`700<01`L05PL00`071`021`<02@L4008700<01`L040L00`071`021`03
00L700T700<01`L00PL00`071`031`<02`L3008700<01`L020L00`071`031`0300L700D70`081`03
00L700<0B@L002d700<01`L05PL4008700<01`L01@L400@700<01`L04@L00`071`021`0300L700T7
00D01`L700021`<02`L400@700<01`L02@L00`071`021`0300L700870`0;1`<0C0L002h700<01`L0
4PL500@700<01`L00PL300@700<01`L00PL00`071`0A1`0500L71`0030L00`071`0300/70`041`03
00L7008700<01`L02@L00`071`021`@02`L304l7000^1`0300L700l70`051`0300L7008710071`03
00L700<700<01`L04@L01@071`L000/70`021`0300L700H70`081`0300L7008700<01`L020L00`07
1`0400X70`1B1`00;`L00`071`0;1`<020L00`071`0400X700<01`L00PL00`071`0A1`0300L70087
00<01`L01@L300031`07008700<01`L00PL400/700<01`L00`L00`071`071`<00`L00`071`051`<0
E@L0030700<01`L01`L300`70P031`0300L700T700<01`L00PL00`071`0A1`0300L7008700@01`L7
0`051`0400L71`@040L00`071`021`0300L700@70`071`0400L71`<0F0L0034700<01`L00`L301D7
00<01`L02@L00`071`021`0300L7014700@01`L710081`0300L000<04`L00`071`021`0300L700<0
2PL405/7000a1`0300L700<06@L00`071`081`0300L700<700<01`L040L00`07000300T70`041`03
00L7014700@01`L70`0:1`<00PL00`071`1J1`00<PL201d700<01`L020L00`071`021`0300L700l7
0`041`0300L700<70`031`0500L71`004`L4008700<01`L01@L300D700<01`L0FPL0054700<01`L0
2@L00`071`021`0300L700/70`031`0500L71`000PL300L700D01`L7000@1`@010L00`071`021`<0
2@L00`071`1I1`00DPL00`071`081`0300L700<700<01`L01`L300L700<01`L00`0:1`0300L70087
00<01`L02PL300@700<01`L00PL400d700<01`L0F0L005<700<01`L020L00`071`031`0300L700<7
0`0:1`<00PL00`071`091`0300L7008700<01`L01PL300L700<01`L0100?1`0300L705P7001C1`03
00L700T700<01`L00PL00`071`0300X70`000`L01`021`0300L700X700D01`L700051`<02PL300<7
00<01`L03PL00`071`1G1`00E0L00`071`091`0300L700870P0:1`<01@L01@071`L000`700H01`L7
00L300X70`071`0300L700h700<01`L0EPL005D700<01`L020L00`071`0;1`<020L00`071`021`03
00L700T700<01`L00`0:1`<02`L00`071`0>1`0300L705D7001F1`0300L700P700<01`L01`L300`7
00<01`L00PL00`071`081`<00PL00`071`051`<03`L00`071`0=1`0300L705D7001F1`0300L700T7
00<01`L00`L3010700D01`L700071`<01PL010071`L3018700<01`L03PL00`071`1D1`00E`L00`07
1`081`0300L700<050L01@071`L000<70`0:1`<05PL00`071`0>1`0300L705<7001H1`0300L700L7
0`0G1`0300L700870`0:1`<000<700L05`L00`071`0>1`0300L70587001I1`0300L700<70`021`03
00L701H710000`L01`071`<010L00`071`0F1`0300L700h700<01`L0DPL005T700<01`L00`061`03
00L701871@031`0300L700<70`081`0300L701H700<01`L03@L205<7001J1`802@L00`071`0?1`<0
1@L01P071`L01`<030L00`071`0F1`0300L700T70`1E1`00IPL00`071`0;1`<020L00`071`0300l7
00<01`L05`L00`071`051`<0F0L006L700<01`L01`L300`70P021`0300L700h700<01`L05PL00`07
1`021`<0F`L006P700<01`L00`L301@700<01`L03PL00`071`0F1`@0GPL006P700<01`L00`0H1`03
00L700h700<01`L04PL50607001Y1`8070L00`071`0=1`0300L700l70`051`0300L705d700271`03
00L700h700<01`L02`L300P700<01`L0G@L008P700<01`L03PL00`071`071`<02`L205h700291`03
00L700h700<01`L00`L300/70`1P1`00R@L00`071`0>1`0300L700<02`L306<7002:1`0300L700h7
0P0;1`<0IPL008/700<01`L05`L306T7002<1`0300L70187101/1`00S0L00`071`0?1`<0L0L008d7
00<01`L02`L307<7002>1`0300L700L70`1f1`00S`L00`071`031`<0N@L008l700<01`L00`1l1`00
T0L207l7003o1a87003o1a87003o1a87003o1a87003o1a87003o1a870000\
\>"],
  ImageRangeCache->{{{0, 272.938}, {282.75, 0}} -> {-10.0829, -10.4469, \
0.0738952, 0.0738952}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[151]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["j = 4, k =1", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AL041, Axes \[Rule] True, Prolog \[Rule] PointSize[0.025], 
      PlotRange \[Rule] \ {{\(-20\), 20}, {\(-20\), 20}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[152]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.5 0.025 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -9 -9 ]
[.125 .4875 9 0 ]
[.25 .4875 -9 -9 ]
[.25 .4875 9 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -6 -9 ]
[.75 .4875 6 0 ]
[.875 .4875 -6 -9 ]
[.875 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -12 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -12 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-20)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-15)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-10)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(10)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(15)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(20)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-20)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-15)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-10)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(10)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(15)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(20)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.025 w
.56012 .95291 Mdot
.62262 .86688 Mdot
.68512 .78086 Mdot
.74762 .69483 Mdot
.81012 .60881 Mdot
.49762 .9326 Mdot
.56012 .84657 Mdot
.62262 .76055 Mdot
.68512 .67453 Mdot
.74762 .5885 Mdot
.81012 .50248 Mdot
.37262 .99831 Mdot
.43512 .91229 Mdot
.49762 .82627 Mdot
.56012 .74024 Mdot
.62262 .65422 Mdot
.68512 .5682 Mdot
.74762 .48217 Mdot
.81012 .39615 Mdot
.31012 .97801 Mdot
.37262 .89198 Mdot
.43512 .80596 Mdot
.49762 .71994 Mdot
.56012 .63391 Mdot
.62262 .54789 Mdot
.68512 .46186 Mdot
.74762 .37584 Mdot
.81012 .28982 Mdot
.24762 .9577 Mdot
.31012 .87168 Mdot
.37262 .78565 Mdot
.43512 .69963 Mdot
.49762 .6136 Mdot
.56012 .52758 Mdot
.62262 .44156 Mdot
.68512 .35553 Mdot
.74762 .26951 Mdot
.81012 .18348 Mdot
.18512 .93739 Mdot
.24762 .85137 Mdot
.31012 .76534 Mdot
.37262 .67932 Mdot
.43512 .5933 Mdot
.49762 .50727 Mdot
.56012 .42125 Mdot
.62262 .33523 Mdot
.68512 .2492 Mdot
.74762 .16318 Mdot
.81012 .07715 Mdot
.18512 .83106 Mdot
.24762 .74504 Mdot
.31012 .65901 Mdot
.37262 .57299 Mdot
.43512 .48697 Mdot
.49762 .40094 Mdot
.56012 .31492 Mdot
.62262 .22889 Mdot
.68512 .14287 Mdot
.74762 .05685 Mdot
.18512 .72473 Mdot
.24762 .63871 Mdot
.31012 .55268 Mdot
.37262 .46666 Mdot
.43512 .38063 Mdot
.49762 .29461 Mdot
.56012 .20859 Mdot
.62262 .12256 Mdot
.68512 .03654 Mdot
.18512 .6184 Mdot
.24762 .53237 Mdot
.31012 .44635 Mdot
.37262 .36033 Mdot
.43512 .2743 Mdot
.49762 .18828 Mdot
.56012 .10226 Mdot
.62262 .01623 Mdot
.18512 .51207 Mdot
.24762 .42604 Mdot
.31012 .34002 Mdot
.37262 .254 Mdot
.43512 .16797 Mdot
.49762 .08195 Mdot
.18512 .40574 Mdot
.24762 .31971 Mdot
.31012 .23369 Mdot
.37262 .14766 Mdot
.43512 .06164 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[152]:=",
  ImageSize->{214.562, 214.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003F0000ePP10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc=H7003F1`00ePL00=H7003F1`00GPL400<7
0P1_1`00GPL00`071`031`0400L706h7001O1`0300L7008700@01`L010L206P7001H1`@010L01@07
1`L0008700<01`L00PL00`071`1W1`00H@L010071`021`0300L7008700<01`L0I`L005h700@01`L0
0PL010071`041`0300L701@70`1@1`00G`L200@70P051`0300L701<7101@1`00K0L201D70`1@1`00
K0L00`071`0E1`0300L704l7001/1`0300L702470`131`00K0L00`071`0P1`@0@`L006`700<01`L0
8@L304<7001/1`808`L00`071`121`00K0L00`071`0]1`<0=`L005h70`0;1`0300L702`7100g1`00
G@L400/700<01`L0;@L303L7001N1`<02`L00`071`0^1`0300L703H7001O1`0300L700X70P0j1`<0
:`L006X70`0j1`@0:`L006T7100k1`<0:`L006X70`0l1`0300L702X7001[1`80J@L006`70P091`<0
G0L006`700<01`L01`L405`7001/1`0300L700P70`1L1`00GPL400870`051`0300L700T700<01`L0
F`L0060700<01`L010L00`071`021`0300L701@70`1@1`00H0L00`071`041`0300L700870P0D1`@0
D0L005P710041`0400L71`<01@L00`071`0D1`<0D0L0060700D01`L700071`0300L701D700<01`L0
C`L005h70`031`0300L700D700<01`L08@L304<7001B1`<02`L010071`L400@700<01`L080L404<7
001A1`@05`L202870`131`00DPL301L700<01`L08PL00`071`121`00D`L00`071`0F1`0300L702d7
0`0g1`00GPL300/700<01`L0;0L403L7001M1`@02`L00`071`0]1`<0=`L005h70`0;1`80;`L00`07
1`0f1`00G`L00`071`0:1`0300L703T70`0[1`00JPL303X7100[1`00J@L403/70`0[1`00JPL303`7
00<01`L0:PL006/70`1X1`00K0L00`071`081`<0G0L006`700<01`L01`L405`7001/1`0300L700P7
0`1L1`00K0L00`071`091`0300L705/7001/1`805@L3050700151`<090L00`071`0C1`@0D0L004@7
100T1`0300L701@70`1@1`00A@L301H710031`801@L00`071`0E1`0300L704l700161`0300L701L7
00D01`L700021`0300L7008700<01`L08@L304<7001B1`<02`L01@071`L0008700<01`L00PL20247
10131`00D@L400<710041`0500L71`000PL00`071`021`0300L702470`131`00DPL300/700D01`L7
00021`0300L7008700<01`L08PL00`071`121`00D`L00`071`081`<00`L010071`041`0300L702d7
0`0g1`00GPL300@70P051`0300L702`7100g1`00G@L400/70P0^1`<0=`L005h70`0;1`0300L702h7
00<01`L0=PL005l700<01`L02PL00`071`0i1`<0:`L006X70`0j1`@0:`L006T7100k1`<0:`L006X7
100k1`0300L702X7001[1`80J@L006`700<01`L020L305`7000i1`<0<0L00`071`071`@0G0L003P7
100`1`0300L700P70`1L1`00>@L303070P0:1`0300L705/7000j1`0300L702l700<01`L050L30507
00151`<090L00`071`0C1`@0D0L004@7100T1`0300L701@70`1@1`00A@L302@700<01`L05@L00`07
1`1?1`00APL00`071`0S1`808PL304<7001B1`<05`L00`071`0P1`@0@`L00547100G1`0300L70247
0`131`00DPL300l70`051`0300L7028700<01`L0@PL005<700<01`L04@L00`071`021`0300L702d7
0`0g1`00GPL300H700<01`L00PL202d7100g1`00G@L500870`051`0300L702d70`0g1`00GPL300<7
00<01`L01@L00`071`0^1`0300L703H7001O1`0300L7008700<01`L01@L00`071`0i1`<0:`L006@7
10021`<0>PL402/7000/1`<0>PL503X70`0[1`00:`L403/70`0l1`0300L702X7000/1`<0?0L206T7
000]1`0300L703`700<01`L020L305`7000i1`<0<0L00`071`071`@0G0L003P7100`1`802@L305`7
000i1`<0<0L00`071`091`0300L705/7000j1`0300L702l700<01`L050L3050700151`<090L00`07
1`0C1`@0D0L004@7100T1`0300L701@70`1@1`001`L400<70P0?1`@00PL3010710031`8010L300`7
0`0E1`805@L3018710031`8040L400870`0@1`@00`L200<700071`0300L700<700@01`L040L00`07
1`041`0300L700l700D01`L700021`0300L7008700<01`L03PL00`071`0B1`0300L701L700<01`L0
1`L300L700D01`L700021`0300L700l700<01`L010L00`071`0=1`0300L700<700@01`L00PL000P7
00<01`L00PL010071`0@1`0300L700@700<01`L03`L01@071`L0008700<01`L03PL3008700<01`L0
4PL00`071`0G1`0300L700H710071`0500L71`000PL00`071`0?1`0300L700@700<01`L03PL00`07
1`021`0400L7008700000`L0000200@700D01`L700021`0300L700H710041`0400L71`<02PL400@7
00D01`L700021`0300L700X72@0E1`0300L701@70`0:1`<01`L01@071`L0008700<01`L03`L01007
1`L3018700D01`L700021`400@L11`002PL010071`021`0300L700h700D01`L7000D1`0500L71`00
0PL00`071`0>1`<05`L00`071`0D1`0300L700/700<01`L01PL01@071`L0008700<01`L03`L01@07
1`L001D700@01`L00PL100470@L000L700@01`L00PL010071`0>1`<00`L00`071`0@1`<00`L01007
1`0A1`805`L201D700<01`L04PL300041`00008700<01`L03@L300<700<01`L040L010071`021`04
00L7008700081`8010L2014700@01`L7100A1`0300L700870P0C1`@01PL300/700<01`L050L401<7
1`0B1`0400L71`@040L200@70P031`00G@L400/700<01`L0;@L303L7001N1`<02`L00`071`0^1`03
00L703H7001O1`0300L700X700<01`L0>@L302/700091lL01PL000T700<01`L05@L00`071`081`<0
2`L00`071`0F1`0300L701<7100H1`0300L701D700<01`L020L300/700<01`L05PL00`071`041`00
:`L403/70`0l1`0300L702X7000/1`<0?0L206T7000]1`0300L703`700<01`L020L305`7000i1`<0
<0L200P7101L1`00>0L4030700<01`L020L305`7000i1`<0<0L00`071`091`0300L705/7000j1`03
00L702l700<01`L050L3050700151`<090L00`071`0C1`@0D0L004@7100T1`805@L3050700151`<0
90L00`071`0E1`0300L704l700161`0300L702<700<01`L08@L304<7001B1`<05`L00`071`0P1`@0
@`L00547100G1`0300L702470`131`00DPL301L70P0S1`0300L70487001C1`0300L701H700<01`L0
;@L303L7001N1`<02`L00`071`0/1`@0=`L005d7100;1`0300L702d70`0g1`00GPL300/700<01`L0
;PL00`071`0f1`00G`L00`071`0:1`80>PL302/7001Z1`<0>PL402/7000/1`<0>PL403/70`0[1`00
:`L403D70`031`<0?0L00`071`0Z1`00;0L303P700@01`L70P1Y1`00;@L00`071`0g1`0300L70087
0P091`<0G0L003T70`0X1`<01@L00`071`071`@0G0L003P7100X1`0300L700D700<01`L020L305`7
000i1`<0:0L00`071`051`0300L700T700<01`L0F`L003X700<01`L09`L400@700<01`L050L30507
00151`<090L201@7101@1`00A0L402@700<01`L050L3050700151`<090L00`071`0E1`0300L704l7
00161`0300L702<700<01`L08@L304<7001B1`<05`L2024710131`00D@L401L700<01`L08@L304<7
001B1`<05`L00`071`0R1`0300L70487001C1`0300L701H700<01`L0;@L303L7001N1`<02`L00`07
1`0/1`@0=`L005d7100;1`80;PL303L7001N1`<02`L00`071`0^1`0300L703H7001O1`0300L700X7
00<01`L0I`L006X70`1Y1`00;0L303X7101Y1`00:`L403/7101X1`00;0L303`70P1Y1`00;@L00`07
1`0l1`0300L700P70`1L1`00>@L3028710031`801@L00`071`071`@0G0L003P7100T1`0500L71`00
0PL00`071`021`0300L700P70`1L1`00>@L302@700D01`L700021`0300L700870P0:1`0300L705/7
000j1`0300L702<700D01`L700021`0300L7008700<01`L050L3050700151`<060L01@071`L00087
00<01`L00PL00`071`0C1`@0D0L004@7100F1`<00`L010071`041`0300L701@70`1@1`00A@L301P7
00<01`L00PL200D700<01`L05@L00`071`1?1`00APL00`071`0S1`808PL304<7001B1`<05`L00`07
1`0P1`@0@`L00547100G1`0300L702470`131`00DPL301L700<01`L08PL00`071`121`00D`L00`07
1`0F1`0300L706L7001N1`<02`L206P7001M1`@02`L00`071`1W1`00GPL300/700<01`L0I`L005l7
00<01`L02PL00`071`1W1`00JPL306T7000/1`<0>PL506P7000[1`@0>`L306T7000/1`<0?0L206T7
000]1`0300L703`700<01`L020L305`7000i1`<0<0L00`071`071`@0G0L003P7100`1`802@L305`7
000i1`<0<0L00`071`091`0300L705/7000j1`0300L702l700<01`L0I`L004D70`0F1`@00PL300D7
00<01`L050L3050700141`@060L00`071`041`0300L7008700<01`L04`L4050700151`<060L00`07
1`041`0300L700870P0E1`<0D0L004H700<01`L05`L010071`L300D700<01`L05@L00`071`1?1`00
DPL300/700D01`L700071`0300L706L7001A1`@02@L300<700<01`L01@L00`071`1W1`00DPL300/7
00@01`L710041`0300L706L7001C1`0300L701H70P1X1`00K0L00`071`1W1`00GPL300/700<01`L0
I`L005d7100;1`0300L706L7001N1`<02`L00`071`1W1`00G`L00`071`0:1`80J0L006X70`1Y1`00
;0L303X7101Y1`00:`L403/70`1Y1`00;0L303`70P1Y1`00;@L00`071`0l1`802@L305`7000i1`<0
<0L00`071`071`@0G0L003P7100`1`0300L700P70`1L1`00>@L3030700<01`L02@L00`071`1K1`00
>PL00`071`0_1`0300L706L700151`<090L206P700141`@090L00`071`1W1`00A@L302@700<01`L0
I`L004H700<01`L05@L400<70P051`0300L706L7001B1`<02@L00`071`031`0400L700@700<01`L0
I`L00547100:1`0300L7008700@01`L010L206P7001B1`<02`L01@071`L0008700<01`L0K0L005<7
00<01`L02`L010071`021`0300L706`7001N1`0400L7008700@01`L0KPL005l70P041`80K`L00=H7
003F1`00ePL00001\
\>"],
  ImageRangeCache->{{{0, 213.562}, {213.562, 0}} -> {-21.8132, -21.5111, \
0.20145, 0.20145}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[152]="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(basis41 = 
      FullSimplify[{A[4, 1, \[Alpha]] /. {m \[Rule] 1, n \[Rule] 0}, 
          A[4, 1, \[Alpha]] /. {m \[Rule] 0, 
              n \[Rule] 1}}]\), "\[IndentingNewLine]", 
    \(orig\  = \ 
      FullSimplify[
        A[4, 1, \[Alpha]] /. {m \[Rule] 0, n \[Rule] 0}]\)}], "Input",
  CellLabel->"In[153]:="],

Cell[BoxData[
    \({{\(-0.09508699431533874`\), \(-3.9623354178282515`\)}, \
{2.4049130056846613`, \(-3.1500361772459855`\)}}\)], "Output",
  CellLabel->"Out[153]="],

Cell[BoxData[
    \({\(-0.09508699431533879`\), 0.2909186239319485`}\)], "Output",
  CellLabel->"Out[154]="]
}, Open  ]],

Cell[BoxData[
    \(\(rad41\  = \ \@\(\((basis41[\([1]\)]\  - \ orig)\) . \
\((basis41[\([1]\)]\  - \ orig)\)\);\)\)], "Input",
  CellLabel->"In[155]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AppendTo[basis41, orig], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-10\), 10}, {\(-10\), 10}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[156]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.49525 .30188 Mdot
.62025 .3425 Mdot
.49525 .51455 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[156]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L0088710031`80U@L008@700D01`L700021`0300L7098700241`0500L71`000PL00`07
1`031`80S@L007`710041`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`07
1`031`0300L708`700221`<00`L010071`051`0300L708`700241`0300L700870P061`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L007d700<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<7
00<01`L0S0L007h700<01`L02PL00`071`031`80S@L007H710041`0300L700L70`061`0300L708`7
001o1`0300L700H700<01`L01PL00`071`2<1`00O0L010071`081`0300L700H700<01`L0S0L007`7
10081`@01@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`700281`<01PL00`071`2<1`00R`L00`071`031`0300L708`7
002;1`0300L700<70P2=1`00PPL400870`061`0300L708`700281`0300L700H700<01`L0S0L008P7
00<01`L01PL00`071`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00S@L608d7002;1`X0R`L008/72P2;1`00RPL<08X7002:1``0RPL008X7302:1`00RPL<08X7
002:1``0RPL008X7302:1`00R`L:08/7002;1`X0R`L008d71P0L1`H0J`L009470P0J1`X0J@L00947
00<01`L06@L:06T7002A1`0300L701P7301X1`00T@L00`071`0H1``0J0L0094700<01`L060L<06P7
002A1`0300L701P7301X1`00T@L00`071`0H1``0J0L009470P0I1``0J0L0094700<01`L06@L:06T7
002A1`0300L701T72P1Y1`00T@L00`071`0K1`H0J`L0094700<01`L0S0L007`710031`0300L70087
0`061`0300L708`7001l1`0300L700`700<01`L00`L00`071`2<1`00O@L00`071`0;1`0300L700<7
0P2=1`00MPL400@700<01`L01`L300H700<01`L0S0L007l700<01`L01PL00`071`061`0300L708`7
001l1`0400L700P700<01`L01PL00`071`2<1`00O@L200T710051`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`700071`@00`L201L700<01`L00`L00`071`021`<06@L301T7
10031`0300L700870`0H1`0300L701L710031`0300L700870`0I1`<06PL00`071`031`0300L70087
0`0F1`@00`L200<700091`0500L71`000PL00`071`0D1`0300L700/700<01`L06@L00`071`0F1`03
00L700`700<01`L05@L00`071`0G1`0300L700`700<01`L06@L00`071`0G1`0300L700/700<01`L0
5@L01@071`L000870@011`4700091`0500L71`000PL00`071`0E1`0300L700X700<01`L06@L00`07
1`0G1`0300L700/700<01`L05@L00`071`0H1`0300L700/700<01`L06@L00`071`0H1`0300L700X7
00<01`L05@L01@071`L000870@011`4700000`L0000200@700D01`L700021`0300L700d710041`03
00L700L70`0C1`@00PL301<710041`0300L700L70`0H1`806PL00`071`071`<06@L301/700<01`L0
1`L301P700D01`L700021`400@L11`002@L01@071`L0008700<01`L05PL00`071`061`0300L701T7
00<01`L070L00`071`061`0300L701P700<01`L06PL00`071`061`0300L701T700<01`L070L00`07
1`061`0300L701P700D01`L700021`400@L11`001`L300<700@01`L05@L010071`081`0300L701T7
00<01`L06@L010071`081`0300L701P700<01`L05`L010071`081`0300L701T700<01`L06@L01007
1`081`0300L701H70`031`0400L7008700091`0300L700870P0F1`@020L401P7100I1`802@L401L7
00<01`L060L200T7100H1`@060L400P7100G1`0300L700870P031`00T@L00`071`2<1`00S@L608d7
002;1`X0R`L000T7o`0B00H700091`0300L700<700<01`L010L00`071`041`0300L700@700<01`L0
10L00`071`031`0300L700@700<01`L010L00`071`041`0300L700@700<01`L00`L00`071`041`03
00L700@700<01`L010L00`071`041`0300L700<700<01`L010L00`071`041`0300L700@730000`L0
1`051`0300L700@700<01`L010L00`071`041`0300L700<700<01`L010L00`071`041`0300L700@7
00<01`L010L00`071`031`0300L700@700<01`L010L00`071`041`0300L700@700<01`L00`L00`07
1`041`0300L700@700<01`L010L00`071`041`0300L700@700091`0300L701l700<01`L07`L00`07
1`0O1`0300L701P7300M1`0300L701l700<01`L07`L00`071`0O1`0300L700@7002:1``0RPL008X7
302:1`00RPL<08X7002:1``0RPL008/72P2;1`00R`L:08/7002=1`H0S@L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L007`7
10031`0300L700870`061`0300L708`7001l1`0300L700`700<01`L00`L00`071`2<1`00O@L00`07
1`0;1`0300L700<70P2=1`00OPL00`071`071`<01PL00`071`2<1`00O`L00`071`061`0300L700H7
00<01`L0S0L007`700@01`L020L00`071`061`0300L708`7001m1`802@L400D700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00R0L300H700<01`L0S0L008/700<01`L00`L00`071`2<1`00R`L00`071`031`80S@L008P7
0`061`0300L708`700281`0300L700H700<01`L0S0L008P700<01`L01PL00`071`2<1`00R0L400D7
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00O@L00`071`031`0300L700870`061`0300L708`7001m1`0300L700/7
00<01`L00`L00`071`2<1`00OPL00`071`0:1`0300L700<70P2=1`00OPL00`071`071`<01PL00`07
1`2<1`00O`L00`071`061`0300L700H700<01`L0S0L007`700@01`L020L00`071`061`0300L708`7
001l1`@020L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00PPL400<70P061`0300L708`700241`0500L71`00
0PL00`071`031`0300L708`700241`0500L71`000PL00`071`031`80S@L008@700D01`L700021`03
00L7098700241`0500L71`000PL00`071`2B1`00PPL300<700@01`L0U0L008@700<01`L00PL209D7
003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.6619, -10.5516, 0.0735301, \
0.0735301}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[156]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice041\  = tiling2D[SphericalCut[N[AL041], 10], \ rad41]\)], "Input",\

  CellLabel->"In[157]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.06501 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.437148 0.0544218 0.516671 0.0544218 [
[ 0 0 0 0 ]
[ 1 1.06501 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.06501 L
0 1.06501 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.56803 1.03965 m
.70408 .85239 L
s
.56803 1.03965 m
.56803 .80818 L
s
.70408 .85239 m
.84014 .66512 L
s
.70408 .85239 m
.70408 .62092 L
s
.84014 .66512 m
.97619 .47786 L
s
.84014 .66512 m
.84014 .43365 L
s
.43197 .99544 m
.56803 .80818 L
s
.43197 .99544 m
.43197 .76397 L
s
.56803 .80818 m
.70408 .62092 L
s
.56803 .80818 m
.56803 .57671 L
s
.70408 .62092 m
.84014 .43365 L
s
.70408 .62092 m
.70408 .38945 L
s
.84014 .43365 m
.84014 .20218 L
s
.29592 .95124 m
.43197 .76397 L
s
.29592 .95124 m
.29592 .71977 L
s
.43197 .76397 m
.56803 .57671 L
s
.43197 .76397 m
.43197 .5325 L
s
.56803 .57671 m
.70408 .38945 L
s
.56803 .57671 m
.56803 .34524 L
s
.70408 .38945 m
.84014 .20218 L
s
.70408 .38945 m
.70408 .15798 L
s
.15986 .90703 m
.29592 .71977 L
s
.15986 .90703 m
.15986 .67556 L
s
.29592 .71977 m
.43197 .5325 L
s
.29592 .71977 m
.29592 .4883 L
s
.43197 .5325 m
.56803 .34524 L
s
.43197 .5325 m
.43197 .30103 L
s
.56803 .34524 m
.70408 .15798 L
s
.56803 .34524 m
.56803 .11377 L
s
.02381 .86282 m
.15986 .67556 L
s
.02381 .86282 m
.02381 .63135 L
s
.15986 .67556 m
.29592 .4883 L
s
.15986 .67556 m
.15986 .44409 L
s
.29592 .4883 m
.43197 .30103 L
s
.29592 .4883 m
.29592 .25683 L
s
.43197 .30103 m
.56803 .11377 L
s
.43197 .30103 m
.43197 .06956 L
s
.02381 .63135 m
.15986 .44409 L
s
.02381 .63135 m
.02381 .39988 L
s
.15986 .44409 m
.29592 .25683 L
s
.15986 .44409 m
.15986 .21262 L
s
.29592 .25683 m
.43197 .06956 L
s
.29592 .25683 m
.29592 .02536 L
s
.02381 .39988 m
.15986 .21262 L
s
.02381 .39988 m
.02381 .16841 L
s
.15986 .21262 m
.29592 .02536 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[157]:=",
  ImageSize->{288, 306.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001<PP10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L005@700<01`L0b@L005<70P3;1`00D`L20</7001B1`0300L00</7001A1`04
00L70</7001@1`0500L71`00b`L0050700D01`L7003;1`00C`L00`071`021`0300L70<T7001>1`03
00L700<700<01`L0b@L004h700<01`L00`L00`071`391`00C@L00`071`041`0300L70<T7001<1`03
00L700D700<01`L0b@L004/700<01`L01PL00`071`391`00B`L00`071`061`0300L702@700<01`L0
XPL004X700<01`L01`L00`071`0S1`80Y0L004T700<01`L020L00`071`0S1`80Y0L004P700<01`L0
2@L00`071`0R1`0300L00:@700181`0300L700T700<01`L08@L010071`2T1`00A`L00`071`0:1`03
00L7020700D01`L7002T1`00APL00`071`0;1`0300L7020700D01`L7002T1`00APL00`071`0;1`03
00L701l700<01`L00PL00`071`2R1`00A@L00`071`0<1`0300L701h700<01`L00`L00`071`2R1`00
A0L00`071`0=1`0300L701h700<01`L00`L00`071`2R1`00@`L00`071`0>1`0300L701d700<01`L0
10L00`071`2R1`00@`L00`071`0>1`0300L701`700<01`L01@L00`071`2R1`00@PL00`071`0?1`03
00L701/700<01`L01PL00`071`0U1`0300L707X700111`0300L7010700<01`L06`L00`071`061`03
00L702@70P1l1`00@@L00`071`0@1`0300L701X700<01`L01`L00`071`0T1`80O0L0040700<01`L0
4@L00`071`0I1`0300L700P700<01`L08`L00`07001l1`00?`L00`071`0B1`0300L701P700<01`L0
2@L00`071`0R1`0400L707`7000n1`0300L701<700<01`L060L00`071`091`0300L7024700D01`L7
001l1`00?PL00`071`0C1`0300L701L700<01`L02PL00`071`0Q1`0500L71`00O0L003d700<01`L0
50L00`071`0F1`0300L700/700<01`L080L00`071`021`0300L707X7000l1`0300L701D700<01`L0
5PL00`071`0;1`0300L701l700<01`L00`L00`071`1j1`00>`L00`071`0F1`0300L701D700<01`L0
30L00`071`0N1`0300L700@700<01`L0NPL003/700<01`L05PL00`071`0D1`0300L700d700<01`L0
7PL00`071`041`0300L707X7000j1`0300L701L700<01`L04`L00`071`0>1`0300L701d700<01`L0
1@L00`071`1j1`00>@L00`071`0H1`0300L701<700<01`L03PL00`071`0L1`0300L700H700<01`L0
NPL003T700<01`L060L00`071`0B1`0300L700l700<01`L06`L00`071`071`0300L702@700<01`L0
D`L003P700<01`L06@L00`071`0A1`0300L7010700<01`L06`L00`071`071`0300L702<70P1E1`00
=`L00`071`0J1`0300L7014700<01`L040L00`071`0J1`0300L700P700<01`L08`L205D700061`03
00L702d700<01`L06`L00`071`0@1`0300L7014700<01`L06@L00`071`091`0300L7028700<01`00
E@L000H700<01`L0;@L00`071`0K1`0300L700l700<01`L04PL00`071`0H1`0300L700X700<01`L0
8@L010071`1E1`001PL00`071`0/1`0300L701`700<01`L03PL00`071`0C1`0300L701P700<01`L0
2PL00`071`0P1`0500L71`00E@L000H700<01`L0:`L00`071`0M1`0300L700h700<01`L04`L00`07
1`0G1`0300L700/700<01`L080L01@071`L005D700061`0300L702/700<01`L07@L00`071`0=1`03
00L701@700<01`L05PL00`071`0<1`0300L701l700<01`L00PL00`071`1C1`001PL00`071`0Z1`03
00L701h700<01`L030L00`071`0E1`0300L701D700<01`L03@L00`071`0N1`0300L700<700<01`L0
D`L000H700<01`L0:@L00`071`0O1`0300L700/700<01`L05PL00`071`0E1`0300L700d700<01`L0
7PL00`071`031`0300L705<700061`0300L702P700<01`L080L00`071`0;1`0300L701H700<01`L0
50L00`071`0>1`0300L701d700<01`L010L00`071`1C1`001PL00`071`0X1`0300L7020700<01`L0
2PL00`071`0G1`0300L701<700<01`L03`L00`071`0L1`0300L700D700<01`L0D`L000H700<01`L0
9`L00`071`0Q1`0300L700T700<01`L060L00`071`0B1`0300L7010700<01`L06`L00`071`061`03
00L705<700061`0300L702H700<01`L08PL00`071`091`0300L701P700<01`L04PL00`071`0@1`03
00L701/700<01`L01PL00`071`0T1`0300L702`700061`0300L702D700<01`L08`L00`071`081`03
00L701T700<01`L04@L00`071`0A1`0300L701X700<01`L01`L00`071`0S1`80;PL000H700<01`L0
9@L00`071`0S1`0300L700L700<01`L06PL00`071`0@1`0300L7018700<01`L06@L00`071`081`03
00L702<70P0^1`001PL00`071`0T1`0300L702@700<01`L01PL00`071`0K1`0300L7010700<01`L0
4PL00`071`0H1`0300L700T700<01`L08PL00`07000^1`001PL00`071`0S1`809PL00`071`061`03
00L701/700<01`L03`L00`071`0C1`0300L701P700<01`L02@L00`071`0Q1`0400L702h700061`03
00L702<70P0V1`0300L700D700<01`L070L00`071`0>1`0300L701@700<01`L05`L00`071`0:1`03
00L7020700D01`L7000^1`001PL00`071`0R1`0300L002H700<01`L010L00`071`0M1`0300L700d7
00<01`L05@L00`071`0F1`0300L700/700<01`L080L01@071`L002h700061`0300L7024700@01`L0
9PL00`071`041`0300L701d700<01`L03@L00`071`0E1`0300L701H700<01`L02`L00`071`0O1`03
00L7008700<01`L0;0L000H700<01`L080L01@071`L002H700<01`L00`L00`071`0N1`0300L700`7
00<01`L05PL00`071`0E1`0300L700`700<01`L07PL00`071`031`0300L702`700061`0300L70207
00D01`L7000V1`0300L7008700<01`L07`L00`071`0;1`0300L701L700<01`L050L00`071`0=1`03
00L701h700<01`L00`L00`071`0/1`001PL00`071`0O1`0300L7008700<01`L090L01@071`L00287
00<01`L02PL00`071`0H1`0300L701<700<01`L03PL00`071`0M1`0300L700@700<01`L0;0L000H7
00<01`L07PL00`071`031`0300L702@700D01`L7000R1`0300L700X700<01`L060L00`071`0C1`03
00L700h700<01`L070L00`071`051`0300L702`700061`0300L701h700<01`L00`L00`071`0T1`04
00L702<700<01`L02@L00`071`0I1`0300L7018700<01`L03`L00`071`0K1`0300L700H700<01`L0
;0L000H700<01`L07@L00`071`041`0300L702@700<01`0090L00`071`081`0300L701X700<01`L0
4@L00`071`0@1`0300L701/700<01`L01PL00`071`0/1`001PL00`071`0L1`0300L700D700<01`L0
90L202D700<01`L01`L00`071`0K1`0300L7014700<01`L040L00`071`0J1`0300L700L700<01`L0
;0L000H700<01`L06`L00`071`061`0300L702@70P0U1`0300L700L700<01`L06`L00`071`0@1`03
00L7014700<01`L06@L00`071`081`0300L702`700061`0300L701/700<01`L01PL00`071`0T1`03
00L702@700<01`L01PL00`071`0L1`0300L700l700<01`L04PL00`071`0H1`0300L700T700<01`L0
;0L000H700<01`L06PL00`071`071`0300L702<70P0V1`0300L700D700<01`L07@L00`071`0>1`03
00L701<700<01`L060L00`071`091`0300L702`700061`0300L701T700<01`L020L00`071`0S1`80
9PL00`071`041`0300L701h700<01`L03PL00`071`0C1`0300L701L700<01`L02PL00`071`0/1`00
1PL00`071`0H1`0300L700T700<01`L08PL00`07000V1`0300L700@700<01`L07PL00`071`0=1`03
00L701@700<01`L05PL00`071`0;1`0300L702`700061`0300L701P700<01`L02@L00`071`0Q1`04
00L702H700<01`L00`L00`071`0O1`0300L700`700<01`L05@L00`071`0F1`0300L700/700<01`L0
;0L000H700<01`L05`L00`071`0:1`0300L7020700D01`L7000V1`0300L7008700<01`L080L00`07
1`0;1`0300L701H700<01`L05@L00`071`0<1`0300L702`700061`0300L701H700<01`L02`L00`07
1`0P1`0500L71`009PL01@071`L002<700<01`L02`L00`071`0F1`0300L701@700<01`L03@L00`07
1`0/1`001PL00`071`0F1`0300L700/700<01`L07`L00`071`021`0300L702@700D01`L7000S1`03
00L700X700<01`L05`L00`071`0C1`0300L700h700<01`L0;0L000H700<01`L05@L00`071`0<1`03
00L701h700<01`L00`L00`071`0T1`0400L702@700<01`L02@L00`071`0H1`0300L701<700<01`L0
3PL00`071`0/1`001PL00`071`0D1`0300L700d700<01`L07@L00`071`041`0300L702@700<01`00
9@L00`071`091`0300L701P700<01`L04PL00`071`0?1`0300L702`700061`0300L701<700<01`L0
3PL00`071`0M1`0300L700@700<01`L090L202H700<01`L020L00`071`0I1`0300L7014700<01`L0
40L00`071`0/1`001PL00`071`0C1`0300L700h700<01`L070L00`071`051`0300L702@70P0V1`03
00L700L700<01`L06PL00`071`0A1`0300L7010700<01`L0;0L000H700<01`L04PL00`071`0?1`03
00L701/700<01`L01PL00`071`0T1`0300L702D700<01`L01PL00`071`0K1`0300L7010700<01`L0
4@L00`071`0/1`001PL00`071`0A1`0300L7010700<01`L06PL00`071`071`0300L702<70P0W1`03
00L700H700<01`L06`L00`071`0?1`0300L7018700<01`L0;0L000H700<01`L04@L00`071`0@1`03
00L701X700<01`L01`L00`071`0S1`809`L00`071`051`0300L701`700<01`L03PL00`071`0C1`03
00L702`700061`0300L7010700<01`L04@L00`071`0I1`0300L700P700<01`L08PL00`07000W1`03
00L700@700<01`L07@L00`071`0>1`0300L701<700<01`L0;0L000H700<01`L03`L00`071`0B1`03
00L701P700<01`L02@L00`071`0Q1`0400L702L700<01`L010L00`071`0M1`0300L700d700<01`L0
50L00`071`0/1`001PL00`071`0>1`0300L701<700<01`L05`L00`071`0:1`0300L7020700D01`L7
000W1`0300L700<700<01`L07PL00`071`0<1`0300L701D700<01`L0;0L000H700<01`L03PL00`07
1`0C1`0300L701L700<01`L02PL00`071`0P1`0500L71`009`L00`071`021`0300L701l700<01`L0
2`L00`071`0F1`0300L702`700061`0300L700d700<01`L050L00`071`0F1`0300L700/700<01`L0
7`L00`071`021`0300L702D700D01`L7000R1`0300L700/700<01`L05PL00`071`0/1`001PL00`07
1`0<1`0300L701D700<01`L05@L00`071`0<1`0300L701h700<01`L00`L00`071`0U1`0500L71`00
8PL00`071`0:1`0300L701L700<01`L0;0L000H700<01`L02`L00`071`0F1`0300L701D700<01`L0
30L00`071`0N1`0300L700<700<01`L09@L010071`0S1`0300L700T700<01`L060L00`071`0/1`00
1PL00`071`0;1`0300L701H700<01`L050L00`071`0=1`0300L701d700<01`L010L00`071`0U1`03
00L002@700<01`L02@L00`071`0H1`0300L702`700061`0300L700X700<01`L05`L00`071`0C1`03
00L700h700<01`L070L00`071`051`0300L702D70P0U1`0300L700P700<01`L06@L00`071`0/1`00
1PL00`071`091`0300L701P700<01`L04PL00`071`0?1`0300L701/700<01`L01PL00`071`0U1`80
9@L00`071`071`0300L701X700<01`L0;0L000H700<01`L02@L00`071`0H1`0300L7018700<01`L0
3`L00`071`0K1`0300L700H700<01`L09@L00`071`0T1`0300L700H700<01`L06`L00`071`0/1`00
1PL00`071`081`0300L701T700<01`L04@L00`071`0@1`0300L701X700<01`L01`L00`071`0T1`80
9PL00`071`061`0300L701/700<01`L0;0L000H700<01`L01`L00`071`0J1`0300L7010700<01`L0
4@L00`071`0I1`0300L700P700<01`L090L202H700<01`L01@L00`071`0L1`0300L702`700061`03
00L700H700<01`L06`L00`071`0?1`0300L7018700<01`L060L00`071`091`0300L702<700<01`00
9PL00`071`041`0300L701d700<01`L0;0L000H700<01`L01PL00`071`0K1`0300L700l700<01`L0
4PL00`071`0H1`0300L700T700<01`L08PL010071`0V1`0300L700@700<01`L07@L00`071`0/1`00
1PL00`071`051`0300L701`700<01`L03PL00`071`0C1`0300L701L700<01`L02PL00`071`0Q1`05
00L71`009PL00`071`031`0300L701h700<01`L0;0L000H700<01`L010L00`071`0M1`0300L700d7
00<01`L050L00`071`0F1`0300L700/700<01`L08@L01@071`L002H700<01`L00PL00`071`0O1`03
00L702`700061`0300L700@700<01`L07@L00`071`0<1`0300L701D700<01`L05PL00`071`0;1`03
00L7020700<01`L00PL00`071`0T1`0500L71`008PL00`071`0/1`001PL00`071`031`0300L701h7
00<01`L030L00`071`0E1`0300L701D700<01`L030L00`071`0O1`0300L700<700<01`L090L01@07
1`L0028700<01`L0;0L000H700<01`L00PL00`071`0O1`0300L700/700<01`L05PL00`071`0D1`03
00L700d700<01`L07PL00`071`041`0300L702@700@01`L08`L00`071`0/1`001PL01@071`L00287
00<01`L02PL00`071`0G1`0300L701<700<01`L03PL00`071`0N1`0300L700@700<01`L090L00`07
000T1`0300L702`700061`0500L71`008PL00`071`0:1`0300L701L700<01`L04`L00`071`0>1`03
00L701d700<01`L01@L00`071`0T1`809@L00`071`0/1`001PL010071`0S1`0300L700T700<01`L0
60L00`071`0B1`0300L700l700<01`L070L00`071`061`0300L702@70P0U1`0300L702`700061`03
00L002@700<01`L020L00`071`0I1`0300L7014700<01`L040L00`071`0K1`0300L700L700<01`L0
90L00`071`0T1`0300L702`700061`809@L00`071`071`0300L701X700<01`L04@L00`071`0@1`03
00L701/700<01`L01`L00`071`0S1`809PL00`071`0/1`001PL202D700<01`L01`L00`071`0J1`03
00L7010700<01`L04@L00`071`0J1`0300L700P700<01`L08`L202H700<01`L0;0L000H700<01`L0
90L00`071`061`0300L701/700<01`L03`L00`071`0B1`0300L701T700<01`L02@L00`071`0R1`03
00L002H700<01`L0;0L000H700<01`L090L00`071`051`0300L701`700<01`L03PL00`071`0C1`03
00L701P700<01`L02PL00`071`0Q1`0400L702H700<01`L0;0L000H700<01`L090L00`071`041`03
00L701d700<01`L03PL00`071`0C1`0300L701P700<01`L02PL00`071`0P1`0500L71`009PL00`07
1`0/1`001PL00`071`0T1`0300L700@700<01`L07@L00`071`0=1`0300L701@700<01`L05`L00`07
1`0;1`0300L7020700D01`L7000V1`0300L702`700061`0300L702@700<01`L00`L00`071`0N1`03
00L700`700<01`L05@L00`071`0F1`0300L700`700<01`L07`L00`071`021`0300L702@700<01`L0
;0L000H700<01`L090L00`071`021`0300L701l700<01`L02`L00`071`0F1`0300L701D700<01`L0
3@L00`071`0N1`0300L700<700<01`L090L00`071`0/1`001PL00`071`0T1`0500L71`008PL00`07
1`0;1`0300L701H700<01`L05@L00`071`0=1`0300L701d700<01`L010L00`071`0T1`0300L702`7
00061`0300L702@700D01`L7000R1`0300L700X700<01`L05`L00`071`0D1`0300L700h700<01`L0
7@L00`071`041`0300L702@700<01`L0;0L000H700<01`L090L010071`0S1`0300L700T700<01`L0
60L00`071`0C1`0300L700l700<01`L070L00`071`051`0300L702@700<01`L0;0L000H700<01`L0
90L00`07000T1`0300L700T700<01`L060L00`071`0B1`0300L7010700<01`L06`L00`071`061`03
00L702@700<01`L0;0L000H700<01`L090L202D700<01`L020L00`071`0I1`0300L7018700<01`L0
40L00`071`0J1`0300L700L700<01`L08`L202h700061`0300L702@70P0U1`0300L700L700<01`L0
6PL00`071`0A1`0300L7014700<01`L06PL00`071`071`0300L702<70P0^1`001PL00`071`0T1`03
00L702@700<01`L01PL00`071`0K1`0300L7010700<01`L04PL00`071`0I1`0300L700P700<01`L0
8PL00`07000^1`001PL00`071`0S1`809PL00`071`061`0300L701/700<01`L040L00`071`0B1`03
00L701P700<01`L02@L00`071`0Q1`0400L702h700061`0300L702<70P0V1`0300L700D700<01`L0
70L00`071`0?1`0300L701<700<01`L05`L00`071`0:1`0300L7020700D01`L7000^1`001PL00`07
1`0R1`0300L002H700<01`L010L00`071`0M1`0300L700h700<01`L050L00`071`0G1`0300L700X7
00<01`L080L01@071`L002h700061`0300L7024700@01`L09PL00`071`041`0300L701d700<01`L0
3@L00`071`0E1`0300L701H700<01`L02`L00`071`0O1`0300L7008700<01`L0;0L000H700<01`L0
80L01@071`L002H700<01`L00`L00`071`0N1`0300L700d700<01`L05@L00`071`0E1`0300L700`7
00<01`L07PL00`071`031`0300L702`700061`0300L7020700D01`L7000V1`0300L7008700<01`L0
7`L00`071`0<1`0300L701H700<01`L05@L00`071`0<1`0300L701h700<01`L00`L00`071`0/1`00
1PL00`071`0O1`0300L7008700<01`L090L01@071`L0028700<01`L02`L00`071`0G1`0300L701@7
00<01`L03@L00`071`0M1`0300L700@700<01`L0;0L000H700<01`L07PL00`071`031`0300L702@7
00D01`L7000R1`0300L700X700<01`L060L00`071`0C1`0300L700h700<01`L070L00`071`051`03
00L702`700061`0300L701h700<01`L00`L00`071`0T1`0400L702<700<01`L02PL00`071`0H1`03
00L7018700<01`L03`L00`071`0K1`0300L700H700<01`L0;0L000H700<01`L07@L00`071`041`03
00L702@700<01`0090L00`071`091`0300L701T700<01`L04PL00`071`0?1`0300L701/700<01`L0
1PL00`071`0T1`0300L700D700061`0300L701`700<01`L01@L00`071`0T1`809@L00`071`081`03
00L701X700<01`L04@L00`071`0@1`0300L701X700<01`L01`L00`071`0S1`0300L700H700061`03
00L701/700<01`L01PL00`071`0T1`809@L00`071`071`0300L701/700<01`L040L00`071`0A1`03
00L701T700<01`L020L00`071`0S1`0300L700H700061`0300L701/700<01`L01PL00`071`0T1`03
00L702@700<01`L01`L00`071`0K1`0300L700l700<01`L04PL00`071`0H1`0300L700T700<01`L0
8PL00`071`071`001PL00`071`0J1`0300L700L700<01`L08`L202H700<01`L01PL00`071`0L1`03
00L700l700<01`L04PL00`071`0H1`0300L700T700<01`L08@L00`071`081`001PL00`071`0I1`03
00L700P700<01`L08`L202H700<01`L01@L00`071`0M1`0300L700h700<01`L04`L00`071`0G1`03
00L700X700<01`L080L00`071`091`001PL00`071`0H1`0300L700T700<01`L08PL00`07000V1`03
00L700@700<01`L07PL00`071`0=1`0300L701@700<01`L05PL00`071`0;1`0300L7020700<01`L0
2@L000H700<01`L060L00`071`091`0300L7024700@01`L09PL00`071`041`0300L701h700<01`L0
30L00`071`0E1`0300L701H700<01`L02`L00`071`0O1`0300L700X700061`0300L701L700<01`L0
2PL00`071`0P1`0500L71`009PL00`071`031`0300L701l700<01`L030L00`071`0E1`0300L701D7
00<01`L030L00`071`0N1`0300L700/700061`0300L701H700<01`L02`L00`071`0P1`0500L71`00
9PL00`071`021`0300L7020700<01`L02`L00`071`0F1`0300L701@700<01`L03@L00`071`0N1`03
00L700/700061`0300L701H700<01`L02`L00`071`0O1`0300L7008700<01`L090L01@071`L002<7
00<01`L02PL00`071`0G1`0300L701<700<01`L03PL00`071`0M1`0300L700`700061`0300L701D7
00<01`L030L00`071`0N1`0300L700<700<01`L090L01@071`L002<700<01`L02PL00`071`0G1`03
00L701<700<01`L03PL00`071`0L1`0300L700d700061`0300L701@700<01`L03@L00`071`0N1`03
00L700<700<01`L090L010071`0T1`0300L700T700<01`L060L00`071`0B1`0300L700l700<01`L0
6`L00`071`0>1`001PL00`071`0C1`0300L700h700<01`L07@L00`071`041`0300L702@700<01`00
9@L00`071`081`0300L701T700<01`L04@L00`071`0@1`0300L701/700<01`L03PL000H700<01`L0
4`L00`071`0>1`0300L701`700<01`L01@L00`071`0T1`809PL00`071`071`0300L701X700<01`L0
4@L00`071`0@1`0300L701X700<01`L03`L000H700<01`L04PL00`071`0?1`0300L701/700<01`L0
1PL00`071`0T1`809PL00`071`071`0300L701X700<01`L040L00`071`0A1`0300L701T700<01`L0
40L000H700<01`L04@L00`071`0@1`0300L701/700<01`L01PL00`071`0T1`0300L702D700<01`L0
1PL00`071`0K1`0300L700l700<01`L04PL00`071`0H1`0300L7014700061`0300L7014700<01`L0
40L00`071`0J1`0300L700L700<01`L08`L202L700<01`L01@L00`071`0L1`0300L700h700<01`L0
4`L00`071`0H1`0300L7014700061`0300L7010700<01`L04@L00`071`0I1`0300L700P700<01`L0
8`L202L700<01`L010L00`071`0M1`0300L700h700<01`L04`L00`071`0G1`0300L7018700061`03
00L700l700<01`L04PL00`071`0H1`0300L700T700<01`L08PL00`07000W1`0300L700@700<01`L0
7@L00`071`0=1`0300L701@700<01`L05PL00`071`0C1`001PL00`071`0>1`0300L701<700<01`L0
60L00`071`091`0300L7024700@01`L09`L00`071`031`0300L701h700<01`L030L00`071`0E1`03
00L701H700<01`L04`L000H700<01`L03PL00`071`0C1`0300L701L700<01`L02PL00`071`0P1`05
00L71`009`L00`071`021`0300L701l700<01`L02`L00`071`0F1`0300L701D700<01`L050L000H7
00<01`L03@L00`071`0D1`0300L701H700<01`L02`L00`071`0P1`0500L71`009`L01@071`L00287
00<01`L02`L00`071`0F1`0300L701@700<01`L05@L000H700<01`L030L00`071`0E1`0300L701H7
00<01`L02`L00`071`0O1`0300L7008700<01`L09@L01@071`L0028700<01`L02PL00`071`0G1`03
00L701<700<01`L05PL000H700<01`L02`L00`071`0F1`0300L701D700<01`L030L00`071`0N1`03
00L700<700<01`L09@L010071`0S1`0300L700T700<01`L060L00`071`0C1`0300L701H700061`03
00L700/700<01`L05PL00`071`0D1`0300L700d700<01`L07@L00`071`041`0300L702D700<01`00
90L00`071`091`0300L701P700<01`L04PL00`071`0G1`001PL00`071`0:1`0300L701L700<01`L0
4`L00`071`0>1`0300L701d700<01`L010L00`071`0U1`809@L00`071`081`0300L701T700<01`L0
4@L00`071`0H1`001PL00`071`091`0300L701P700<01`L04`L00`071`0>1`0300L701`700<01`L0
1@L00`071`0U1`809@L00`071`071`0300L701X700<01`L04@L00`071`0H1`001PL00`071`091`03
00L701P700<01`L04PL00`071`0?1`0300L701/700<01`L01PL00`071`0U1`0300L702@700<01`L0
1PL00`071`0K1`0300L7010700<01`L06@L000H700<01`L020L00`071`0I1`0300L7014700<01`L0
40L00`071`0J1`0300L700L700<01`L090L202H700<01`L01PL00`071`0K1`0300L700l700<01`L0
6PL000H700<01`L01`L00`071`0J1`0300L7014700<01`L040L00`071`0J1`0300L700L700<01`L0
90L202H700<01`L01@L00`071`0L1`0300L700h700<01`L06`L000H700<01`L01PL00`071`0K1`03
00L7010700<01`L04@L00`071`0I1`0300L700P700<01`L08`L00`07000V1`0300L700@700<01`L0
7@L00`071`0>1`0300L701/700061`0300L700H700<01`L06`L00`071`0?1`0300L7018700<01`L0
60L00`071`091`0300L7028700@01`L09PL00`071`041`0300L701d700<01`L03@L00`071`0L1`00
1PL00`071`051`0300L701`700<01`L03PL00`071`0C1`0300L701L700<01`L02PL00`071`0Q1`05
00L71`009PL00`071`031`0300L701h700<01`L030L00`071`0M1`001PL00`071`041`0300L701d7
00<01`L03PL00`071`0C1`0300L701L700<01`L02PL00`071`0Q1`0500L71`009PL00`071`021`03
00L701l700<01`L02`L00`071`0N1`001PL00`071`041`0300L701d700<01`L03@L00`071`0D1`03
00L701H700<01`L02`L00`071`0P1`0300L7008700<01`L090L01@071`L0028700<01`L02`L00`07
1`0N1`001PL00`071`031`0300L701h700<01`L030L00`071`0E1`0300L701D700<01`L030L00`07
1`0O1`0300L700<700<01`L090L01@071`L0028700<01`L02PL00`071`0O1`001PL00`071`021`03
00L701l700<01`L02`L00`071`0F1`0300L701D700<01`L030L00`071`0N1`0300L700@700<01`L0
90L010071`0S1`0300L700T700<01`L080L000H700D01`L7000R1`0300L700/700<01`L05PL00`07
1`0D1`0300L700d700<01`L07PL00`071`041`0300L702@700<01`0090L00`071`091`0300L70207
00061`0500L71`008PL00`071`0:1`0300L701L700<01`L04`L00`071`0>1`0300L701d700<01`L0
1@L00`071`0T1`809@L00`071`081`0300L7024700061`0400L702<700<01`L02@L00`071`0H1`03
00L7018700<01`L03`L00`071`0L1`0300L700H700<01`L090L202D700<01`L01`L00`071`0R1`00
1PL00`07000T1`0300L700T700<01`L060L00`071`0B1`0300L700l700<01`L06`L00`071`071`03
00L702@700<01`L090L00`071`061`0300L702<700061`809@L00`071`081`0300L701T700<01`L0
4@L00`071`0@1`0300L701/700<01`L01`L00`071`0S1`809PL00`071`061`0300L702<700061`80
9@L00`071`071`0300L701X700<01`L040L00`071`0A1`0300L701X700<01`L020L00`071`0S1`80
9PL00`071`051`0300L702@700061`0300L702@700<01`L01PL00`071`0K1`0300L700l700<01`L0
4PL00`071`0I1`0300L700T700<01`L08PL00`07000V1`0300L700@700<01`L09@L000H700<01`L0
90L00`071`061`0300L701/700<01`L03`L00`071`0B1`0300L701P700<01`L02PL00`071`0Q1`04
00L702H700<01`L010L00`071`0U1`001PL00`071`0T1`0300L700D700<01`L070L00`071`0>1`03
00L701<700<01`L060L00`071`0:1`0300L7020700D01`L7000V1`0300L700<700<01`L09PL000H7
00<01`L090L00`071`041`0300L701d700<01`L03@L00`071`0D1`0300L701L700<01`L02`L00`07
1`0P1`0500L71`009PL00`071`021`0300L702L700061`0300L702@700<01`L010L00`071`0M1`03
00L700`700<01`L05@L00`071`0F1`0300L700`700<01`L07`L00`071`021`0300L702@700D01`L7
000Z1`001PL00`071`0T1`0300L700<700<01`L07PL00`071`0<1`0300L701D700<01`L05@L00`07
1`0=1`0300L701h700<01`L00`L00`071`0T1`0500L71`00:PL000H700<01`L090L00`071`021`03
00L701l700<01`L02`L00`071`0F1`0300L701D700<01`L03@L00`071`0N1`0300L700<700<01`L0
90L010071`0[1`001PL00`071`0T1`0500L71`008PL00`071`0:1`0300L701L700<01`L050L00`07
1`0>1`0300L701d700<01`L010L00`071`0T1`0300L002`700061`0300L702@700D01`L7000R1`03
00L700X700<01`L05`L00`071`0C1`0300L700l700<01`L070L00`071`051`0300L702@70P0]1`00
1PL00`071`0T1`0400L702<700<01`L02@L00`071`0H1`0300L7018700<01`L040L00`071`0K1`03
00L700H700<01`L090L202d700061`0300L702@700<01`0090L00`071`081`0300L701T700<01`L0
4PL00`071`0@1`0300L701/700<01`L01PL00`071`0T1`0300L702`700061`0300L702@70P0U1`03
00L700L700<01`L06PL00`071`0A1`0300L7014700<01`L06PL00`071`071`0300L702<700<01`L0
;@L000H700<01`L090L202D700<01`L01`L00`071`0J1`0300L7010700<01`L04PL00`071`0I1`03
00L700P700<01`L08`L00`071`0]1`001PL00`071`0T1`0300L702@700<01`L01PL00`071`0K1`03
00L7010700<01`L04PL00`071`0H1`0300L700T700<01`L08PL00`071`0^1`001PL00`071`0S1`80
9PL00`071`051`0300L701`700<01`L03`L00`071`0C1`0300L701P700<01`L02@L00`071`0Q1`03
00L702l700061`0300L702<70P0V1`0300L700@700<01`L07@L00`071`0>1`0300L701@700<01`L0
5`L00`071`0:1`0300L7020700<01`L0<0L000H700<01`L08PL00`07000V1`0300L700@700<01`L0
7@L00`071`0=1`0300L701D700<01`L05PL00`071`0;1`0300L7020700<01`L0<0L000H700<01`L0
8@L010071`0V1`0300L700<700<01`L07PL00`071`0=1`0300L701D700<01`L05PL00`071`0;1`03
00L701l700<01`L0<@L000H700<01`L080L01@071`L002H700<01`L00PL00`071`0O1`0300L700`7
00<01`L05PL00`071`0E1`0300L700`700<01`L07PL00`071`0b1`001PL00`071`0P1`0500L71`00
9PL01@071`L0028700<01`L02`L00`071`0G1`0300L701@700<01`L03@L00`071`0M1`0300L703<7
00061`0300L701l700<01`L00PL00`071`0T1`0500L71`008PL00`071`0:1`0300L701P700<01`L0
4`L00`071`0>1`0300L701d700<01`L0<`L000H700<01`L07PL00`071`031`0300L702@700@01`L0
8`L00`071`0:1`0300L701P700<01`L04`L00`071`0>1`0300L701`700<01`L0=0L000H700<01`L0
7@L00`071`041`0300L702@700<01`0090L00`071`091`0300L701T700<01`L04PL00`071`0?1`03
00L701/700<01`L0=@L000H700<01`L07@L00`071`041`0300L702@70P0U1`0300L700P700<01`L0
6PL00`071`0A1`0300L7010700<01`L06PL00`071`0f1`001PL00`071`0L1`0300L700D700<01`L0
90L202D700<01`L01`L00`071`0K1`0300L7014700<01`L040L00`071`0J1`0300L703H700061`03
00L701/700<01`L01PL00`071`0T1`0300L702@700<01`L01`L00`071`0K1`0300L7010700<01`L0
4@L00`071`0I1`0300L703L700061`0300L701X700<01`L01`L00`071`0S1`809PL00`071`061`03
00L701`700<01`L03`L00`071`0B1`0300L701P700<01`L0>0L000H700<01`L06PL00`071`071`03
00L702<70P0V1`0300L700D700<01`L07@L00`071`0>1`0300L701<700<01`L05`L00`071`0i1`00
1PL00`071`0I1`0300L700P700<01`L08PL00`07000V1`0300L700@700<01`L07PL00`071`0>1`03
00L701<700<01`L05`L00`071`0i1`001PL00`071`0H1`0300L700T700<01`L08@L010071`0V1`03
00L700@700<01`L07PL00`071`0=1`0300L701@700<01`L05PL00`071`0j1`001PL00`071`0G1`03
00L700X700<01`L080L01@071`L002H700<01`L00`L00`071`0O1`0300L700`700<01`L05@L00`07
1`0E1`0300L703/700061`0300L701L700<01`L02PL00`071`0P1`0500L71`009PL00`071`021`03
00L7020700<01`L02`L00`071`0F1`0300L701D700<01`L0>`L000H700<01`L05PL00`071`0;1`03
00L701l700<01`L00PL00`071`0T1`0500L71`008`L00`071`0;1`0300L701H700<01`L050L00`07
1`0l1`001PL00`071`0E1`0300L700`700<01`L07PL00`071`031`0300L702@700D01`L7000S1`03
00L700X700<01`L05`L00`071`0C1`0300L703d700061`0300L701D700<01`L030L00`071`0N1`03
00L700<700<01`L090L010071`0T1`0300L700T700<01`L060L00`071`0B1`0300L703h700061`03
00L701@700<01`L03@L00`071`0M1`0300L700@700<01`L090L00`07000U1`0300L700T700<01`L0
60L00`071`0B1`0300L703h700061`0300L701<700<01`L03PL00`071`0L1`0300L700D700<01`L0
90L202H700<01`L020L00`071`0I1`0300L7014700<01`L0?`L000H700<01`L04PL00`071`0?1`03
00L701/700<01`L01PL00`071`0T1`809PL00`071`071`0300L701X700<01`L040L00`071`101`00
1PL00`071`0B1`0300L700l700<01`L06`L00`071`061`0300L702@700<01`L09@L00`071`061`03
00L701/700<01`L03`L00`071`111`001PL00`071`0A1`0300L7010700<01`L06PL00`071`071`03
00L702<70P0W1`0300L700H700<01`L06`L00`071`0?1`0300L7044700061`0300L7010700<01`L0
4@L00`071`0I1`0300L700P700<01`L08`L202L700<01`L01@L00`071`0L1`0300L700h700<01`L0
@PL000H700<01`L03`L00`071`0B1`0300L701P700<01`L02@L00`071`0R1`0300L002L700<01`L0
10L00`071`0M1`0300L700d700<01`L0@`L000H700<01`L03`L00`071`0B1`0300L701P700<01`L0
2@L00`071`0Q1`0400L702L700<01`L010L00`071`0M1`0300L700`700<01`L0A0L000H700<01`L0
3PL00`071`0C1`0300L701L700<01`L02PL00`071`0P1`0500L71`009`L00`071`031`0300L701h7
00<01`L030L00`071`141`001PL00`071`0=1`0300L701@700<01`L05PL00`071`0;1`0300L70207
00D01`L7000W1`0300L7008700<01`L07`L00`071`0;1`0300L704D700061`0300L700`700<01`L0
5@L00`071`0F1`0300L700/700<01`L07`L00`071`021`0300L702D700D01`L7000R1`0300L700X7
00<01`L0APL000H700<01`L030L00`071`0E1`0300L701D700<01`L030L00`071`0N1`0300L700<7
00<01`L09@L01@071`L0028700<01`L02PL00`071`161`001PL00`071`0;1`0300L701H700<01`L0
50L00`071`0=1`0300L701h700<01`L00`L00`071`0U1`0400L702<700<01`L02@L00`071`171`00
1PL00`071`0:1`0300L701L700<01`L04`L00`071`0>1`0300L701d700<01`L010L00`071`0U1`03
00L002@700<01`L020L00`071`181`001PL00`071`0:1`0300L701L700<01`L04`L00`071`0>1`03
00L701`700<01`L01@L00`071`0U1`809@L00`071`071`0300L704T700061`0300L700T700<01`L0
60L00`071`0B1`0300L700l700<01`L06`L00`071`061`0300L702D70P0U1`0300L700L700<01`L0
B@L000H700<01`L020L00`071`0I1`0300L7014700<01`L040L00`071`0K1`0300L700H700<01`L0
9@L00`071`0T1`0300L700H700<01`L0BPL000H700<01`L01`L00`071`0J1`0300L7014700<01`L0
40L00`071`0J1`0300L700L700<01`L090L202H700<01`L01@L00`071`1;1`001PL00`071`071`03
00L701X700<01`L040L00`071`0A1`0300L701T700<01`L020L00`071`0T1`809PL00`071`041`03
00L704`700061`0300L700H700<01`L06`L00`071`0?1`0300L7018700<01`L060L00`071`091`03
00L702<700<01`009PL00`071`041`0300L704`700061`0300L700D700<01`L070L00`071`0>1`03
00L701<700<01`L060L00`071`091`0300L7028700@01`L09PL00`071`031`0300L704d700061`03
00L700@700<01`L07@L00`071`0>1`0300L701<700<01`L05`L00`071`0:1`0300L7024700D01`L7
000V1`0300L7008700<01`L0CPL000H700<01`L010L00`071`0M1`0300L700d700<01`L050L00`07
1`0F1`0300L700/700<01`L08@L01@071`L002H700D01`L7001A1`001PL00`071`031`0300L701h7
00<01`L030L00`071`0E1`0300L701H700<01`L02`L00`071`0P1`0300L7008700<01`L090L01@07
1`L0054700061`0300L7008700<01`L07`L00`071`0;1`0300L701H700<01`L05@L00`071`0<1`03
00L701l700<01`L00`L00`071`0T1`0400L7058700061`0500L71`008PL00`071`0;1`0300L701H7
00<01`L050L00`071`0=1`0300L701h700<01`L010L00`071`0T1`0300L005<700061`0500L71`00
8PL00`071`0:1`0300L701L700<01`L04`L00`071`0>1`0300L701h700<01`L010L00`071`0T1`80
E0L000H700@01`L08`L00`071`091`0300L701P700<01`L04`L00`071`0>1`0300L701d700<01`L0
1@L00`071`0T1`80E0L000H700<01`0090L00`071`091`0300L701P700<01`L04PL00`071`0?1`03
00L701`700<01`L01PL00`071`0T1`0300L705<700061`809@L00`071`081`0300L701T700<01`L0
4@L00`071`0@1`0300L701/700<01`L01`L00`071`0S1`0300L705@700061`809@L00`071`071`03
00L701X700<01`L04@L00`071`0@1`0300L701/700<01`L01`L00`071`0S1`0300L705@700061`03
00L702@700<01`L01PL00`071`0K1`0300L7010700<01`L04@L00`071`0J1`0300L700P700<01`L0
8PL00`071`1E1`00;@L00`071`061`0300L701/700<01`L03`L00`071`0B1`0300L701T700<01`L0
2@L00`071`0Q1`0300L705H7000]1`0300L700D700<01`L070L00`071`0>1`0300L701<700<01`L0
60L00`071`0:1`0300L7020700<01`L0E`L002d700<01`L010L00`071`0M1`0300L700h700<01`L0
4`L00`071`0H1`0300L700X700<01`L080L00`071`1G1`00;@L00`071`041`0300L701d700<01`L0
3@L00`071`0D1`0300L701L700<01`L02`L00`071`0O1`0300L705P7000]1`0300L700<700<01`L0
7PL00`071`0<1`0300L701D700<01`L05PL00`071`0<1`0300L701h700<01`L0F@L002d700<01`L0
0PL00`071`0O1`0300L700/700<01`L05PL00`071`0E1`0300L700d700<01`L07PL00`071`1I1`00
;@L01@071`L0028700<01`L02`L00`071`0F1`0300L701D700<01`L03@L00`071`0M1`0300L705X7
000]1`0500L71`008PL00`071`0:1`0300L701L700<01`L050L00`071`0>1`0300L701`700<01`L0
F`L002d700@01`L08`L00`071`091`0300L701P700<01`L04`L00`071`0?1`0300L701/700<01`L0
G0L002d700<01`0090L00`071`091`0300L701P700<01`L04PL00`071`0@1`0300L701/700<01`L0
G0L002d70P0U1`0300L700P700<01`L06@L00`071`0B1`0300L7010700<01`L06PL00`071`1M1`00
;@L202D700<01`L01`L00`071`0J1`0300L7014700<01`L04@L00`071`0I1`0300L705h7000]1`03
00L702@700<01`L01PL00`071`0K1`0300L7010700<01`L04PL00`071`0H1`0300L705l7001D1`03
00L700H700<01`L06`L00`071`0@1`0300L7018700<01`L060L00`071`1O1`00E0L00`071`051`03
00L701`700<01`L03`L00`071`0C1`0300L701L700<01`L0H0L005@700<01`L010L00`071`0M1`03
00L700h700<01`L050L00`071`0F1`0300L70647001D1`0300L700@700<01`L07@L00`071`0=1`03
00L701D700<01`L05PL00`071`1Q1`00E0L00`071`031`0300L701h700<01`L03@L00`071`0E1`03
00L701D700<01`L0HPL005@700<01`L00PL00`071`0O1`0300L700`700<01`L05PL00`071`0D1`03
00L706<7001D1`0500L71`008PL00`071`0;1`0300L701L700<01`L04`L00`071`1T1`00E0L01@07
1`L0028700<01`L02PL00`071`0H1`0300L701<700<01`L0I0L005@700@01`L08`L00`071`0:1`03
00L701P700<01`L04PL00`071`1U1`00E0L00`07000T1`0300L700T700<01`L06@L00`071`0A1`03
00L706H7001D1`809@L00`071`081`0300L701X700<01`L04@L00`071`1V1`00E0L202D700<01`L0
1`L00`071`0K1`0300L7010700<01`L0I`L005@700<01`L090L00`071`071`0300L701/700<01`L0
3`L00`071`1X1`00N`L00`071`061`0300L701`700<01`L03PL00`071`1Y1`00N`L00`071`051`03
00L701d700<01`L03PL00`071`1Y1`00N`L00`071`041`0300L701h700<01`L03@L00`071`1Z1`00
N`L00`071`041`0300L701h700<01`L030L00`071`1[1`00N`L00`071`031`0300L701l700<01`L0
2`L00`071`1/1`00N`L00`071`021`0300L7020700<01`L02`L00`071`1/1`00N`L01@071`L002<7
00<01`L02PL00`071`1]1`00N`L01@071`L002<700<01`L02@L00`071`1^1`00N`L010071`0T1`03
00L700T700<01`L0KPL007/700<01`009@L00`071`081`0300L706l7001k1`809PL00`071`071`03
00L70707001k1`809PL00`071`061`0300L70747001k1`0300L702D700<01`L01PL00`071`1a1`00
X`L00`071`051`0300L70787002S1`0300L700@700<01`L0L`L00:<700<01`L010L00`071`1c1`00
X`L00`071`031`0300L707@7002S1`0300L7008700<01`L0M@L00:<700D01`L7001h1`00X`L01@07
1`L007P7002S1`0400L707T7002S1`0300L007X7002S1`80N`L00:<70P1k1`00X`L00`071`1j1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {305.688, 0}} -> {-8.03268, -9.49487, \
0.064025, 0.064025}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[157]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice41\  = 
      tiling2D[SphericalCut[N[Join[AL041, \ AL141, \ AL241, \ AL341]], 10], \ 
        rad41]\)], "Input",
  CellLabel->"In[158]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97054 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499981 0.0480782 0.485412 0.0480782 [
[ 0 0 0 0 ]
[ 1 .97054 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .97054 L
0 .97054 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.6156 .94743 m
.7358 .782 L
s
.6156 .94743 m
.6156 .74294 L
s
.6156 .94743 m
.42329 .86932 L
s
.7358 .782 m
.856 .61656 L
s
.7358 .782 m
.7358 .57751 L
s
.7358 .782 m
.54349 .70389 L
s
.856 .61656 m
.97619 .45113 L
s
.856 .61656 m
.856 .41207 L
s
.856 .61656 m
.66368 .53845 L
s
.97619 .45113 m
.78388 .37302 L
s
.49541 .90838 m
.6156 .74294 L
s
.49541 .90838 m
.49541 .70389 L
s
.49541 .90838 m
.3031 .83027 L
s
.6156 .74294 m
.7358 .57751 L
s
.6156 .74294 m
.6156 .53845 L
s
.6156 .74294 m
.8171 .79279 L
s
.6156 .74294 m
.42329 .66483 L
s
.7358 .57751 m
.856 .41207 L
s
.7358 .57751 m
.7358 .37302 L
s
.7358 .57751 m
.93729 .62735 L
s
.7358 .57751 m
.54349 .4994 L
s
.856 .41207 m
.856 .20758 L
s
.856 .41207 m
.66368 .33396 L
s
.37521 .86932 m
.49541 .70389 L
s
.37521 .86932 m
.37521 .66483 L
s
.37521 .86932 m
.57671 .91917 L
s
.37521 .86932 m
.1829 .79121 L
s
.49541 .70389 m
.6156 .53845 L
s
.49541 .70389 m
.49541 .4994 L
s
.49541 .70389 m
.6969 .75374 L
s
.49541 .70389 m
.3031 .62578 L
s
.6156 .53845 m
.7358 .37302 L
s
.6156 .53845 m
.6156 .33396 L
s
.6156 .53845 m
.8171 .5883 L
s
.6156 .53845 m
.42329 .46034 L
s
.7358 .37302 m
.856 .20758 L
s
.7358 .37302 m
.7358 .16853 L
s
.7358 .37302 m
.93729 .42287 L
s
.7358 .37302 m
.54349 .29491 L
s
.856 .20758 m
.66368 .12948 L
s
.25502 .83027 m
.37521 .66483 L
s
.25502 .83027 m
.25502 .62578 L
s
.25502 .83027 m
.45651 .88012 L
s
.37521 .66483 m
.49541 .4994 L
s
.37521 .66483 m
.37521 .46034 L
s
.37521 .66483 m
.57671 .71468 L
s
.37521 .66483 m
.1829 .58673 L
s
.49541 .4994 m
.6156 .33396 L
s
.49541 .4994 m
.49541 .29491 L
s
.49541 .4994 m
.6969 .54925 L
s
.49541 .4994 m
.3031 .42129 L
s
.6156 .33396 m
.7358 .16853 L
s
.6156 .33396 m
.6156 .12948 L
s
.6156 .33396 m
.8171 .38381 L
s
.6156 .33396 m
.42329 .25586 L
s
.7358 .16853 m
.54349 .09042 L
s
.13482 .79121 m
.25502 .62578 L
s
.13482 .79121 m
.13482 .58673 L
s
.13482 .79121 m
.33632 .84106 L
s
.25502 .62578 m
.37521 .46034 L
s
.25502 .62578 m
.25502 .42129 L
s
.25502 .62578 m
.45651 .67563 L
s
.25502 .62578 m
.06271 .54767 L
s
.37521 .46034 m
.49541 .29491 L
s
.37521 .46034 m
.37521 .25586 L
s
.37521 .46034 m
.57671 .51019 L
s
.37521 .46034 m
.1829 .38224 L
s
.49541 .29491 m
.6156 .12948 L
s
.49541 .29491 m
.49541 .09042 L
s
.49541 .29491 m
.6969 .34476 L
s
.49541 .29491 m
.3031 .2168 L
s
.6156 .12948 m
.8171 .17932 L
s
.6156 .12948 m
.42329 .05137 L
s
.13482 .58673 m
.25502 .42129 L
s
.13482 .58673 m
.13482 .38224 L
s
.13482 .58673 m
.33632 .63657 L
s
.25502 .42129 m
.37521 .25586 L
s
.25502 .42129 m
.25502 .2168 L
s
.25502 .42129 m
.45651 .47114 L
s
.25502 .42129 m
.06271 .34318 L
s
.37521 .25586 m
.49541 .09042 L
s
.37521 .25586 m
.37521 .05137 L
s
.37521 .25586 m
.57671 .3057 L
s
.37521 .25586 m
.1829 .17775 L
s
.49541 .09042 m
.6969 .14027 L
s
.13482 .38224 m
.25502 .2168 L
s
.13482 .38224 m
.13482 .17775 L
s
.13482 .38224 m
.33632 .43209 L
s
.25502 .2168 m
.37521 .05137 L
s
.25502 .2168 m
.45651 .26665 L
s
.37521 .05137 m
.57671 .10122 L
s
.13482 .17775 m
.33632 .2276 L
s
.8171 .79279 m
.93729 .62735 L
s
.8171 .79279 m
.8171 .5883 L
s
.8171 .79279 m
.62479 .71468 L
s
.93729 .62735 m
.93729 .42287 L
s
.93729 .62735 m
.74498 .54925 L
s
.57671 .91917 m
.6969 .75374 L
s
.57671 .91917 m
.57671 .71468 L
s
.57671 .91917 m
.3844 .84106 L
s
.6969 .75374 m
.8171 .5883 L
s
.6969 .75374 m
.6969 .54925 L
s
.6969 .75374 m
.50459 .67563 L
s
.8171 .5883 m
.93729 .42287 L
s
.8171 .5883 m
.8171 .38381 L
s
.8171 .5883 m
.62479 .51019 L
s
.93729 .42287 m
.74498 .34476 L
s
.45651 .88012 m
.57671 .71468 L
s
.45651 .88012 m
.45651 .67563 L
s
.45651 .88012 m
.2642 .80201 L
s
.57671 .71468 m
.6969 .54925 L
s
.57671 .71468 m
.57671 .51019 L
s
.57671 .71468 m
.3844 .63657 L
s
.6969 .54925 m
.8171 .38381 L
s
.6969 .54925 m
.6969 .34476 L
s
.6969 .54925 m
.50459 .47114 L
s
.8171 .38381 m
.8171 .17932 L
s
.8171 .38381 m
.62479 .3057 L
s
.33632 .84106 m
.45651 .67563 L
s
.33632 .84106 m
.33632 .63657 L
s
.33632 .84106 m
.144 .76295 L
s
.45651 .67563 m
.57671 .51019 L
s
.45651 .67563 m
.45651 .47114 L
s
.45651 .67563 m
.2642 .59752 L
s
.57671 .51019 m
.6969 .34476 L
s
.57671 .51019 m
.57671 .3057 L
s
.57671 .51019 m
.3844 .43209 L
s
.6969 .34476 m
.8171 .17932 L
s
.6969 .34476 m
.6969 .14027 L
s
.6969 .34476 m
.50459 .26665 L
s
.8171 .17932 m
.62479 .10122 L
s
.21612 .80201 m
.33632 .63657 L
s
.21612 .80201 m
.21612 .59752 L
s
.33632 .63657 m
.45651 .47114 L
s
.33632 .63657 m
.33632 .43209 L
s
.33632 .63657 m
.144 .55847 L
s
.45651 .47114 m
.57671 .3057 L
s
.45651 .47114 m
.45651 .26665 L
s
.45651 .47114 m
.2642 .39303 L
s
.57671 .3057 m
.6969 .14027 L
s
.57671 .3057 m
.57671 .10122 L
s
.57671 .3057 m
.3844 .2276 L
s
.6969 .14027 m
.50459 .06216 L
s
.21612 .59752 m
.33632 .43209 L
s
.21612 .59752 m
.21612 .39303 L
s
.21612 .59752 m
.02381 .51941 L
s
.33632 .43209 m
.45651 .26665 L
s
.33632 .43209 m
.33632 .2276 L
s
.33632 .43209 m
.144 .35398 L
s
.45651 .26665 m
.57671 .10122 L
s
.45651 .26665 m
.45651 .06216 L
s
.45651 .26665 m
.2642 .18854 L
s
.57671 .10122 m
.3844 .02311 L
s
.09593 .55847 m
.21612 .39303 L
s
.09593 .55847 m
.09593 .35398 L
s
.21612 .39303 m
.33632 .2276 L
s
.21612 .39303 m
.21612 .18854 L
s
.33632 .2276 m
.45651 .06216 L
s
.09593 .35398 m
.21612 .18854 L
s
.78388 .782 m
.90407 .61656 L
s
.78388 .782 m
.78388 .57751 L
s
.90407 .61656 m
.90407 .41207 L
s
.54349 .90838 m
.66368 .74294 L
s
.54349 .90838 m
.54349 .70389 L
s
.66368 .74294 m
.78388 .57751 L
s
.66368 .74294 m
.66368 .53845 L
s
.66368 .74294 m
.86518 .79279 L
s
.78388 .57751 m
.90407 .41207 L
s
.78388 .57751 m
.78388 .37302 L
s
.42329 .86932 m
.54349 .70389 L
s
.42329 .86932 m
.42329 .66483 L
s
.42329 .86932 m
.62479 .91917 L
s
.54349 .70389 m
.66368 .53845 L
s
.54349 .70389 m
.54349 .4994 L
s
.54349 .70389 m
.74498 .75374 L
s
.66368 .53845 m
.78388 .37302 L
s
.66368 .53845 m
.66368 .33396 L
s
.66368 .53845 m
.86518 .5883 L
s
.78388 .37302 m
.78388 .16853 L
s
.3031 .83027 m
.42329 .66483 L
s
.3031 .83027 m
.3031 .62578 L
s
.3031 .83027 m
.50459 .88012 L
s
.42329 .66483 m
.54349 .4994 L
s
.42329 .66483 m
.42329 .46034 L
s
.42329 .66483 m
.62479 .71468 L
s
.54349 .4994 m
.66368 .33396 L
s
.54349 .4994 m
.54349 .29491 L
s
.54349 .4994 m
.74498 .54925 L
s
.66368 .33396 m
.78388 .16853 L
s
.66368 .33396 m
.66368 .12948 L
s
.66368 .33396 m
.86518 .38381 L
s
.1829 .79121 m
.3031 .62578 L
s
.1829 .79121 m
.1829 .58673 L
s
.1829 .79121 m
.3844 .84106 L
s
.3031 .62578 m
.42329 .46034 L
s
.3031 .62578 m
.3031 .42129 L
s
.3031 .62578 m
.50459 .67563 L
s
.42329 .46034 m
.54349 .29491 L
s
.42329 .46034 m
.42329 .25586 L
s
.42329 .46034 m
.62479 .51019 L
s
.54349 .29491 m
.66368 .12948 L
s
.54349 .29491 m
.54349 .09042 L
s
.54349 .29491 m
.74498 .34476 L
s
.66368 .12948 m
.86518 .17932 L
s
.1829 .58673 m
.3031 .42129 L
s
.1829 .58673 m
.1829 .38224 L
s
.1829 .58673 m
.3844 .63657 L
s
.3031 .42129 m
.42329 .25586 L
s
.3031 .42129 m
.3031 .2168 L
s
.3031 .42129 m
.50459 .47114 L
s
.42329 .25586 m
.54349 .09042 L
s
.42329 .25586 m
.42329 .05137 L
s
.42329 .25586 m
.62479 .3057 L
s
.54349 .09042 m
.74498 .14027 L
s
.06271 .54767 m
.1829 .38224 L
s
.06271 .54767 m
.06271 .34318 L
s
.06271 .54767 m
.2642 .59752 L
s
.1829 .38224 m
.3031 .2168 L
s
.1829 .38224 m
.1829 .17775 L
s
.1829 .38224 m
.3844 .43209 L
s
.3031 .2168 m
.42329 .05137 L
s
.3031 .2168 m
.50459 .26665 L
s
.42329 .05137 m
.62479 .10122 L
s
.06271 .34318 m
.1829 .17775 L
s
.06271 .34318 m
.2642 .39303 L
s
.1829 .17775 m
.3844 .2276 L
s
.86518 .79279 m
.86518 .5883 L
s
.62479 .91917 m
.74498 .75374 L
s
.62479 .91917 m
.62479 .71468 L
s
.74498 .75374 m
.86518 .5883 L
s
.74498 .75374 m
.74498 .54925 L
s
.86518 .5883 m
.86518 .38381 L
s
.50459 .88012 m
.62479 .71468 L
s
.50459 .88012 m
.50459 .67563 L
s
.62479 .71468 m
.74498 .54925 L
s
.62479 .71468 m
.62479 .51019 L
s
.74498 .54925 m
.86518 .38381 L
s
.74498 .54925 m
.74498 .34476 L
s
.86518 .38381 m
.86518 .17932 L
s
.3844 .84106 m
.50459 .67563 L
s
.3844 .84106 m
.3844 .63657 L
s
.50459 .67563 m
.62479 .51019 L
s
.50459 .67563 m
.50459 .47114 L
s
.62479 .51019 m
.74498 .34476 L
s
.62479 .51019 m
.62479 .3057 L
s
.74498 .34476 m
.86518 .17932 L
s
.74498 .34476 m
.74498 .14027 L
s
.2642 .80201 m
.3844 .63657 L
s
.2642 .80201 m
.2642 .59752 L
s
.3844 .63657 m
.50459 .47114 L
s
.3844 .63657 m
.3844 .43209 L
s
.50459 .47114 m
.62479 .3057 L
s
.50459 .47114 m
.50459 .26665 L
s
.62479 .3057 m
.74498 .14027 L
s
.62479 .3057 m
.62479 .10122 L
s
.144 .76295 m
.2642 .59752 L
s
.144 .76295 m
.144 .55847 L
s
.2642 .59752 m
.3844 .43209 L
s
.2642 .59752 m
.2642 .39303 L
s
.3844 .43209 m
.50459 .26665 L
s
.3844 .43209 m
.3844 .2276 L
s
.50459 .26665 m
.62479 .10122 L
s
.50459 .26665 m
.50459 .06216 L
s
.144 .55847 m
.2642 .39303 L
s
.144 .55847 m
.144 .35398 L
s
.2642 .39303 m
.3844 .2276 L
s
.2642 .39303 m
.2642 .18854 L
s
.3844 .2276 m
.50459 .06216 L
s
.3844 .2276 m
.3844 .02311 L
s
.02381 .51941 m
.144 .35398 L
s
.144 .35398 m
.2642 .18854 L
s
.2642 .18854 m
.3844 .02311 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[158]:=",
  ImageSize->{288, 279.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00015`P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L006h70P2`1`00K@L200031`000:h7001]1`800`L30:/7001/1`0300L000H7
0P2Y1`00J`L010071`081`<0YPL006X700D01`L7000;1`80Y0L006X700D01`L7000=1`<0X@L006T7
00<01`L00PL00`071`0>1`80W`L006P700<01`L0100:1`<01@L309`7001W1`0300L700800PL400H7
0P000`L0000300@70P2J1`00I`L00`071`02008700@01`L710021`800`L700870`2G1`00IPL01P07
1`07008700<01`L01@L400H70P000`L0000300031`0000D70P2>1`00I@L010071`021`0400L700L7
00<01`L01@041`<00`L600041`001`80S0L006@700@01`L00`L010071`061`0500L71`0010L60003
1`0000D71@031`<0R@L006@700@01`L00`L010071`061`0500L71`001`L500041`0000@700<01`00
0`031`80Q`L006<700@01`L010L010071`051`0300L7008700<01`L010L010071`021`H000D700L7
00021`T0Q0L0068700@01`L01@L010071`041`0300L700<700<01`L00`L01@071`L000L710000`L0
1`031`<000<700000`221`00H@L010071`061`0400L700<700<01`L010L00`071`031`0500L71`00
20L00`071`0400D70P031`@0O`L0064700@01`L01PL010071`031`0300L700@700<01`L00PL00`07
1`021`0300L700D700<01`L00PL700<70`041`@0N`L0060700@01`L01`L010071`021`0300L700D7
00D01`L700051`0300L700@700@01`L70`031`8000<700001P051`D0M`L005l700@01`L020L01P07
1`0700P700@01`L01PL00`071`031`0400L71`8000<700000`001@L0000700P010L707<7001N1`05
00L71`0020L01P071`0700P700@01`L01PL00`071`031`0400L71`8000<700L00`L700<71`031`80
0PL406l7001N1`0400L700T700<01`L00P091`0300L000L700<01`L00PL02@071`L01`0700081`D0
10L800041`0000<7101[1`00G@L010071`0:1`0400L700X70P081`0500L71`000`L01P071`0700L7
00D01`L01`0400<70`031`H00PL200031`0006T7001L1`0400L700/700@01`002PL00`071`071`05
00L71`000PL01`071`L01`001PL01@071`L000@71P000`L000051`H00`L306H7001K1`0500L71`00
2`L01007000:1`0300L700L700@01`L00`L01`071`L01`001PL01@071`L000L72@051`D010L206@7
001K1`0400L700`70P000`L01`081`802@L00`0700031`0300L7008700<01`001@L00`071`021`03
00L700@700<01`L00`000`L0000400061`071`071P0010L0001Q1`00FPL010071`0=1`0400L700P7
00<01`002@L200<700<01`L00`L00`0700041`0300L700<700<01`L00`L01@071`L000870P041`@0
00<700L00`L200031`0000@0G`L005T700D01`L7000=1`0400L700L700@01`L02@L2008700<01`L0
10L00`0700031`0300L700@700<01`L00`L01@071`L000@70`021`0300L000@010L300871@1L1`00
F0L01@071`L000d70P021`0300L700D700@01`L02@L01@071`L000H700<01`000`L00`071`041`03
00L7008700<01`L00PL00`071`051`8010L700<70`031`@0F@L005P700@01`L03@L00`0700021`03
00L700@700D01`L700081`800PL00`071`051`0300L0008700<01`L01@L01@071`L000D700<01`L0
1@L00`07000400870`000`L0000600@71@1E1`00E`L010071`0=1`0400L7008700<01`L00`L00`07
1`021`0300L700H70P000`L01`071`0500L01`0020L01@071`L000D700<01`L010L00`071`020087
10021`800PL800@71P1A1`00EPL01@071`L000d700@01`L00PL00`071`021`0300L700<700<01`L0
1@L0100700091`0500L01`0020L010071`061`0300L700@700<01`L00P021`0400L71`P00`L70087
0`000`L0000204d7001E1`0500L71`003@L01@071`L0008700<01`L00PL00`071`031`0300L700@7
00<01`L00P091`0400L000T700<01`001`L00`071`031`0600L700L00PL00`071`051`D010L90003
1`0000<70`1:1`00E@L010071`0=1`0300L7008700@01`L00`L00`071`041`0300L700<700D01`L7
000:1`0300L000X700<01`001`L00`071`021`0400L7008700@01`L01`L00`071`0500@70P041`H0
00<70000BPL005@700@01`L03@L00`071`031`0400L7008700<01`L01@L00`071`031`0300L70080
2PL300X70P081`0300L7008700<01`000`L010071`061`0500L71`0010L900D71@1:1`00D`L01@07
1`L000d700<01`L00`L01P071`0700P700<01`L00PL01P071`0700X70`0:1`0300L700L700D01`L7
00021`0500L71`000PL00`071`041`0500L71`001PL600031`0000D700<01`000`171`00DPL01@07
1`L000d700<01`L010L01P071`0700P700D01`L700031`0300L000X700<01`002@L200T700@01`L0
0PL00`071`021`0400L700D700<01`L00PL00`071`041`0300L700P00PL010071`021`H0@PL00587
00@01`L03@L00`071`051`0300L700802@L010071`031`0400L700T70P000`L01`081`802@L00`07
00021`0300L700<700@01`L010L00`071`031`0300L700<700D01`L700021`800`L400031`0700<7
0`000`L0000203h7001A1`0500L71`003@L00`071`051`0400L700X700@01`L00PL01@071`L000T7
0P000`L01`071`0300L000T700<01`000PL00`071`031`0400L700<700<01`L010L00`071`031`05
00L71`0010L300031`0700D01@L200<7100j1`00D0L01@071`L000d700<01`L01PL01007000:1`03
00L0008700<01`L00PL00`071`061`0500L01`001`L010071`091`800PL00`071`041`0400L700<7
00<01`L010L00`071`021`0300L7008700<01`L01@L200<71`031`<010L403H7001?1`0500L71`00
3@L00`071`071`0400L000X70P031`0300L7008700<01`L01@L01P071`0700L700@01`L02@L01007
1`071`0400L7008700<01`L01@L01@071`L000D700<01`L010L00`071`0200041`071`800PL50003
1`0000H7100b1`00C`L010071`0=1`0300L700P70P000`L01`091`800PL00`071`031`0300L700@7
00L01`L700L000H700D01`L700081`800PL00`071`051`0600L700L020L010071`061`0300L700@7
00<01`L00P000`L01`031`800`L800L7100^1`00CPL01@071`L000d700<01`L020L010071`0:1`04
00L700H700<01`L010L01`071`L01`001@L00`071`021`0300L700H70P000`L01`071`0600L700L0
20L010071`061`0300L700<700@01`L70P000`L01`051`D00`L500T7100Z1`009PL300/70`0F1`05
00L71`003@L00`071`081`800PL00`071`071`8000<700L01PL00`071`031`0300L7008700<01`00
10L00`071`031`0300L700D700@01`002@L00`071`0200T700<01`001`L00`071`021`0900L71`07
00L000P70`071`<02`L302L7000V1`0300L700@01PL200031`0000<04@L01@071`L000d700<01`L0
2@L2008700<01`L01PL01@0700L000L700<01`L00PL00`071`031`0300L000@700<01`L00`L00`07
1`041`0400L700X700@01`L02PL200P700<01`L00PL010071`021`0300L000L700<01`L010051`80
30L202L7000V1`0300L700@710021`800`L700d700D01`L7000=1`0300L700P700<01`000PL00`07
1`061`0400L000P700D01`L700061`0300L000<700<01`L010L00`071`041`0400L700X700@01`00
2PL200P700D01`L700021`0700L71`0700061`0500L71`000`L200<70P0<1`809`L002H700<01`L0
20L400H70P000`L0000300P70P021`0300L700/700<01`L020L010071`021`0300L700D700@01`L0
2@L01@071`L000H700<01`000PL00`071`051`0300L700<700<01`L00P0:1`0400L000X700<01`L0
1`L010071`031`0700L71`0700061`0500L71`001@L300031`0700X700<01`009`L002H700<01`L0
20L00`071`0500@70`031`@00`L200031`0000d700<01`L020L01@071`L0008700<01`L010L00`07
1`0200T700@01`L01`L00`0700021`0300L700D700<01`L00PL01P071`0700X70P000`L01`081`80
2@L00`0700031`0300L7008700<01`001@L00`071`021`0300L700@7100:1`0400L702L7000V1`03
00L700L700D01`L700041`H000<700001@L500031`0700<02@L00`071`091`0500L71`000PL00`07
1`041`0300L700802@L00`0700081`0500L01`0020L01@071`L000<700<01`002PL010071`081`03
00L000T700<01`000PL00`071`031`0300L000@700<01`L00`L00`071`031`0400L71`<01`L01@07
1`L002L7000V1`0300L700L700D01`L700071`D000@7000010L00`07000300<70P071`0300L700P7
00<01`L00PL010071`051`0600L700L02@L00`0700081`0400L000T700D01`L700021`0400L700T7
0P021`0300L700H700<01`002@L2008700<01`L010L00`0700041`0300L700<700<01`L00`L01@07
1`L000870`041`0500L71`009`L002H700<01`L01PL00`071`021`0300L700@700@01`L00PL60004
1`071`800PL700@700<01`L020L00`071`031`0400L700@700@01`L00PL00`071`071`802@L00`07
000:1`0400L7008700D01`L700091`800PL00`071`051`0400L700T700D01`L700061`0300L000<7
00<01`L010L00`071`021`0300L7008700<01`L00`L200031`0700<700<01`L09@L002H700<01`L0
1@L00`071`031`0300L700<700D01`L700071`@000<700L01`L600X700<01`L010L010071`031`04
00L700<700<01`L01`L00`071`081`0300L000X700<01`000PL00`071`021`0300L700H700<01`00
0PL00`071`041`0500L71`002@L010071`071`0300L0008700<01`L01@L01@071`L000D700<01`L0
1@L200@700<01`L09@L002H700<01`L010L00`071`041`0300L700<700D01`L700081`0300L700@0
2PL400P700<01`L010L010071`031`0400L700<700<01`L01PL200X70`0:1`800`L00`071`021`03
00L700D700@01`L00PL00`071`031`0300L7008700<01`L01PL200031`0700L700<01`000PL00`07
1`051`0500L71`001@L00`071`041`0300L700800PL00`071`0U1`009PL00`071`041`0300L700@7
00<01`L00PL00`071`021`0300L700D700@01`L720061`0300L700D00`L00`071`051`0400L70087
00@01`L010L00`071`061`802PL00`07000:1`800PL00`071`031`0300L700D700@01`L00PL00`07
1`031`0300L7008700<01`L01@L01@0700L000P700D01`0700081`0400L700H700<01`L010L00`07
1`02008700<01`L09@L002H700<01`L00`L00`071`051`0500L71`001@L00`071`041`0400L71`<0
0`L200031`00008000<700001@L600L700H01`L01`021`0300L700<700<01`L01@L00`07000:1`03
00L000X700@01`L01PL00`071`041`0500L71`000PL00`071`021`0300L700<700<01`L010L00`07
1`0200T700@01`002@L00`0700071`0300L700<700@01`L70P021`0300L702D7000V1`0300L70087
00<01`L01PL010071`061`0300L700@700<01`L00P000`L0000200870`021`L00`L300031`000080
0`L00`071`02008700<01`L010L00`071`041`0400L700T70P000`L01`081`800PL00`071`041`03
00L700<700<01`L00PL010071`031`0300L700@700<01`L010L010071`0:1`0300L000X700<01`00
1`L00`071`021`0700L71`0700021`0300L702D7000V1`0300L7008700<01`L01PL010071`061`03
00L700<700@01`L70P000`L01`021`@000<700000P021`P000<700000`L400870P021`0300L700@7
00<01`L010L010071`081`0500L01`0020L01@0700L000L700<01`L00PL00`071`031`0400L700<7
00<01`L010L00`071`031`0300L700802PL00`07000:1`8020L00`071`021`0400L7008700@01`L0
9`L002H700D01`L700091`0300L000L700<01`L00PL02@071`L01`0700071`H010L:00@71@000`L0
1`061`0300L700<700D01`L700081`0500L01`0020L0100700081`0300L7008700<01`L00`L01007
1`021`0300L700D700<01`L00PL010071`L200X70`0:1`0300L700L700D01`L700021`0500L71`00
0PL00`071`0U1`009PL010071`0:1`8020L00`071`021`0400L7008700<01`0020L00`071`0400@7
0`031`D000<700L00P000`L000071`0300L7008700<01`L00PL00`071`051`0600L700L01`L01007
1`091`0500L71`001PL01P071`0700P700<01`L00PL01P071`0700X700<01`002@L200T700@01`L0
0`L01@071`L0008700<01`L09@L002H700<01`002`L200P700D01`L700021`0700L71`0700071`05
00L71`000`L600041`0000@70`0010L000021`801@L01@071`L000D700<01`L010L01`071`L01`00
1PL01@071`L000T700@01`L01`L00`071`0200T700D01`L700021`0400L700X700<01`002@L200T7
00<01`000`L00`071`021`0400L702L7000V1`0300L000/700<01`L01`L010071`031`0700L71`07
00071`0500L71`001PL500870P041`D010L3008700D01`L700051`0300L700<700<01`L00PL00`07
00061`0300L700802@L00`0700081`0300L700802@L010071`021`0500L71`002@L200031`0700L7
00<01`002@L00`0700021`0300L700<700@01`L09`L002H70P0;1`802@L00`0700031`0300L70087
00<01`001PL00`071`021`0300L700<700<01`L01P000`L000021`0300L700H00`L3008700<01`L0
10L00`071`031`0300L7008700<01`001@L01P071`0700T700<01`0020L010071`0:1`0300L000<7
00D01`L700081`0500L01`001`L010071`091`800PL00`071`041`0400L702L7000V1`0300L700T7
00<01`002@L00`0700021`0300L700<700<01`001@L00`071`031`0300L7008700D01`L700021`80
00<7000010000`L000021`L000@700001`L00`071`021`0300L700<700<01`0010L01`071`L01`00
2@L200T700@01`002PL00`0700021`0300L7008700<01`L01@L01P071`0700L700@01`L02@L01@07
1`L000H700@01`L09`L002H700<01`L02@L00`0700091`800PL00`071`041`0300L000@700<01`L0
10L00`071`021`0500L71`0010L300871@051`800PL600D700D01`L700061`0300L000<700D01`L7
00021`0300L700L700<01`L020L200031`0700T70P021`0300L700<700<01`L01@L01P071`0700H7
00D01`L700081`800PL00`071`051`0400L702L7000U1`802PL010071`091`0500L71`001PL00`07
00041`0300L700@700D01`L700041`0300L700D70P0010L000L400@71@000`L0000200<700D01`L7
00061`0300L000<700@01`L00`L00`071`061`802PL200031`0700T700D01`L700051`0300L700@7
00L01`L700L000D700<01`L00PL00`071`061`8000<700L01`L010071`0W1`0090L00`0700091`05
00L71`002@L010071`071`0300L000<700<01`L01@L010071`051`0300L700D700<01`000P0010L0
1`L500<70P041`D00PL00`071`051`0300L0008700D01`L700031`0300L700H70P0:1`0400L700X7
00@01`L01PL00`071`031`0300L7008700<01`0010L00`071`031`0300L700D700D01`0700081`04
00L702L7000S1`0400L700P700<01`L00PL00`071`061`8000<700L01`L00`0700021`0300L700H7
00@01`L01@L00`071`041`0300L7008000<700000P021`8000<700000P000`L0000200@710071`05
00L01`000`L00`071`021`0300L700D700<01`002@L2008700<01`L01`L200031`0700H700<01`L0
0`L00`071`021`0300L000@700<01`L00`L00`071`041`0300L700802@L010071`0W1`008`L01007
1`081`0300L7008700<01`L01@L01@0700L000P700<01`000PL00`071`061`0300L000H700<01`L0
10L00`071`02008700<01`L06P031`0400L000<700<01`L00`L00`071`041`0400L700P700<01`00
0PL00`071`061`0400L000P700<01`L00PL00`071`031`0300L000<700<01`L010L00`071`041`04
00L700X700@01`L09`L0028700D01`L700071`0300L700<700<01`L010L00`071`0200T700D01`07
00091`801`L00`071`031`0600L700L00PL00`071`041`D010L400031`00008000@7000710000`L0
00021`0300L700@700<01`L010L010071`081`0300L0008700<01`L01PL0100700081`0500L71`00
1PL00`0700021`0300L700D700<01`L00`L00`071`0200X700@01`L09`L0024700<01`L00PL00`07
1`041`0300L700@700<01`L010L010071`0:1`0400L000X70P071`0300L7008700@01`L00PL01007
1`071`0300L700@01@L200<71@021`@00PL00`071`041`0300L700<700D01`L700071`0400L70087
00<01`L01@L010071`091`0400L700L700<01`000PL00`071`051`0300L7008700@01`L70P0:1`04
00L702L7000P1`0300L700<700<01`L010L00`071`041`0300L700<700<01`L00P0:1`0300L000/7
00<01`L01PL00`071`021`0300L000<700@01`L01PL01@071`L000<710000`L0000300@71P000`L0
00071`0300L7008700<01`L00PL00`071`041`0500L71`000PL00`071`041`0300L700802@L01007
1`071`0500L01`0020L01@071`L000<700<01`002PL010071`0W1`0080L00`071`031`0300L700<7
00<01`L01@L00`071`021`0400L71`802PL00`07000:1`8020L01@071`L0008700D01`L700021`03
00L700@700D01`L700051`H00PL200D71@0010L000041`0500L71`001@L00`071`041`0500L71`00
0PL00`071`031`0600L700L02@L00`0700081`0400L000T700D01`L700021`0400L700X700@01`L0
9`L001l700<01`L010L00`071`021`0300L700H700<01`L00PL01P071`0700X70`091`0300L000P7
00@01`L00PL00`071`021`0400L700D700<01`L00PL00`071`051`<000D700001`0200<700<01`00
1@000`L000021`0500L71`001@L00`071`031`0300L7008700@01`L01@L01P071`0700T70P091`03
00L000X700@01`L00`L010071`0:1`0400L702L7000N1`0300L700D700D01`L700091`0500L71`00
0PL010071`0:1`0300L000T700<01`0020L00`0700021`0300L700<700@01`L010L00`071`031`03
00L700@700<01`L00`021`L000<700000PL8008700<01`L010L00`071`021`0300L700<700@01`L0
10L010071`021`0300L700L70P091`0300L000X700<01`000`L01@071`L000X700@01`L09`L001h7
00<01`L01@L01@071`L000T700@01`L00PL01@071`L000T70P000`L01`071`0400L700P700<01`00
0PL00`071`031`0400L700@700<01`L00`L00`071`031`0500L71`000PL300<71@051`800PL400L7
00D01`L700061`0400L700<700@01`L00`L00`071`071`0300L700P70`0:1`800`L00`071`021`03
00L700P700@01`L09`L001d700<01`L01PL010071`0:1`0300L000<700D01`L700091`8000<700L0
1PL01@071`L000P70P021`0300L700@700@01`L00`L00`071`041`0300L700<700D01`L700051`80
00<700L01P041`D000<700000P031`0500L71`001PL010071`031`0300L000@700<01`L01PL200X7
00<01`002PL2008700<01`L00`L00`071`081`0400L702L7000L1`0300L700L700<01`002`L00`07
00021`0300L7008700<01`L01PL01@0700L000L700D01`L700081`0400L700L700@01`L00PL00`07
1`051`0300L7008700<01`L00PL00`071`051`8000@700000PL500<70P041`D00PL00`071`051`04
00L7008700@01`L010L00`071`061`802PL00`07000:1`0500L71`001@L00`071`081`0400L702L7
000K1`0300L700P70P0<1`800PL00`071`031`0300L700D700H01`L01`061`0300L7008700<01`L0
1@L2008700<01`L01@L010071`021`0300L700D700D01`L700051`0300L700@700<01`L010041`80
00<700001P041`H01PL01P071`07008700<01`L00`L00`071`051`0300L000T70P000`L01`081`80
0PL00`071`041`0300L700P700@01`L09`L001/700<01`L020L200`700D01`L700051`0300L700D7
00H01`L01`051`0300L700<700<01`L01@L200031`0700L700H01`L01`081`0400L700H700<01`L0
0`L010071`L200031`0000<00PL;00<710000`L00002008700<01`L00P021`0300L700@700<01`L0
10L010071`081`0500L01`0020L01@0700L000L700<01`L020L010071`0W1`006PL00`071`091`03
00L700/700@01`L01PL00`071`041`0700L71`0700041`0300L700@700<01`L010L0100700091`03
00L700802@L010071`061`0300L700<700@01`L70P000`L01`031`@000<700000`L800870P031`@0
00<700000PL00`071`041`0300L700<700D01`L700081`0500L01`0020L0100700081`0300L700P7
00@01`L09`L001T700<01`L02@L200`70P000`L01`061`0300L700<700<01`L00PL00`0700041`03
00L700@700<01`L00`L010071`0:1`0400L700X700<01`001`L00`071`021`0900L71`0700L000P7
1P031`P000@700000PL00`07000200031`0700H700<01`L00`L01@071`L000L700H01`L01`071`03
00L7008020L00`071`081`0400L702L7000I1`0300L700P700<01`002`L0100700081`0300L70087
00<01`L00`L00`0700031`0300L700D700<01`L00`L010071`0:1`0400L700X70P081`0500L71`00
0`L01P071`0700L700D01`L01`0400<70`031`L000@700070P071`0300L7008700<01`L00PL00`07
1`041`0700L71`0700061`0500L71`002@L00`071`081`0400L702L7000H1`0300L700T700<01`00
2`L0100700081`0300L7008700<01`L00`L00`0700021`0300L700H700<01`L00PL00`071`0200X7
00@01`002PL00`071`071`0500L71`000PL01`071`L01`001PL01@071`L000D71@000`L000051`L0
0PL300@700D01`L700051`0300L700<700<01`L00PL00`0700061`0300L700802@L00`071`081`04
00L702L7000G1`0300L700T700@01`L02PL010071`091`0500L71`001PL00`0700021`0300L700H7
00D01`L700021`0300L000X70P000`L01`091`0300L700L700@01`L00`L01`071`L01`001PL01@07
1`L000L72@041`H010L2008700D01`L700051`0300L700<700<01`L00PL00`0700051`0400L71`80
2@L00`071`081`0400L702L7000F1`0300L700T700D01`L700091`0300L700802@L010071`071`05
00L01`002@L010071`031`0300L000X70P000`L01`081`802@L00`0700031`0300L7008700<01`00
1@L00`071`021`0300L700@700<01`L00`000`L0000400061`071`071P0010L000021`0300L700@7
00<01`L00PL00`071`031`0300L000@700L01`L700L000T700<01`L020L010071`0W1`005PL00`07
1`091`0500L71`0020L01P071`0700T700<01`0020L01007000:1`0400L7008700@01`L02PL01007
1`081`0300L000T70P031`0300L700<700<01`0010L00`071`031`0300L700<700D01`L700021`<0
0`L600@70P000`L0000400L700D01`L700061`0300L000<700D01`L700021`0300L700L700<01`L0
20L010071`0W1`005@L00`071`091`0300L7008700<01`L01PL01P071`0700T700<01`0020L00`07
000;1`0300L0008700D01`L700091`800PL00`071`051`0400L700T70P021`0300L700@700<01`00
0`L00`071`041`0300L700<700D01`L700051`800PL700@70`000`L0000400@700D01`L700061`03
00L000<700@01`L00`L00`071`071`0300L700P700@01`L09`L001@700<01`L02@L00`071`031`03
00L700D700@01`L00PL00`071`071`802@L00`07000;1`800PL00`071`021`0300L700H700<01`00
0PL00`071`051`0400L700T700D01`L700061`0300L000<700<01`L010L00`071`021`0300L70087
00<01`L01@L200041`001`L00`L300<710001@L01`L000L700<01`000PL01@071`L000<700<01`L0
1`L00`071`081`0400L702L7000C1`0300L700T700<01`L010L00`071`041`0400L700<700<01`L0
1`L00`071`081`<02`L01@071`L000@700<01`L01PL00`0700021`0300L700@700D01`L700081`80
0PL00`071`051`0300L0008700<01`L01@L01@071`L000D700<01`L01@L00`07000400870`000`L0
000600@71@081`0500L01`000`L00`071`021`0300L700L700<01`L020L010071`0W1`004`L00`07
1`091`0300L700@700<01`L010L00`0700041`0300L700H70P0:1`0300L000/700@01`L01@L00`07
1`051`0400L7008700<01`L00`L00`071`021`0300L700H70P000`L01`071`0500L01`0020L01007
1`061`0300L700@700<01`L00P021`@00PL2008720031`L010L0100700031`0300L700<700<01`L0
1`L00`071`081`0400L702L7000B1`802PL00`071`051`0300L700<700@01`L010L00`071`061`80
2PL00`07000:1`8000<700L01@L00`071`041`0500L71`000PL00`071`021`0300L700<700<01`L0
1@L0100700091`0500L01`0020L010071`061`0300L700@700<01`L00P021`0400L71`P00`L80005
1`0000L01@000`L000031`0300L700<700<01`L01`L00`071`081`0400L702L7000B1`0300L000<0
1@L00`071`061`0300L7008700@01`L01@L00`071`051`0300L000T70P000`L01`081`0500L01`00
1PL00`071`041`0500L71`000PL00`071`021`0300L700<700<01`L010L00`071`0200T700@01`00
2@L00`0700071`0300L700<700H01`L01`021`0300L700D71@051`P000<700000`L4008700<01`L0
10L00`071`071`0300L700P700@01`L09`L0018700@01`L71`091`0500L71`000PL00`071`041`03
00L700@700@01`L020L01@0700L000P700<01`L00P071`0300L700<700<01`L00PL010071`031`03
00L700@700<01`L00`L01@071`L000X700<01`002PL200P700<01`L00PL010071`021`0400L700L7
00<01`L01@041`<00`L900031`0000L700<01`L01`L00`071`081`0400L702L7000B1`0300L700<7
0`000`L0000200H700D01`L700021`0300L700@700<01`L010L010071`081`0500L01`0020L01007
1`081`0300L7008700<01`L00`L010071`021`0300L700D700<01`L00`L00`071`0200X70`0:1`80
20L01@071`L0008700D01`L700021`0300L700@700D01`L700041`H000<700001@L500031`0700<0
10L00`071`071`0300L700P700@01`L09`L0018700<01`L01PL200<710021`0300L7008000<700L0
1PL00`071`031`0500L71`001`L01P071`0700L700<01`L00P081`0500L71`001PL01P071`0700P7
00<01`L00PL01P071`0700X70`0:1`0300L700L700D01`L700021`0500L71`000PL00`071`041`05
00L71`001PL600041`0000@700<01`000`031`800PL00`071`071`0300L700P700@01`L09`L00187
00<01`L01PL00`07000200@70`0010L000L200L700<01`L00PL00`071`021`0300L700@700L01`L7
00L000H700@01`L70P081`0500L71`001PL01P071`0700P700D01`L700031`0300L000X700<01`00
2@L200T700@01`L00PL00`071`021`0400L700D700<01`L00PL00`071`041`0300L700T000@70007
0P000`L0000700T700<01`L020L010071`0W1`004PL00`071`061`0300L700870P041`D00PL300@7
00D01`L700051`0300L700<700<01`L00PL00`0700061`0600L700L020L010071`071`0300L70080
2@L010071`031`0400L700T70P000`L01`071`0300L000T700<01`000PL00`071`031`0400L700@7
00<01`L00`L00`071`031`0500L71`000PL200<710000`L01`031`<000<700000`071`0300L700P7
00@01`L09`L0018700<01`L01PL00`071`041`800PL200031`0000@000<700000PL01@071`L000D7
00<01`L00`L00`071`021`0300L000D700@01`L00PL00`071`061`0300L000P700@01`L02PL01007
1`021`0500L71`002@L200031`0700L700<01`002@L2008700<01`L010L010071`031`0300L700@7
00<01`L00`L01@071`L000@70`000`L01`0500D70P000`L01`0400@700<01`L020L010071`0W1`00
4PL00`071`061`0300L700H70`021`0300L700<71P021`0300L700@700<01`L00PL00`071`031`03
00L000@700D01`L700021`0300L700H700<01`0020L01007000:1`0300L0008700<01`L00PL00`07
1`061`0500L01`001`L010071`091`800PL00`071`041`0400L700<700<01`L010L00`071`021`03
00L7008700<01`L01@L200031`0000L00`L300@71@0:1`0400L702L7000B1`0300L700H700<01`L0
1`L500T710071`0500L71`001PL00`0700031`0500L71`000`L00`071`061`802@L01007000:1`80
0`L00`071`021`0300L700D700H01`L01`061`0500L71`002@L010071`071`0400L7008700<01`L0
1@L01@071`L000D700<01`L010L00`071`0400<70P000`L0000600@71P071`0400L702L7000B1`03
00L700H700<01`L01`L300041`0000P70P0010L000041`0500L71`001PL00`0700031`0400L700@7
00<01`L01PL00`071`081`8000<700L02@L2008700<01`L00`L00`071`041`0700L71`0700061`05
00L71`0020L200031`0700L700H01`L01`081`0400L700H700<01`L00`L010071`L200031`0000<0
00D700001`0800<70`000`L0000200<700@01`L09`L0018700<01`L01PL00`071`061`0600L000L0
0PL200H70P041`D00PL00`071`051`0300L0008700D01`L700041`0300L700H700<01`L020L01007
1`0:1`0400L700H700<01`L010L01`071`L01`001@L00`071`021`0300L700D700D01`0700081`03
00L700802@L010071`061`0300L700<700@01`L70P000`L01`031`L00`L500041`071`<00PL40087
00<01`L09@L0018700<01`L01PL00`071`051`0300L700@010L200@70`051`H01`L01@0700L000<7
00<01`L00`L00`071`051`802@L2008700<01`L01`L200031`0700H700<01`L00`L00`071`021`03
00L000@700<01`L00`L00`071`051`0400L000T700<01`L00P091`0300L000L700<01`L00PL02@07
1`L01`0700081`D010L400D70P031`@09`L0018700<01`L01PL00`071`041`0500L71`000PL400<7
1@000`L0000300<70`000`L0000200<700@01`000`L00`071`041`0300L700@700<01`002@L20087
00<01`L01PL01@0700L000L700<01`L00PL00`071`031`0300L000<700<01`L010L00`071`041`04
00L700X700@01`L02PL200P700D01`L700031`0600L700L01`L01@071`0700@00`L300H710000`L0
000W1`004PL00`071`061`0300L700@700D01`L700021`0400L71`@00PL200<7200010L000021`@0
00<700000PL00`071`051`0300L700<700@01`L020L00`0700021`0300L700H700@01`0020L01@07
1`L000H700<01`000`L00`071`041`0300L700<700<01`L00P0:1`0400L000X700<01`L01`L01@07
1`L0008700L01`L700L000H700D01`L700041`H000<700001`L402L7000B1`0300L700H700<01`L0
0`L00`071`021`0400L700L71`031`8000<700000`000`L000031`@00PL00`071`051`0300L700<7
00@01`L01`L010071`021`0300L700D700@01`L02@L01@071`L000H700<01`000PL00`071`051`03
00L7008700@01`L70P0:1`8000<700L02@L00`071`071`0400L700<700L01`L700L000H700D01`L7
00071`T010L502H7000B1`0300L700H700<01`L00PL00`071`031`0400L700L700<01`L01P031`<0
0`L900031`0000P700<01`L00PL01@071`L000H700D01`L700021`0300L700@700<01`L00P091`04
00L700L700D01`0700081`0300L7008700H01`L01`0:1`8000<700L020L200T700<01`000`L00`07
1`021`0300L000D700<01`L00PL00`071`041`0300L700<000<7000010001PL01`L01`8090L00187
00<01`L01PL01@071`L000H700@01`L01PL01@071`L000@71P000`L000051`D000<700L00`051`05
00L71`0010L00`071`041`0500L71`000PL00`071`041`0300L700802@L00`0700081`0400L000T7
00D01`L700021`0400L700X700@01`L020L00`0700091`800`L00`071`031`0300L000@700<01`L0
0`L00`071`031`0500L71`000PL200<710021`0400L71`<08@L0018700<01`L01PL01@071`L000H7
00@01`L01PL01@071`L000L71@0010L000041`0300L000<00`L200<700D01`L700041`0300L700<7
00<01`L00PL010071`051`0600L700L02@L00`0700081`0400L000T700@01`L00`L010071`091`80
0PL00`071`051`0400L700T70P021`0300L700@700<01`0010L00`071`031`0300L700<700D01`L7
00041`<00PL600D70P0O1`004PL00`071`061`0400L700L700@01`L01@L00`071`021`0300L700@7
00<01`L02@0010L000L200031`0000P00PL00`071`031`0300L7008700<01`L00`L010071`041`04
00L7008700<01`L01`L200T700<01`002PL00`0700031`0500L71`0020L00`0700021`0300L700D7
00@01`L02@L01@071`L000H700<01`000`L00`071`041`0300L7008700<01`L00PL00`071`051`80
00@700L71P031`<070L0018700<01`L01PL00`0700081`0400L700@700<01`L00`L00`071`031`05
00L71`000PL3008710000`L01`031`<000<7000010061`0500L71`001PL010071`031`0400L700<7
00<01`L01`L00`071`081`<02PL00`0700021`0300L7008700<01`L01PL00`0700021`0300L700@7
00D01`L700081`800PL00`071`051`0300L0008700<01`L01@L01@071`L000D700<01`L01@L01007
00021`0300L700L000@700006PL0018700<01`L01PL200T700@01`L00`L00`071`041`0300L700<7
00D01`L700051`8000<700L01@051`800PL500@700D01`L700061`0400L700<700@01`L00`L00`07
1`061`802PL300X70P021`0300L700<700<01`L01@L010071`021`0300L700<700<01`L00PL00`07
1`061`8000<700L01`L00`0700021`0300L700D700D01`L700051`0300L700@700<01`L00P021`03
00L700<70P021`L05`L0018700<01`L01PL200T700@01`L00`L00`071`041`0300L7008700<01`L0
0PL00`071`051`8000<700001`031`@00`L5008700<01`L01@L010071`021`0400L700@700<01`L0
1PL200X700<01`002PL01@071`L000D700<01`L010L01@071`L0008700<01`L00PL00`071`031`03
00L700D700D01`0700081`0500L01`0020L010071`061`0300L700@700<01`L00P021`0300L700D7
10021`D05@L0018700<01`L01PL00`071`081`0400L7008700<01`L01@L01@071`L000D700<01`L0
10L00`071`0400<70P000`L0000200041`0000D71@071`0600L700L00PL00`071`031`0300L700D7
00<01`002@L200031`0700P70P021`0300L700@700<01`L00`L00`071`021`0400L700@700<01`L0
0`L00`071`041`0300L700802@L0100700091`0300L000L700<01`L00`L01P071`07008700<01`L0
1PL0100700051`<04`L0018700<01`L01@L200X700H01`L01`081`0400L700H700<01`L00`L01007
1`L200031`0000<000@700000PL8008720031`0300L700800PL00`071`041`0300L700@700@01`L0
20L01@0700L000T70P000`L01`061`0300L700<700<01`L00PL010071`031`0300L700@700<01`L0
0`L01@071`L000X700<01`002PL00`0700071`0300L7008700@01`L00PL010071`071`0500L700L0
0`031`804`L0018700<01`L010L00`07000:1`0600L700L020L010071`061`0300L700<700@01`L7
0P000`L01`031`P00PL800870P021`@00PL2008700<01`L010L00`071`041`0400L700P700D01`07
00081`0400L000P700<01`L00PL00`071`031`0400L7008700<01`L01@L00`071`031`0300L70080
2PL00`07000:1`8020L00`071`021`0300L000<700@01`L01PL01@071`L000@70P000`L0000C1`00
4PL00`071`041`0300L000X700<01`L00P091`0300L000L700<01`L00PL02@071`L01`0700081`D0
1@L300031`0000D00PL500031`0700H700<01`L00`L01@071`L000L700H01`L01`071`0300L70080
20L01@071`L000H700H01`L01`081`0300L7008700@01`L70P0:1`<02PL00`071`071`0500L71`00
0PL01@071`L0008700<01`L010L01@071`L000H70`0C1`004PL00`071`031`0400L700X700@01`L0
2PL200P700D01`L700031`0600L700L020L00`071`0500<710031`H000@700070P071`0300L70087
00<01`L00PL00`071`041`0700L71`0700061`0500L71`002@L010071`071`0600L700L020L01@07
1`L000<700<01`002PL00`0700091`802@L010071`021`0300L7008700@01`L01@L00`071`021`03
00L700<700<01`L0100@1`004PL00`071`021`0500L71`002PL01007000:1`0300L700L700D01`L7
00021`0700L71`0700071`0500L71`000`L600870P051`H00PL300@700D01`L700051`0300L700@7
00L01`L700L000H700<01`L00P091`0400L700L700<01`L00P091`0400L700<700@01`L02PL00`07
00091`802@L00`0700021`0300L700<700@01`L010L00`071`031`0300L7008700D01`L700031`80
3PL0018700D01`L700041`0300L700P700@01`002PL00`071`071`0400L700<700L01`L700L000L7
00D01`L700061`H000@700000`L200031`0000800`L2008700D01`L700051`0300L700<700<01`L0
0PL00`0700051`0400L71`802@L00`0700081`0400L700X700@01`L00PL01@071`L000T70P000`L0
1`071`0300L000T700<01`000PL00`071`031`0400L700<700<01`L010L00`071`021`0500L71`00
1@L300/7000B1`0500L71`0010L00`071`081`8000<700L020L200T700<01`000`L00`071`021`03
00L000H700<01`L00PL00`071`031`0300L700<000<7000010001PL01`L01`H000@700000PL00`07
1`041`0300L7008700<01`L00`L00`0700041`0700L71`0700091`802@L01007000:1`0300L000<7
00D01`L700081`0500L01`001`L010071`091`800PL00`071`041`0400L700<700<01`L010L01@07
1`L000@700<01`L01PL200T7000B1`0400L700D700<01`L020L010071`081`0300L000T70P031`03
00L700<700<01`001@L00`071`031`0300L7008700D01`L700021`8010L600@70P000`L0000400L7
00D01`L700061`0300L000<700D01`L700021`0300L700L700<01`L020L01007000:1`800`L00`07
1`021`0300L700D700H01`L01`071`0400L700T700@01`L01`L010071`021`0300L700D700@01`L0
1@L00`071`081`801`L0018700<01`001PL00`071`081`0400L700L700@01`L02@L2008700<01`L0
10L00`0700041`0300L700@700<01`L00PL01@071`L000@70`021`L010L300031`0000@010L01@07
1`L000H700<01`000`L010071`031`0300L700L700<01`L020L200031`0700T70P021`0300L700<7
00<01`L01@L01P071`0700H700D01`L700081`800PL00`071`051`0600L700L020L010071`051`03
00L700P700<01`L01PL001870P071`0300L700L70P021`0300L700D700@01`L02@L01@071`L000H7
00<01`0010L00`071`041`0500L71`0010L00`071`051`8000@700071`031`<00`L400051`071`00
1`L00`0700021`0500L71`000`L00`071`061`802PL010071`0:1`0500L71`001@L00`071`041`07
00L71`0700051`0300L7008700<01`L01PL200031`0700L700H01`L01`081`0300L000H700<01`L0
20L00`071`061`004PL200L700<01`L01PL00`0700021`0300L700@700D01`L700081`800PL00`07
1`051`0300L000<700<01`L01@L010071`051`0300L700D700<01`0010031`8000<700001P041`D0
20L01@0700L000<700<01`L00PL00`071`051`0300L000T70P021`0300L700L70P021`0300L700@7
00<01`L00`L00`071`021`0300L000@700<01`L00`L00`071`051`0400L000T700<01`L00P091`80
1`L00`071`071`0300L700L7000B1`0300L700H700<01`L01@L010071`021`0300L700<700<01`L0
0PL00`071`061`8000<700L01`L00`0700021`0300L700H700<01`001PL00`071`041`0300L70080
0PL400870`000`L0000600<71`041`0400L000<700<01`L00`L00`071`041`0400L700T70P021`03
00L700H700D01`0700071`0300L700<700<01`L00PL00`0700041`0300L700<700<01`L010L01007
1`0:1`0400L700X70P071`0300L700H700<01`L020L001470P081`0300L700D700@01`L00PL00`07
1`021`0300L700<700<01`L01@L0100700091`0500L01`002@L00`0700061`0300L700@700<01`L0
0P021`0400L71`@000@700000`L800051`0000L01@000`L000031`0300L700<700<01`L010L01007
1`081`0300L0008700<01`L01PL0100700081`0300L7008700<01`L00`L00`0700031`0300L700@7
00<01`L010L010071`0:1`0400L000X700<01`L01PL00`071`051`0300L700T7000@1`0300L000P7
00<01`L010L01@071`L0008700<01`L00PL00`071`031`0300L700@700<01`L00P091`0500L01`00
2@L200L700<01`L00`L01P071`07008700<01`L01@L600<72@000`L000031`@00PL00`071`041`03
00L700<700D01`L700071`0400L7008700<01`L01@L00`071`0200P700D01`L700061`0300L00087
00<01`L01@L00`071`031`0300L700802PL0100700091`8020L00`071`051`0300L700T7000@1`03
00L000P700<01`L00`L00`071`021`0400L700<700<01`L010L00`071`031`0500L71`002PL01007
000:1`0300L700H700<01`L00PL010071`021`0400L700L700<01`L01@041`8010L900031`0000L7
00<01`L00PL00`071`021`0300L700@700D01`L700021`0300L700@700D01`L700091`0400L700L7
00<01`000PL00`071`051`0300L7008700H01`L01`0:1`8000<700L01`L00`0700081`0300L700@7
00<01`L02PL000l700@01`L020L00`071`021`0300L700<700@01`L00PL00`071`051`0300L700<7
00<01`L00P0:1`0300L000/700<01`L01PL01@071`L0008700D01`L700021`0300L700@700D01`L7
00041`T01@L500031`0700<010L01@071`L000D700<01`L010L01@071`L0008700<01`L010L00`07
1`0200T700@01`L01`L01@0700L000P700D01`L700031`0300L000X700@01`L020L00`0700081`03
00L700<700<01`L02`L000h700D01`L700081`0300L7008700<01`L00`L01P071`0700P700<01`L0
0PL01P071`0700X70`0:1`8020L01@071`L0008700D01`L700021`0300L700@700D01`L700071`D0
00<700001@L00`07000300<70P021`0500L71`001@L00`071`031`0300L7008700@01`L01@L01P07
1`0700T700<01`0020L0100700091`0500L71`000PL010071`091`800PL00`071`051`0400L700P7
00<01`L00PL00`071`0<1`003@L00`071`021`0300L700H700D01`L700061`0600L700L020L01@07
1`L000<700<01`002PL300T700<01`0020L010071`021`0300L7008700@01`L01@L00`071`021`03
00L700@700<01`L020021`8000@700072@021`0300L700@700<01`L00PL00`071`031`0400L700@7
00L01`L700L000T70P091`0300L000X700@01`L00PL01@071`L000T70P021`0300L700@700D01`L7
00081`0300L7008700<01`L030L000d700<01`L00PL00`071`061`0400L700L700<01`L00P091`04
00L700<700@01`L02PL00`0700081`0400L700P700<01`000PL00`071`031`0400L700@700<01`L0
0`L00`071`031`0500L71`000PL200<710000`L01`031`<000<700000`071`0500L71`001PL01007
1`031`0500L71`000PL00`071`071`802@L00`07000:1`0300L0008700<01`L00PL00`071`061`03
00L0008700<01`L010L01@071`L000P700D01`L7000?1`0030L00`071`031`0300L700H700@01`L0
1`L010071`0:1`0400L7008700D01`L700091`8000<700L01`L010071`081`800`L00`071`031`04
00L700@700<01`L00`L00`071`031`0500L71`0010L300031`0700D01@L200031`0000@010L01@07
1`L000H700@01`L00`L010071`031`0300L700L700<01`L020L300X70P031`0300L7008700<01`L0
1@L010071`021`0300L700<700<01`L00PL00`071`061`0400L70107000;1`0300L700@700<01`L0
1PL00`0700081`0400L000X700<01`000PL00`071`021`0300L700H700D01`0700071`0500L71`00
20L2008700<01`L010L010071`031`0300L700@700<01`L00PL00`071`021`0300L700D70P000`L0
000700<70`031`H00PL00`071`051`0400L7008700@01`L010L00`071`061`802PL00`07000:1`80
0PL00`071`031`0300L700D700@01`L00PL00`071`021`0300L700<700<01`L01PL010071`0@1`00
2PL00`071`051`0300L700H70P091`0400L000X70P031`0300L7008700<01`L01PL01@0700L000H7
00<01`L00PL00`071`061`0400L700L700@01`L00PL00`071`051`0500L71`001@L00`071`041`03
00L700@00PL2008720041`H01`L01P071`0700<700<01`L00PL00`071`061`802PL00`07000:1`04
00L700H700<01`L010L01@071`L0008700D01`L700061`0300L700H700<01`004@L000X700<01`L0
1@L00`071`061`0300L700P70P000`L01`091`800PL00`071`031`0300L700D700H01`L01`061`03
00L7008700<01`L01@L2008700<01`L01@L010071`021`0300L700D700@01`L01PL00`071`041`03
00L7008000<700000P000`L000031`P00`L300031`0000800`L00`071`0200<700<01`L00`L00`07
1`051`0300L000T70P000`L01`081`800PL00`071`041`0300L700<700<01`L00PL010071`031`03
00L700@700<01`L01PL2018700091`0300L700H700<01`L01PL00`071`081`0400L700X700@01`L0
1PL00`071`041`0700L71`0700051`0300L700<700<01`L010L01@0700L000P700H01`L01`081`04
00L700H700<01`L00`L010071`L200031`07008720031`P000<700000`L400870P021`0300L700@7
00<01`L010L010071`081`0500L01`0020L01@0700L000L700<01`L00PL00`071`031`0400L70087
00<01`L01@L00`071`061`0300L7014700081`0300L700L700<01`L01@L200T70P021`0300L700L7
0P000`L01`061`0300L700<700<01`L00PL00`0700041`0300L700@700<01`L010L0100700091`03
00L700802@L00`0700071`0300L7008700T01`L700L01`001`L400H71`000`L000041`D00PL00`07
1`041`0300L700<700D01`L700081`0500L01`0020L0100700081`0300L7008700<01`L00`L01P07
1`0700P700<01`L01PL00`071`0A1`001`L00`071`081`0300L700@700<01`002@L2008700<01`L0
1PL01@0700L000L700<01`L00`L00`071`021`0300L000<700<01`L01@L00`071`031`0400L700X7
00@01`L02PL200P700<01`L00PL010071`021`0300L000L700<01`L01@041`800`L600031`070080
00<700001`L00`071`031`0500L71`001`L01P071`0700L700@01`L02@L01@071`L000H700H01`L0
1`081`0300L700D70P0C1`001`L00`071`081`0300L700@700<01`0020L00`0700021`0300L700H7
00@01`0020L00`071`021`0300L700<700<01`000`L00`071`051`0300L7008700D01`L7000:1`04
00L700X70P081`0500L71`000PL01`071`L01`001PL01@071`L000<72P041`@000H7000700L200D7
00<01`L00PL00`071`021`0300L700@700L01`L700L000H700D01`L700091`0400L700L700<01`L0
0P091`0300L700@700<01`004`L000H70P0:1`0300L700<700@01`L01`L010071`021`0300L700D7
00@01`L02@L01@071`L000H700<01`000PL00`071`061`0500L71`000`L200X700@01`002PL00`07
1`071`0400L700<700L01`L700L000H700D01`L700051`L000<700001@L500@70`021`0500L71`00
1@L00`071`031`0300L7008700<01`001PL00`071`0200T700<01`0020L010071`0:1`0300L700<7
00@01`L04`L000P70P081`0300L7008700D01`L700061`0500L71`000PL00`071`041`0300L70080
2@L010071`071`0500L01`002@L01@071`L0008700<01`002PL200031`0700P70P091`0300L000<7
00<01`L00PL00`0700051`0300L7008700<01`L010L400871P021`0300L700D010L300<700<01`L0
0`L00`071`031`0300L7008700<01`001@L01P071`0700T700<01`0020L01007000:1`0300L700<7
00@01`L04`L000X70`051`0500L71`0010L00`071`041`0500L71`000PL00`071`041`0300L70080
2@L010071`071`0400L000X700@01`L00`L00`07000:1`8000<700L01`L00`0700091`0300L00087
00<01`L00`L00`0700041`0300L700<700<01`L00`L010071`L300<71P021`0300L700H00PL400H7
00<01`L00PL00`071`031`0300L000@700L01`L700L000T70P091`0400L000X700<01`L00PL01@07
1`L001<7000=1`800`L01@071`L000@700<01`L00`L00`071`021`0400L700D700H01`L01`091`03
00L000P700@01`002PL00`0700031`0400L700X700@01`L020L00`0700091`800PL00`071`041`03
00L000@700<01`L00`L00`071`031`0500L71`000PL300@71@051`8000<700001@051`0500L71`00
1PL00`0700031`0500L71`000PL00`071`071`0300L700P70P000`L01`091`0500L71`0010L00`07
1`0A1`003`L4008700<01`L00`L00`071`021`0300L700<700@01`L010L010071`021`0300L700L7
0P091`0300L000/70P031`0500L71`002@L2008700<01`L01@L010071`091`0500L71`001PL00`07
00031`0300L700@700<01`L00PL00`071`021`0300L700<70P000`L01`0200031`00008010L:00<7
00D01`L700061`0300L000<700@01`L00`L00`071`061`802PL010071`0:1`0500L71`0010L00`07
1`0A1`004PL300H700D01`L700061`0400L700<700@01`L00`L00`071`071`0300L700P70`0;1`80
0PL00`071`021`0300L700H700<01`000PL00`071`041`0500L71`002@L010071`071`0300L00087
00<01`L01@L01@071`L000D700<01`L01@L200061`001`071P031`8010L5008700<01`L01@L00`07
00021`0500L71`000`L00`071`061`802PL010071`0:1`0400L700D700<01`L04@L001871@041`05
00L71`001PL010071`031`0400L700<700<01`L01`L00`071`081`<02`L01@071`L000@700<01`L0
1PL00`0700021`0300L700<700<01`L00PL00`071`061`8000<700L01`L00`0700021`0300L700D7
00D01`L700051`0300L700@700<01`L01@031`<000<700001@061`@01`L01@0700L000<700<01`L0
0PL00`071`051`0300L000T70P021`0300L700P700<01`001PL00`071`0A1`004PL200<70`001@L0
1`L000L700@01`L00PL010071`041`0300L700H70P0:1`0300L000X70P021`0300L700<700<01`L0
1@L010071`021`0300L700<700<01`L00PL00`071`051`0500L01`0020L01@0700L000P700@01`L0
1PL00`071`041`0300L700800PL400<70P000`L0000600<720031`0400L000<700<01`L00`L00`07
1`041`0400L700P700<01`000PL00`071`081`801`L00`071`0A1`004PL300D70P000`L01`071`06
00L700L00PL00`071`031`0300L700D700<01`002@L200031`0700P700D01`0700061`0300L700@7
00D01`L700021`0300L7008700<01`L00`L00`071`041`0300L700802@L0100700091`0300L000L7
00<01`L00`L010071`L2008700@01`L7100010L000031`P00`L200031`00008000<700000PL00`07
1`041`0300L700@700@01`L020L00`0700021`0300L700P70P071`0300L70147000D1`D00PL400L7
00<01`L00P021`0300L700@700<01`L010L010071`081`0500L01`002@L01@0700L000H700<01`L0
10L01@071`L0008700D01`L700061`0300L700@700@01`L02PL00`07000:1`0300L000L700<01`L0
0PL01`071`L01`000PL00`071`051`H010L800870P021`@00PL00`071`041`0300L700<700D01`L7
00071`0400L7008700<01`L020L00`071`061`0300L70147000F1`8000<700000P021`801@L00`07
1`02008700<01`L010L00`071`041`0400L700P700D01`0700081`0300L700801`L00`071`031`03
00L7008700@01`L00`L00`071`041`0300L700<700<01`L00P0:1`0300L000X70P081`0300L70087
00@01`L00PL010071`071`0300L700H00`L300<72@000`L000071`0300L7008700<01`L00PL00`07
1`041`0500L71`000PL00`071`071`8020L00`071`0A1`0060L400031`0000D00PL00`071`020003
1`0700H700<01`L00`L01@071`L000L700H01`L01`071`0500L71`0020L00`071`021`0300L700<7
00@01`L00PL00`071`051`0300L7008700@01`L70P0:1`<02PL00`071`071`0500L71`000PL01@07
1`L0008700<01`L010L01@071`L000@71P000`L000051`D000<700L00`041`0500L71`001@L00`07
1`031`0300L7008700@01`L020L00`0700081`0300L70147000K1`8010L6008700@01`001`L00`07
1`021`0300L7008700<01`L010L01`071`L01`001PL010071`L200P700D01`L700061`0600L700L0
20L00`071`021`0600L700L02PL00`0700091`802@L010071`031`0500L71`000PL00`071`041`05
00L71`001`L500041`0000@700<01`000`031`800PL01@071`L000D700<01`L00`L00`071`021`04
00L700P700<01`0020L00`071`0A1`007@L300D71P021`801@L01@071`L000D700<01`L010L01`07
1`L01`001PL010071`L200P700D01`L700061`0300L700802@L01@071`L0008700@01`L02PL00`07
00091`802@L00`0700031`0300L7008700@01`L01@L00`071`021`0300L700@700<01`L02@0010L0
00L2008720021`0300L700@700<01`L00PL00`071`031`0400L700L700@01`L020L00`071`0A1`00
80L200@700<01`L010021`<00PL01@071`L000D700<01`L00`L00`071`021`0300L000D700L01`L7
00L000P700@01`L01`L00`071`0200T700@01`L00PL01@071`L000T70P000`L01`071`0300L000T7
00<01`000PL00`071`031`0400L700@700<01`L00`L00`071`031`0500L71`000PL200<710000`L0
1`041`8000<700000`071`0500L71`001PL010071`061`0500L71`0020L00`071`0A1`008PL20087
00D01`L01`0600041`00008700<01`L010L00`071`021`0300L700<700<01`0010L01@071`L00087
00<01`L01PL00`0700081`0400L700X700<01`000`L01@071`L000P700D01`0700071`0400L700T7
0P021`0300L700@700@01`L00`L00`071`041`0300L700<700D01`L700041`<000<700L01@051`T0
10L01@071`L000H700@01`L01@L00`071`021`0300L700H700<01`L04@L002@70`000`L000041`80
00<7000010071`0500L71`001PL00`0700031`0300L7008700@01`L020L00`0700081`0400L000X7
00<01`000PL00`071`021`0300L700D700H01`L01`071`0400L700T700D01`L700061`0400L700<7
00<01`L010L00`071`021`0300L7008700<01`L01@L200031`0000L010L200@71@021`0300L700D7
00@01`L01@L00`071`021`0300L700H700<01`L04@L002H710061`<000<700000`051`0500L71`00
1PL00`0700031`0500L71`000`L00`071`061`802@L200031`0700T70P021`0300L700<700<01`L0
1@L01P071`0700H700D01`L700081`800PL00`071`051`0400L7008700<01`L01@L01@071`L000D7
00<01`L010L00`071`0400<70P000`L0000300041`0000<71P071`0400L700@700<01`L00`L00`07
1`061`0300L70147000V1`8000@700001`L300<710001@L01`L000L700<01`000PL01@071`L000@7
00<01`L01PL00`071`081`8000<700L02@L01@071`L000D700<01`L010L01`071`L01`001@L00`07
1`021`0300L700H70P000`L01`071`0600L700L020L010071`061`0300L700<700@01`L70P000`L0
000300051`0000L01@000`L000031`<000<700000P031`0400L700<700<01`L010L00`071`061`03
00L70147000V1`8000@700L70P061`@00`L600P700D01`0700041`0300L7008700<01`L01PL00`07
1`081`0400L700X700@01`L01PL00`071`031`0300L7008700<01`0010L00`071`031`0300L700D7
00D01`0700081`0300L700802@L010071`061`0300L700<700@01`L70P000`L01`031`L00`L50004
1`001`<00PL4008700D01`L700061`0300L700H700<01`L04@L002H700<01`000`021`8010L00`07
000400<70P000`L0000200@700@01`0010L00`071`031`0300L700D70P091`800PL00`071`071`80
00<700L01PL00`071`031`0300L7008700<01`0010L00`071`031`0300L700@700<01`L00P091`03
00L700802@L00`0700071`0300L7008700T01`L700L01`0020L500D70`051`800`L4008700<01`L0
1@L00`071`061`0300L70147000V1`0400L700871`000`L01`021`/00PL500031`0000<700<01`L0
10L00`071`041`0300L000P700<01`000PL00`071`061`0400L000P700<01`L00PL00`071`031`03
00L000<700<01`L010L00`071`041`0400L700X700@01`L02PL200P700D01`L700031`0600L700L0
1`L01@071`0700@00`L200L710001@L000L000P700<01`L01PL00`071`0A1`009PL010071`061`D0
1@L800031`0000@710021`0300L700D700<01`L00`L010071`081`0300L0008700<01`L01PL01007
00081`0500L71`001PL00`0700021`0300L700D700<01`L00`L00`071`0200X700@01`002PL00`07
1`071`0500L71`000PL01`071`L01`001PL01@071`L000@71P0:1`D02@L00`071`061`0300L70147
000V1`0400L700X710051`800`L500870`0010L000071`0300L700<700@01`L01`L010071`021`03
00L700D700@01`L02@L010071`071`0300L0008700<01`L01@L00`071`021`0400L71`802PL20003
1`0700T700<01`L01`L010071`031`0700L71`0700061`0500L71`001`L600L71@091`0300L700H7
00<01`L04@L002H700@01`L02PL010071`L4008710041`H00PL400D700<01`L00PL01@071`L000H7
00D01`L700021`0300L700@700<01`L00P091`0400L700L700D01`0700081`0500L71`000`L00`07
000:1`8000<700L020L200T700<01`000`L00`071`021`0300L000D700<01`L00PL00`071`041`03
00L700<000<700000P031`0500L700L00P071`0300L700H700<01`L04@L002H700@01`L02PL00`07
1`031`H00PL200D71@041`800`L01@071`L000@700<01`L010L01@071`L0008700<01`L00`L01P07
1`0700T700<01`0020L0100700091`0500L71`000PL010071`0:1`0400L700P700<01`002@L200<7
00<01`L00`L00`0700041`0300L700<700<01`L00`L01@071`L000870P031`@000<700000`L300@7
00<01`L01PL00`071`0A1`009PL010071`0:1`0300L700D70`001@L0000700800PL200031`0000@0
0`L200031`07008700<01`L00PL00`071`031`0300L7008700@01`L01@L01P071`0700T70P091`03
00L000X700@01`L00`L010071`091`800PL00`071`051`0400L700T70P021`0300L700@700<01`00
0`L00`071`041`0300L700<700D01`L700041`<00PL600D70P021`0300L700H700<01`L04@L002H7
00@01`L02PL00`071`071`<00PL700031`0000871P001PL0000700D700<01`L00PL00`071`031`04
00L700@700@01`L00PL00`071`071`802@L00`07000:1`0300L000<700D01`L700081`0300L00087
00<01`L01@L010071`091`0500L71`001PL00`0700031`0300L700@700<01`L00PL00`071`021`03
00L700D70P001PL000L01`@00`L300P700<01`L04@L002H700@01`L02PL00`071`071`0300L700<0
0`L500D70P021`H01@L01@071`L000H700@01`L00`L010071`031`0300L700L700<01`L020L300X7
0P031`0300L7008700<01`L01PL00`0700021`0300L700@700D01`L700081`800PL00`071`051`03
00L0008700<01`L01@L01@071`L000D700<01`L01@L0100700021`0300L700<7100010L000061`03
00L70147000V1`0400L700X700<01`L01`L00`071`031`<00PL600@70`000`L00005008700D01`L7
00061`0400L700<700<01`0010L00`071`061`802PL00`07000:1`800PL00`071`031`0300L700D7
00@01`L00PL00`071`031`0300L7008700<01`L01PL200031`0700L700D01`0700081`0400L700H7
00<01`L010L010071`031`0300L700L71`031`0300L70147000V1`0400L700X700<01`L01`L00`07
1`041`<000@700000PL500<70`041`@00PL00`071`051`0400L7008700@01`L010L00`071`061`80
2PL00`07000:1`0500L71`001@L00`071`041`0500L71`000PL00`071`021`0300L700<700<01`L0
1@L0100700091`0500L01`0020L010071`061`0300L700@700@01`L00`L00`071`071`0400L71`D0
00<700L04PL002H700@01`L02PL00`071`071`0300L700@700<01`L010041`8000<700001P051`D0
1PL01P071`07008700<01`L00`L00`071`051`0300L000T70P000`L01`081`800PL00`071`041`03
00L700<700<01`L00PL010071`041`0300L700<700<01`L010L00`071`0200T700@01`002@L00`07
00071`0300L700<700@01`L010L00`071`061`0300L700H70`0C1`009PL010071`0:1`0300L700L7
00<01`L00`L010071`L200031`0000<00PL300031`0000H00PL200031`0000@00PL00`071`020087
00<01`L010L00`071`041`0400L700P700D01`0700081`0500L01`001`L00`071`031`0300L70087
00@01`L00`L00`071`041`0300L700<700D01`L7000:1`0300L000X70P081`0300L7008700@01`L0
1@L00`071`051`0300L700P700<01`L04PL002H700@01`L02PL00`071`071`0300L7008700<01`L0
0PL200031`0700<7100010L000031`L00`L2008710000`L000021`0300L700@700<01`L00`L01@07
1`L000P700D01`0700081`0400L000P700<01`L00PL00`071`031`0400L7008700<01`L01@L00`07
1`031`0300L700802PL300X70P081`0500L71`000PL00`071`041`0300L700@700<01`L02@L00`07
1`0B1`009PL010071`0:1`0300L700L700<01`L00PL02@071`L01`0700081`H010L300031`000080
00L700001`0700<000<700L01PL00`071`031`0500L71`001`L01P071`0700L700<01`L00P081`05
00L71`001PL01P071`0700P700<01`L00PL01P071`0700X70`0:1`0300L700L700D01`L700021`03
00L700@700<01`L010L00`071`081`0300L701<7000V1`0400L700X700<01`L01`L01@071`L000<7
00H01`L01`081`0300L700D00`L400<71P0010L000L200L700<01`L00PL00`071`021`0300L700@7
00L01`L700L000H700D01`L700091`0400L700L700H01`L01`081`0500L71`000`L00`07000:1`03
00L000T70P091`0400L7008700<01`L01@L00`071`031`0300L700P700<01`L050L002H700@01`L0
2PL00`071`071`0400L700<700L01`L700L000L700D01`L700041`D00PL200D71P021`<010L01@07
1`L000D700<01`L00`L00`071`021`0300L000H700<01`L00P091`0400L700L700<01`L00P091`04
00L700<700@01`L02@L200031`0700L700<01`002@L00`0700021`0300L700H700<01`L00PL00`07
1`081`0300L701D7000V1`0400L700X700<01`L01`L00`0700041`0700L71`0700071`0500L71`00
1PL600041`0000<70P000`L0000200<70P021`0500L71`001@L00`071`031`0300L7008700<01`00
1@L010071`L200T700<01`0020L010071`0:1`0400L7008700D01`L700091`8000<700L01`L00`07
00091`800PL00`071`071`0500L71`002`L00`071`0E1`009PL010071`0:1`0300L700L700<01`00
0`L00`071`021`0300L000H700<01`L00PL00`071`031`0300L700<000<7000010001@L01`L00087
1@0010L000021`0300L700@700<01`L00PL00`071`031`0300L000@700L01`L700L000T70P091`04
00L000X700<01`000PL00`071`021`0300L700H700D01`0700071`0400L700T70P021`0300L700L7
00D01`L7000:1`0300L701H7000V1`0400L700X700<01`L01`L200<700<01`L00`L00`0700051`03
00L700<700<01`L00PL01@071`L000870`031`H01@L800L700D01`L700061`0300L000<700D01`L7
00021`0300L700L700<01`L020L01007000:1`800`L00`071`021`0300L700D700H01`L01`061`05
00L71`002@L010071`0:1`0400L700X700<01`L05`L002H700@01`L02PL00`071`071`0500L71`00
1PL00`0700041`0300L700@700<01`L00PL01@071`L000D70P021`L01@L900@700D01`L700061`03
00L000<700@01`L00`L00`071`071`0300L700P70P000`L01`091`800PL00`071`031`0300L700@7
00L01`L700L000H700D01`L700081`8000<700L02PL00`07000:1`0300L701P7000V1`0400L700X7
00<01`L01`L01@071`L000H700<01`0010L00`071`041`0500L71`0010L00`071`051`8000@70007
1`041`800`L400051`071`001`L00`0700021`0500L71`000`L00`071`061`802PL010071`0:1`04
00L700H700<01`L010L01`071`L01`001@L00`071`021`0300L700D700D01`07000;1`802`L00`07
1`0H1`009PL010071`0:1`0300L700H70P021`0300L700D700<01`000`L00`071`051`0400L700D7
00<01`L01@L00`07000400<70P000`L0000600@71@081`0500L01`000`L00`071`021`0300L700D7
00<01`002@L2008700<01`L01`L200031`0700H700<01`L00`L00`071`021`0300L000@700<01`L0
0`L00`071`051`0400L000`70P0:1`0300L701T7000V1`0400L700X700<01`L01@L01@0700L000P7
00<01`000PL00`071`061`0300L000H700<01`L010L00`071`02008710021`<000<700001P031`L0
10L0100700031`0300L700<700<01`L010L010071`091`800PL00`071`061`0500L01`001`L00`07
1`021`0300L700<700<01`000`L00`071`041`0300L700@700@01`L03@L00`071`081`0300L701X7
000V1`0400L700X700<01`L010L00`071`0200T700D01`0700091`0300L000H700<01`L010L00`07
1`02008700@01`L7100010L000031`P000D700001`0500031`0000<700<01`L00`L00`071`041`04
00L700P700<01`000PL00`071`061`0400L000P700D01`L700061`0300L000<700<01`L010L00`07
1`031`0300L7008030L200X700<01`L06PL002H700@01`L02PL00`071`041`0300L700802@L01@07
00L000T70P071`0300L700<700H01`L01`021`0300L700D71P041`P000<700000`L4008700<01`L0
10L00`071`031`0500L71`001`L010071`021`0300L700D700@01`L02@L01@071`L000H700<01`00
0PL00`071`051`0300L7008700@01`L70P0;1`0300L000T700<01`L06`L002H700@01`L02PL00`07
1`031`0500L71`002PL01007000:1`0300L700H700<01`L00PL010071`021`0400L700L700<01`L0
1@041`<00`L900031`0000L700<01`L00PL00`071`021`0300L700@700D01`L700021`0300L700@7
00<01`L00P091`0400L700L700D01`0700081`0300L7008700H01`L01`0;1`0300L000P700<01`L0
70L002H700@01`L02PL00`071`021`0400L71`802PL00`07000;1`0300L700H700D01`L700021`05
00L71`000PL00`071`041`0500L71`0010L600031`0000D71@000`L01`0300@700D01`L700051`03
00L700@700D01`L700021`0300L700@700<01`L00P091`0300L000P700@01`002@L01@071`L00087
00@01`L02PL010071`071`0300L701d7000V1`0400L700X700<01`L00PL01P071`0700X70`0:1`80
20L01@071`L0008700D01`L700021`0300L700@700D01`L700071`D000@7000010L00`07000300<7
0P021`0500L71`001@L00`071`031`0300L7008700@01`L01@L01P071`0700T700<01`0020L01007
00091`0400L700<700@01`L02@L01@071`L000L700<01`L07@L002H700@01`L02PL01@071`L000<7
00<01`002PL300T700<01`0020L010071`021`0300L7008700@01`L01@L00`071`021`0300L700@7
00<01`L02@0010L000L200031`0000L00PL00`071`041`0300L7008700<01`L00`L010071`041`04
00L7008700<01`L01`L200T700<01`002PL00`0700031`0500L71`0020L00`071`021`0300L700@7
00<01`L07PL002H700@01`L02PL010071`031`0400L700X700<01`0020L010071`081`0300L00087
00<01`L00`L010071`041`0300L700<700<01`L00`L01@071`L000870P031`@000<700L00`L30003
1`0000<01`L01@071`L000H700@01`L00`L010071`031`0300L700L700<01`L020L300X700<01`00
0PL00`071`021`0300L700H700<01`L00PL00`071`031`0300L701l7000V1`0400L700X700<01`00
0`L01@071`L000T70P000`L01`071`0400L700P70P021`0300L700@700@01`L00`L00`071`041`03
00L700<700D01`L700041`<000<700L01@051`8000<7000010041`0500L71`001PL010071`031`04
00L700<700<01`L01PL200X70`0:1`800PL00`071`031`0300L700D700<01`L00`L00`071`031`03
00L701l7000V1`0400L700X700<01`000PL00`071`021`0300L700H700D01`0700071`0500L71`00
20L2008700<01`L010L010071`031`0300L700@700<01`L00PL00`071`021`0300L700D70P000`L0
000700<70`041`D00PL00`071`051`0400L7008700@01`L010L00`071`061`802PL00`07000:1`05
00L71`001@L00`071`041`0300L700@700<01`L00PL00`071`0P1`009PL010071`0:1`800`L00`07
1`021`0300L700H700D01`0700061`0300L7008700<01`L01PL010071`071`0400L7008700<01`L0
1@L01@071`L000D700<01`L010L00`071`0400<70P000`L0000600D71@071`0600L700L00PL00`07
1`031`0300L700D700<01`002@L200031`0700P70P021`0300L700@700<01`L00`L00`071`051`05
00L71`008`L002H700@01`L02PL01@071`L000D700<01`L01@L01P071`0700H700<01`L00PL00`07
1`051`8000<700L01`L01P071`0700P700@01`L01PL00`071`031`0400L71`8000<700000`001@L0
000700P00`L800<700<01`L00P021`0300L700@700<01`L010L010071`081`0500L01`002@L20003
1`0700H700<01`L00`L00`071`051`0400L702@7000V1`0400L700X700@01`L01PL00`071`041`07
00L71`0700051`0300L700<700<01`L010L01@0700L000P700H01`L01`081`0400L700H700<01`L0
0`L010071`L200031`0700<71`031`P00PL2008710021`800PL00`071`041`0300L700@700@01`L0
20L01@0700L000P700@01`0020L00`071`021`0300L700H700@01`L090L002H700@01`L02@L20003
1`0700H700<01`L00`L00`071`021`0300L000@700<01`L010L00`071`041`0400L000T700<01`L0
0P091`0300L000L700<01`L00PL02@071`L01`0700081`D010L800041`0000871@000`L01`061`03
00L700<700D01`L700071`0600L700L01`L00`071`0200P700D01`L700091`0300L002D7000V1`04
00L700P700D01`0700071`0300L700<700<01`L00PL00`0700031`0300L700D700<01`L00`L01007
1`0:1`0400L700X70P081`0500L71`000`L01P071`0700L700D01`L01`0400<70`031`L000@70007
0P071`0300L7008700<01`L00PL00`071`041`0700L71`0700061`0500L71`002@L010071`0:1`80
9PL002H700@01`L020L0100700081`0300L7008700<01`L00`L00`0700031`0300L700D700<01`L0
0PL00`071`0200X700@01`002PL00`071`071`0500L71`000PL01`071`L01`001PL01@071`L000@7
1P000`L000051`L00PL300@700D01`L700051`0300L700@700L01`L700L000H700<01`L00P091`04
00L700X700<01`L09@L002H700@01`L01`L010071`091`0500L71`001PL00`0700021`0300L700H7
00D01`L700031`802PL01007000:1`0300L700L700@01`L00`L01`071`L01`001PL01@071`L000L7
2@041`H010L2008700D01`L700051`0300L700<700<01`L00PL00`0700051`0400L71`802@L00`07
000;1`0300L702D7000V1`0400L700H700<01`L00P091`0400L700L700D01`0700091`0500L71`00
0PL00`07000:1`8000<700L020L200T700<01`000`L00`071`021`0300L000D700<01`L00PL00`07
1`041`0300L700<000<7000010001PL01`L01`H000@700000PL00`071`041`0300L7008700<01`L0
0`L00`0700041`0700L71`0700091`802`L202L7000V1`0400L700D700@01`L70P091`0400L700L7
00@01`002PL010071`021`0400L700X700@01`L020L00`0700091`800`L00`071`031`0300L000@7
00<01`L00`L00`071`031`0500L71`000PL200@71P041`8000<7000010071`0500L71`001PL00`07
00031`0500L71`000PL00`071`071`0300L700T700<01`009`L002H700@01`L01@L01P071`0700T7
00<01`0020L01007000:1`0300L000<700@01`L02PL010071`071`0400L700T70P021`0300L700@7
00<01`000`L00`071`041`0300L700<700D01`L700041`<00PL700@70`000`L0000400@700D01`L7
00061`0300L000<700@01`L00`L00`071`071`0300L700T700<01`009`L002H700@01`L010L01007
1`021`0300L700L70P091`0300L000/70P031`0500L71`002@L2008700<01`L01@L010071`091`05
00L71`001PL00`0700031`0300L700@700<01`L00PL00`071`021`0300L700D70P0010L000L700<7
0`031`@000D700L700071`0300L0008700D01`L700031`0300L700H70P0:1`0400L702L7000V1`04
00L700<700@01`L00`L00`071`071`0300L700P70`0;1`800PL00`071`021`0300L700H700<01`00
0PL00`071`041`0500L71`0020L2008700<01`L01@L00`0700021`0300L700D700D01`L700051`03
00L700D700<01`0010021`<000<700001P041`D020L01@0700L000<700<01`L00PL00`071`051`03
00L000T700D01`L7000W1`009PL010071`031`0400L700<700<01`L01`L00`071`081`<02`L01007
1`051`0300L700D700@01`L00PL00`071`031`0300L7008700<01`L01PL200031`0700L700D01`07
00081`0500L71`001@L00`071`041`0300L700800PL400870P021`P00`L700@700@01`000`L00`07
1`031`0300L700@700@01`L020L00`071`021`0300L702D7000V1`0400L7008700@01`L010L00`07
1`061`802PL00`07000:1`800PL00`071`031`0300L700D700@01`L00PL00`071`021`0300L700<7
00<01`L01@L0100700091`0500L01`0020L010071`061`0300L700@700<01`L00P021`0400L71`L0
10L800051`0000L01@000`L000031`0300L700<700<01`L010L010071`081`0300L7008700<01`L0
9@L002H700H01`L01`021`0300L700<700<01`L01@L00`0700091`8000<700L020L01@0700L000H7
00<01`L010L01@071`L0008700<01`L00PL00`071`031`0300L700@700<01`L00P091`0400L000T7
00<01`001`L00`071`031`0600L700L00PL00`071`051`D01PL700031`0000<70`031`0300L700@7
00<01`L00`L01@071`L000L700<01`L00`L00`071`0U1`009PL00`071`02008700<01`L010L00`07
1`041`0400L700P700D01`0700091`0400L000L700<01`L00`L00`071`021`0400L700<700<01`L0
10L00`071`031`0500L71`002PL00`07000:1`0300L000L700<01`L00PL010071`021`0400L700L7
00@01`L710041`0300L700<720031`0300L700D700<01`L00PL00`071`021`0300L700@700<01`L0
10L00`071`0U1`009PL00`071`02008700<01`L010L00`071`041`0400L700P700D01`0700081`04
00L700P700<01`L00PL00`071`031`0400L7008700<01`L01@L00`071`031`0300L700802PL300X7
0P081`0300L7008700<01`000`L010071`061`0300L700H71@091`@00PL00`071`061`0500L71`00
1@L00`071`041`0300L700@700<01`L09@L002H700<01`L00P000`L01`061`0300L700<700D01`L7
00071`0600L700L01`L01@071`L000P700<01`L00PL00`071`031`0600L700L020L00`071`021`06
00L700L02PL300X700<01`L01`L01@071`L0008700D01`L700021`0300L700@700<01`L020L600P7
00<01`000`071`0500L71`001@L00`071`031`0300L700D700<01`L09@L002H700<01`L00PL200L7
00<01`L00PL00`071`021`0300L700@700L01`L700L000H700@01`L70P081`0500L71`001PL01P07
1`0700P700D01`L700031`0300L000X700<01`002@L200T700@01`L00PL00`071`021`0400L700D7
00<01`L02@L00`071`0800870P021`0300L000D00PL010071`061`0300L7008700<01`L01PL00`07
1`0U1`009PL01@071`L000870`041`0500L71`001@L00`071`041`0700L71`0700061`0600L700L0
20L010071`071`0300L700802@L010071`031`0400L700T70P000`L01`081`802@L00`0700021`03
00L700<700@01`L010L00`071`091`0300L700@70P031`@000<700L00`L300031`0000<01`L01@07
1`L000T700<01`L09@L002H700D01`L700051`800PL01@071`L000D700<01`L00`L00`071`021`03
00L000D700L01`L700L000P700@01`L01`L010071`0:1`0400L7008700D01`L700091`8000<700L0
1`L00`0700091`0300L0008700<01`L00`L010071`031`0300L700X700<01`L01PL300031`0700D0
1@L200031`0000@010L01@071`L000T700<01`L09@L002H700@01`L020L3008700<01`L010L00`07
1`021`0300L700<700<01`0010L01@071`L0008700<01`L01PL00`0700081`0400L000X700<01`00
0PL00`071`021`0300L700H700D01`0700071`0400L700T70P021`0300L700@700@01`L00`L00`07
1`091`0300L700X70P000`L000031`@00`L300@71@021`0300L700P700<01`L09@L002H700<01`00
2`L300L700D01`L700061`0300L000<700D01`L700031`0300L700H70P091`0400L000X70P031`03
00L7008700<01`L01@L01P071`0700L700@01`L02@L010071`071`0400L7008700<01`L02@L00`07
1`0:1`0300L7008020L500031`0000H7100:1`0300L702D7000V1`8030L200041`0000@700D01`L7
00061`0300L000<700@01`L010L00`071`061`0300L700P70P000`L01`091`800PL00`071`031`03
00L700@700L01`L700L000H700D01`L700081`800PL00`071`051`0600L700L02`L00`071`0;1`04
00L700d71`031`800PL400H700<01`L09@L002H70P0<1`8010L2008700@01`L01`L00`0700021`05
00L71`0010L00`071`061`0300L700P700@01`L02PL010071`061`0300L700@700L01`L700L000D7
00<01`L00PL00`071`061`8000<700L01`L01P071`0700/700<01`L02PL01@071`L001471@000`L0
00061`@00PL00`071`0U1`009PL300/70`051`<000<700L01`L01@0700L000<700<01`L00`L00`07
1`051`802@L2008700<01`L01`L200031`0700H700<01`L00`L00`071`021`0300L000@700<01`L0
0`L00`071`051`0400L000T700<01`L00P0;1`0300L700X700D01`L7000F1`<02`L302L7000Y1`@0
2@L500<70`081`0400L000<700<01`L010L00`071`041`0300L000T70P021`0300L700H700D01`07
00071`0300L7008700<01`L00`L00`0700041`0300L700<700<01`L010L010071`0:1`0400L700/7
00<01`L02`L010071`1?1`00;@L400L7200010L000051`0400L000<700<01`L010L00`071`041`03
00L000P700<01`000PL00`071`061`0400L000P700D01`L700061`0300L000<700<01`L010L00`07
1`041`0400L700X700@01`002`L00`071`0:1`0400L70507000a1`@01PL200031`0000<000<70000
0`L0100700021`0300L700D700<01`L00`L010071`071`0400L7008700<01`L01@L010071`091`05
00L71`001PL00`0700021`0300L700D700<01`L00`L00`071`0200X700@01`002PL00`071`0:1`05
00L71`00D0L003D710041`<00`L700<70P081`0300L7008700D01`L700061`0500L71`000PL00`07
1`041`0300L700802@L010071`071`0300L0008700<01`L01@L00`071`021`0600L700L02PL20003
1`0700P700<01`L02PL01@071`L00547000i1`@00`L200D710021`0300L000801@L01@071`L000@7
00<01`L010L01@071`L0008700<01`L010L00`071`0200T700<01`0020L01@0700L000P700D01`L7
00031`0300L000X700@01`L020L00`071`0;1`0400L70587000m1`@000@7000010L00`07000300<7
0P031`0500L71`0010L00`071`031`0300L7008700@01`L01@L01P071`0700T700<01`0020L01007
00091`0500L71`000PL010071`091`800PL00`071`061`0300L700X700@01`L0D`L004471P021`05
00L700L020001@L01`L000D700<01`L00PL00`071`031`0400L700@700@01`L00PL00`071`071`80
2@L00`07000:1`0400L7008700D01`L700091`800PL00`071`051`0300L700X700D01`L7001C1`00
APL400031`0700<70`000`L0000400H700D01`L700061`0400L700<700@01`L00`L00`071`071`03
00L700P700<01`002PL00`0700021`0300L7008700<01`L01PL00`0700021`0300L700@700<01`L0
2`L010071`1D1`00B@L500D70P021`D010L01@071`L000H700@01`L00`L010071`031`0300L700H7
0P0:1`<02PL200<700<01`L00PL00`071`051`0400L7008700<01`L00`L00`071`0;1`0400L705D7
00191`8000<7000010031`@00PL6008700<01`L01@L010071`021`0400L700@700<01`L01PL200X7
00<01`002PL2008700<01`L00`L00`071`051`0400L7008700<01`L00`L00`071`0:1`0500L71`00
E@L004T70P041`8000<700000P0010L000041`H01`L01P071`07008700<01`L00`L00`071`051`03
00L000X700<01`002PL010071`061`0300L700@700D01`L700021`0300L7008700<01`L02PL01@07
1`L005H7001;1`@00PL300871`031`<000<700000P031`0300L700800PL00`071`041`0300L700@7
00@01`L02@L200031`0700P70P021`0300L700@700<01`L00`L00`071`021`0400L700<700<01`L0
2`L010071`1G1`00C`L400031`0000@720000`L000031`@00PL2008700<01`L010L00`071`041`04
00L700P700D01`0700081`0500L01`001`L00`071`021`0300L700<700@01`L00`L00`071`0:1`04
00L705P7001C1`H010L:00@71@000`L01`061`0300L700<700D01`L700081`0500L01`0020L01007
00081`0300L7008700<01`L00`L010071`021`0300L700X700D01`L7001H1`00E`L400D70P031`D0
00<700L00`L200L700<01`L00PL00`071`021`0300L700D700H01`L01`071`0400L700T700D01`L7
00061`0600L700L03@L010071`1I1`00F`L400<70`041`<00`L00`071`0200D700D01`L700051`03
00L700@700L01`L700L000H700D01`L700091`0400L700L700<01`L00P0=1`0400L705X7001N1`D0
0PL200@71@041`<00PL01@071`L000D700<01`L00`L00`071`021`0300L000H700<01`L00P091`03
00L000P700<01`L00P0<1`0400L705/7001P1`H000<700000PL00`071`0600<70`021`0300L700@7
00<01`L00`L00`071`021`0300L000D700H01`L01`091`0300L000P700@01`L030L01@071`L005/7
001S1`8000<7000010000`L01`021`L000@700001`L00`071`021`0300L700<700<01`0010L01`07
1`L01`002@L200T700@01`0030L010071`1L1`00I@L3008710061`800PL600D700D01`L700061`03
00L000<700D01`L700021`0300L700L700<01`L020L200031`0700X700@01`L0G@L006P70P0010L0
00L400@71@000`L0000200<700D01`L700061`0300L000<700@01`L00`L00`071`061`802PL20003
1`0700T700D01`L7001M1`00JPL300@71@031`8010L5008700<01`L01@L00`0700021`0500L71`00
0`L00`071`061`802PL010071`0:1`0400L705h7001]1`@00PL200031`00008000<700000P041`@0
1`L01@0700L000<700<01`L00PL00`071`051`0300L000T70P021`0300L700L700@01`L0G`L00747
1`021a400`L0100700031`0300L700<700<01`L010L010071`081`0300L0008700<01`L01PL01007
1`1P1`00M@L500@710000`L0000200041`001`@000<700000PL00`071`041`0300L700@700@01`L0
20L00`0700021`0300L700H700@01`L0H0L007T710051`800`L500870`031`0300L700@700<01`L0
0`L01@071`L000L700@01`L00PL00`071`051`0400L70647001m1`@00`L300@710041`0300L700D7
00<01`L00PL00`071`021`0300L700@700D01`L700021`0300L700@700@01`L0HPL007l71P021`80
1@L500P700D01`L700051`0300L700@700D01`L700021`0300L700<700@01`L0H`L008470`001@L0
000700800`L00`071`0500D700D01`L700051`0300L700<700<01`L00PL010071`051`0400L706<7
00241`800PL7008700<01`L01P001@L01`L000H700<01`L00PL00`071`031`0400L700@700@01`L0
I0L008H70`031`D01@L2008710071`0500L71`001PL010071`031`0400L706D700291`800`L600@7
1@000`L0000200<700D01`L700061`0400L700<700<01`00IPL008/70P000`L000031`D00`L200D7
10021`0300L700D700@01`L00PL010071`1V1`00S@L200H70P000`L0000200041`0000D71@061`06
00L700L00PL00`071`1U1`00U`L300871P031`800`L4008700<01`L00P021`0300L706H7002J1`80
10L400031`0000L710000`L000021`0300L706H7002L1`<01@L200X700@01`000PL00`071`1W1`00
W`L200l700<01`L00PL00`071`1X1`00X@L200d700D01`L7001[1`00X`L300X700D01`L7001[1`00
YPL200P700@01`L0K0L00:P70`051`0300L006d7002[1`800`L206h7002]1`8000<70000KPL00:l7
0P1_1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {278.5, 0}} -> {-10.4011, -10.0964, 0.0724844, \
0.0724844}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[158]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["j = 4, k =2", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AL042, Axes \[Rule] True, Prolog \[Rule] PointSize[0.025], 
      PlotRange \[Rule] \ {{\(-20\), 20}, {\(-20\), 20}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[159]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.5 0.025 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -9 -9 ]
[.125 .4875 9 0 ]
[.25 .4875 -9 -9 ]
[.25 .4875 9 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -6 -9 ]
[.75 .4875 6 0 ]
[.875 .4875 -6 -9 ]
[.875 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -12 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -12 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-20)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-15)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-10)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(10)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(15)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(20)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-20)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-15)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-10)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(10)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(15)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(20)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.025 w
.94932 .41723 Mdot
.88682 .50325 Mdot
.82432 .58927 Mdot
.76182 .6753 Mdot
.69932 .76132 Mdot
.97319 .27804 Mdot
.91069 .36406 Mdot
.84819 .45009 Mdot
.78569 .53611 Mdot
.72319 .62213 Mdot
.66069 .70816 Mdot
.59819 .79418 Mdot
.99706 .13885 Mdot
.93456 .22487 Mdot
.87206 .3109 Mdot
.80956 .39692 Mdot
.74706 .48294 Mdot
.68456 .56897 Mdot
.62206 .65499 Mdot
.55956 .74101 Mdot
.49706 .82704 Mdot
.95843 .08568 Mdot
.89593 .17171 Mdot
.83343 .25773 Mdot
.77093 .34375 Mdot
.70843 .42978 Mdot
.64593 .5158 Mdot
.58343 .60183 Mdot
.52093 .68785 Mdot
.45843 .77387 Mdot
.39593 .8599 Mdot
.91981 .03252 Mdot
.85731 .11854 Mdot
.79481 .20456 Mdot
.73231 .29059 Mdot
.66981 .37661 Mdot
.60731 .46264 Mdot
.54481 .54866 Mdot
.48231 .63468 Mdot
.41981 .72071 Mdot
.35731 .80673 Mdot
.29481 .89276 Mdot
.81868 .06537 Mdot
.75618 .1514 Mdot
.69368 .23742 Mdot
.63118 .32345 Mdot
.56868 .40947 Mdot
.50618 .49549 Mdot
.44368 .58152 Mdot
.38118 .66754 Mdot
.31868 .75357 Mdot
.25618 .83959 Mdot
.19368 .92561 Mdot
.71755 .09823 Mdot
.65505 .18426 Mdot
.59255 .27028 Mdot
.53005 .3563 Mdot
.46755 .44233 Mdot
.40505 .52835 Mdot
.34255 .61438 Mdot
.28005 .7004 Mdot
.21755 .78642 Mdot
.15505 .87245 Mdot
.09255 .95847 Mdot
.61643 .13109 Mdot
.55393 .21711 Mdot
.49143 .30314 Mdot
.42893 .38916 Mdot
.36643 .47519 Mdot
.30393 .56121 Mdot
.24143 .64723 Mdot
.17893 .73326 Mdot
.11643 .81928 Mdot
.05393 .90531 Mdot
.5153 .16395 Mdot
.4528 .24997 Mdot
.3903 .336 Mdot
.3278 .42202 Mdot
.2653 .50804 Mdot
.2028 .59407 Mdot
.1403 .68009 Mdot
.0778 .76612 Mdot
.0153 .85214 Mdot
.41417 .19681 Mdot
.35167 .28283 Mdot
.28917 .36886 Mdot
.22667 .45488 Mdot
.16417 .5409 Mdot
.10167 .62693 Mdot
.03917 .71295 Mdot
.31305 .22967 Mdot
.25055 .31569 Mdot
.18805 .40171 Mdot
.12555 .48774 Mdot
.06305 .57376 Mdot
.00055 .65979 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[159]:=",
  ImageSize->{245, 245},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003e0000m@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?D7003e1`00m@L00?D7003e1`00m@L006d7
10031`80O`L006d700<01`L00`L010071`1n1`00KPL00`071`021`0400L700@70P1h1`00I`L400@7
00D01`L700021`0300L7008700<01`L0M`L0070700@01`L00PL00`071`021`0300L707L7001]1`04
00L7008700@01`L010L00`071`1g1`00KPL200@70P051`0300L707L7001k1`0300L707L7001k1`80
G@L401L7001k1`0300L705`7100G1`00N`L00`071`1L1`@05`L007/700<01`L0G0L401L7001k1`03
00L707L7001k1`80N0L007/700<01`L0M`L007/700<01`L0A@L402h7001k1`0300L704D7100^1`00
N`L00`071`151`@0;PL007/700<01`L0A@L402h7001k1`80N0L007/700<01`L0I@L400h7001k1`03
00L706D7100>1`00N`L00`071`1U1`@03PL007/700<01`L0;PL403<7100>1`00N`L00`071`0^1`@0
A@L007/70P0_1`@0A@L007/700<01`L0;PL404D7001k1`0300L704h7100U1`00N`L00`071`1>1`@0
9@L006d710021`<01@L00`071`1>1`@09@L006l700<01`L010L00`071`021`0300L701H7100d1`@0
9@L006l700<01`L010L00`071`021`805`L405d7001W1`@010L010071`L300D700<01`L05PL405@7
10051`00K`L01@071`L000L700<01`L05PL405@710051`00K@L300<700<01`L01@L00`071`1^1`@0
1@L006l700@01`L710041`0300L703H7100d1`@01@L007/70P0g1`@0?@L007/700<01`L0=PL403d7
001k1`0300L000<0<`L403d7001k1`0300L000<0M0L007/700<01`000`1C1`@07@L007/700<01`00
0`1C1`@07@L007/70P1G1`@07@L007/700<01`L07`L403<7100M1`00N`L00`071`0O1`@0E0L006H7
100A1`0300L701l7101D1`00IPL4014700<01`L07`L405@7001V1`@04@L00`071`0o1`@0=0L006H7
100A1`80@0L403@7001k1`0300L703l7100d1`00N`L00`071`081`@0<`L403@7001k1`0300L700P7
101[1`00N`L00`071`081`@0D`L401@7001?1`@0:0L00`071`081`@0D`L401@7001?1`@0:0L20607
100D1`00C`L402P700<01`L0:0L403<7100D1`00C`L402P700<01`L0:0L404/7001]1`@00`L200D7
00<01`L0:0L404/7001_1`D00PL00`071`021`0300L702P7101;1`00K`L5008700<01`L00PL204T7
100[1`00I`L400@71@021`0300L7008700<01`L0B0L402/7001_1`D00PL00`071`021`0300L704P7
100[1`00K@L300<700@01`L010L00`071`0A1`@0<`L402/7001_1`0300L700870P051`0300L70147
101R1`00N`L00`071`0A1`@0D`L400/7001H1`@07`L20187101C1`@02`L005P7100O1`0300L706P7
100;1`00F0L401l700<01`L0<@L403<7100;1`00F0L401l700<01`L0<@L40487001k1`0300L70347
10121`00N0L403<710121`00N0L507P7001h1`@0D`L4028700111`@0<`L405<7100R1`00@@L403H7
00<01`L06PL403<7100R1`00@@L403H700<01`L06PL403<7100R1`00@@L403H70P0K1`@0F@L00647
100F1`0300L701X7101I1`00H@L401H700<01`L0M`L00647100F1`0300L703X7100i1`00H@L401H7
00<01`L0>PL403T7001k1`0300L703X7100i1`00N`L200@7100c1`@0>@L007/700<01`L00`L40707
001k1`0300L700<7101C1`@06@L004T7100^1`0300L700<7101C1`@06@L004T7100V1`<01@L00`07
1`1J1`@06@L004T7100Y1`0300L7008700<01`L08`L403<7100I1`00B@L402T700<01`L00PL202@7
101@1`00J@L800870`051`0300L702<7101@1`00J@L400H700<01`L01@L00`071`0S1`@0D0L006T7
10061`0300L700D700<01`L0@`L40307000b1`@0<`L400H710041`0300L704<7100`1`00<PL404D7
00<01`L0@`L40307000b1`@0A@L200`7100d1`@0<0L0038710151`0300L700/7101X1`00N`L00`07
1`0;1`@0E0L40107001B1`@09@L00`071`0;1`@0E0L40107001B1`@09@L00`071`1S1`@040L00587
100U1`80;0L403@7100@1`00DPL402D700<01`L0:`L404P7001k1`0300L702/710181`00LPL400D7
00<01`L0:`L404P7001b1`@01@L00`071`1;1`@0:0L003/7100c1`@01@L00`071`1;1`@0:0L003/7
100c1`@01@L204`7100X1`00>`L403`700<01`L050L403<7100X1`001`L400<70P0C1`@00PL300l7
10000`L0000200<70P0F1`<06@L00`071`0D1`L05PL400<70P0D1`@00PL301@710031`800`L000L7
00<01`L00`L010071`0D1`0300L700@700<01`L04`L01@071`L0008700<01`L05PL00`071`0F1`03
00L701@710031`0300L701D700D01`L700021`0300L701<700<01`L010L00`071`0A1`0300L700<7
00@01`L00PL000P700<01`L00PL010071`0D1`0300L700@700<01`L04`L01@071`L0008700<01`L0
3`L400<700<01`L05PL00`071`0D1`@00`L00`071`0E1`0500L71`000PL00`071`0C1`0300L700@7
00<01`L04PL00`071`021`0400L7008700000`L0000200@700D01`L700021`0300L700X710041`04
00L71`<03PL400@700D01`L700021`0300L700d72@0I1`0300L701P70`0H1`0500L71`000PL00`07
1`0C1`0400L71`<05PL01@071`L000870@011`47000:1`0400L7008700<01`L04PL01@071`L001P7
00D01`L700021`0300L700l71@0K1`806@L00`071`0H1`D00PL00`071`0C1`0500L71`006@L01007
1`021`400@L11`001`L010071`021`0400L701871@000`L01`0E1`<00`L010071`0A1`D06`L00`07
1`0H1`0300L701H71`021`0300L701470`031`0300L701@700@01`L00PL010071`021`0020L200@7
0P0D1`@000<700000P0E1`0300L700870P0F1`@060L00`071`0H1`@05`L701H700@01`L7100D1`80
10L200<7000T1`@0D`L403<7100o1`0090L405<7101f1`002@OV00H700091`0300L7008700<01`L0
0`L00`071`031`0300L7008700<01`L00`L00`071`031`0300L700<700<01`L00PL00`071`031`03
00L700<700<01`000`051`0300L700<700<01`L00`L00`071`021`0300L700<700<01`L00`L00`07
1`031`0300L7008700<01`L00`L4008700<01`L00PL00`071`031`0300L700<700<01`L00`L00`07
1`021`0300L700<700<01`L00`L00`071`031`0300L7008700<01`L00`L00`071`031`0300L70087
00<01`L00`L00`071`031`D000<700L00`L00`071`031`0300L700<700<01`L00`L00`071`041`00
2@L00`071`0I1`0300L701X700<01`000`0F1`0300L701X700<01`L06PL00`071`0401D700<01`L0
6PL501P700<01`L010L004@7100c1`0300L701d7100c1`@07`L004@7100c1`0300L701d7101F1`00
I0L401<700<01`L07@L405H7001T1`@04`L207P7001T1`@04`L00`071`0m1`@0=PL002d7100c1`@0
4`L00`071`0m1`@0=PL002d7101:1`0300L703d7100f1`00;@L404X700<01`L01PL403<7100f1`00
;@L404X700<01`L01PL406d7001k1`801`L406d7001=1`@0:PL00`071`061`@0K@L004d7100Z1`03
00L707L7001=1`@0:PL00`071`0V1`@0C@L001H7100c1`@0:PL00`071`0V1`@0C@L001H7101C1`@0
2PL00`071`0V1`@0C@L001H7101C1`@02PL202L7101=1`005PL405<7100:1`0300L704H7100]1`00
=PL403<7100:1`0300L704H7100]1`00=PL4044700<01`L0APL402d7000f1`@0@@L00`071`0?1`@0
<`L402d7000f1`@0@@L20107101T1`00N`L00`071`0?1`@0I0L005H7100Q1`0300L700l7101T1`00
EPL4024700<01`L0M`L005H7100I1`<01@L00`071`0_1`@0A0L001h7100d1`@070L00`071`021`03
00L702l710141`007PL405@700<01`L00PL2030710141`007PL405471`000`L01`0`1`@0A0L001h7
101A1`0300L700@000<700L0N0L007<700<01`L010000`L01`1h1`00?PL403471`000`L01`1h1`00
?PL403T700<01`L060L405/700071`@0<`L403T70P0I1`@0F`L000L7100c1`@0>@L00`071`0H1`@0
F`L000L7101C1`@06@L00`071`0H1`@0F`L000L7101C1`@06@L00`071`1g1`00GPL401T700<01`L0
>0L403/7000W1`@0<`L401T700<01`L0>0L403/7000W1`@0D0L203T7100k1`009`L4050700<01`L0
100d1`@0>`L002L7101@1`0300L700@0L`L007/700<01`L0101c1`00A`L4030700<01`L0101c1`00
A`L403070P0Q1`@0D`L004L7100`1`0300L70207101C1`0040L403<7100`1`0300L70207101C1`00
40L405<7100@1`0300L70207101C1`0040L405<7100@1`0300L707L7000@1`@0D`L4010700<01`L0
M`L00307100c1`@040L207P7000`1`@0A`L00`071`1g1`00<0L404L700<01`L02@L406X7000`1`@0
A`L00`071`091`@0JPL006d710031`801@L00`071`091`@0JPL00507100K1`0500L71`000PL00`07
1`021`0300L700T7101Z1`00D0L401/700D01`L700021`0300L700870P1h1`00D0L401/700D01`L7
00021`0300L7008700<01`L0:@L404X7000I1`@0<`L401/700D01`L700021`0300L7008700<01`L0
:@L404X7000I1`@0D0L300<700@01`L010L00`071`0Y1`@0BPL001T7101B1`L01@L00`071`0Y1`@0
BPL001T7101C1`@01`L207P7000i1`@0<`L400L700<01`L0M`L003T7100c1`@01`L00`071`1g1`00
>@L403h700<01`L04PL40647000i1`@0?PL00`071`0B1`@0H@L007/700<01`L04PL40647001I1`@0
7PL201<7101Q1`00F@L401h700<01`L0M`L005T7100N1`0300L707L7000R1`@0<`L401h700<01`L0
M`L00287101E1`0300L707L7000R1`@0D`L407P7000R1`@0D`L407P7001i1`@0N0L00487100c1`@0
N0L00487100e1`0300L707L7000;1`@0<`L403D700<01`L0M`L000/7100c1`@0=@L00`071`1g1`00
2`L405<7100E1`80N0L000/7101C1`@05@L00`071`1g1`00HPL401D700<01`L0M`L002/7100c1`@0
1`L400870`051`0300L707L7000[1`@0@0L00`071`041`0300L7008700<01`L0M`L002/710101`03
00L700@700<01`L00PL207P7000[1`@0@0L010071`L300D700<01`L0M`L006l700D01`L700071`03
00L707L7001;1`@07PL300<700<01`L01@L00`071`1g1`00B`L4020700@01`L710041`0300L707L7
001;1`@0;0L00`071`1g1`0050L403<7100/1`80N0L001@7101S1`0300L707L7000D1`@0H`L00`07
1`1g1`0050L406<700<01`L0M`L003@710131`0300L707L7000d1`@0@`L00`071`1g1`00=0L404<7
0P1h1`00=0L404<700<01`L0M`L007/700<01`L0M`L007/700<01`L0M`L007/700<01`L0M`L007/7
00<01`L0M`L001`7101K1`80N0L001`7101K1`0300L707L7000L1`@0F`L00`071`1g1`0070L405/7
00<01`L0M`L007/700<01`L0M`L007/70P1h1`00N`L00`071`1g1`00N`L00`071`1g1`00N`L00`07
1`1g1`00K@L400<70P051`0300L707L7001]1`0300L700<700@01`L010L00`071`1g1`00KPL00`07
1`021`0400L700@70P1h1`00K`L01@071`L0008700<01`L0O0L0070700@01`L00PL00`071`1l1`00
K@L010071`021`0400L707h7001^1`8010L207l7003e1`00m@L00?D70000\
\>"],
  ImageRangeCache->{{{0, 244}, {244, 0}} -> {-21.5723, -21.3103, 0.174674, \
0.174674}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[159]="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(basis42 = 
      FullSimplify[{A[4, 2, \[Alpha]] /. {m \[Rule] 1, n \[Rule] 0}, 
          A[4, 2, \[Alpha]] /. {m \[Rule] 0, 
              n \[Rule] 1}}]\), "\[IndentingNewLine]", 
    \(orig\  = \ 
      FullSimplify[
        A[4, 2, \[Alpha]] /. {m \[Rule] 0, n \[Rule] 0}]\)}], "Input",
  CellLabel->"In[160]:="],

Cell[BoxData[
    \({{\(-3.7978575143606745`\), 
        1.134090981615794`}, {\(-2.2527725424859373`\), 
        3.260718002495894`}}\)], "Output",
  CellLabel->"Out[160]="],

Cell[BoxData[
    \({0.24722745751406264`, \(-0.18023679868204007`\)}\)], "Output",
  CellLabel->"Out[161]="]
}, Open  ]],

Cell[BoxData[
    \(\(rad42\  = \ \@\(\((basis42[\([1]\)]\  - \ orig)\) . \
\((basis42[\([1]\)]\  - \ orig)\)\);\)\)], "Input",
  CellLabel->"In[162]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AppendTo[basis42, orig], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-10\), 10}, {\(-10\), 10}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[163]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.31011 .5567 Mdot
.38736 .66304 Mdot
.51236 .49099 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[163]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L0088710031`80U@L008@700D01`L700021`0300L7098700241`0500L71`000PL00`07
1`031`80S@L007`710041`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`07
1`031`0300L708`700221`<00`L010071`051`0300L708`700241`0300L700870P061`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L007d700<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<7
00<01`L0S0L007h700<01`L02PL00`071`031`80S@L007H710041`0300L700L70`061`0300L708`7
001o1`0300L700H700<01`L01PL00`071`2<1`00O0L010071`081`0300L700H700<01`L0S0L007`7
10081`@01@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`700281`<01PL00`071`2<1`00R`L00`071`031`0300L708`7
002;1`0300L700<70P2=1`00PPL400870`061`0300L708`700281`0300L700H700<01`L0S0L008P7
00<01`L01PL00`071`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00O0L400<700<01`L00PL300H7
00<01`L0S0L007`700<01`L030L00`071`031`0300L708`7001m1`0300L700/700<01`L00`L208d7
001f1`@010L00`071`071`<01PL00`071`2<1`00O`L00`071`061`0300L700H700<01`L0S0L007`7
00@01`L020L00`071`061`0300L708`7001m1`802@L400D700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L000L710031`805`L00`071`031`0300L700870`0I1`<06@L400<7
00<01`L00PL301P700<01`L05`L400<700<01`L00PL301T70`0J1`0300L700<700<01`L00PL301H7
10031`800`L000T700D01`L700021`0300L701@700<01`L02`L00`071`0I1`0300L701H700<01`L0
30L00`071`0E1`0300L701L700<01`L030L00`071`0I1`0300L701L700<01`L02`L00`071`0E1`05
00L71`000PL100470@L000T700D01`L700021`0300L701D700<01`L02PL00`071`0I1`0300L701L7
00<01`L02`L00`071`0E1`L050L00`071`0;1`0300L701T700<01`L060L00`071`0:1`0300L701D7
00D01`L700021`400@L11`0000<700000P041`0500L71`000PL00`071`0=1`@010L00`071`071`<0
4`L400870`0C1`@010L00`071`071`<05`L:01<700<01`L01`L301T70`0K1`0300L700L70`0H1`05
00L71`000PL100470@L000T700D01`L700021`0300L701H700<01`L01PL00`071`0I1`0300L701`7
00<01`L01PL00`071`0G1`X050L00`071`061`0300L701T700<01`L070L00`071`061`0300L701P7
00D01`L700021`400@L11`001`L300<700@01`L05@L010071`081`0300L701T700<01`L06@L01007
1`081`0300L701H7300@1`0400L700P700<01`L06@L00`071`0I1`0400L700P700<01`L05PL300<7
00@01`L00PL000T700<01`L00PL201H710081`@060L401T70P091`@05@L<01470P091`@060L401P7
10081`@05`L00`071`021`800`L008l730251`00S`L<08D7002?1``0Q@L000T7o`0B00H700091`03
00L700<700<01`L010L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@700<01`L0
10L00`071`041`0300L700@700<01`L00`L00`071`041`0300L700@700<01`L010L00`071`041`03
00L700<700<01`L010L00`071`041`0300L700@700<01`L00`L:00@700<01`L010L00`071`041`03
00L700@700<01`L00`L00`071`041`0300L700@700<01`L010L00`071`041`0300L700<700<01`L0
10L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@700<01`L010L00`071`041`03
00L700@700<01`L010L000T700<01`L07`L00`071`0O1`0300L701l700<01`L07PL:01T700<01`L0
7`L00`071`0O1`0300L701l700<01`L010L009471`281`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7001K1`H0<0L00`071`2<1`00
F@L:02h700<01`L0S0L005T72P0^1`0300L708`7001H1``0;@L00`071`2<1`00F0L<02d70P2=1`00
F0L<02d700<01`L0S0L005P7300]1`0300L708`7001H1``0;@L00`071`2<1`00F0L<02d700<01`L0
S0L005T72P0^1`0300L708`7001I1`X0;PL208d7001K1`H0<0L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7001l1`@00`L00`071`021`<0
1PL00`071`2<1`00O0L00`071`0<1`0300L700<700<01`L0S0L007d700<01`L02`L00`071`031`80
S@L007h700<01`L01`L300H700<01`L0S0L007l700<01`L01PL00`071`061`0300L708`7001l1`04
00L700P700<01`L01PL00`071`2<1`00O@L200T710051`0300L708`7001`1`H06`L00`071`2<1`00
KPL:01T700<01`L0S0L006h72P0I1`80S@L006d7300H1`0300L708`7001]1``060L00`071`2<1`00
K@L<01P700<01`L0S0L006d7300H1`0300L708`7001]1``060L00`071`2<1`00K@L<01P700<01`L0
S0L006h72P0I1`80S@L006h72P0I1`0300L708`7001`1`H06`L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L008P70`061`0300L708`7002;1`03
00L700<700<01`L0S0L008/700<01`L00`L208d700281`<01PL00`071`2<1`00R0L00`071`061`03
00L708`700281`0300L700H700<01`L0S0L008P710051`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80
S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L007d700<01`L0
0`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<700<01`L0S0L007h700<01`L0
2PL00`071`031`80S@L007h700<01`L01`L300H700<01`L0S0L007l700<01`L01PL00`071`061`03
00L708`7001l1`0400L700P700<01`L01PL00`071`2<1`00O0L400P710051`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0088710031`801PL00`071`2<1`00Q0L01@071`L0008700<01`L00`L00`071`2<1`00Q0L01@07
1`L0008700<01`L00`L208d700241`0500L71`000PL00`071`2B1`00Q0L01@071`L0008700<01`L0
TPL008870`031`0400L709@700241`0300L700870P2E1`00o`LQ1`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.6619, -10.5516, 0.0735301, \
0.0735301}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[163]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice042\  = tiling2D[SphericalCut[N[AL042], 10], \ rad42]\)], "Input",\

  CellLabel->"In[164]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97711 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.487782 0.0494217 0.477389 0.0494217 [
[ 0 0 0 0 ]
[ 1 .97711 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .97711 L
0 .97711 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .44367 m
.85264 .61373 L
s
.97619 .44367 m
.77628 .50863 L
s
.85264 .61373 m
.72908 .78379 L
s
.85264 .61373 m
.65272 .67868 L
s
.72908 .78379 m
.60553 .95384 L
s
.72908 .78379 m
.52917 .84874 L
s
.89983 .33857 m
.77628 .50863 L
s
.89983 .33857 m
.69991 .40353 L
s
.77628 .50863 m
.65272 .67868 L
s
.77628 .50863 m
.57636 .57358 L
s
.65272 .67868 m
.52917 .84874 L
s
.65272 .67868 m
.45281 .74364 L
s
.52917 .84874 m
.32925 .9137 L
s
.82347 .23347 m
.69991 .40353 L
s
.82347 .23347 m
.62355 .29842 L
s
.69991 .40353 m
.57636 .57358 L
s
.69991 .40353 m
.5 .46848 L
s
.57636 .57358 m
.45281 .74364 L
s
.57636 .57358 m
.37645 .63854 L
s
.45281 .74364 m
.32925 .9137 L
s
.45281 .74364 m
.25289 .8086 L
s
.74711 .12837 m
.62355 .29842 L
s
.74711 .12837 m
.54719 .19332 L
s
.62355 .29842 m
.5 .46848 L
s
.62355 .29842 m
.42364 .36338 L
s
.5 .46848 m
.37645 .63854 L
s
.5 .46848 m
.30009 .53344 L
s
.37645 .63854 m
.25289 .8086 L
s
.37645 .63854 m
.17653 .7035 L
s
.67075 .02326 m
.54719 .19332 L
s
.67075 .02326 m
.47083 .08822 L
s
.54719 .19332 m
.42364 .36338 L
s
.54719 .19332 m
.34728 .25828 L
s
.42364 .36338 m
.30009 .53344 L
s
.42364 .36338 m
.22372 .42834 L
s
.30009 .53344 m
.17653 .7035 L
s
.30009 .53344 m
.10017 .59839 L
s
.47083 .08822 m
.34728 .25828 L
s
.47083 .08822 m
.27092 .15318 L
s
.34728 .25828 m
.22372 .42834 L
s
.34728 .25828 m
.14736 .32323 L
s
.22372 .42834 m
.10017 .59839 L
s
.22372 .42834 m
.02381 .49329 L
s
.27092 .15318 m
.14736 .32323 L
s
.27092 .15318 m
.071 .21813 L
s
.14736 .32323 m
.02381 .49329 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[164]:=",
  ImageSize->{288, 281.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00016@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00;l70P1O1`00_0L40607002i1`<00`L00`071`1N1`00]@L400D700<01`L0
G`L00;870`081`0300L70607002_1`<02PL00`071`1Q1`00[0L300d700<01`L0H@L00:T70`0?1`03
00L70687002V1`<04@L00`071`1S1`00XPL401@700<01`L0H`L009l70`0G1`0300L706@7002L1`<0
6@L00`071`1U1`00V@L301/700<01`L0IPL009H70`0N1`0300L706H7002C1`<080L00`071`1W1`00
S`L4028700<01`L0J0L008`70`0V1`0300L706P700291`<0:0L00`071`1Y1`00QPL302X700<01`L0
JPL008<7100[1`0300L706/700201`<00`L00`071`0Y1`0300L706/7001m1`<01@L00`071`0Y1`03
00L706`7001j1`<01`L00`071`0Y1`0300L706d7001g1`<02@L00`071`0Z1`0300L706d7001d1`<0
30L00`071`0Y1`0300L706h7001a1`<03PL00`071`0Y1`0300L706l7001^1`<040L00`071`0Y1`03
00L70707001Z1`@04PL00`071`0Z1`0300L70707001W1`<05PL00`071`0Y1`0300L70747001T1`<0
60L00`071`0Y1`0300L70787001Q1`<06PL00`071`0Z1`0300L702L70P191`00GPL301`700<01`L0
:PL00`071`0U1`@0BPL005/70`0O1`0300L702T700<01`L08`L300<700<01`L0B0L005P70`0Q1`03
00L702T700<01`L08@L300D700<01`L0B@L005D70`0S1`0300L702X700<01`L07PL300L700<01`L0
BPL005870`0V1`0300L702T700<01`L070L300T700<01`L0B`L004l70`0X1`0300L702T700<01`L0
6PL300`700<01`L0B`L004`70`0Z1`0300L702X700<01`L05`L300h700<01`L0C0L004T7100[1`03
00L702X700<01`L05@L3010700<01`L0C@L004H70`031`0300L702T700<01`L0:@L00`071`0C1`<0
4PL00`071`1>1`00@`L300D700<01`L0:@L00`071`0Y1`0300L701470`0E1`0300L704h700101`<0
1`L00`071`0Y1`0300L702X700<01`L03PL301L700<01`L0C`L003d70`091`0300L702T700<01`L0
:PL00`071`0<1`<06@L00`071`1@1`00>PL300`700<01`L0:@L00`071`0Y1`0300L700X70`0K1`03
00L70547000g1`<03PL00`071`0Y1`0300L702X700<01`L01`L301h700<01`L0D@L003@70`0@1`03
00L702T700<01`L0:PL00`071`051`<080L00`071`1B1`00<@L301<700<01`L0:0L00`071`0Z1`03
00L700<70`0R1`0300L705<7000^1`<05@L00`071`0Y1`0300L702T700@01`L70`0U1`0300L705<7
000[1`<05`L00`071`0Y1`0300L702X7100W1`0300L705@7000X1`<06@L00`071`0Y1`0300L702T7
0`0Y1`0300L705D7000U1`<070L00`071`0X1`0300L702L7100Z1`0300L705H7000R1`<07PL00`07
1`0Y1`0300L702<710031`0300L702P700<01`L0EPL001l70`0P1`0300L702T700<01`L08@L300H7
00<01`L0:0L00`071`1G1`0070L302<700<01`L0:0L00`071`0O1`<020L00`071`0X1`0300L705P7
000I1`<09@L00`071`0Y1`0300L701`70`0:1`0300L702P700<01`L0F@L001H70`0W1`0300L702T7
00<01`L06PL300d700<01`L0:0L00`071`1I1`0050L202T700<01`L0:@L00`071`0G1`@03`L00`07
1`0X1`0300L705X7000o1`0300L702P700<01`L05@L3018700<01`L0:0L00`071`1K1`00?PL00`07
1`0Y1`0300L701870`0D1`0300L702P700<01`L0G0L003d700<01`L0:@L00`071`0@1`<05`L00`07
1`0X1`0300L705`7000m1`0300L702P700<01`L03@L401T700<01`L0:0L00`071`0X1`80<`L003`7
00<01`L0:0L00`071`0;1`<070L00`071`0X1`0300L702H7100d1`00>`L00`071`0Y1`0300L700P7
0`0N1`0300L702P700<01`L090L300<700<01`L0<PL003X700<01`L0:@L00`071`061`<08@L00`07
1`0X1`0300L702470`051`0300L703<7000j1`0300L702P700<01`L010L302<700<01`L0:0L00`07
1`0O1`<01`L00`071`0d1`00>@L00`071`0X1`0400L71`@09@L00`071`0X1`0300L701d70`091`03
00L703D7000h1`0300L702T7100X1`0300L702T700<01`L06PL300`700<01`L0=@L003P700<01`L0
9`L302/700<01`L0:0L00`071`0H1`<03PL00`071`0f1`00=`L00`071`0U1`@0;0L00`071`0X1`03
00L701H70`0@1`0300L703L7000f1`0300L702<70`031`0300L702T700<01`L0:0L00`071`0C1`@0
4PL00`071`0h1`00=@L00`071`0Q1`<01@L00`071`0Y1`0300L702T700<01`L040L301H700<01`L0
>0L003D700<01`L07PL300L700<01`L0:PL00`071`0X1`0300L700h70`0H1`0300L703T7000d1`03
00L701`70`091`0300L702X700<01`L0:0L00`071`0<1`<06PL00`071`0j1`00<`L00`071`0J1`<0
30L00`071`0Y1`0300L702P700<01`L02PL301`700<01`L0>`L003<700<01`L05`L300h700<01`L0
:@L00`071`0Y1`0300L700L70`0O1`0300L703/7000b1`0300L701D70`0@1`0300L702X700<01`L0
:0L00`071`051`<08@L00`071`0l1`00<@L00`071`0C1`<04`L00`071`0Y1`0300L702P700<01`L0
0`L302<700<01`L0?@L0030700<01`L04@L301D700<01`L0:@L00`071`0X1`0400L71`<09PL00`07
1`0m1`00<0L00`071`0>1`<05`L00`071`0Y1`0300L702T7100X1`0300L703h7000_1`0300L700`7
0`0I1`0300L702X700<01`L09`L302X700<01`L0?`L002h700<01`L02PL301`700<01`L0:@L00`07
1`0U1`@0:`L00`071`101`00;PL00`071`071`<07PL00`071`0Y1`0300L702<70`031`0300L702T7
00<01`L0@0L002d700<01`L01@L3020700<01`L0:@L00`071`0P1`@01@L00`071`0Y1`0300L70447
000/1`0300L700<70`0S1`0300L702T700<01`L07@L300P700<01`L0:@L00`071`121`00:`L01007
1`L302D700<01`L0:@L00`071`0K1`<02PL00`071`0Y1`0300L704<7000[1`@09`L00`071`0Y1`03
00L701T70`0=1`0300L702T700<01`L0@`L002X70P0Y1`0300L702T700<01`L05`L300l700<01`L0
:@L00`071`141`00:@L00`071`0Y1`0300L702T700<01`L050L3014700<01`L0:@L00`071`151`00
:@L00`071`0X1`0300L702T700<01`L04@L401@700<01`L0:0L00`071`161`00:0L00`071`0X1`03
00L702T700<01`L03`L301L700<01`L0:@L00`071`161`009`L00`071`0Y1`0300L702P700<01`L0
3@L301T700<01`L0:@L00`071`0X1`807@L002H700<01`L0:@L00`071`0Y1`0300L700X70`0K1`03
00L702T700<01`L09PL401h7000V1`0300L702P700<01`L0:@L00`071`081`<07PL00`071`0X1`03
00L702@70`031`0300L701`7000U1`0300L702P700<01`L0:@L00`071`061`<080L00`071`0Y1`03
00L702470`051`0300L701d7000T1`0300L702T700<01`L0:0L00`071`031`@08PL00`071`0Y1`03
00L701l70`071`0300L701h7000S1`0300L702T700<01`L0:@L00`071`0302H700<01`L0:0L00`07
1`0M1`<02@L00`071`0O1`008`L00`071`0X1`0300L702T7100X1`0300L702T700<01`L06PL300`7
00<01`L07`L0028700<01`L0:@L00`071`0W1`<0:PL00`071`0Y1`0300L701P70`0>1`0300L70207
000Q1`0300L702T700<01`L09@L402/700<01`L0:@L00`071`0F1`<040L00`071`0Q1`0080L00`07
1`0Y1`0300L702<70`031`0300L702T700<01`L0:0L00`071`0C1`@04PL00`071`0R1`0080L00`07
1`0X1`0300L702470`051`0300L702T700<01`L0:@L00`071`0@1`<05PL00`071`0R1`007`L00`07
1`0Y1`0300L701h70`071`0300L702T700<01`L0:@L00`071`0>1`<060L00`071`0S1`007PL00`07
1`0Y1`0300L701`70`091`0300L702X700<01`L0:0L00`071`0<1`<06PL00`071`0T1`007PL00`07
1`0X1`0300L701X70`0<1`0300L702T700<01`L0:0L00`071`0:1`<070L00`071`0U1`007@L00`07
1`0Y1`0300L701L70`0>1`0300L702T700<01`L0:@L00`071`071`<07`L00`071`0U1`0070L00`07
1`0Y1`0300L701D70`0@1`0300L702T700<01`L0:@L00`071`051`<08@L00`071`0V1`006`L00`07
1`0Y1`0300L701<70`0C1`0300L702T700<01`L0:0L00`071`031`<08`L00`071`0W1`006`L00`07
1`0X1`0300L701470`0E1`0300L702T700<01`L0:0L010071`L302H700<01`L09`L001X700<01`L0
:@L00`071`0>1`<05`L00`071`0Y1`0300L702T7100X1`0300L702P7000I1`0300L702T700<01`L0
30L301T700<01`L0:PL00`071`0W1`<0:PL00`071`0Y1`0060L00`071`0Y1`0300L700X70`0L1`03
00L702T700<01`L09@L402/700<01`L0:PL001P700<01`L0:@L00`071`071`<07PL00`071`0Y1`03
00L702<70`031`0300L702T700<01`L0:PL001L700<01`L0:@L00`071`051`<080L00`071`0Y1`03
00L702470`051`0300L702T700<01`L0:`L001H700<01`L0:@L00`071`031`<08`L00`071`0Y1`03
00L701h70`071`0300L702T700<01`L0;0L001D700<01`L0:@L010071`L302D700<01`L0:@L00`07
1`0L1`<02@L00`071`0Y1`0300L702d7000E1`0300L702T7100W1`0300L702T700<01`L06PL300`7
00<01`L0:@L00`071`0]1`0050L00`071`0X1`<0:@L00`071`0Z1`0300L701L70`0>1`0300L702T7
00<01`L0;PL001<700<01`L09PL402/700<01`L0:@L00`071`0E1`<040L00`071`0Y1`0300L702l7
000B1`0300L702@70`031`0300L702P700<01`L0:@L00`071`0C1`<04`L00`071`0X1`0300L70307
000B1`0300L702470`051`0300L702P700<01`L0:@L00`071`0A1`<05@L00`071`0Y1`0300L70307
000A1`0300L701l70`071`0300L702T700<01`L0:@L00`071`0>1`<05`L00`071`0Y1`0300L702P7
0P071`0040L00`071`0M1`<02@L00`071`0Y1`0300L702T700<01`L030L301T700<01`L0:@L00`07
1`0V1`@020L0010700<01`L06PL300`700<01`L0:0L00`071`0Y1`0300L700X70`0L1`0300L702P7
00<01`L090L300<700<01`L01PL000l700<01`L060L300h700<01`L0:0L00`071`0Z1`0300L700L7
0`0N1`0300L702T700<01`L08@L300D700<01`L01`L000h700<01`L05PL3010700<01`L0:@L00`07
1`0Y1`0300L700D70`0P1`0300L702T700<01`L07`L300L700<01`L020L000d700<01`L04`L40187
00<01`L0:@L00`071`0Y1`0300L700<70`0S1`0300L702P700<01`L07@L300T700<01`L02@L000d7
00<01`L040L301H700<01`L0:0L00`071`0Y1`0400L71`<09@L00`071`0Y1`0300L701X70`0<1`03
00L700T7000<1`0300L700h70`0H1`0300L702T700<01`L0:@L402L700<01`L0:@L00`071`0H1`<0
3PL00`071`0:1`002`L00`071`0<1`<06PL00`071`0Y1`0300L702P70`0Y1`0300L702T700<01`L0
5PL3010700<01`L02`L000X700<01`L02PL301`700<01`L0:@L00`071`0V1`@0:`L00`071`0X1`03
00L701<7100B1`0300L700`7000:1`0300L700L70`0O1`0300L702P700<01`L090L300<700<01`L0
:0L00`071`0Y1`0300L701070`0F1`0300L700`700091`0300L700D70`0Q1`0300L702T700<01`L0
80L400D700<01`L0:0L00`071`0Y1`0300L700h70`0H1`0300L700d700081`0300L700<70`0S1`03
00L702T700<01`L07PL300P700<01`L0:@L00`071`0X1`0300L700`70`0J1`0300L700h700071`04
00L71`<09PL00`071`0X1`0300L701`70`0:1`0300L702T700<01`L0:0L00`071`0:1`<070L00`07
1`0?1`001`L402P700<01`L0:@L00`071`0I1`<03@L00`071`0X1`0300L702T700<01`L01`L301l7
00<01`L03`L000H70P0Z1`0300L702T700<01`L05`L300l700<01`L0:0L00`071`0Y1`0300L700D7
0`0Q1`0300L70107000a1`0300L702T700<01`L05@L3014700<01`L0:@L00`071`0X1`0300L700<7
0`0S1`0300L70147000a1`0300L702P700<01`L04PL401<700<01`L0:@L00`071`0X1`0400L71`<0
9PL00`071`0A1`00<0L00`071`0Y1`0300L700l70`0G1`0300L702P700<01`L0:@L402P700<01`L0
4PL002l700<01`L0:@L00`071`0=1`<06@L00`071`0Y1`0300L702L70`0Z1`0300L701<7000^1`03
00L702T700<01`L02`L301/700<01`L0:@L00`071`0U1`@0:`L00`071`0D1`00;PL00`071`0Y1`03
00L700P70`0N1`0300L702P700<01`L08`L300<700<01`L0:@L00`071`0D1`00;@L00`071`0Y1`03
00L700H70`0P1`0300L702P700<01`L08@L300D700<01`L0:@L00`071`0E1`00;0L00`071`0Y1`03
00L700<7100R1`0300L702T700<01`L07PL300L700<01`L0:@L00`071`0F1`00:`L00`071`0Y1`04
00L71`<09@L00`071`0Y1`0300L701`70`091`0300L702T700<01`L05`L002/700<01`L0:@L402P7
00<01`L0:0L00`071`0J1`<030L00`071`0Y1`0300L701L7000Z1`0300L702P70`0Z1`0300L702T7
00<01`L05`L300h700<01`L0:@L00`071`0H1`00:@L00`071`0V1`@0:`L00`071`0Y1`0300L701D7
0`0@1`0300L702T700<01`L06@L002P700<01`L090L300<700<01`L0:0L00`071`0Y1`0300L701<7
0`0C1`0300L702P700<01`L06PL002P700<01`L08@L300D700<01`L0:@L00`071`0X1`0300L70147
0`0E1`0300L702T700<01`L06PL002L700<01`L07`L300L700<01`L0:@L00`071`0Y1`0300L700h7
0`0G1`0300L702T700<01`L06`L002H700<01`L07@L300T700<01`L0:@L00`071`0Y1`0300L700`7
0`0I1`0300L702T700<01`L070L002H700<01`L06PL300`700<01`L0:@L00`071`0X1`0300L700X7
0`0L1`0300L702P700<01`L07@L002D700<01`L060L300h700<01`L0:@L00`071`0Y1`0300L700L7
0`0N1`0300L702T700<01`L07@L002@700<01`L05PL3010700<01`L0:@L00`071`0Y1`0300L700D7
0`0P1`0300L702T700<01`L07PL002<700<01`L04`L4018700<01`L0:@L00`071`0Y1`0300L700<7
0`0S1`0300L702P700<01`L07`L002<700<01`L040L301H700<01`L0:@L00`071`0X1`0400L71`<0
9@L00`071`0Y1`0300L701l7000R1`0300L700h70`0H1`0300L702T700<01`L0:@L402L700<01`L0
:@L00`071`0P1`008@L00`071`0<1`<06PL00`071`0Y1`0300L702P70`0Y1`0300L702T700<01`L0
8@L0020700<01`L02PL301`700<01`L0:@L00`071`0V1`@0:`L00`071`0X1`0300L70287000P1`03
00L700L70`0O1`0300L702T700<01`L08`L300<700<01`L0:0L00`071`0Y1`0300L70287000O1`03
00L700D70`0Q1`0300L702T700<01`L080L400D700<01`L0:0L00`071`0Y1`0300L702<7000N1`03
00L700<70`0S1`0300L702T700<01`L07PL300P700<01`L0:@L00`071`0X1`0300L702@7000M1`04
00L71`<09PL00`071`0X1`0300L701`70`0:1`0300L702T700<01`L0:0L00`071`0U1`007@L402P7
00<01`L0:@L00`071`0I1`<03@L00`071`0X1`0300L702T700<01`L09@L001`70P0Z1`0300L702T7
00<01`L05`L300l700<01`L0:0L00`071`0Y1`0300L702H700171`0300L702T700<01`L05@L30147
00<01`L0:@L00`071`0X1`0300L702L700171`0300L702T700<01`L04@L401<700<01`L0:@L00`07
1`0X1`0300L702P700161`0300L702T700<01`L03`L301L700<01`L0:0L00`071`0Y1`0300L702P7
00151`0300L702T700<01`L03@L301T700<01`L0:@L00`071`0W1`80:`L004@700<01`L0:@L00`07
1`0;1`<06`L00`071`0Y1`0300L702D7100/1`00A0L00`071`0Y1`0300L700P70`0M1`0300L702T7
00<01`L08`L300<700<01`L0:PL004<700<01`L0:@L00`071`061`<080L00`071`0X1`0300L70247
0`051`0300L702/700121`0300L702T700<01`L00`L4028700<01`L0:@L00`071`0N1`<01`L00`07
1`0/1`00@@L00`071`0Y1`0400L71`<09@L00`071`0Y1`0300L701`70`091`0300L702d700111`03
00L702T7100X1`0300L702P700<01`L06PL300`700<01`L0;@L0040700<01`L0:0L302X700<01`L0
:@L00`071`0G1`<03PL00`071`0^1`00?`L00`071`0V1`@0:`L00`071`0Y1`0300L701D70`0@1`03
00L702l7000n1`0300L702@70`031`0300L702P700<01`L0:@L00`071`0C1`<04`L00`071`0_1`00
?PL00`071`0Q1`<01@L00`071`0Y1`0300L702P700<01`L04@L301D700<01`L0<0L003d700<01`L0
7`L300L700<01`L0:@L00`071`0Y1`0300L700h70`0G1`0300L70347000l1`0300L701d70`091`03
00L702T700<01`L0:@L00`071`0<1`<06@L00`071`0b1`00?0L00`071`0J1`<030L00`071`0X1`03
00L702T700<01`L02PL301`700<01`L0<PL003/700<01`L060L300h700<01`L0:@L00`071`0Y1`03
00L700L70`0N1`0300L703<7000j1`0300L701H70`0@1`0300L702T700<01`L0:@L00`071`051`<0
80L00`071`0d1`00>@L00`071`0C1`@04PL00`071`0Y1`0300L702T700<01`L00`L302<700<01`L0
=0L003T700<01`L040L301H700<01`L0:0L00`071`0Y1`0400L71`<09@L00`071`0e1`00>0L00`07
1`0>1`<060L00`071`0Y1`0300L702T7100W1`0300L703H7000g1`0300L700`70`0J1`0300L702T7
00<01`L0:0L302T700<01`L0=`L003H700<01`L02PL301`700<01`L0:@L00`071`0V1`@0:`L00`07
1`0g1`00=PL00`071`071`<07`L00`071`0X1`0300L702@70`031`0300L702P700<01`L0>0L003D7
00<01`L01@L3024700<01`L0:@L00`071`0Q1`<01@L00`071`0X1`0300L703T7000d1`0300L700<7
0`0S1`0300L702T700<01`L07`L300L700<01`L0:@L00`071`0i1`00<`L010071`L302H700<01`L0
:0L00`071`0M1`<02@L00`071`0Y1`0300L703X7000c1`@0:0L00`071`0Y1`0300L701X70`0<1`03
00L702P700<01`L0>`L003870P0Z1`0300L702T700<01`L060L300h700<01`L0:0L00`071`0l1`00
G@L00`071`0Y1`0300L701H70`0@1`0300L702T700<01`L0?0L005d700<01`L0:0L00`071`0C1`@0
4PL00`071`0Y1`0300L703d7001L1`0300L702T700<01`L040L301H700<01`L0:0L00`071`0n1`00
F`L00`071`0Y1`0300L700h70`0H1`0300L702T700<01`L0?PL005X700<01`L0:@L00`071`0<1`<0
6PL00`071`0Y1`0300L703l7001J1`0300L702P700<01`L02PL301`700<01`L0:@L00`071`101`00
F@L00`071`0Y1`0300L700L70`0O1`0300L702P700<01`L0@@L005P700<01`L0:@L00`071`051`<0
8@L00`071`0Y1`0300L70447001G1`0300L702T700<01`L00`L302<700<01`L0:@L00`071`121`00
E`L00`071`0X1`0400L71`<09PL00`071`0X1`0300L704<7001F1`0300L702T7100X1`0300L702T7
00<01`L0@`L005D700<01`L0:0L302X700<01`L0:@L00`071`141`00E0L00`071`0V1`@0:`L00`07
1`0Y1`0300L704D7001D1`0300L702<70`031`0300L702T700<01`L0:0L00`071`161`00D`L00`07
1`0P1`@01@L00`071`0Y1`0300L702T700<01`L0APL0058700<01`L07PL300P700<01`L0:@L00`07
1`0Y1`0300L704L7001B1`0300L701/70`0:1`0300L702T700<01`L0:@L00`071`181`00D@L00`07
1`0I1`<03@L00`071`0Y1`0300L702T700<01`L0B0L0050700<01`L05`L300l700<01`L0:@L00`07
1`0Y1`0300L704T7001?1`0300L701D70`0A1`0300L702T700<01`L0:@L00`071`1:1`00C`L00`07
1`0A1`@04`L00`071`0Y1`0300L702T700<01`L0B`L004h700<01`L03`L301L700<01`L0:@L00`07
1`0Y1`0300L704/7001=1`0300L700d70`0I1`0300L702T700<01`L0:0L204h7001<1`0300L700/7
0`0K1`0300L702T700<01`L09PL404l7001<1`0300L700P70`0N1`0300L702P700<01`L090L300<7
00<01`L0C@L004/700<01`L01PL3020700<01`L0:@L00`071`0Q1`<01@L00`071`1>1`00BPL00`07
1`031`@08PL00`071`0Y1`0300L701l70`071`0300L704l700191`0400L71`<09@L00`071`0Y1`03
00L701d70`091`0300L7050700191`@0:0L00`071`0Y1`0300L701X70`0<1`0300L7050700181`80
:PL00`071`0Y1`0300L701P70`0>1`0300L70547001c1`0300L702T700<01`L05PL3010700<01`L0
DPL0078700<01`L0:@L00`071`0C1`@04PL00`071`1C1`00LPL00`071`0Y1`0300L701070`0F1`03
00L705<7001a1`0300L702T700<01`L03PL301P700<01`L0E0L0070700<01`L0:@L00`071`0<1`<0
6PL00`071`1E1`00L0L00`071`0X1`0300L700X70`0L1`0300L705H7001_1`0300L702T700<01`L0
1`L301l700<01`L0EPL006h700<01`L0:@L00`071`051`<08@L00`071`1G1`00K@L00`071`0Y1`03
00L700<70`0S1`0300L705P7001]1`0300L702P700@01`L70`0V1`0300L705P7001/1`0300L702T7
100X1`0300L705T7001[1`0300L702P70`0Z1`0300L705X7001Z1`0300L702H70`0/1`0300L705/7
001Z1`0300L702<70`0_1`0300L705/7001Y1`0300L70207100a1`0300L705`7001X1`0300L701h7
0`0d1`0300L705d7001W1`0300L701`70`0f1`0300L705h7001W1`0300L701T70`0i1`0300L705h7
001V1`0300L701L70`0k1`0300L705l7001U1`0300L701D70`0m1`0300L70607001U1`0300L70147
100o1`0300L70647001T1`0300L700l70`131`0300L70647001S1`0300L700d70`151`0300L70687
001R1`0300L700/70`171`0300L706<7001R1`0300L700P70`191`0300L706@7001Q1`0300L700H7
0`1<1`0300L706@7001P1`0300L700<7101>1`0300L706D7001O1`0400L71`<0D@L00`071`1V1`00
G`L405@700<01`L0IPL005h70P1F1`0300L706L7002e1`0300L706P7002d1`0300L706T7002d1`03
00L706T7002c1`0300L706X7002b1`0300L706/7002a1`0300L706`7002a1`0300L706`7002`1`03
00L706d7002_1`0300L706h7002^1`0300L706l7002^1`0300L706l7002]1`0300L70707003o1b47
003o1b47003o1b47003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {280.375, 0}} -> {-9.8718, -9.6595, 0.0705158, \
0.0705158}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[164]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice42\  = 
      tiling2D[SphericalCut[N[Join[AL042, \ AL142, \ AL242, \ AL342]], 10], \ 
        rad42]\)], "Input",
  CellLabel->"In[165]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97511 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.500134 0.0481718 0.487487 0.0481718 [
[ 0 0 0 0 ]
[ 1 .97511 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .97511 L
0 .97511 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .45462 m
.85576 .62038 L
s
.97619 .45462 m
.78133 .51793 L
s
.97619 .45462 m
.84222 .29555 L
s
.85576 .62038 m
.73533 .78614 L
s
.85576 .62038 m
.6609 .68369 L
s
.85576 .62038 m
.72179 .46131 L
s
.73533 .78614 m
.6149 .95189 L
s
.73533 .78614 m
.54047 .84945 L
s
.73533 .78614 m
.60136 .62706 L
s
.6149 .95189 m
.48093 .79282 L
s
.90176 .35218 m
.78133 .51793 L
s
.90176 .35218 m
.7069 .41549 L
s
.90176 .35218 m
.76779 .1931 L
s
.78133 .51793 m
.6609 .68369 L
s
.78133 .51793 m
.58647 .58125 L
s
.78133 .51793 m
.89122 .69451 L
s
.78133 .51793 m
.64736 .35886 L
s
.6609 .68369 m
.54047 .84945 L
s
.6609 .68369 m
.46604 .74701 L
s
.6609 .68369 m
.77079 .86026 L
s
.6609 .68369 m
.52693 .52462 L
s
.54047 .84945 m
.34561 .91276 L
s
.54047 .84945 m
.4065 .69038 L
s
.82733 .24973 m
.7069 .41549 L
s
.82733 .24973 m
.63247 .31305 L
s
.82733 .24973 m
.93722 .42631 L
s
.82733 .24973 m
.69336 .09066 L
s
.7069 .41549 m
.58647 .58125 L
s
.7069 .41549 m
.51204 .4788 L
s
.7069 .41549 m
.81679 .59206 L
s
.7069 .41549 m
.57293 .25642 L
s
.58647 .58125 m
.46604 .74701 L
s
.58647 .58125 m
.39161 .64456 L
s
.58647 .58125 m
.69636 .75782 L
s
.58647 .58125 m
.4525 .42218 L
s
.46604 .74701 m
.34561 .91276 L
s
.46604 .74701 m
.27118 .81032 L
s
.46604 .74701 m
.57593 .92358 L
s
.46604 .74701 m
.33207 .58793 L
s
.34561 .91276 m
.21164 .75369 L
s
.7529 .14729 m
.63247 .31305 L
s
.7529 .14729 m
.55804 .2106 L
s
.7529 .14729 m
.86279 .32386 L
s
.63247 .31305 m
.51204 .4788 L
s
.63247 .31305 m
.43761 .37636 L
s
.63247 .31305 m
.74236 .48962 L
s
.63247 .31305 m
.4985 .15397 L
s
.51204 .4788 m
.39161 .64456 L
s
.51204 .4788 m
.31718 .54212 L
s
.51204 .4788 m
.62193 .65538 L
s
.51204 .4788 m
.37807 .31973 L
s
.39161 .64456 m
.27118 .81032 L
s
.39161 .64456 m
.19675 .70788 L
s
.39161 .64456 m
.5015 .82113 L
s
.39161 .64456 m
.25764 .48549 L
s
.27118 .81032 m
.13721 .65125 L
s
.67847 .04485 m
.55804 .2106 L
s
.67847 .04485 m
.48361 .10816 L
s
.67847 .04485 m
.78836 .22142 L
s
.55804 .2106 m
.43761 .37636 L
s
.55804 .2106 m
.36318 .27392 L
s
.55804 .2106 m
.66793 .38718 L
s
.55804 .2106 m
.42407 .05153 L
s
.43761 .37636 m
.31718 .54212 L
s
.43761 .37636 m
.24275 .43967 L
s
.43761 .37636 m
.5475 .55293 L
s
.43761 .37636 m
.30364 .21729 L
s
.31718 .54212 m
.19675 .70788 L
s
.31718 .54212 m
.12232 .60543 L
s
.31718 .54212 m
.42707 .71869 L
s
.31718 .54212 m
.18321 .38305 L
s
.19675 .70788 m
.30664 .88445 L
s
.19675 .70788 m
.06278 .5488 L
s
.48361 .10816 m
.36318 .27392 L
s
.48361 .10816 m
.28875 .17147 L
s
.48361 .10816 m
.5935 .28473 L
s
.36318 .27392 m
.24275 .43967 L
s
.36318 .27392 m
.16832 .33723 L
s
.36318 .27392 m
.47307 .45049 L
s
.36318 .27392 m
.22921 .11485 L
s
.24275 .43967 m
.12232 .60543 L
s
.24275 .43967 m
.0479 .50299 L
s
.24275 .43967 m
.35264 .61625 L
s
.24275 .43967 m
.10878 .2806 L
s
.12232 .60543 m
.23221 .782 L
s
.28875 .17147 m
.16832 .33723 L
s
.28875 .17147 m
.0939 .23479 L
s
.28875 .17147 m
.39864 .34805 L
s
.16832 .33723 m
.0479 .50299 L
s
.16832 .33723 m
.27821 .5138 L
s
.0479 .50299 m
.15778 .67956 L
s
.0939 .23479 m
.20378 .41136 L
s
.89122 .69451 m
.77079 .86026 L
s
.89122 .69451 m
.69636 .75782 L
s
.89122 .69451 m
.75725 .53543 L
s
.77079 .86026 m
.57593 .92358 L
s
.77079 .86026 m
.63682 .70119 L
s
.93722 .42631 m
.81679 .59206 L
s
.93722 .42631 m
.74236 .48962 L
s
.93722 .42631 m
.80325 .26723 L
s
.81679 .59206 m
.69636 .75782 L
s
.81679 .59206 m
.62193 .65538 L
s
.81679 .59206 m
.68282 .43299 L
s
.69636 .75782 m
.57593 .92358 L
s
.69636 .75782 m
.5015 .82113 L
s
.69636 .75782 m
.56239 .59875 L
s
.57593 .92358 m
.44196 .7645 L
s
.86279 .32386 m
.74236 .48962 L
s
.86279 .32386 m
.66793 .38718 L
s
.86279 .32386 m
.72882 .16479 L
s
.74236 .48962 m
.62193 .65538 L
s
.74236 .48962 m
.5475 .55293 L
s
.74236 .48962 m
.60839 .33055 L
s
.62193 .65538 m
.5015 .82113 L
s
.62193 .65538 m
.42707 .71869 L
s
.62193 .65538 m
.48796 .4963 L
s
.5015 .82113 m
.30664 .88445 L
s
.5015 .82113 m
.36753 .66206 L
s
.78836 .22142 m
.66793 .38718 L
s
.78836 .22142 m
.5935 .28473 L
s
.78836 .22142 m
.65439 .06235 L
s
.66793 .38718 m
.5475 .55293 L
s
.66793 .38718 m
.47307 .45049 L
s
.66793 .38718 m
.53396 .2281 L
s
.5475 .55293 m
.42707 .71869 L
s
.5475 .55293 m
.35264 .61625 L
s
.5475 .55293 m
.41353 .39386 L
s
.42707 .71869 m
.30664 .88445 L
s
.42707 .71869 m
.23221 .782 L
s
.42707 .71869 m
.2931 .55962 L
s
.30664 .88445 m
.17267 .72537 L
s
.71393 .11898 m
.5935 .28473 L
s
.71393 .11898 m
.51907 .18229 L
s
.5935 .28473 m
.47307 .45049 L
s
.5935 .28473 m
.39864 .34805 L
s
.5935 .28473 m
.45953 .12566 L
s
.47307 .45049 m
.35264 .61625 L
s
.47307 .45049 m
.27821 .5138 L
s
.47307 .45049 m
.3391 .29142 L
s
.35264 .61625 m
.23221 .782 L
s
.35264 .61625 m
.15778 .67956 L
s
.35264 .61625 m
.21867 .45717 L
s
.23221 .782 m
.09824 .62293 L
s
.51907 .18229 m
.39864 .34805 L
s
.51907 .18229 m
.32421 .2456 L
s
.51907 .18229 m
.3851 .02322 L
s
.39864 .34805 m
.27821 .5138 L
s
.39864 .34805 m
.20378 .41136 L
s
.39864 .34805 m
.26467 .18897 L
s
.27821 .5138 m
.15778 .67956 L
s
.27821 .5138 m
.08335 .57712 L
s
.27821 .5138 m
.14424 .35473 L
s
.15778 .67956 m
.02381 .52049 L
s
.44464 .07985 m
.32421 .2456 L
s
.44464 .07985 m
.24978 .14316 L
s
.32421 .2456 m
.20378 .41136 L
s
.32421 .2456 m
.12935 .30892 L
s
.20378 .41136 m
.08335 .57712 L
s
.24978 .14316 m
.12935 .30892 L
s
.87065 .66619 m
.75022 .83195 L
s
.87065 .66619 m
.67579 .72951 L
s
.75022 .83195 m
.55536 .89526 L
s
.91665 .39799 m
.79622 .56375 L
s
.91665 .39799 m
.72179 .46131 L
s
.79622 .56375 m
.67579 .72951 L
s
.79622 .56375 m
.60136 .62706 L
s
.79622 .56375 m
.9061 .74032 L
s
.67579 .72951 m
.55536 .89526 L
s
.67579 .72951 m
.48093 .79282 L
s
.84222 .29555 m
.72179 .46131 L
s
.84222 .29555 m
.64736 .35886 L
s
.84222 .29555 m
.9521 .47212 L
s
.72179 .46131 m
.60136 .62706 L
s
.72179 .46131 m
.52693 .52462 L
s
.72179 .46131 m
.83168 .63788 L
s
.60136 .62706 m
.48093 .79282 L
s
.60136 .62706 m
.4065 .69038 L
s
.60136 .62706 m
.71125 .80363 L
s
.48093 .79282 m
.28607 .85613 L
s
.76779 .1931 m
.64736 .35886 L
s
.76779 .1931 m
.57293 .25642 L
s
.76779 .1931 m
.87768 .36968 L
s
.64736 .35886 m
.52693 .52462 L
s
.64736 .35886 m
.4525 .42218 L
s
.64736 .35886 m
.75725 .53543 L
s
.52693 .52462 m
.4065 .69038 L
s
.52693 .52462 m
.33207 .58793 L
s
.52693 .52462 m
.63682 .70119 L
s
.4065 .69038 m
.28607 .85613 L
s
.4065 .69038 m
.21164 .75369 L
s
.4065 .69038 m
.51639 .86695 L
s
.69336 .09066 m
.57293 .25642 L
s
.69336 .09066 m
.4985 .15397 L
s
.69336 .09066 m
.80325 .26723 L
s
.57293 .25642 m
.4525 .42218 L
s
.57293 .25642 m
.37807 .31973 L
s
.57293 .25642 m
.68282 .43299 L
s
.4525 .42218 m
.33207 .58793 L
s
.4525 .42218 m
.25764 .48549 L
s
.4525 .42218 m
.56239 .59875 L
s
.33207 .58793 m
.21164 .75369 L
s
.33207 .58793 m
.13721 .65125 L
s
.33207 .58793 m
.44196 .7645 L
s
.21164 .75369 m
.32153 .93026 L
s
.4985 .15397 m
.37807 .31973 L
s
.4985 .15397 m
.30364 .21729 L
s
.4985 .15397 m
.60839 .33055 L
s
.37807 .31973 m
.25764 .48549 L
s
.37807 .31973 m
.18321 .38305 L
s
.37807 .31973 m
.48796 .4963 L
s
.25764 .48549 m
.13721 .65125 L
s
.25764 .48549 m
.06278 .5488 L
s
.25764 .48549 m
.36753 .66206 L
s
.13721 .65125 m
.2471 .82782 L
s
.42407 .05153 m
.30364 .21729 L
s
.42407 .05153 m
.22921 .11485 L
s
.42407 .05153 m
.53396 .2281 L
s
.30364 .21729 m
.18321 .38305 L
s
.30364 .21729 m
.10878 .2806 L
s
.30364 .21729 m
.41353 .39386 L
s
.18321 .38305 m
.06278 .5488 L
s
.18321 .38305 m
.2931 .55962 L
s
.06278 .5488 m
.17267 .72537 L
s
.22921 .11485 m
.10878 .2806 L
s
.22921 .11485 m
.3391 .29142 L
s
.10878 .2806 m
.21867 .45717 L
s
.9061 .74032 m
.71125 .80363 L
s
.9521 .47212 m
.83168 .63788 L
s
.9521 .47212 m
.75725 .53543 L
s
.83168 .63788 m
.71125 .80363 L
s
.83168 .63788 m
.63682 .70119 L
s
.71125 .80363 m
.51639 .86695 L
s
.87768 .36968 m
.75725 .53543 L
s
.87768 .36968 m
.68282 .43299 L
s
.75725 .53543 m
.63682 .70119 L
s
.75725 .53543 m
.56239 .59875 L
s
.63682 .70119 m
.51639 .86695 L
s
.63682 .70119 m
.44196 .7645 L
s
.51639 .86695 m
.32153 .93026 L
s
.80325 .26723 m
.68282 .43299 L
s
.80325 .26723 m
.60839 .33055 L
s
.68282 .43299 m
.56239 .59875 L
s
.68282 .43299 m
.48796 .4963 L
s
.56239 .59875 m
.44196 .7645 L
s
.56239 .59875 m
.36753 .66206 L
s
.44196 .7645 m
.32153 .93026 L
s
.44196 .7645 m
.2471 .82782 L
s
.72882 .16479 m
.60839 .33055 L
s
.72882 .16479 m
.53396 .2281 L
s
.60839 .33055 m
.48796 .4963 L
s
.60839 .33055 m
.41353 .39386 L
s
.48796 .4963 m
.36753 .66206 L
s
.48796 .4963 m
.2931 .55962 L
s
.36753 .66206 m
.2471 .82782 L
s
.36753 .66206 m
.17267 .72537 L
s
.65439 .06235 m
.53396 .2281 L
s
.65439 .06235 m
.45953 .12566 L
s
.53396 .2281 m
.41353 .39386 L
s
.53396 .2281 m
.3391 .29142 L
s
.41353 .39386 m
.2931 .55962 L
s
.41353 .39386 m
.21867 .45717 L
s
.2931 .55962 m
.17267 .72537 L
s
.2931 .55962 m
.09824 .62293 L
s
.45953 .12566 m
.3391 .29142 L
s
.45953 .12566 m
.26467 .18897 L
s
.3391 .29142 m
.21867 .45717 L
s
.3391 .29142 m
.14424 .35473 L
s
.21867 .45717 m
.09824 .62293 L
s
.21867 .45717 m
.02381 .52049 L
s
.3851 .02322 m
.26467 .18897 L
s
.26467 .18897 m
.14424 .35473 L
s
.14424 .35473 m
.02381 .52049 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[165]:=",
  ImageSize->{288, 280.812},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000160P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L006h700<01`L0[`L006d700<01`00/0L006d700@01`L0[`L006`700D01`L7002_1`00
J`L00`071`031`0300L70:`7001Z1`0300L700D700<01`L0Z`L006X700<01`L01PL00`071`2Z1`00
J@L00`071`081`0300L704X70P1M1`00J0L00`071`0:1`0300L70080A0L400031`0705/7001W1`03
00L700/710000`L01`0o1`<00`L00`07001L1`00I`L00`071`081`<000D700L01`0203`70`051`05
00L71`00F`L006H700<01`L01PL300D700@01`L70P0g1`@01`L00`071`031`0300L705P7001U1`03
00L700@70`071`0300L000<700<01`L0<PL300H70P021`0300L700@700<01`L0F0L006D700@01`L7
0`091`0500L71`000PL203070`061`@000@700L01`L00`071`1G1`00I0L00`07000200`700<01`L0
0PL00`071`0202`70`061`<00`L010071`081`0300L705L7001S1`<03PL00`071`031`0600L700L0
:0L300H70`051`0600L700L020L00`071`1F1`00H0L3010700<01`L01@L01P071`0702@70`051`@0
1`L010071`021`0300L700L700<01`L0E@L005d70`021`0300L700h700<01`L01PL01P0700070207
0`051`<02PL01@071`L000<700<01`L01PL00`071`1E1`00F`L200@700<01`L03PL00`071`061`D0
00<700L070L300D70`0=1`0400L700D700<01`L01PL00`071`1D1`00F0L300D700<01`L03PL00`07
1`041`<00`L01@0700L001T70`051`<03`L010071`071`0300L700H700<01`L0D`L005D70`071`03
00L700l700@01`L70`051`0700L01`07000D1`@01@L3014700D01`L700081`0300L700800`L00`07
1`1C1`00DPL300X700<01`L03PL500L700H01`L01`021`0300L700h70`061`<04`L01@071`L000T7
10000`L01`021`0300L70587001?1`<030L00`071`0=1`<02PL00`071`021`0300L0008700<01`L0
2PL300H70`0F1`0400L700L70`021`8000<700000`L00`071`1A1`00C0L300h700<01`L02`L400`7
00<01`L00`L200<700<01`L01PL300H70`0H1`0400L700D70`051`800PL2008700<01`L0D@L004T7
0`0A1`0300L700P70`031`0300L700T700<01`L01@L200<700<01`L00PL300H70`0J1`0500L71`00
0PL300L700<01`000`L01@071`L0058700161`<04`L00`071`061`<01@L00`071`091`0300L700L7
0P021`0300L000801@L401d700<01`L010091`0500L71`000PL200<700<01`L0C`L004<70`0E1`03
00L700@70`071`0300L700T700<01`L020L200031`00008000@700L70`0P1`0300L0008030L00`07
1`021`0300L700800PL00`071`1?1`00@@L201L700<01`L00PL300X700<01`L02@L00`071`081`<0
0`L00`07000202870`000`L01`0;1`0300L700@700D01`0700021`0300L704h700101`0300L001L7
00<01`000P0<1`0300L700T700<01`L01PL300870P001PL0000702070`031`0300L700X700<01`L0
1PL00`07000200031`0704l700101`0400L001D70`0>1`0300L700T700<01`L00`L400D70`031`03
00L001/710021`0400L700`700<01`L01PL500041`0704l7000o1`0400L71`8040L4010700<01`L0
2PL00`071`0300H70`000`L000041`8060L300D700@01`L03@L00`071`031`<00`L2008700<01`00
CPL003h700<01`L00`L00`071`0;1`<00PL00`071`0?1`0300L700T710061`@000<700L00`031`03
00L001@70`071`0500L71`0030L010071`L300D70P0010L01`L204h7000m1`0300L700@70P091`<0
1@L00`071`0>1`0300L700P70`061`<00`L010071`021`0300L700870P0A1`<02PL010071`0<1`D0
1`L02P071`0700L01`1=1`00?@L00`071`051`801@L300L700<01`L03PL00`071`061`@01@L300D7
00H01`L01`021`0300L700870P0=1`<030L010071`0;1`<02PL00`071`021`800PL00`07001<1`00
?0L00`071`061`0400L01`<02@L00`071`0?1`0300L700<70`031`0300L000<01`L010071`021`03
00L7008010L200T70`0>1`0400L700T70`000`L01`0:1`0300L700<70P021`80C0L003/700<01`L0
20L300/700<01`L03`L010071`L300D70`0:1`0500L71`000`L00`071`0200@700<01`L010L30107
00D01`L700061`<00`L00`071`091`0300L700D70P021`80B`L003X700<01`L02@L200031`0700T7
00<01`L03PL00`07000200D70`0=1`0400L700D700<01`L00P041`0300L700<04`L010071`041`<0
1@L00`071`091`0300L700L700@01`L70P000`L000171`00>PL00`071`091`800PL00`071`061`03
00L700h70`051`<00PL00`071`0:1`0400L700L700D01`0700031`<05@L010071`021`<020L00`07
1`081`0300L700T700<01`L010000`L01`151`00>@L00`071`091`0400L7008700<01`L010L00`07
1`0;1`D010L300@700<01`L02PL01@071`L000P700<01`0010000`L01`0D1`0400L71`<02PL00`07
1`091`0300L700T70`021`8000<700L0A@L003P700<01`L02@L00`071`021`0300L000H700<01`L0
20L300<700<01`L00`061`0300L700X700D01`L7000:1`@000D700L7000C1`0300L0008030L00`07
1`091`0300L700L70`000`L01`021`0500L71`00A@L003P700<01`L020L00`071`031`0400L700@7
00<01`L01PL300D710081`0300L700/700@01`L020L300031`0000@00PL00`071`0?1`<000<700L0
30L00`071`081`0300L700@710051`0500L01`000PL00`071`131`00=`L00`071`091`0300L700@7
00@01`L00PL00`071`041`<01PL300/700<01`L02PL010071`061`<01@L200031`0000870P0<1`D0
0PL00`071`0;1`0300L700T700@01`L70`061`8000<700000`L010071`141`00=PL00`071`091`03
00L700H700<01`L00P041`<01PL300031`0700X700<01`L02PL01@071`L0008710071`<00PL20087
0P081`<00`L01@071`L000`700<01`L02@L00`07000200H710000`L01`0200870P021`0300L70447
000e1`0300L700T700<01`L01`L01P071`L01`<01@L400<700<01`L02@L00`071`0;1`0300L700@0
2PL00`071`0200870P021`8010L300H700@01`L030L00`071`091`<01PL300<700D01`L01`020087
0P000`L01`121`00=@L00`071`081`0300L700T700<01`000`0010L01`L300L700<01`L020L00`07
1`0;1`0300L000803@L010071`L200071`0000L01`0400P700@01`L03@L00`071`061`<01PL300D7
00<01`L00P0010L01`021`8000<700L0@@L003@700<01`L02@L00`071`081`<00`L00`07000200T7
00<01`L02@L00`071`0:1`<000<700L030L00`071`031`0500L700L0100:1`0500L71`0030L00`07
1`041`<00PL00`071`0400L700@01`L00PL0200700L01`070P121`00<`L00`071`091`0300L700H7
0`000`L000021`<000<700L020L00`071`091`0300L700P70`031`0300L700/700<01`L01@L00`07
000400031`0700L700D01`L7000<1`0300L700870`041`@02PL01@071`L000<700@01`000PL01007
00111`00<`L00`071`081`0300L700<710041`@00PL010071`071`0300L700T700<01`L01PL30087
00@01`L03@L00`071`051`D000H700L01`071`0400L700`700<01`L00`051`<03@L010071`051`80
00@700L70P000`L01`0o1`00<PL00`071`091`0300L700<01`L200031`0700<700<01`001`L00`07
1`091`0300L700<70`041`0400L700h700<01`L00PL300870P0020L01`0700L01@L010071`0=1`<0
1@L300031`0700`700@01`L01`L200051`0700L00P101`00<@L00`071`091`@02@L0100700L200@7
00<01`001@L00`071`091`0400L71`<01PL01@071`L000d700<01`L00`051`800PL0100700021`05
00L71`000`L00`071`071`@01@L300<700<01`L02`L01@071`L000P70P001@L000070080?`L00307
00<01`L020L300`700@01`L00PL00`071`021`8010L00`071`091`0300L000802@L010071`0=1`@0
1`L01P07000700870P021`0400L7008700<01`L01@L3008700@01`L70`051`0300L700/700D01`L7
00091`L000<70000?PL0030700<01`L01@L400d700P01`L01`0700D70P031`0300L700L7100;1`04
00L700`70`091`0400L71`8000@700L70P0010L01`021`0300L700<70`051`@01`L00`071`0<1`04
00L700L70`001@L0000700800PL00`071`0l1`00;`L00`071`031`<00`L00`071`0:1`0400L70087
00@01`L01@L200031`0700H70`000`L01`0;1`0400L700X70`000`L01`091`0300L700870P001@L0
1`L0008700@01`L00`L300H70`0:1`0300L700/700@01`L01@L300D700@01`L70P021`0300L703/7
000^1`0400L71`<01@L00`071`0:1`0500L71`000`L010071`051`801@L300<700<01`L02PL01@07
1`L000L70`031`0300L700P700<01`L00`L0100700021`<000<700L010061`@02`L00`071`0;1`06
00L71`0710071`0300L000870P021`80?0L002d700<01`000P071`0300L700/700@01`L01@L00`07
00051`800PL300D700<01`L02`L010071`051`<01@L00`071`081`0300L700D700@01`000PL20004
1`0000D710021`0300L700T700<01`L030L00`071`0300X700D01`L700021`800PL00`071`0j1`00
;0L300X700<01`L02PL010071`071`0300L000@710081`0300L700X700@01`L00PL400L700<01`L0
2@L00`071`051`0400L70087100010L01`L300H700<01`L020L00`071`0<1`@03@L010071`L20087
0P021`0300L703T7000X1`D02`L00`071`0:1`0500L71`0020L0100700L300031`0700L700<01`L0
2PL010071`L300/700<01`L020L00`071`071`0300L000800PL200041`0000P700<01`L02@L00`07
1`0:1`<000<700L030L00`071`031`0300L700<000<70000>PL002D70`031`0300L700T700<01`L0
2PL01@071`L000X710001@L01`L000H700<01`L02PL00`07000200d700<01`L020L00`071`071`<0
00<700000PL300031`0700L700<01`L02@L00`071`081`@00`L00`071`0:1`0300L700D700<01`L0
0`000`L0000i1`008PL300H700<01`L020L00`071`0;1`0400L700P7100010L000L200031`0000@7
00<01`L02PL300031`0700`700<01`L02@L00`071`031`@00PL00`07000300051`001`0020L00`07
1`081`0300L700H70`031`0400L700`700<01`L01PL400061`0700L0>0L001l70`081`0300L700T7
00<01`L02PL010071`061`<010L200<700<01`L00P031`0300L700L710021`0300L700/700<01`L0
2@L010071`L300H70`000`L01`021`0400L700H700<01`L02@L00`071`031`<01@L010071`0=1`03
00L700<70`000`L0000200061`0700L0=`L001`70`0:1`0300L700T700<01`L02PL01@071`L00087
10071`<00PL200870P000`L01`061`<00PL01@071`L000d700<01`L020L00`07000200H710000`L0
1`0200870P021`0300L7008700<01`L02@L010071`L300L700D01`L7000<1`0400L71`<01@L20008
1`0700L01`0f1`006PL200`700<01`L02@L00`071`0;1`0300L700@02PL00`071`0200870P0010L0
00051`<01@L010071`0=1`0300L700P70`061`<00`L01@071`0700800PL200031`07008700<01`L0
2@L00`07000200T700D01`L7000<1`D01`L200031`0000870P021`0300L703<7000K1`0300L700X7
00<01`L020L00`071`0;1`0300L000803@L01@071`L000<70P000`L000021`<01`L010071`0=1`03
00L700H710051`<01@L00`071`0200870P021`8000D700L700091`@030L010071`0;1`<02PL00`07
1`0200041`071`8000<700L0=0L001/700<01`L02@L00`071`091`0300L700X70`000`L01`0<1`03
00L700<700D01`L01`0500T700D01`L7000<1`0300L700@70`021`0300L700@01`L010071`021`08
00L01`0700L200031`0700H70`000`L01`0<1`0400L700T70`000`L01`0:1`0400L71`8000D700L7
00021`0300L70387000L1`0300L700L700<01`L02@L00`071`081`<00`L00`071`0;1`0300L700D7
00<01`L010000`L01`071`0500L71`003@L010071`L300@7100:1`0500L71`000`L0100700021`80
00<700L010L300<700<01`L02`L01@071`L000H70`031`0300L700T700<01`L00PL0100700021`80
0PL00`071`0a1`007@L00`071`061`0300L700P700<01`L01PL3008700@01`L03@L00`071`061`@0
00H700L01`071`0400L700d700<01`000P051`<03@L010071`051`8000@700L70P000`L01`0300D7
00<01`L030L010071`041`<01@L00`071`091`0300L700@700@01`000PL200031`000387000M1`03
00L700D700<01`L02@L00`071`031`<010L010071`0>1`0300L700<70`000`L01`0200031`000087
00<01`L00`L010071`0=1`<01@L300031`0700`700@01`L01`L200031`0700D020L00`071`0;1`04
00L700870`081`0300L700P700<01`L01@L010071`021`@000<700L0<0L001h700<01`L00`L00`07
1`091`0400L71`<01PL01@071`L000d700@01`L70`051`0500L700L00P021`0500L71`000`L00`07
1`071`@01@L300<700<01`L02`L01@071`L000P70P001@L0000700801`L00`071`0;1`0300L700@0
2PL00`071`091`0300L700H700<01`000P021`8000<700L0<0L001h700<01`L00PL00`071`091`03
00L000802@L010071`0=1`D01`L300041`071`800PL010071`021`0300L700D70`031`0300L700<0
1@L00`071`0;1`0500L71`002@L700031`0000D700<01`L02`L00`07000200`700<01`L02@L00`07
1`061`<000<700000PL2008700<01`L0;PL001l700D01`L700091`@02`L010071`0<1`<02PL00`07
1`0200051`071`000PL00`0700021`0300L700<70`051`@020L00`071`0;1`0400L700L70`001@L0
000700800PL00`071`021`0300L700/70`000`L01`0;1`0300L700T700<01`L010L3008700L01`L0
1`07008000<700L0;`L0020700<01`001`L300031`0700/700@01`L02PL300031`0700X700@01`L7
0P001@L01`L0008700@01`L00`L300H70`0:1`0300L700/700@01`L01@L300D700@01`L70P000`L0
00031`0300L700L71@021`0300L700/700<01`L02@L010071`L300D70P021`0500L71`000PL00`07
1`0]1`0080L200D70`031`0300L700X700D01`L700071`<00`L00`071`091`0300L700870P0010L0
1`L300031`0700@01PL400/700<01`L02`L01P071`L01`@01`L00`0700021`800PL010071`071`<0
0`L010071`0=1`0300L700T700<01`000P051`@000<700L00P021`800PL00`071`0/1`0080L20087
0`051`0300L700/700@01`L01@L300D700<01`L02@L00`071`041`8000@700L70P0010L000051`@0
0`L00`071`091`0300L700/700<01`L00`0:1`0500L71`000PL200870P051`<01@L01@071`L000`7
00<01`L02@L300D70`031`0500L700L00P021`8000<700L0;@L0020710081`0300L700X700@01`L0
0`L300P700<01`L020L00`071`051`0400L00087100010L01`L300H700<01`L02@L00`071`0;1`@0
3@L010071`L200870P000`L000021`<020L010071`0=1`0300L700H70`051`<01@L00`071`020087
00P01`L01`0702d7000O1`8000<700L01`L00`071`0:1`0400L71`@02PL00`071`091`0300L700H7
00<01`000P001@L0000700<020L00`071`091`0300L700X70`000`L01`0<1`0300L700<700<01`L0
1`0:1`0400L700d700<01`L010L3008700<01`L00`071`0400L7008700@01`000PL01007000]1`00
80L010071`061`0300L700X700<01`L00`0<1`0300L700T700<01`L01PL300031`0000870`000`L0
1`071`0300L700T700<01`L020L400<700<01`L02PL00`071`041`800PL300031`0000T700D01`L7
000<1`0300L700<70P041`@02@L01@071`L000<700@01`000PL200031`0702/7000P1`8000<700L0
10L00`071`0;1`@03@L00`071`091`0300L700<710021`0300L000<000D7000700081`0300L700T7
00<01`L01@L300<700@01`L030L00`071`061`@000<700L00P081`0500L71`0030L010071`L300@7
0`0<1`0400L700D70P0020L01`0700L0:`L0024700@01`L010L00`071`071`@00PL00`071`0<1`03
00L700T700<01`L00`061`<000@700L70P021`0300L700@700<01`L02@L00`071`031`<01@L01007
1`0=1`0300L700<70`000`L0000200031`0700801`L010071`0=1`@010L400d700@01`L01`L20005
1`0700L00P0[1`008@L2008700@01`L01`L3008700D01`L7000=1`0300L700T710061`@000@700L0
0`L2008700<01`L00PL00`071`091`0400L71`<01`L01@071`L000`700@01`L70`041`<000D700L0
1`0200D700@01`L030L300@70`031`0300L700X700D01`L700081`8000D700001`0202X7000R1`80
00@700L01@L300D700@01`L03@L00`071`081`<01PL300<700H01`L01`031`8000<700L00PL00`07
1`0:1`@02@L01@071`L000`700<01`000P071`8000<700000PL200031`07008700D01`L700091`@0
0`L300D700<01`L02PL01@071`L000T7100010L01`L202T7000S1`8000<700L00PL300L700@01`L0
3PL00`071`051`@01@L300D700<01`L00P021`0800L700L01`021`0300L700L7100<1`0400L700`7
0`091`0300L7008000@700L70P001@L01`L0008700<01`L01@L3008700<01`L00P071`0300L700/7
00@01`L01`L300031`0000@00PL00`071`0W1`008`L00`07000400T700D01`L7000=1`0300L700<7
0`031`0300L000<01`L010071`021`0400L0008700H01`001`071`<000<700L030L010071`0:1`@0
2`L020071`0700L00PL00`071`02008700<01`L00`L300D70`091`0300L700X700@01`L01@L300D7
00<01`L00`000`L0000X1`0090L400X700D01`L7000=1`0400L71`<01@L300X700D01`L700031`0:
00L000L01`0700D70`041`0300L700X700D01`L700071`<00PL00`071`091`0300L7008700@01`00
0PL200051`071`000`L300D70`0;1`0300L700X700D01`L700021`<01`L00`0700021`800PL00`07
1`0V1`0090L01@0700L000T700@01`L03@L00`07000200D70`0=1`0400L700D70P002@L01`0700L0
1`0300H700<01`L02`L010071`051`<010L00`071`091`0300L700<700<01`L00P021`8000<700L0
10051`<000<700L02PL00`071`0;1`0300L700@02@L01@071`L000870P021`0300L702D7000U1`04
00L000P700@01`L03@L300D70`000`L01`0<1`0400L700L70P000`L01`0500P700<01`L02`L01007
1`031`<01`L00`071`081`0300L700D700@01`L00`L00`07000200D70`031`0300L700T700<01`L0
2`L00`07000200`700@01`L70P021`800PL00`071`0T1`009PL0100700061`0500L71`002@L500@7
0`041`0300L700X700D01`L700081`H000<700001`L00`071`0;1`0400L700870P091`0300L700T7
00<01`L01PL01@07000700@000@700L70`061`0300L700T700<01`L02PL400d700<01`L00`L00`07
1`0300031`0002D7000V1`0300L700801@L010071`071`<00`L00`071`0300H700<01`L02PL01@07
1`L000T7100010L01`L200H700<01`L02PL010071`L300X700<01`L02@L00`071`071`0300L00080
0PL200041`0000P700<01`L02@L00`071`081`<00`L00`071`0:1`0300L700@70P021`0400L01`80
90L002L700@01`L010L010071`051`<01@L400P700<01`L02`L010071`071`<000<7000010021`03
00L700<700<01`L02`L400`700<01`L02@L00`071`071`<000<700000PL300031`0700L700<01`L0
2@L00`071`061`<00PL010071`0=1`0300L700D70P0010L000L302@7000X1`0400L7008700@01`L0
0`L300H70`0;1`0300L700X700@01`L01@L300D700<01`L00P021`800`L00`071`0:1`<000<700L0
30L00`071`091`0300L700<710021`0300L000<00PL010071`071`0300L700P700<01`L01@L200@7
00@01`L03@L00`071`061`D000<700L00P0S1`00:0L00`071`0300<710061`<000<700L02PL00`07
1`0:1`0500L71`000PL300L700<01`000PL2008700D01`L700091`@00PL00`071`0;1`0300L700T7
00@01`L70`061`<000<700000PL200031`0700D700<01`L02@L00`071`021`<01@L01@071`L000`7
00<01`L010L300091`0700L01`0700808PL002T700<01`L00P021`801@L400<700<01`L02@L00`07
1`0;1`0300L700@02@L01@071`L000870P021`0300L000L70`021`0500L71`0030L00`071`091`03
00L000801PL400031`0700<00PL200031`0700<700<01`L02@L00`071`0300L700D01`L7000=1`04
00L71`<01@L01P0700L01`8000<700L080L002T700<01`L00P0010L01`021`<01PL00`071`091`03
00L700/700<01`000P0<1`0400L71`8000@700000PL00`071`031`<01@L010071`0=1`0300L700P7
0`061`<00`L010071`021`0500L700L00P031`0300L700T7100:1`0400L700d71@071`0600L000L0
0PL200031`0701l7000Z1`8000D700001`0300T700<01`L02@L00`071`0:1`@03@L00`071`031`03
00L700H000@700001`L010071`0=1`0300L700H710051`<01@L01`071`0700L00P021`0400L00087
00<01`L01`L300`700@01`L030L300X700P01`L01`07008700@01`L07`L002X70P021`<000<700L0
20L00`071`091`0300L700P70`031`0300L700X700<01`L010L2008700<01`000`091`0500L71`00
30L00`071`041`<00PL00`071`0400L700@01`L00PL00`071`0200870P000`L000071`<000<700L0
2`L01@071`L000T7100<1`0600L71`070P031`0300L001l7000Z1`@000D7000700081`0300L700T7
00<01`L01PL3008700@01`L030L00`071`061`8000D700001`0200P700D01`L7000<1`0300L70087
0`041`@02PL01@071`L000<700P01`0700L01`801@L300<700<01`L02`L010071`071`<00`L00`07
1`091`0300L7008700<01`L00P031`0300L001h7000Y1`8000@700L70P021`0300L700D700<01`L0
20L00`071`051`8010L010071`0=1`0300L700H71@000`L01`0200L700@01`L03@L00`07000200D7
0`0=1`0400L700D700H01`0700L400041`0000D700<01`L02`L010071`051`<01@L00`071`091`03
00L700@700<01`L00P021`0400L001d7000X1`0500L01`000`L2008700<01`L00`L00`071`091`03
00L700870`051`0500L71`0030L00`071`041`<000T700L01`0700L00P051`0400L700d70`051`<0
00<700L030L010071`071`0600L01`0710081`0300L700X700@01`L00`L300L700<01`L02@L00`07
1`061`0500L000L0100N1`00:0L01P071`0700<70P000`L01`031`0300L700T700<01`L00`071`05
00L71`0030L00`071`021`<01@L01P0700L01`8000<700L00PL01@071`L000T710051`<00`L00`07
1`0;1`0400L700T70P0010L000021`0300L700D700<01`L02PL010071`L400X700<01`L02@L00`07
1`061`0300L000800PL201h7000W1`0300L700800PL020071`0700L00PL00`071`091`@02PL01007
1`0=1`D01`L01P07000700870P001@L01`L0008700<01`L01@L3008700@01`L70`051`0300L700/7
00D01`L700091`L00PL00`071`031`0300L700/700<01`000P0<1`0300L700T700<01`L01PL30087
0P0010L0000M1`009PL010071`021`0300L000<700@01`000PL00`071`071`<030L010071`0<1`<0
2PL020071`0700L00PL00`071`02008700<01`L00`L300D710081`0300L700/700@01`L01`L30087
0P000`L000021`800`L00`071`0;1`@03@L00`071`091`0300L700<710021`0400L71`800PL201`7
000U1`0500L71`000`L00`0700021`0400L01`801`L300031`0700/700D01`L700091`@030L01P07
1`L01`800PL200051`071`000`L300H70`0:1`0300L700/700@01`L01@L300D70P021`800PL01@07
1`L000T710021`0300L700/700<01`L02PL00`071`0300H70P021`800PL00`07000K1`009@L01007
1`051`800`L00`07000200@70`031`0300L700/700@01`L01`L3008700<01`L02PL00`071`021`03
00L700800PL200031`0700@01PL400/700<01`L02`L010071`021`@01`L0100700021`800PL00`07
00071`<00PL01@071`L000d700<01`L02@L400H710031`<00PL201/7000T1`0400L700L70P031`@0
00@700001@L00`071`0;1`0400L700D70`051`0300L700T700<01`L010L00`071`02008700<01`00
0P051`@00PL00`071`091`0300L700`700<01`L00`0:1`0500L71`000PL200<700<01`L00`L300D7
00@01`L03@L00`071`081`<01PL300<700@01`L00PL01P071`0701X7000S1`0500L71`0020L20087
1@081`0300L700X700@01`L00`L300L700<01`L02@L00`071`061`0500L000L0100010L01`L300H7
00<01`L02@L00`071`0;1`@03@L00`071`021`0300L7008000D700001`0300L700@01`L03@L00`07
1`061`@01@L300D700@01`L010L01P071`0701T7000R1`0500L71`002@L200870P021`801PL00`07
1`0:1`0400L71`@02@L00`071`0:1`0300L700H700<01`000P021`8000@7000020L00`071`091`03
00L700X70`000`L01`0<1`0300L700<70P000`L0000500T700D01`L7000=1`0300L700<70`031`03
00L000<01`L010071`051`800PL00`07000H1`008PL010071`0;1`<000<700000PL00`071`031`03
00L700/700<01`000P0;1`0300L700X700<01`L01PL300051`0000L00`000`L01`071`0300L700T7
00<01`L020L4008700<01`L02`L00`071`051`8000D700001`0200P700D01`L7000=1`0400L71`<0
1@L300X700D01`L700061`8000D700L7000G1`008@L010071`0=1`8000<700000PL200<700<01`L0
2`L400d700<01`L02@L00`071`031`@00PL00`070003008700@01`L01`L00`071`081`0300L700H7
0`031`0400L700`700<01`L01PL500031`0700801`L010071`0=1`0300L000801@L300d700@01`L0
20L200051`071`005PL0020700D01`L7000=1`800PL2008700D01`L700091`@00PL00`071`0;1`03
00L700T700@01`L70`061`<000<700000PL200031`0700D700<01`L02@L00`071`031`<01@L01007
1`0=1`0300L700<70`000`L01`02008700@01`001@L010071`0=1`<01@L3008700<01`L02PL01007
1`091`0500L01`000PL00`071`0C1`0080L010071`0=1`0400L7008700L01`L700L000L70`021`05
00L71`0030L00`071`0:1`@01PL400031`0700<00PL200031`0700<700<01`L02@L010071`L300L7
00@01`L03@L010071`L300D70P0010L01`L200031`07008700D01`L700091`D010L300@700<01`L0
2PL01@071`L000X710021`0300L701<7000O1`0400L700d700@01`L70P000`L000031`0300L700<7
0`051`0400L700d700<01`L020L300H70`031`0400L7008700D01`L01`0200<700<01`L02@L00`07
000200X700<01`003@L500L700`01`001`0700L01`021`0400L700L70`031`0300L700<01PL00`07
1`0:1`0500L71`002PL400051`071`0050L001h700@01`L03PL00`071`021`0300L7008000D70000
1`0300L700@01`L03@L00`071`061`@01@L300D700H01`L01`021`0500L700L00P021`0300L700L7
100<1`0400L700/70`0:1`0500L700L00P021`0400L01`800PL00`071`031`<01@L400P700<01`L0
2`L010071`081`<00PL400<700<01`L04@L001d700D01`L7000=1`0300L700<70P000`L0000500T7
00D01`L7000<1`0300L700@70`021`0300L700@01`L010071`021`0300L700800PL200031`0000L7
0`000`L01`0<1`0400L700T70`000`L01`0:1`0600L71`070P021`8000D700L700031`<01PL300/7
00<01`L02PL010071`061`<01@L200031`0000<700<01`L040L001d700@01`L03@L00`071`051`80
00D700001`0200P700D01`L7000<1`0300L700870`051`<02PL01@071`L000<700<01`L00P000`L0
1`0200D70`031`0300L700/700@01`L01`L300<700<01`L02@L00`071`021`0300L700800PL20003
1`0700@01PL300031`0700X700<01`L02PL01@071`L0008710071`0300L000870P031`0300L700l7
000L1`0400L700d700<01`L01`L400031`0700801`L010071`0=1`0300L000801@L300d700@01`L0
1@L00`071`0200031`00008000@700001@L00`071`0<1`0300L000D70`051`0300L700T700<01`L0
10L010071`031`D01@L400<700<01`L02@L00`071`0;1`0300L700@02PL01@071`L0008700<01`L0
0PL00`071`0>1`006`L01@071`L000d700<01`L01`L0100700021`0400L000D700@01`L03@L300D7
0`000`L01`0<1`0400L700L700H01`0700L400P700<01`L02`L010071`021`<020L00`071`081`03
00L700H700D01`L01`0400041`071`<01`L00`071`081`0300L700/700<01`000P0=1`0300L70087
00@01`0010L00`071`0=1`006PL01@071`L000d700<01`L02@L0100700021`8000<700L00PL01@07
1`L000T710051`<00`L00`071`0;1`0500L71`0020L00`070003008700<01`L01@L00`071`0;1`03
00L700@02PL00`071`091`0300L700H700<01`000P031`0300L000802@L00`071`091`0300L700X7
0`000`L01`0<1`0300L700<700@01`L010L00`071`0=1`006PL010071`0=1`0300L700T700`01`00
1`0700L01`021`0400L700L70`021`0400L71`<01PL00`071`0:1`0500L71`002@L7008700<01`L0
0`L00`071`0;1`0300L0008030L00`071`091`0300L700H70`000`L000021`<000<700L020L00`07
1`091`0300L700P70`031`0300L700/700<01`L01@L0100700041`0300L700`7000I1`0400L700h7
00<01`L020L01@071`0700800PL200870P021`0300L700<70`051`@020L00`071`0;1`0400L700L7
0`021`8000<700000PL200<700<01`L02`L400h700<01`L020L00`071`031`@00PL00`0700030087
00@01`L01`L00`071`091`0300L700H70`021`0400L700d700<01`L01@L400H700<01`L02`L001P7
00D01`L7000=1`0300L700T700H01`L700L200870P001@L01`L000<70`061`<02PL00`071`0;1`04
00L700D70`051`<000<700000PL01@071`L000T71@021`0300L700/700<01`L02@L00`071`0300H7
0`000`L000031`0300L000L700<01`L02@L00`071`031`<010L010071`0>1`0300L700870`021`80
1`L00`071`0:1`0060L010071`0=1`0300L700T700<01`L00PL00`071`0200870P000`L01`0400H7
100;1`0300L700/700H01`L700L400L700@01`000PL2008700<01`001`L300<700@01`L03@L00`07
1`091`@01PL400031`0700<00PL200031`0700@700<01`L02@L010071`L300H700D01`L7000=1`03
00L700<01@L200P700<01`L02@L001L700@01`L03@L00`071`091`0300L700@700@01`L00`L00`07
000200D710021`0300L700X700<01`L02`L00`071`0300X700@01`L70P000`L000031`0300L700<7
0`061`0300L000d700<01`L020L300H70`031`0400L700870P021`<010L00`071`091`0300L00080
2@L010071`0=1`@01`L00`0700091`0300L700P7000F1`0400L700h700<01`L020L00`071`061`05
00L000L0100010L01`L300H700<01`L02@L00`071`0;1`@03@L00`071`021`8000@700070`0010L0
00081`0300L000h700<01`L01@L400D70`051`0:00L700L01`0700870`031`0300L700L7100;1`04
00L700`70`091`0500L71`0020L00`071`081`005@L01@071`L000d700<01`L02@L00`071`061`03
00L000800PL200041`0000P700<01`L02@L00`071`0:1`<00PL00`071`0:1`0300L700@700<01`00
1P0:1`0400L700d700<01`L00`L300<700<01`L00`071`0400L7008700T01`L01`0700L00P000`L0
1`061`<000<700L02`L010071`0:1`<000<700L02@L00`071`021`0300L700H700<01`L01`L001D7
00@01`L03@L00`071`091`0300L700H70`000`L000021`<000<700L01`L00`071`091`0300L700P7
10031`0300L700X700<01`L01PL00`07000200031`0000T700@01`L03@L010071`L300D710091`05
00L71`000`L00`071`02008700@01`001@L300<700<01`L02PL01@071`L000L70`031`0300L700P7
00<01`L00`L00`071`071`0300L700H7000D1`0400L700h700<01`L020L00`071`031`@00PL00`07
0003008700@01`L01`L00`071`091`0300L700D70`031`0400L700`700<01`L01PL500031`070080
20L00`07000=1`0300L000801PL300`700@01`L01@L01@0700L000870`021`<01@L00`071`0;1`04
00L700D70`051`0300L700P700<01`L01@L00`071`061`801`L001<700@01`L03PL00`071`081`04
00L71`<01PL300031`0000870P000`L01`051`0300L700T700<01`L00`L300D700@01`L03@L00`07
1`031`<00PL3008700@01`001PL00`07000=1`<01PL300031`0700/700@01`L01`L01P0700L01`D0
20L00`071`0:1`0400L7008710071`0300L700T700<01`L01@L00`071`031`@020L0018700D01`L7
000=1`0300L700T710061`@000<700L00`021`8000<700L00`L00`071`091`0400L71`<01`L01@07
1`L000`700@01`L70`051`8000@700L70P000`L01`031`0400L700T71@051`<00`L00`071`0:1`05
00L71`0020L0100700L300031`0700L700<01`L02PL010071`L300/700<01`L020L00`071`071`03
00L000800`L00`071`061`004PL010071`0=1`0300L700P70`061`<00`L010071`021`0500L700L0
0P031`0300L700T700<01`000P0:1`0400L700`71@071`0<00L000L01`0700L00`L00`0700071`<0
0`L00`071`0400D700<01`L02PL01@071`L000X71`000`L01`051`0300L700X700<01`000P0=1`03
00L700P700<01`L01`L300D700<01`L01`L0014700@01`L03PL00`071`051`@01@L300D700L01`L0
1`0700800PL0100700021`0300L700L7100<1`0400L700/70`0:1`0400L71`<00PL02@0700L01`07
00051`<01PL300P700<01`L02`L010071`081`@000@700070P000`L000041`0300L700X70`000`L0
1`0<1`0300L700T700<01`L00`L4008700<01`L00PL00`071`081`0040L01@071`L000d700<01`L0
0`L3008700<01`L010071`0400L7008700<01`L00P021`0300L000801`L300031`0700`700@01`L0
2@L300031`0700X700<01`L00PL300870P001@L000L000<70`061`<02`L00`071`0:1`0400L700H7
0`041`800`L200031`0000<700<01`L01`L4008700<01`L02`L00`071`091`0400L71`<01PL20087
00<01`L02@L000l700D01`L7000=1`0400L71`<01@L300X700D01`L700031`0300L7008000D700L7
00051`<00`L00`071`0;1`0500L71`001PL300<700<01`L02@L00`071`031`0400L0008710000`L0
000200H70`000`L01`0:1`0300L700X700D01`L700021`@01`L300870P021`8000<700L01PL30087
00D01`L7000=1`0300L700P700<01`000P061`@00`L00`071`091`003`L010071`0=1`0300L00080
1@L300d700@01`L01@L01P0700L01`@000@700001@L00`071`0<1`0400L700@70`051`0300L700T7
00<01`L01@L00`0700031`D01PL300<700<01`L02@L00`071`0;1`0300L700@02PL00`071`020087
0P0010L000051`<01@L010071`0=1`0300L700P70`061`<00`L010071`0<1`003PL010071`0=1`<0
1@L300031`0700`700@01`L01`L01P0700L01`@020L00`071`0;1`0400L700870`081`0300L700T7
00<01`L01@L01@071`0700@000<700L00PL300H700<01`L020L00`071`0;1`0300L000803@L01@07
1`L000<70P000`L000021`<01`L010071`0=1`0300L700H710051`<01@L010071`0=1`003@L01@07
1`L000T71@041`<00`L00`071`0;1`0500L71`0020L00`070003008700<01`L01@L00`071`0;1`04
00L71`<02PL00`071`091`0300L700L71@021`0300L000<020L00`071`091`0300L700X70`000`L0
1`0<1`0300L700<700<01`L01`091`0500L71`0030L00`071`041`<00PL00`071`0400L700@01`L0
3PL000d700@01`L01`L300<700<01`L00`061`0300L700X700D01`L700091`L00PL00`071`031`03
00L700/700<01`000P0<1`0300L700T700<01`L01PL400041`071`D02@L00`071`091`0300L700P7
0`031`0300L700/700<01`L01@L00`071`0400031`0700L700D01`L7000=1`0400L71`<010L400X7
00D01`L7000>1`0030L010071`051`<01PL300P700<01`L02`L010071`071`<000D700L01`020087
0P031`0300L700/70`000`L01`0<1`0300L700T700<01`L00`L300<700<01`000`001@L01`L000P7
00<01`L020L00`071`061`<00PL010071`0=1`0300L700H710001PL01`0700L700@01`L03@L00`07
000200D70`0=1`0400L700l7000;1`0400L700<70`061`<02PL00`071`0;1`0400L700D70`051`80
0PL200870P021`0300L700L71@021`0300L700/700<01`L02@L010071`L300H71@031`0300L000L7
00<01`L02@L00`071`031`<010L010071`0>1`0300L700<70`000`L01`0200031`00008700<01`L0
0`L010071`0=1`<01@L300031`0700`700@01`L040L000X700@01`L710061`<000<700L02@L00`07
1`0;1`0500L71`000PL300L700@01`000PL200870`071`<00`L01@071`L000`700<01`L02@L00`07
000200H710000`L0000200870P000`L01`041`0300L700T700@01`L70`061`0500L71`003@L01007
1`L300D700D01`L01`02008700D01`L700031`0300L700L710051`<00`L00`071`0;1`0500L71`00
40L000X700<01`L00P051`@00`L00`071`091`0300L700/700<01`L010091`0400L71`8000<70000
0PL200D70`061`0400L700`700<01`L02@L300H70`031`0500L000L00P021`<010L00`071`091`03
00L000802@L010071`0=1`D01`L300041`071`800PL010071`021`0300L700D70`031`0300L700<0
1@L00`071`0;1`0500L71`004@L000T700<01`L00PL00`071`0300L700<01`L020L00`071`0;1`03
00L0008030L00`071`021`0300L7008000D700001`0300P700@01`L03@L00`071`061`@01@L300D7
00T01`0700L01`000PL300<700<01`L01`L400/700@01`L030L300X700<01`L00P001@L01`L00087
00<01`000PL00`071`031`<01@L400P700<01`L02`L010071`0B1`0020L00`071`031`<02@L00`07
1`081`0300L700/70`000`L01`0;1`0300L700@700<01`001P0:1`0500L71`0030L00`071`031`@0
0PL00`071`0400L700@01`L00PL0200700L01`070P000`L01`061`<000<700L02`L010071`0:1`<0
00<700L02PL010071`L200051`071`000PL010071`031`<01PL300X700<01`L02`L010071`0C1`00
1`L010071`L300031`0700P700<01`L020L00`071`091`<00`L00`071`0:1`0300L700H700<01`00
0P0010L01`081`0500L71`0030L010071`L300D7100:1`0400L700@700@01`000PL0100700051`<0
0`L00`071`0:1`0500L71`001`L300<700<01`L02@L00`071`021`8000@700L70`000`L01`0400H7
100;1`0300L700/700D01`L7000C1`001`L400D700<01`L01PL00`071`081`0300L700D710021`04
00L700d700<01`L01@L500061`0700L01`L010071`0<1`0300L000801PL300d700<01`001PL20004
1`071`<00PL300D700<01`L02`L010071`051`<01@L00`071`091`0300L700@70P0010L01`L20004
1`0000D710031`0300L700T700<01`L02`L010071`0D1`001PL200P700<01`L01@L00`071`081`03
00L700<70`051`0400L700d700<01`L00`L300870`0010L01`021`0300L700<700@01`L030L300H7
0`000`L01`0<1`0400L700L70P000`L01`0500P700<01`L02PL010071`031`<020L00`071`081`03
00L700D700@01`000PL400041`071`<01PL00`071`091`0300L700/700@01`L05@L000L700<01`L0
1`L00`071`031`0300L700P700@01`L70`071`0500L71`0030L010071`L300D70P001PL01`070087
00D01`L700031`0300L700L710051`<00`L00`071`0;1`0400L700T70P001PL0000700P700<01`L0
2PL010071`L400X700<01`L02@L00`071`061`0300L0008000D700001`0300P700<01`L02@L00`07
1`0;1`0400L701H700081`0300L700H700<01`L00PL00`071`081`0300L000802PL010071`0=1`@0
1`L02P07000700L01`021`0400L7008700<01`L01@L3008700@01`L70`051`0300L700/700@01`L0
2PL700031`0700D700<01`L02PL00`071`0300`700<01`L02@L00`071`061`<000<700000PL30003
1`0700L700<01`L02@L00`071`0;1`0500L71`005PL000T700<01`L01PL01@071`L000T70`0<1`04
00L700/70`0:1`0400L71`<00PL2008700<01`000PL00`071`031`<01@L400P700<01`L02`L00`07
00081`<000D700001`0200031`0000@700<01`L02`L400d700<01`L02@L00`071`031`@00PL00`07
000300051`001`0020L00`071`091`0300L700/700@01`L05`L000T700<01`L01`L00`0700071`@0
3@L010071`091`<000<700L02PL00`071`021`<00PL2008700@01`L00`L300H70`0:1`0300L700/7
00@01`L01@L300D700@01`L70P000`L000031`0300L700L710021`0300L700`700<01`L02@L00`07
1`0300H70`0010L01`L2008700<01`L010L00`071`091`0300L700/700@01`L060L000X700<01`L0
1PL200D70`021`0300L700/700D01`L700061`<00`L00`071`091`0300L700<70`031`<000<700L0
10061`@02`L00`071`0;1`0400L7008710071`0300L000870P021`8000<700L01PL3008700D01`L7
000=1`0300L700T710061`@000@700L00`L2008700<01`L00PL00`071`091`0300L700/700D01`L7
000H1`002`L00`071`051`800PL300@700<01`L030L010071`041`<01PL00`071`081`0300L700D7
0`031`8000@700001@L4008700<01`L02PL00`071`0;1`0300L000<02PL01@071`L000870P0010L0
00051`<01@L010071`0=1`0300L700P70`061`<00`L01P071`0700<70P000`L01`021`0300L700X7
00<01`L02PL01@071`L001T7000<1`0300L700@710071`0300L700/700@01`L00PL300P700<01`L0
2@L00`071`051`0400L00087100010L01`L300H700<01`L02@L00`071`0;1`@03@L010071`L20087
0P000`L000021`<01`L010071`0>1`0300L700D710051`<01@L00`071`02008700P01`L01`070087
00<01`L02@L00`071`0;1`0400L701X7000=1`0300L700870P000`L01`061`0300L700/700@01`L7
0`0:1`0300L700T700<01`L01`L00`07000200051`0700L00`081`0300L700T700<01`L02PL30003
1`0700`700<01`L00`L00`071`0700T700D01`L7000=1`0300L700<70`031`0300L000<01`L01007
1`021`0400L0008700H01`001`0;1`0300L700/700@01`L06`L000h700<01`L00PL010071`051`03
00L700/700<01`000P0=1`0300L700P700<01`L01`L300031`0700870`000`L01`071`0300L700T7
00<01`L020L4008700<01`L02`L00`071`051`0300L700@000<700L01`L01@071`L000d700@01`L7
0`051`<02PL01@071`L000<700X01`001`0700L030L00`071`0:1`0500L71`006`L000h700<01`L0
0PL200031`0700<700<01`L02`L300031`0700`700<01`L02@L00`071`031`@00PL00`0700030005
1`071`0020L00`071`091`0300L700D70`031`0300L000d700<01`L01PL400061`0700L01`L01007
1`0=1`0300L000801@L300d700@01`L01@L200081`0700L01`0:1`0300L700/700@01`L070L000l7
00<01`L00PL010071`031`0300L700L71@021`0300L700/700<01`L02@L010071`L300H71@021`80
0PL00`071`041`0300L700T700<01`L00`L300D700@01`L03@L00`071`031`<000<700000P000`L0
00021`0300L700<700@01`L03@L300D70`000`L01`0<1`0400L700L70P000`L01`0400T700<01`L0
2`L010071`0M1`0040L010071`L2008700<01`001`L300<700D01`L7000<1`0300L700T700<01`00
0P061`@000@700L00`L2008700<01`L00PL00`071`091`0400L71`<01`L010071`0=1`0400L71`<0
1@L200031`0700800PL01@071`L000<700<01`L01`L500@70`041`0300L700X700D01`L700081`D0
0PL200L700<01`L02`L010071`0N1`004@L010071`L200031`0000D70`061`0400L700d700<01`L0
20L300H70`031`0300L700<00`L010071`031`0300L700X710091`0400L700d700<01`000P071`80
00<700000PL2008700@01`L00PL00`071`051`<00`L00`071`0300H700<01`L02PL01@071`L000T7
100010L01`L200H700<01`L02PL01@071`L001h7000B1`0400L71`@00PL300P700@01`L03@L00`07
1`061`@01@L300D700<01`L00P000`L000021`800PL010071`091`@030L010071`0<1`<02@L00`07
1`0200051`071`000PL00`0700021`0300L700<70`051`@020L00`071`0;1`0400L700L70`000`L0
0004008700<01`L00`L00`071`0;1`0400L701l7000C1`0500L700L0100:1`0500L71`0030L00`07
1`041`<00PL00`071`0400L700@01`L00PL0100700021`8000@700L01`L300031`0700`700@01`L0
2PL400/700@01`L70P001@L01`L0008700@01`L00`L300H70`0;1`0300L700X700@01`L01@L300D7
00<01`L00P021`800`L00`071`0;1`0400L70207000D1`0300L700@02PL01@071`L000d700@01`L7
0`041`@02PL01@071`L000<70P0020L01`0700L01@L300@700<01`L02PL010071`081`<00PL00`07
1`091`0300L7008700@01`000PL300031`0700@01PL300031`0700X700<01`L02PL01@071`L00087
0`071`0300L000870P021`0500L71`0030L010071`0Q1`0050L020071`0700L02@L010071`0=1`03
00L000801@L300d700@01`L01@L200091`0700L01`0700<01PL00`071`0;1`0300L000H70`041`03
00L700T700<01`L010L0100700021`8000@700001@L400<700<01`L02@L00`071`0;1`0300L700@0
2@L01@071`L0008700L01`L700L000`700D01`L7000Q1`005@L01@071`07008020L010071`0=1`<0
1@L300031`0700`700@01`L01`L200031`0700D020L00`071`0;1`0400L700<70`071`0300L700P7
00<01`L01@L010071`021`@000@700L70`061`0300L700T700<01`L02`L00`07000200`700@01`L7
0P000`L000031`0300L700/700@01`L08PL001H700D01`L01`0200H700D01`L700091`@01@L300<7
00<01`L02`L01@071`L000P700<01`000`000`L000071`0300L700/700@01`L00PL200T700<01`L0
2@L00`071`061`0300L0008000D700001`0300T700<01`L02@L00`071`0:1`@03@L00`071`031`03
00L7008000@700002`L010071`0S1`005`L00`0700021`801@L010071`071`<00`L00`071`0300D7
00<01`L02`L01@071`L000T710001PL01`0700H700<01`L02PL00`071`0400X700<01`L02@L00`07
1`061`<000<700000PL300031`0700P700<01`L02@L00`071`081`<00`L00`071`0:1`0300L700@7
0P021`0400L01`802@L01@071`L002<7000H1`0300L0008700<01`L00PL010071`051`<01@L400P7
00<01`L02`L010071`071`<000<700L010000`L000051`0300L700/7100<1`0300L700T700<01`L0
10L3008700<01`000`001@L000L000P700<01`L02@L00`071`061`<00PL010071`0<1`0300L700H7
0P000`L000021`8020L01@071`L002@7000I1`0300L0008700@01`L00PL010071`L300H70`0:1`03
00L700/700@01`L01@L300D700<01`L00P021`800`L00`071`0:1`<000<700L030L00`071`091`04
00L71`<01@L300041`071`800PL00`071`051`0300L700P700<01`L01@L200@700@01`L03@L00`07
1`061`D00`L200L700@01`L09@L001T700<01`000PL300<710061`<000<700L02@L00`071`0;1`05
00L71`000PL300L700<01`000PL2008700D01`L700091`@00PL00`071`0;1`0300L700T700<01`00
0P051`@000<700L00P021`800PL00`071`031`0300L700T700<01`L00PL300D700D01`L7000<1`03
00L700@70`001PL01`0700<70P051`0400L702H7000J1`0300L000870P021`801@L400<700<01`L0
2@L00`071`0;1`0300L700@02@L00`071`0200870P021`0300L000L70`021`0500L71`0030L00`07
1`091`<01@L300<700D01`L01`0200870P000`L01`031`0300L700T700<01`L00`071`0500L71`00
30L00`071`021`<01@L01@0700L0008700<01`000`L01@071`L002H7000K1`800PL200<700<01`L0
0`061`0300L700T700<01`L02`L00`07000200`700@01`L70P0010L000021`0300L700<70`051`04
00L700d700<01`L01PL300D70`051`0300L700800PL020071`0700L00PL00`071`091`@02PL01007
1`0=1`D01`L01P07000700<700<01`000PL010071`0W1`0070L300031`0000870`091`0300L700P7
00<01`L02`L400d700<01`L00`L00`071`0600041`0000L700@01`L03@L00`071`041`<00PL00`07
1`0300L700@01`L00PL0100700021`0400L0008700<01`L01`L300`700@01`L030L300X700P01`L0
1`07008700<01`L00P021`0300L702H7000M1`800PL300031`0700P700<01`L020L00`071`091`<0
0`L00`071`0:1`0300L700@70P021`0300L000<02@L010071`0=1`0300L700<70P041`@02@L01@07
1`L000<700T01`001`0700L00P071`<000<700L02`L01@071`L000T7100<1`0600L71`070P031`03
00L0008700<01`L09`L001d710001@L000L000P700<01`L02@L00`071`061`<00PL010071`0<1`03
00L700H70P001@L00007008020L01@071`L000`700@01`L70`041`<030L010071`051`8000D700L0
1`0300@70`031`0300L700/700@01`L01`L3008700<01`L02PL00`071`021`0300L700800`L01@07
00L002T7000L1`8000@700L70P021`0300L700@700<01`L02@L00`071`051`8010L010071`0=1`03
00L700H71@000`L01`0200L700@01`L03@L400@7100=1`0400L700L70P000`L01`0400041`0000D7
00<01`L02`L010071`051`<01@L00`071`091`0300L700@700<01`L00P021`0400L002X7000M1`03
00L000<70P021`0300L700<700<01`L020L00`071`031`<01@L01@071`L000`700<01`L010L30009
1`0700L01`0700801@L010071`0<1`<010L300<700<01`L02PL01@071`L000P70P000`L0000400P7
00<01`L02PL010071`031`<01`L00`071`091`0300L700H700D01`001`0402/7000N1`0300L000<7
0P000`L01`031`0300L700T700<01`L00`071`0500L71`0030L00`071`021`<01@L0100700021`80
00<700L00PL01@071`L000T710031`<01@L00`071`0:1`0500L71`002@L200041`0000870P061`03
00L700X700@01`L710091`0300L700X700<01`L01PL00`07000200870P0[1`007PL010071`021`05
00L01`000PL00`071`091`@02PL010071`0=1`D01`L200041`0700870P001@L01`L0008700<01`L0
1@L3008700<01`L00P071`0300L700/700@01`L02PL7008700<01`L00`L00`071`0;1`0300L00080
2`L00`071`0:1`0300L700H70`001@L000070080:`L001l700@01`000PL0100700021`0300L700L7
0`0<1`0400L700`70`0:1`0800L700L01`021`0500L01`000PL00`071`031`<01@L300T700<01`L0
2PL010071`081`<00PL200031`0000870P031`0300L700/7100=1`0300L700T700<01`L00`L40087
00@01`070P021`0300L702P7000P1`0900L000L01`0700801`L300031`0700/700D01`L700091`@0
30L01P071`L01`800PL200051`071`000`L300D70`0;1`0300L700X700D01`L700051`<01@L20087
0P021`0500L71`002@L4008700<01`L02`L00`071`091`0400L71`<01PL200870P021`0300L702P7
000Q1`8000D700L01`0300@70`031`0300L700/700@01`L01`L3008700<01`L02PL00`071`021`03
00L700800PL200031`0700@01@L300031`0700X700<01`L02`L010071`021`@01`L010071`021`07
00L71`0700071`<00PL01@071`L000`700<01`L02PL400H710031`<00PL00`071`0W1`008PL20003
1`0700@000@700001@L00`071`0;1`0400L700D70`051`0300L700T700<01`L010L010071`031`03
00L000801@L300<700<01`L02@L00`071`0;1`0300L700@02PL010071`L200031`0000<700<01`L0
0`L300D700@01`L03@L00`071`081`<01PL300<700@01`L00PL010071`0Y1`008`L300031`0000<0
1`L00`071`0;1`0400L700<70`071`0300L700T700<01`L01@L00`071`0200031`00008000@700L7
0`061`0300L700T700<01`L02PL00`07000200d700<01`L00PL00`071`0200051`0000L00`071`04
00L700d700<01`L01PL400D70`051`0400L700@700@01`L0:0L002<70P0010L000021`801PL00`07
1`0:1`0400L71`@02@L00`071`0:1`0300L700H700<01`000P021`8000@7000020L00`071`091`03
00L700X70`000`L01`0<1`0300L700<70P000`L0000500T700D01`L7000<1`0300L700@70`021`03
00L700@01`L010071`051`800PL00`071`0U1`0090L200041`00008700<01`L00`L00`071`0;1`03
00L000802`L00`071`0:1`0300L700H70`000`L000021`<000<700L01`L00`071`091`0300L700P7
10021`0300L700/700<01`L01@L200051`0000L00P081`0500L71`0030L00`071`021`<01@L300X7
00D01`L700061`8000<700L09PL002D700<01`L00P021`800`L00`071`0;1`@03@L00`071`091`03
00L700<710021`0300L000<00PL00`0700081`0300L700P700<01`L01PL3008700@01`L03@L00`07
1`061`D000<700L00P071`0400L700d700<01`000P051`<03@L010071`081`8000<700L09@L002H7
00<01`L00P021`0500L71`002@L4008700<01`L02`L00`071`091`0400L71`<01PL300031`000087
0P000`L01`051`0300L700T700<01`L00`L300@700D01`L7000=1`0300L700<70`000`L01`020087
00@01`001@L010071`0=1`<01@L300031`0700`700@01`L02@L01@0700L002D7000W1`0400L000<7
00<01`001`L3008700D01`L7000<1`0300L700X710061`@000<700L00`021`8000<700L00`L00`07
1`091`0400L71`<01PL01@071`L000d700@01`L70`051`0400L000870P000`L01`021`0500L71`00
2@L400D70`031`0300L700/700D01`L7000:1`@09@L002L70P000`L000031`0300L700<70`051`04
00L700d700<01`L020L300H70`031`0400L7008700D01`L01`0200<700<01`L02@L00`07000200T7
00@01`L03@L500L700`01`001`0700L01`021`0400L700L70`021`0400L71`<01PL00`071`0:1`05
00L71`002@L500031`0702<7000X1`0300L7008000D700001`0300L700@01`L03@L00`071`061`@0
1@L300D700L01`L01`0700800PL0100700021`0300L700L7100;1`0400L700`70`0:1`0500L700L0
0P021`800PL2008700<01`L00`L300D710081`0300L700/700@01`L01`L300<700@01`0090L002P7
0P000`L0000500T700D01`L7000<1`0300L700@70`021`0300L700@01`L010071`021`0300L70080
0PL200031`0000L70`000`L01`0;1`0500L71`002@L300031`0700X700H01`L700L200870P001@L0
1`L000<70`061`<02PL00`071`0;1`0400L700D70`051`0400L01`808`L002T70P001@L000070080
20L01@071`L000`700<01`L00PL300D70`0:1`0500L71`000`L0200700L01`070P051`<00`L00`07
1`0;1`0400L700L70`031`0300L700T700<01`L00PL00`071`0200870P000`L01`0400H7100;1`03
00L700/700H01`L700L400L700@01`L00PL20287000Z1`8000D700L01`0200L700@01`L03@L00`07
000200D70`0=1`0400L700D700H01`0700L400041`0000D700<01`L02`L010071`051`<01@L00`07
1`091`0300L700@700@01`L00`L00`07000200D710021`0300L700X700<01`L02`L00`071`0300X7
00<01`L00PL010071`0R1`00:PL01P07000700870P051`0400L700d70`051`<000<700L030L01007
1`071`0600L01`0710081`0300L700X700@01`L00`L300P700<01`L020L00`071`061`0500L000L0
100010L01`L300H700<01`L02@L00`071`0;1`@03@L00`071`031`0400L00247000[1`0:00L000L0
1`0700<700D01`L700091`@01@L300<700<01`L02`L010071`091`8000@700000PL00`071`051`03
00L700X700@01`L7100:1`0300L700T700<01`L01PL00`07000200870P0010L000081`0300L700T7
00<01`L02PL3008700<01`L02PL00`071`041`0400L70247000/1`<00PL01@0700L0008700@01`L0
1`L3008700@01`L70`061`0300L700X700D01`L700091`L00PL00`071`031`0300L700/700<01`00
0P0<1`0300L700T700<01`L01PL300031`0000870`000`L01`071`0300L700T700<01`L020L400<7
00<01`L02PL00`071`061`0400L00207000/1`0400L000870P021`800PL00`071`031`<01@L400P7
00<01`L02`L010071`071`<000D700001`02008700<01`L00PL00`071`0;1`@03PL00`071`081`03
00L700<710021`0300L000<00PL010071`071`0300L700T700<01`L01@L300<700@01`L030L00`07
1`061`@08@L002d700@01`000PL200051`071`000`L300H70`0:1`0300L700/700@01`L01@L300D7
0P021`800PL01@071`L000T710021`0300L700`700<01`L020L010071`L300H70`000`L000021`80
00<700L01@L00`071`091`0300L700<70`051`0400L700d700<01`L00`L300870P0Q1`00;@L01007
1`031`8000<700L010061`@02`L00`071`0;1`0400L7008710071`0400L000870P021`0300L000L7
0`021`0500L71`003@L00`071`091`@01PL400031`0700<00PL200031`0700<700<01`L02@L01007
1`L300L700D01`L7000<1`0400L71`<01@L20247000^1`0400L700<700<01`L00P051`@00PL00`07
1`0:1`0300L700X700@01`L70`0:1`0500L71`000PL200870P051`<01@L010071`0=1`0300L700P7
0`061`<00`L010071`021`0500L700L00P031`0300L700T700<01`000P0:1`0400L700`71@071`03
00L00247000_1`0500L000L00`021`0300L700<01PL00`071`091`0300L700/7100=1`0300L70087
00<01`L00P001@L0000700<01`L010071`0>1`0300L700D710051`<01@L01`071`0700L00P021`04
00L0008700<01`L01`L400`700@01`L02`L300X700D01`L7000P1`00;`L00`071`02008700<01`L0
0`081`0300L700T700<01`L02PL300031`0700`700<01`L00`L200031`0000D02@L01@071`L000d7
00<01`L00`L3008700<01`L010071`0400L7008700<01`L00P021`0300L000801`L300031`0700`7
00@01`L02@L300031`0700X700<01`L00PL00`071`0M1`00<0L0100700021`<000<700L01`L00`07
1`091`0300L700P710021`0300L700/700<01`L01@L200051`0000L00P081`0500L71`003@L01007
1`L300D70`0:1`0500L71`000`L00`071`0200051`071`001@L300<700<01`L02`L01@071`L000H7
0`031`0300L700T700<01`L00`L00`071`0M1`00<0L00`070003008700@01`L01`L00`071`091`03
00L700D70`021`0500L71`0030L00`071`061`D000<700L00P071`0400L700d700<01`000P051`<0
3@L010071`051`0600L01`07100010L000051`0300L700`700@01`L010L300D700<01`L02@L00`07
1`051`0300L701`7000a1`8000<700000PL200031`0700D700<01`L02@L00`071`031`<01@L01007
1`0=1`0300L700<70`000`L0000200870P000`L01`041`0400L700d70`051`<000<700L030L01007
1`071`0600L01`0710081`0300L700/700@01`L00PL300P700<01`L02@L00`071`051`0300L701`7
000b1`0300L700800PL200031`0700<700<01`L02@L010071`L300L700@01`L03@L010071`L300D7
0P0010L01`L200031`07008700D01`L700091`D010L300<700<01`L02`L01@071`L000P700<01`00
0`021`0300L700D700<01`L02`L010071`L300X700<01`L02@L00`071`071`0300L701/7000c1`04
00L000870P000`L01`021`0300L700T700<01`000P091`0400L700d71@071`0700L000L01`020087
00@01`L00PL00`071`051`<00`L00`071`0300H700<01`L02PL01@071`L000T71@001@L01`L000D7
00<01`L02`L00`07000200`700<01`L02@L00`071`091`0300L701X7000d1`0400L000870P001@L0
1`L000T7100;1`0500L71`002`L300X700D01`L01`0200870P021`800PL00`071`031`<01PL300P7
00<01`L02`L010071`071`<000D700L01`0200870P031`0300L700/70`000`L01`0<1`0300L700T7
00<01`L02@L00`071`0J1`00=0L01@0700L000870P000`L000071`<000<700L030L010071`091`<0
00<700L02PL01P071`L01`800PL200051`071`000`L300H70`0:1`0300L700/700@01`L01@L300D7
0P021`800PL2008700<01`L01`L5008700<01`L02`L00`071`091`0300L700X70P0K1`00=@L02007
00L01`070P051`<00`L00`071`0;1`0400L700L70`031`0300L700T700<01`L00PL01@0700L00087
0P000`L01`0400H70`000`L01`091`0300L700/700D01`L700021`<01`L0100700021`800PL300L7
0`031`0500L71`0030L00`071`091`0300L700P70`0M1`00=PL01P0700L01`@000@700001@L00`07
1`0;1`0400L700D70`051`0300L700T700<01`L010L0100700031`0300L000801@L400<700<01`L0
2@L00`071`0;1`0300L700@02@L010071`L2008700<01`L00P051`<01PL010071`0<1`0300L700T7
00<01`L01PL30207000g1`800PL00`07000300P700<01`L02PL01@071`L000870`081`0300L700P7
00<01`L01PL01@07000700@000@700L70`071`0300L700P700<01`L02`L00`07000200`700<01`L0
0PL00`071`0200051`0000L00`081`0400L700d700<01`L02@L00`071`031`<08`L003P70P001@L0
000700801`L00`071`0;1`0300L700@02PL00`071`091`0300L700H700<01`000P021`8000@70000
2@L00`071`081`0300L700/70`000`L01`0;1`0300L700@700D01`L01`0400X700D01`L7000<1`03
00L700T700<01`L0100V1`00>@L200051`0000L00P051`0300L700/700<01`000P0<1`0300L700T7
00<01`L01PL300031`0000870`000`L01`081`0300L700P700<01`L02@L300<700<01`L02PL00`07
1`061`0300L0008000@700L020L01@071`L000`700<01`L02@L402X7000j1`0300L700800PL200<7
00<01`L02`L400h700<01`L020L00`071`031`@00PL00`07000300031`00008700<01`L01PL00`07
1`081`0300L700D710021`0400L700d700<01`L01@L400@700<01`001`L010071`0<1`0300L700P7
0`0]1`00>`L00`071`02008700D01`L700091`@00`L00`071`0;1`0300L700T700<01`L00`061`<0
00<700L00PL200031`0700H700<01`L020L00`071`031`<01@L010071`0=1`0300L700<70`021`80
10L010071`051`0400L700d700<01`L01@L300031`0702d7000k1`0400L71`800PL00`0700071`<0
0`L010071`0=1`0300L700T710061`@000<700L00P031`8000<700L010L00`071`081`0400L71`<0
1`L01@071`L000`700@01`L70`051`801@L010071`031`0500L71`0030L00`071`031`<00`L00`07
1`0]1`00?0L00`071`0200<700<01`L00`L300D700@01`L03@L00`071`081`<01PL300<700@01`L0
0PL01@071`07008010L00`071`081`0300L000802PL010071`0=1`@01`L0100700051`0400L70087
00@01`L030L010071`L300D700<01`L0;PL003d700<01`L00P001@L0000700<01`L010071`0>1`03
00L700D710051`<01@L01`071`0700L00P021`0400L000<700<01`L01`L300`700@01`L02`L300X7
00@01`L70P041`0600L700L00PL00`071`0;1`@020L00`071`0^1`00?@L200031`0000D02@L01@07
1`L000d700<01`L00`L300<700<01`000`071`0700L71`0700021`800PL01P07000700L7100=1`04
00L700T70`000`L01`0:1`0300L700870P041`0400L7008700<01`L02PL300X700<01`L0;`L003h7
0P001@L0000700802@L010071`0=1`0400L71`<01@L300X700D01`L700031`0300L7008000@700L7
0P051`<00PL00`071`0;1`0500L71`001PL300<700<01`L02@L00`071`031`801@L200041`0700T7
100;1`0300L70307000o1`8000D700L01`0200L700@01`L03@L00`07000200D70`0=1`0400L700D7
00P01`0700L01`800PL300@700<01`L030L010071`041`<01PL00`071`081`0300L700D70P041`80
00<700001PL4008700<01`L02PL00`071`0`1`00?`L01P07000700870P051`0400L700d70`051`<0
0PL00`071`0:1`0500L71`001PL01`07000700L010071`0300L700/700@01`L00PL300P700<01`L0
2@L00`071`051`0300L000<710041`<01PL00`071`091`0300L7034700101`8000P700L01`0700<7
00D01`L700091`D010L300@700<01`L02PL01@071`L000P700<01`0010000`L01`061`0300L700/7
00@01`L70`0:1`0300L700T700<01`L01`L00`07000200051`0700L00`081`0300L700T700<01`L0
<PL0040700/01`0700L01`0700021`0400L700L70`031`0300L700<01PL00`071`0;1`0400L700X7
10001@L01`L000D700<01`L02`L00`07000200d700<01`L020L00`071`071`<000<700L00PL300X7
00<01`L02@L00`071`0c1`00@@L0100700021`0600L000L00PL00`071`031`<01PL300P700<01`L0
2`L010071`081`@000<700L00`000`L000031`0300L700/70`000`L01`0<1`0300L700T700<01`L0
0`L4008700<01`000`000`L01`0:1`0300L700T700<01`L0<`L0048700@01`000PL200051`071`00
0`L300H70`0;1`0300L700X700D01`L700051`<010L200870P021`800PL00`071`071`D00PL00`07
1`0;1`0300L700T700@01`L70`061`<000D700L7000:1`0300L700T700<01`L0=0L0048700@01`L0
0`L200031`0700@01PL300031`0700X700<01`L02`L010071`021`@020L200870P021`<01`L300<7
00D01`L7000<1`0300L700T700<01`000P061`<010L01@071`L000P700<01`L02@L00`071`0e1`00
@`L010071`031`8000<700001@L400<700<01`L02@L00`071`0;1`0300L700@03@L200051`0000L0
0P051`<01PL010071`0=1`0300L700P70`061`<01PL00`0700031`0300L700@700<01`L02PL00`07
1`0e1`00A0L01@071`0700<01@L300L700<01`L020L00`071`0;1`0300L000804@L00`071`060004
1`0000P700@01`L03@L00`071`061`@01@L300P700D01`L700021`0300L700@700<01`L02@L00`07
1`0f1`00A0L00`071`0200870P0010L000091`0300L700T700<01`L02PL300031`07018700D01`L0
1`0400X700D01`L7000<1`0300L700@70`021`0300L700@02PL00`071`031`0400L700@700<01`L0
2@L00`071`0g1`00A@L0100700021`<02`L00`071`091`0300L700P710021`0300L701<700<01`00
10000`L01`071`0500L71`003@L010071`L300@7100>1`0300L700@700<01`000`L00`071`0:1`03
00L703L700151`0300L000<00PL00`071`091`0300L700P700<01`L01PL3008700@01`L05@L300<7
00D01`0700071`0400L700d700<01`000P051`<040L00`071`061`0500L01`0030L00`071`0h1`00
APL200031`0000<700<01`L01`L00`071`091`0300L700<70`041`0500L71`004PL3008700<01`L0
0PL2008700<01`L00`L010071`0=1`<01@L300031`0700l700<01`L020L01007000;1`0300L703T7
001:1`800PL200L700<01`L02@L010071`L300L700@01`L040L300H700<01`L00PL2008700D01`L7
00031`0300L700L710051`<00`L00`071`0?1`0300L700P70`0;1`0300L703X7001:1`0300L00087
00<01`L010L00`071`091`0300L000802@L010071`0>1`<02@L200@70P021`0400L7008700<01`L0
1@L300<700<01`L00`051`0300L700l700<01`L01`L400031`0700T700<01`L0>PL004/700<01`00
0PL00`071`031`0300L700L7100;1`0500L71`002`L300d70P041`0600L700L00PL00`071`031`<0
1@L400P700<01`L03PL00`071`051`<010L00`0700081`0300L703/7001<1`0400L01`800`L00`07
1`051`<000<700L02`L01@071`L000T70`0A1`8010L010071`021`0400L71`<01PL300X700<01`L0
3PL00`071`031`<020L200L700<01`L0?0L004`700<01`000PL200031`0700@70`031`0300L700/7
00@01`L01`L301@70P041`<000<700L010061`<000<700L02@L00`071`0?1`0300L700<030L200H7
00<01`L0?0L004d700<01`000PL200<70`051`0300L700/700@01`L01@L301P70P041`8000@70000
1@L400<700<01`L02@L00`071`0>1`@040L00`071`031`0300L703d7001>1`0400L01`D020L00`07
1`0:1`0600L71`07100K1`0300L000<70`051`<01PL00`071`091`0300L700d70`0C1`800`L00`07
1`0n1`00CPL00`071`0300031`0700L700<01`L02`L00`071`03020700<01`000P000`L000021`<0
2@L00`071`081`0300L700/7100F1`8000<700L0@0L004l700D01`L01`0200L700<01`L02`L40287
0`000`L01`021`<02`L00`071`081`0300L700T70`031`0300L701D700<01`00@@L004l700@01`L7
0P000`L01`041`0300L700X70`021`0300L701d70`021`0300L000<000<700002PL00`071`091`03
00L700H70`051`0300L701H70P121`00D0L010071`L200031`0700<700<01`L01`L400<700<01`L0
6`L300D70`0010L01`L200T700<01`L02@L00`071`051`801`L00`071`0D1`<0A0L0054700D01`L7
00021`0400L700L70`031`0400L701/70`051`<010L010071`L200P700<01`L020L00`071`031`<0
2@L00`071`0A1`<0A`L0054700@01`L70P021`801@L300D700D01`L7000H1`<01@L300P700@01`L7
0P061`0300L700T700<01`L00`0;1`0300L700l70`1:1`00DPL010071`L200031`0000870`071`05
00L71`005PL300D70`0<1`0600L700L010L00`071`091`@03@L00`071`0<1`@0C@L005<700H01`L7
00L400X700@01`L050L300D70`0@1`0600L700L00`L00`071`071`<03`L00`071`0:1`<0D@L005<7
00<01`L00PL200031`0700T700@01`L04`L200D70`0D1`0500L01`000PL00`071`051`<000<700L0
3`L00`071`071`<0E0L005@700<01`L01@L00`071`061`0500L71`0040L300@70`0H1`0400L01`80
1@L300<700<01`L03PL00`071`051`<0E`L005@700<01`L01PL00`071`051`0400L700h70`041`<0
70L00`07000200870`051`0300L700h700<01`L00`L305X7001E1`0300L700H700<01`L00`L01007
1`0<1`<010L301l700<01`0010071`0300L700h700@01`L70`1M1`00EPL00`071`061`0500L71`00
0`L00`071`071`<010L302<70`021`0300L700D700<01`L03PL40607001F1`0300L700L700<01`00
0`L00`071`051`<01@L202L700<01`000PL00`071`031`0300L700d70`1S1`00E`L00`071`061`03
00L0008700<01`L00`L300D70`0Z1`800PL00`071`021`0300L700/7101U1`00F0L00`071`061`04
00L700<70`051`<0;PL2008700D01`L700091`@00PL00`071`1T1`00F0L00`071`051`0400L01`@0
1@L3038700L01`L700L000L70`061`0300L706@7001I1`0300L700@700<01`L00P051`<0=@L200<7
00<01`L00`L300P700<01`L0I@L005T700<01`L00`L00`071`051`<0>@L200051`0700L00`0:1`03
00L706H7001J1`0500L71`001@L303d700<01`000`0=1`0300L706H7001K1`0300L000<70`111`80
0PL00`071`0:1`0300L706L7001K1`0300L000<0B@L00`071`081`0300L706P7001L1`80C@L00`07
1`061`0300L706T7002/1`0300L700D700<01`L0J@L00:d700<01`L00`L00`071`1Z1`00[PL01@07
1`L006d7002^1`0400L706h7002_1`0300L006h7002`1`0300L706d7003o1b47003o1b47003o1b47
003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {279.812, 0}} -> {-10.3839, -10.1198, \
0.0723425, 0.0723425}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[165]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["j = 4, k =3", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AL043, Axes \[Rule] True, Prolog \[Rule] PointSize[0.025], 
      PlotRange \[Rule] \ {{\(-20\), 20}, {\(-20\), 20}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[166]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.5 0.025 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -9 -9 ]
[.125 .4875 9 0 ]
[.25 .4875 -9 -9 ]
[.25 .4875 9 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -6 -9 ]
[.75 .4875 6 0 ]
[.875 .4875 -6 -9 ]
[.875 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -12 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -12 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-20)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-15)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-10)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(10)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(15)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(20)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-20)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-15)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-10)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(10)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(15)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(20)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.025 w
.90649 .49994 Mdot
.86787 .55311 Mdot
.82924 .60628 Mdot
.79061 .65944 Mdot
.75198 .71261 Mdot
.71336 .76577 Mdot
.67473 .81894 Mdot
.6361 .8721 Mdot
.59748 .92527 Mdot
.55885 .97844 Mdot
.86787 .44678 Mdot
.82924 .49994 Mdot
.79061 .55311 Mdot
.75198 .60628 Mdot
.71336 .65944 Mdot
.67473 .71261 Mdot
.6361 .76577 Mdot
.59748 .81894 Mdot
.55885 .8721 Mdot
.52022 .92527 Mdot
.48159 .97844 Mdot
.82924 .39361 Mdot
.79061 .44678 Mdot
.75198 .49994 Mdot
.71336 .55311 Mdot
.67473 .60628 Mdot
.6361 .65944 Mdot
.59748 .71261 Mdot
.55885 .76577 Mdot
.52022 .81894 Mdot
.48159 .8721 Mdot
.44297 .92527 Mdot
.79061 .34045 Mdot
.75198 .39361 Mdot
.71336 .44678 Mdot
.67473 .49994 Mdot
.6361 .55311 Mdot
.59748 .60628 Mdot
.55885 .65944 Mdot
.52022 .71261 Mdot
.48159 .76577 Mdot
.44297 .81894 Mdot
.40434 .8721 Mdot
.75198 .28728 Mdot
.71336 .34045 Mdot
.67473 .39361 Mdot
.6361 .44678 Mdot
.59748 .49994 Mdot
.55885 .55311 Mdot
.52022 .60628 Mdot
.48159 .65944 Mdot
.44297 .71261 Mdot
.40434 .76577 Mdot
.36571 .81894 Mdot
.71336 .23412 Mdot
.67473 .28728 Mdot
.6361 .34045 Mdot
.59748 .39361 Mdot
.55885 .44678 Mdot
.52022 .49994 Mdot
.48159 .55311 Mdot
.44297 .60628 Mdot
.40434 .65944 Mdot
.36571 .71261 Mdot
.32709 .76577 Mdot
.67473 .18095 Mdot
.6361 .23412 Mdot
.59748 .28728 Mdot
.55885 .34045 Mdot
.52022 .39361 Mdot
.48159 .44678 Mdot
.44297 .49994 Mdot
.40434 .55311 Mdot
.36571 .60628 Mdot
.32709 .65944 Mdot
.28846 .71261 Mdot
.6361 .12779 Mdot
.59748 .18095 Mdot
.55885 .23412 Mdot
.52022 .28728 Mdot
.48159 .34045 Mdot
.44297 .39361 Mdot
.40434 .44678 Mdot
.36571 .49994 Mdot
.32709 .55311 Mdot
.28846 .60628 Mdot
.24983 .65944 Mdot
.59748 .07462 Mdot
.55885 .12779 Mdot
.52022 .18095 Mdot
.48159 .23412 Mdot
.44297 .28728 Mdot
.40434 .34045 Mdot
.36571 .39361 Mdot
.32709 .44678 Mdot
.28846 .49994 Mdot
.24983 .55311 Mdot
.2112 .60628 Mdot
.55885 .02145 Mdot
.52022 .07462 Mdot
.48159 .12779 Mdot
.44297 .18095 Mdot
.40434 .23412 Mdot
.36571 .28728 Mdot
.32709 .34045 Mdot
.28846 .39361 Mdot
.24983 .44678 Mdot
.2112 .49994 Mdot
.17258 .55311 Mdot
.48159 .02145 Mdot
.44297 .07462 Mdot
.40434 .12779 Mdot
.36571 .18095 Mdot
.32709 .23412 Mdot
.28846 .28728 Mdot
.24983 .34045 Mdot
.2112 .39361 Mdot
.17258 .44678 Mdot
.13395 .49994 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[166]:=",
  ImageSize->{225.188, 225.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Q0000h@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc>47003Q1`00h@L00>47003Q1`00h@L006<7
10031`80M@L006<700<01`L00`L010071`1d1`00I0L00`071`021`0400L700@70P1^1`00G@L400@7
00D01`L700021`0300L7008700<01`L0K@L006H700@01`L00PL400031`0700T7101Q1`00H`L01007
1`021`0300L700@000<700L02@L40647001T1`8010L600031`0700T7101Q1`00K0L400031`0000T7
101Q1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L206h7
001a1`0300L706d7001a1`0300L706d7001T1`@02@L00`071`0400`7101I1`00I0L400T700<01`L0
100<1`@0F@L006@710091`0300L700@030L405T7001T1`@02@L200031`00008030L405T7001a1`03
00L706d7001a1`0300L706d7001a1`0300L706d7001a1`0300L706d7001a1`80KPL0074700<01`L0
K@L0074700<01`L0K@L006<710021`<01@L00`071`1]1`00G0L400D700<01`L010L400031`0700T7
100=1`@0D0L005`710051`0300L700@710000`L000091`@03@L40507001L1`D010L010071`L70003
1`0700T7100=1`@0D0L005`710051`0500L71`000PL400031`0700T7100=1`@0D0L006<70`031`03
00L700D700<01`L0K@L006D700@01`L710041`0300L706d7001a1`80KPL0074700<01`L0K@L00747
00<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L005@7100<1`@02@L200031`00008030L400d7
10181`00E0L400`710091`0300L700@030L400d710181`00E0L400`710091`0300L700@030L400d7
10181`00E0L400`710091`0300L700@030L400d710181`00L@L00`071`1]1`00L@L00`071`1]1`00
L@L206h7001a1`0300L706d7001a1`0300L706d7001a1`0300L706d7001a1`0300L706d7001<1`@0
30L400`710000`L000091`@03@L400`710101`00C0L400`7100<1`@000<700L02@L400d7100<1`@0
@0L004`7100<1`@030L400031`0700T7100=1`@030L40407001<1`@030L400<710031`H000<700L0
2@L400d7100<1`@0@0L006D700D01`L700021`0300L7008700<01`L0K@L006D700D01`L700021`03
00L700870P1^1`00G@L400@700D01`L700021`0300L7008700<01`L0K@L006D700D01`L700021`03
00L7008700<01`L0K@L006<70`031`0400L700@700<01`L0K@L006D700<01`L00PL200D700<01`L0
K@L007470P1^1`00A0L400`7100<1`@02@L00`071`0400`7100=1`@030L403P700141`@030L400`7
10091`0300L700@030L400d7100<1`@0>0L004@7100<1`@030L400T700<01`L0100<1`@03@L400`7
100h1`00A0L400`7100<1`@02@L00`071`0400`7100=1`@030L403P7001a1`0300L706d7001a1`80
KPL0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L007470P1^1`00
?0L400`7100<1`@030L400031`0700T7100=1`@030L400`7100`1`00?0L400`7100<1`@030L40003
1`0700T7100=1`@030L400`7100`1`00?0L400`7100<1`@030L400031`0700T7100=1`@030L400`7
100`1`00?0L400`7100<1`@030L400031`0700T7100=1`@030L400`7100`1`00L@L206h7001a1`03
00L706d7001a1`0300L706d7001Y1`<01@L00`071`1]1`00K0L00`071`021`0300L706d7001/1`03
00L700870P1^1`00H`L400870`051`0300L706d7000d1`@030L400`7100<1`@000<700L01PL00`07
1`0400`7100=1`@030L400`7100X1`00=0L400`7100<1`@030L400031`0700H700<01`L0100<1`@0
3@L400`7100<1`@0:0L003@7100<1`@030L400`710000`L0000200@700<01`L0100<1`@03@L400`7
100<1`@0:0L003@7100<1`@030L400`710091`8000<700000P0<1`@03@L400`7100<1`@0:0L00747
00<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L00747
0P1^1`00L@L00`071`1]1`00;0L400`7100<1`@030L400`710000`L01`091`@03@L400`7100<1`@0
30L40207000/1`@030L400`7100<1`@030L400031`0700T7100=1`@030L400`7100<1`@080L002`7
100<1`@030L400`7100<1`@000<700L02@L400d7100<1`@030L400`7100P1`00;0L400`7100<1`@0
30L400`710000`L000091`@03@L400`7100<1`@030L4020700071`@00`L2014710021`<04@L400<7
0P0D1`<05PL00`071`0E1`<050L400<70P0B1`@00PL3014710031`800`L000L700<01`L00`L01007
1`0B1`0300L700@700<01`L040L01@071`L0008700<01`L050L00`071`0C1`0300L701P700<01`L0
4`L01@071`L0008700<01`L04@L00`071`041`0300L700h700<01`L00`L010071`021`0020L00`07
1`021`0400L7018700<01`L010L00`071`0@1`0500L71`000PL00`071`0D1`0300L701<700<01`L0
60L00`071`0C1`0500L71`000PL00`071`0A1`0300L700@700<01`L03`L00`071`021`0400L70087
00000`L0000200@700D01`L700021`0300L700P710041`0400L71`<02`L400@700D01`L700021`03
00L700/710021`<05PL00`071`0E1`<05PL01@071`L0008700<01`L04@L010071`L301<700D01`L7
00021`400@L11`002PL010071`021`0300L7010700D01`L7000E1`0500L71`000PL00`071`0A1`03
00L701H70P0F1`0300L701H700D01`L700021`0300L7014700D01`L7000F1`0400L700870@011`47
00071`0400L7008700@01`L040L300<700<01`L04@L300<700@01`L04`L00`071`0F1`0300L701D7
00<01`L050L300<700@01`L04@L300<700<01`L04@L010071`021`0400L7008700081`8010L201<7
00@01`L7100B1`0300L700870P0D1`@05@L00`071`0E1`@05@L00`071`021`8050L010071`L40147
0P041`800`L002<7100=1`@030L400`7100<1`@02@L00`071`0400`7100=1`@030L400`7100<1`@0
60L002<7100=1`@030L400`7100<1`@02@L00`071`0400`7100=1`@030L400`7100<1`@060L000T7
dP061`002@L00`071`021`0300L7008700<01`L00PL00`071`021`0300L700<710000`L01`031`03
00L7008700<01`0010041`0300L7008700<01`000`041`0300L700<700<01`000`041`0300L70087
00<01`L010041`0300L7008700<01`L010041`0300L7008700<01`L010031`0300L7008700<01`L0
0PL4008700<01`L00PL00`071`021`@00PL00`071`021`0300L7008710000`L01`041`0300L70087
10000`L01`031`0300L7008700<01`L00`L00`071`041`002@L00`071`0G1`0300L701L700<01`L0
5`L00`071`0G1`0300L701L700<01`L05`L00`071`0H1`0300L701L700<01`L010L0074700<01`L0
K@L0074700<01`L0K@L0074700<01`L0K@L007470P1^1`00L@L00`071`1]1`00L@L00`071`1]1`00
L@L00`071`1]1`00;0L400`7100<1`@030L400`710000`L01`091`@03@L400`7100<1`@030L40207
000/1`@030L400`7100<1`@030L400031`0000T7100=1`@030L400`7100<1`@080L002`7100<1`@0
30L400`7100<1`@000<700L02@L400d7100<1`@030L400`7100P1`00;0L400`7100<1`@030L400`7
10000`L01`091`@03@L400`7100<1`@030L40207001a1`0300L706d7001a1`0300L706d7001a1`80
KPL0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L003@7100<1`@0
30L400`710091`8000<700000P0<1`@03@L400`7100<1`@0:0L003@7100<1`@030L400`710091`03
00L700@030L400d7100<1`@030L402P7000d1`@030L400`7100<1`@02@L00`071`0400`7100=1`@0
30L400`7100X1`00=0L400`7100<1`@030L400T700<01`L0100<1`@03@L400`7100<1`@0:0L006T7
0`051`0300L706d7001/1`0300L7008700<01`L0K@L006`700<01`L00PL206h7001Y1`<01@L00`07
1`1]1`00J@L00`071`051`0300L706d7001Y1`0300L700D700<01`L0K@L006T710041`0300L706d7
000l1`@030L400`7100<1`@000<700002@L400d7100<1`@030L40307000l1`@030L400`7100<1`@0
00<700L02@L400d7100<1`@030L40307000l1`@030L400`7100<1`@000<700L02@L400d7100<1`@0
30L40307000l1`@030L400`7100<1`@000<700L02@L400d7100<1`@030L40307001a1`0300L706d7
001a1`80KPL0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L00747
0P1^1`00A0L400`7100<1`@02@L00`071`0400`7100=1`@030L403P700141`@030L400`710091`03
00L700@030L400d7100<1`@0>0L004@7100<1`@030L400T700<01`L0100<1`@03@L400`7100h1`00
A0L400`7100<1`@02@L00`071`0400`7100=1`@030L403P7001a1`80KPL0074700<01`L0K@L00747
00<01`L0K@L0074700<01`L0K@L006<710031`801@L00`071`1]1`00I@L01@071`L0008700<01`L0
0PL00`071`1]1`00I@L01@071`L0008700<01`L00PL206h7001<1`@030L400D700D01`L700021`@0
00<700L02@L400d7100<1`@0@0L004`7100<1`@01@L01@071`L0008710000`L01`091`@03@L400`7
10101`00C0L400`710031`<00`L00`071`0400031`0700T7100=1`@030L40407001<1`@030L400D7
00<01`L00PL600031`0700T7100=1`@030L40407001a1`80KPL0074700<01`L0K@L0074700<01`L0
K@L0074700<01`L0K@L0074700<01`L0K@L007470P1^1`00L@L00`071`1]1`00E0L400`710091`03
00L700@030L400d710181`00E0L400`710091`0300L700@030L400d710181`00E0L400`710091`03
00L700@030L400d710181`00E0L400`710091`8000<700000P0<1`@03@L404P7001a1`0300L706d7
001a1`0300L706d7001a1`0300L706d7001a1`0300L706d7001a1`0300L706d7001a1`80KPL00747
00<01`L0K@L005`7100<1`@000<700L02@L400d7101@1`00G0L400<710021`L000<700L02@L400d7
101@1`00G0L400D700<01`L010L400031`0700T7100=1`@0D0L005`710051`0300L700@710000`L0
00091`@03@L40507001U1`0400L71`<01@L00`071`1]1`00I@L01@071`L000L700<01`L0K@L006<7
0`031`0300L700D700<01`L0K@L006D700@01`L710041`0300L706d7001a1`80KPL0074700<01`L0
K@L0074700<01`L0K@L006@710091`0300L700@030L405T7001T1`@02@L00`071`0400`7101I1`00
I0L400T70P000`L0000200`7101I1`00I0L400T700<01`L0100<1`@0F@L0074700<01`L0K@L00747
00<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L007470P1^1`00L@L00`071`1]1`00L@L00`07
1`1]1`00L@L00`071`1]1`00K0L400031`0700T7101Q1`00K0L400031`0000T7101Q1`00K0L40003
1`0700T7101Q1`00K0L400031`0700T7101Q1`00H`L400<70P051`0300L706d7001S1`0300L700<7
00@01`L010L00`071`1]1`00I0L00`071`021`0400L700@70P1^1`00I@L01@071`L0008700<01`L0
LPL006H700@01`L00PL00`071`1b1`00H`L010071`021`0400L707@7001T1`8010L207D7003Q1`00
h@L00>470000\
\>"],
  ImageRangeCache->{{{0, 224.188}, {224.188, 0}} -> {-21.7212, -21.4343, \
0.191218, 0.191218}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[166]="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(basis43 = 
      FullSimplify[{A[4, 3, \[Alpha]] /. {m \[Rule] 1, n \[Rule] 0}, 
          A[4, 3, \[Alpha]] /. {m \[Rule] 0, 
              n \[Rule] 1}}]\), "\[IndentingNewLine]", 
    \(orig\  = \ 
      FullSimplify[
        A[4, 3, \[Alpha]] /. {m \[Rule] 0, n \[Rule] 0}]\)}], "Input",
  CellLabel->"In[167]:="],

Cell[BoxData[
    \({{\(-0.7362224859969771`\), \(-2.128831602210094`\)}, \
{\(-0.7362224859969771`\), 2.1244224395501057`}}\)], "Output",
  CellLabel->"Out[167]="],

Cell[BoxData[
    \({0.80886248587776`, \(-0.002204581329994182`\)}\)], "Output",
  CellLabel->"Out[168]="]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    \(\(rad43\  = \@\(\((basis43[\([1]\)]\  - \ orig)\) . \((basis43[\([1]\)]\
\  - \ orig)\)\);\)\)], "Input",
  CellLabel->"In[169]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AppendTo[basis43, orig], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-10\), 10}, {\(-10\), 10}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[170]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.46319 .39356 Mdot
.46319 .60622 Mdot
.54044 .49989 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[170]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L0088710031`80U@L008@700D01`L700021`0300L7098700241`0500L71`000PL00`07
1`031`80S@L007`710041`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`07
1`031`0300L708`700221`<00`L010071`051`0300L708`700241`0300L700870P061`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L007d700<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<7
00<01`L0S0L007h700<01`L02PL00`071`031`80S@L007H710041`0300L700L70`061`0300L708`7
001o1`0300L700H700<01`L01PL00`071`2<1`00O0L010071`081`0300L700H700<01`L0S0L007`7
10081`@01@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`700281`<01PL00`071`2<1`00R`L00`071`031`0300L708`7
002;1`0300L700<70P2=1`00PPL400870`061`0300L708`700281`0300L700H700<01`L0S0L008P7
00<01`L01PL00`071`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00O0L400<700<01`L00PL300H7
00<01`L0S0L007`700<01`L01@L600031`0700@700<01`L0S0L007d700<01`L00PL:00D70P2=1`00
MPL400@700@01`L72P051`0300L708`7001o1`0300L000/010L00`071`2<1`00O0L01@071`0700`0
10L00`071`2<1`00O@L2008730041`0300L708`700211``010L00`071`2<1`00P@L<00@700<01`L0
S0L0084730041`80S@L008872P051`0300L708`700221`X01@L00`071`2<1`00Q0L600L700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`700071`@00`L201L700<01`L00`L00`071`021`<0
6@L301T710031`0300L700870`0H1`0300L701L710031`0300L700870`0I1`<06PL00`071`031`03
00L700870`0F1`@00`L200<700091`0500L71`000PL00`071`0D1`0300L700/700<01`L06@L00`07
1`0F1`0300L700`700<01`L05@L00`071`0G1`0300L700`700<01`L06@L00`071`0G1`0300L700/7
00<01`L05@L01@071`L000870@011`4700091`0500L71`000PL00`071`0E1`0300L700X700<01`L0
6@L00`071`0G1`0300L700/700<01`L05@L00`071`0H1`0300L700/700<01`L06@L00`071`0H1`03
00L700X700<01`L05@L01@071`L000870@011`4700000`L0000200@700D01`L700021`0300L700d7
10041`0300L700L70`0C1`@00PL301<710041`0300L700L70`0H1`806PL00`071`071`<06@L301/7
00<01`L01`L301P700D01`L700021`400@L11`002@L01@071`L0008700<01`L05PL00`071`061`03
00L701T700<01`L070L00`071`061`0300L701P700<01`L01@L600l700<01`L01PL00`071`0I1`03
00L701`700<01`L01PL00`071`0H1`0500L71`000PL100470@L000L70`031`0400L701D700@01`L0
20L00`071`0I1`0300L701T700@01`L020L00`071`0H1`0300L700<72P0:1`0400L700P700<01`L0
6@L00`071`0I1`0400L700P700<01`L05PL300<700@01`L00PL000T700<01`L00PL201H710081`@0
60L401T70P091`@05`L00`071`031`X02`L200T7100H1`@060L400P7100G1`0300L700870P031`00
T@L00`071`021``0OPL0094700<01`L00PL<07h7002A1`0300L70087301n1`002@Oo01801PL000T7
00<01`L00`L00`071`041`0300L700@700<01`L010L00`071`041`0300L700<700<01`L010L00`07
1`041`0300L700@700<01`L010L00`071`031`0300L700@700<01`L010L00`071`041`0300L700@7
00<01`L00`L00`071`041`0300L700@700<01`L010L00`071`041`0300L7008730031`0300L700@7
00<01`L010L00`071`031`0300L700@700<01`L010L00`071`041`0300L700@700<01`L00`L00`07
1`041`0300L700@700<01`L010L00`071`041`0300L700<700<01`L010L00`071`041`0300L700@7
00<01`L010L00`071`041`002@L00`071`0O1`0300L701l700<01`L07`L00`071`0O1`0300L70087
300A1`0300L701l700<01`L07`L00`071`0O1`0300L700@7002A1`0300L700<72P1o1`00T@L00`07
1`031`X0O`L0094700<01`L01@L60847002A1`0300L708`7002A1`80S@L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`700241`H01`L00`071`2<1`00PPL:00D7
00<01`L0S0L008872P051`0300L708`700211``010L00`071`2<1`00P@L<00@70P2=1`00P@L<00@7
00<01`L0S0L0084730041`0300L708`700211``010L00`071`2<1`00P@L<00@700<01`L0S0L007`7
10021`X01@L00`071`2<1`00O0L00`071`031`X01@L00`071`2<1`00O@L00`071`041`H000<700L0
10L208d7001n1`0300L700L70`061`0300L708`7001o1`0300L700H700<01`L01PL00`071`2<1`00
O0L010071`081`0300L700H700<01`L0S0L007d70P091`@01@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`700281`<0
1PL00`071`2<1`00R`L00`071`031`0300L708`7002;1`0300L700<70P2=1`00R0L300H700<01`L0
S0L008P700<01`L01PL00`071`2<1`00R0L00`071`061`0300L708`700281`@01@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7001m1`0300L700<700<01`L00PL300H700<01`L0S0L007d700<01`L02`L00`071`031`03
00L708`7001n1`0300L700X700<01`L00`L208d7001n1`0300L700L70`061`0300L708`7001o1`03
00L700H700<01`L01PL00`071`2<1`00O0L010071`081`0300L700H700<01`L0S0L007`710081`@0
1@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80
S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`700221`@00`L200H700<01`L0S0L008@700D01`L700021`0300L700<7
00<01`L0S0L008@700D01`L700021`0300L700<70P2=1`00Q0L01@071`L0008700<01`L0TPL008@7
00D01`L700021`0300L7098700221`<00`L010071`2D1`00Q0L00`071`021`80U@L00?l78@L00?l7
8@L00?l78@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.6619, -10.5516, 0.0735301, \
0.0735301}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[170]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice043\  = tiling2D[SphericalCut[N[AL043], 10], \ rad43]\)], "Input",\

  CellLabel->"In[171]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00101 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.497965 0.0560358 0.500626 0.0560358 [
[ 0 0 0 0 ]
[ 1 1.00101 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00101 L
0 1.00101 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.97619 .61967 m
.88961 .73884 L
s
.97619 .61967 m
.88961 .5005 L
s
.88961 .73884 m
.80303 .858 L
s
.88961 .73884 m
.80303 .61967 L
s
.80303 .858 m
.71645 .97717 L
s
.80303 .858 m
.71645 .73884 L
s
.71645 .97717 m
.62987 .858 L
s
.97619 .38134 m
.88961 .5005 L
s
.97619 .38134 m
.88961 .26217 L
s
.88961 .5005 m
.80303 .61967 L
s
.88961 .5005 m
.80303 .38134 L
s
.80303 .61967 m
.71645 .73884 L
s
.80303 .61967 m
.71645 .5005 L
s
.71645 .73884 m
.62987 .858 L
s
.71645 .73884 m
.62987 .61967 L
s
.62987 .858 m
.54329 .97717 L
s
.62987 .858 m
.54329 .73884 L
s
.54329 .97717 m
.45671 .858 L
s
.88961 .26217 m
.80303 .38134 L
s
.88961 .26217 m
.80303 .143 L
s
.80303 .38134 m
.71645 .5005 L
s
.80303 .38134 m
.71645 .26217 L
s
.71645 .5005 m
.62987 .61967 L
s
.71645 .5005 m
.62987 .38134 L
s
.62987 .61967 m
.54329 .73884 L
s
.62987 .61967 m
.54329 .5005 L
s
.54329 .73884 m
.45671 .858 L
s
.54329 .73884 m
.45671 .61967 L
s
.45671 .858 m
.37013 .97717 L
s
.45671 .858 m
.37013 .73884 L
s
.37013 .97717 m
.28355 .858 L
s
.80303 .143 m
.71645 .26217 L
s
.80303 .143 m
.71645 .02383 L
s
.71645 .26217 m
.62987 .38134 L
s
.71645 .26217 m
.62987 .143 L
s
.62987 .38134 m
.54329 .5005 L
s
.62987 .38134 m
.54329 .26217 L
s
.54329 .5005 m
.45671 .61967 L
s
.54329 .5005 m
.45671 .38134 L
s
.45671 .61967 m
.37013 .73884 L
s
.45671 .61967 m
.37013 .5005 L
s
.37013 .73884 m
.28355 .858 L
s
.37013 .73884 m
.28355 .61967 L
s
.28355 .858 m
.19697 .73884 L
s
.71645 .02383 m
.62987 .143 L
s
.62987 .143 m
.54329 .26217 L
s
.62987 .143 m
.54329 .02383 L
s
.54329 .26217 m
.45671 .38134 L
s
.54329 .26217 m
.45671 .143 L
s
.45671 .38134 m
.37013 .5005 L
s
.45671 .38134 m
.37013 .26217 L
s
.37013 .5005 m
.28355 .61967 L
s
.37013 .5005 m
.28355 .38134 L
s
.28355 .61967 m
.19697 .73884 L
s
.28355 .61967 m
.19697 .5005 L
s
.19697 .73884 m
.11039 .858 L
s
.19697 .73884 m
.11039 .61967 L
s
.11039 .858 m
.02381 .73884 L
s
.54329 .02383 m
.45671 .143 L
s
.45671 .143 m
.37013 .26217 L
s
.45671 .143 m
.37013 .02383 L
s
.37013 .26217 m
.28355 .38134 L
s
.37013 .26217 m
.28355 .143 L
s
.28355 .38134 m
.19697 .5005 L
s
.28355 .38134 m
.19697 .26217 L
s
.19697 .5005 m
.11039 .61967 L
s
.19697 .5005 m
.11039 .38134 L
s
.11039 .61967 m
.02381 .73884 L
s
.11039 .61967 m
.02381 .5005 L
s
.37013 .02383 m
.28355 .143 L
s
.28355 .143 m
.19697 .26217 L
s
.19697 .26217 m
.11039 .38134 L
s
.19697 .26217 m
.11039 .143 L
s
.11039 .38134 m
.02381 .5005 L
s
.11039 .38134 m
.02381 .26217 L
s
.11039 .143 m
.02381 .26217 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[171]:=",
  ImageSize->{288, 288.25},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L006X700<01`L0;PL00`071`0_1`0300L70507001Y1`0300L002h700<01`00
;`L00`07001A1`00J@L00`07000^1`0300L002l700<01`00D@L006P700D01`L7000/1`0500L71`00
;@L01@071`L00507001W1`0300L700<700<01`L0:0L00`071`031`0300L702T700<01`L00`L00`07
1`1=1`00IPL00`071`051`0300L702H700<01`L01@L00`071`0W1`0300L700D700<01`L0C0L006H7
00<01`L01@L00`071`0V1`0300L700D700<01`L09`L00`071`051`0300L704`7001U1`0300L700L7
00<01`L090L00`071`071`0300L702D700<01`L01`L00`071`1;1`00I0L00`071`091`0300L70287
00<01`L02@L00`071`0S1`0300L700T700<01`L0BPL006<700<01`L02`L00`071`0Q1`0300L700X7
00<01`L08@L00`071`0;1`0300L704T7001S1`0300L700/700<01`L080L00`071`0;1`0300L70247
00<01`L02`L00`071`191`00HPL00`071`0=1`0300L701h700<01`L03@L00`071`0O1`0300L700d7
00<01`L0B0L0064700<01`L03`L00`071`0M1`0300L700h700<01`L07@L00`071`0?1`0300L704L7
001P1`0300L7014700<01`L06`L00`071`0@1`0300L701/700<01`L04@L00`071`161`00H0L00`07
1`0A1`0300L701X700<01`L04@L00`071`0K1`0300L7014700<01`L0APL005l700<01`L04`L00`07
1`0H1`0300L701<700<01`L06@L00`071`0C1`0300L704D7001N1`0300L701D700<01`L05`L00`07
1`0D1`0300L701L700<01`L05@L00`071`141`00GPL00`071`0E1`0300L701H700<01`L05@L00`07
1`0G1`0300L701D700<01`L0A0L005d700<01`L05`L00`071`0D1`0300L701L700<01`L05@L00`07
1`0G1`0300L704<7001L1`0300L701T700<01`L04`L00`071`0H1`0300L701<700<01`L06@L00`07
1`121`00F`L00`071`0K1`0300L7014700<01`L06PL00`071`0A1`0300L701/700<01`L0@@L005/7
00<01`L06`L00`071`0@1`0300L701/700<01`L04@L00`071`0K1`0300L70447001J1`0300L701d7
00<01`L03PL00`071`0M1`0300L700l700<01`L07@L00`071`101`00F@L00`071`0O1`0300L700d7
00<01`L07PL00`071`0=1`0300L701l700<01`L0?`L005P700<01`L08@L00`071`0;1`0300L70207
00<01`L02`L00`071`0Q1`0300L703h7001H1`0300L7024700<01`L02PL00`071`0Q1`0300L700/7
00<01`L08@L00`071`0n1`00E`L00`071`0S1`0300L700T700<01`L08PL00`071`091`0300L702<7
00<01`L0?@L005H700<01`L09@L00`071`071`0300L702@700<01`L01`L00`071`0U1`0300L703`7
001E1`0300L702L700<01`L01@L00`071`0V1`0300L700D700<01`L09`L00`071`0k1`00E@L00`07
1`0W1`0300L700D700<01`L09PL00`071`051`0300L702L700<01`L0>`L005@700<01`L0:@L00`07
1`031`0300L702P700<01`L00`L00`071`0Y1`0300L703X7001C1`0300L702/700D01`L7000/1`05
00L71`00;@L00`071`0i1`00DPL00`071`0]1`0300L002h700<01`00;`L00`071`0h1`00DPL00`07
1`0]1`0300L002h700<01`00;`L00`071`0h1`007`L00`071`0_1`0300L702l700<01`L0;PL00`07
1`0_1`0300L703L7000N1`0300L002l700<01`00;`L00`07000^1`0300L002l700<01`00>0L001h7
00<01`00;`L00`07000_1`0300L002h700<01`00;`L00`07000h1`007@L01@071`L002d700D01`L7
000]1`0500L71`00;0L01@071`L002d700D01`L7000g1`0070L00`071`031`0300L702T700<01`L0
0`L00`071`0Y1`0300L700<700<01`L0:0L00`071`031`0300L702T700<01`L00`L00`071`0d1`00
6`L00`071`051`0300L702L700<01`L01@L00`071`0W1`0300L700D700<01`L09PL00`071`051`03
00L702L700<01`L01@L00`071`0c1`006`L00`071`051`0300L702L700<01`L01@L00`071`0W1`03
00L700D700<01`L09PL00`071`051`0300L702L700<01`L01@L00`071`0c1`006PL00`071`071`03
00L702D700<01`L01`L00`071`0U1`0300L700L700<01`L090L00`071`071`0300L702D700<01`L0
1`L00`071`0b1`006@L00`071`091`0300L702<700<01`L02@L00`071`0S1`0300L700T700<01`L0
8PL00`071`091`0300L702<700<01`L02@L00`071`0a1`0060L00`071`0;1`0300L7024700<01`L0
2`L00`071`0Q1`0300L700X700<01`L08@L00`071`0;1`0300L7024700<01`L02`L00`071`0`1`00
60L00`071`0;1`0300L7024700<01`L02`L00`071`0Q1`0300L700/700<01`L080L00`071`0;1`03
00L7024700<01`L02`L00`071`0`1`005`L00`071`0=1`0300L701l700<01`L03@L00`071`0O1`03
00L700d700<01`L07PL00`071`0=1`0300L701l700<01`L03@L00`071`0_1`005PL00`071`0?1`03
00L701d700<01`L03`L00`071`0M1`0300L700h700<01`L07@L00`071`0?1`0300L701d700<01`L0
3`L00`071`0^1`005@L00`071`0A1`0300L701/700<01`L04@L00`071`0K1`0300L7010700<01`L0
6`L00`071`0A1`0300L701/700<01`L04@L00`071`0]1`005@L00`071`0A1`0300L701/700<01`L0
4@L00`071`0K1`0300L7014700<01`L06PL00`071`0A1`0300L701/700<01`L04@L00`071`0]1`00
50L00`071`0C1`0300L701T700<01`L04`L00`071`0I1`0300L701<700<01`L060L00`071`0C1`03
00L701T700<01`L04`L00`071`0/1`004`L00`071`0E1`0300L701L700<01`L05@L00`071`0G1`03
00L701@700<01`L05`L00`071`0E1`0300L701L700<01`L05@L00`071`0[1`004`L00`071`0E1`03
00L701L700<01`L05@L00`071`0G1`0300L701D700<01`L05PL00`071`0E1`0300L701L700<01`L0
5@L00`071`0[1`004PL00`071`0G1`0300L701D700<01`L05`L00`071`0E1`0300L701L700<01`L0
50L00`071`0G1`0300L701D700<01`L05`L00`071`0Z1`004@L00`071`0I1`0300L701<700<01`L0
6@L00`071`0C1`0300L701P700<01`L04`L00`071`0I1`0300L701<700<01`L06@L00`071`0Y1`00
40L00`071`0K1`0300L7014700<01`L06`L00`071`0A1`0300L701X700<01`L04@L00`071`0K1`03
00L7014700<01`L06`L00`071`0X1`0040L00`071`0K1`0300L7014700<01`L06`L00`071`0A1`03
00L701/700<01`L040L00`071`0K1`0300L7014700<01`L06`L00`071`0X1`003`L00`071`0M1`03
00L700l700<01`L07@L00`071`0?1`0300L701d700<01`L03PL00`071`0M1`0300L700l700<01`L0
7@L00`071`0W1`003PL00`071`0O1`0300L700d700<01`L07`L00`071`0=1`0300L701h700<01`L0
3@L00`071`0O1`0300L700d700<01`L07`L00`071`0V1`003@L00`071`0Q1`0300L700/700<01`L0
8@L00`071`0;1`0300L7020700<01`L02`L00`071`0Q1`0300L700/700<01`L08@L00`071`0U1`00
3@L00`071`0Q1`0300L700/700<01`L08@L00`071`0;1`0300L7024700<01`L02PL00`071`0Q1`03
00L700/700<01`L08@L00`071`0U1`0030L00`071`0S1`0300L700T700<01`L08`L00`071`091`03
00L7028700<01`L02@L00`071`0S1`0300L700T700<01`L08`L00`071`0T1`002`L00`071`0U1`03
00L700L700<01`L09@L00`071`071`0300L702@700<01`L01`L00`071`0U1`0300L700L700<01`L0
9@L00`071`0S1`002PL00`071`0W1`0300L700D700<01`L09`L00`071`051`0300L702H700<01`L0
1@L00`071`0W1`0300L700D700<01`L09`L00`071`0R1`002PL00`071`0W1`0300L700D700<01`L0
9`L00`071`051`0300L702H700<01`L01@L00`071`0W1`0300L700D700<01`L09`L00`071`0R1`00
2@L00`071`0Y1`0300L700<700<01`L0:@L00`071`031`0300L702P700<01`L00`L00`071`0Y1`03
00L700<700<01`L0:@L00`071`0Q1`0020L00`071`0[1`0500L71`00;@L01@071`L002`700D01`L7
000]1`0500L71`00;@L00`071`0P1`001`L00`071`0]1`0300L002l700<01`00;PL00`07000_1`03
00L002l700<01`L07`L000L700<01`L0;@L00`07000_1`0300L002h700<01`00;`L00`07000_1`03
00L701l700061`0300L702l700<01`L0;`L00`071`0^1`0300L702l700<01`L0;`L00`071`0N1`00
1`L00`071`0]1`0300L002l700<01`00;PL00`07000_1`0300L002l700<01`007`L000L700<01`L0
;@L00`07000_1`0300L002h700<01`00;`L00`07000_1`0300L001l700081`0300L702/700D01`L7
000]1`0500L71`00;0L01@071`L002d700D01`L7000]1`0500L71`007PL000T700<01`L0:@L00`07
1`031`0300L702T700<01`L00`L00`071`0X1`0300L700<700<01`L0:@L00`071`031`0300L702T7
00<01`L00`L00`071`0K1`002PL00`071`0W1`0300L700D700<01`L09`L00`071`051`0300L702L7
00<01`L010L00`071`0W1`0300L700D700<01`L09`L00`071`051`0300L701X7000:1`0300L702L7
00<01`L01@L00`071`0W1`0300L700D700<01`L09PL00`071`051`0300L702L700<01`L01@L00`07
1`0W1`0300L700D700<01`L06PL000/700<01`L09@L00`071`071`0300L702D700<01`L01`L00`07
1`0T1`0300L700L700<01`L09@L00`071`071`0300L702D700<01`L01`L00`071`0I1`0030L00`07
1`0S1`0300L700T700<01`L08`L00`071`091`0300L702<700<01`L020L00`071`0S1`0300L700T7
00<01`L08`L00`071`091`0300L701P7000<1`0300L702<700<01`L02@L00`071`0S1`0300L700T7
00<01`L08PL00`071`091`0300L702<700<01`L02@L00`071`0S1`0300L700T700<01`L060L000d7
00<01`L08@L00`071`0;1`0300L7024700<01`L02`L00`071`0P1`0300L700/700<01`L08@L00`07
1`0;1`0300L7024700<01`L02`L00`071`0G1`003PL00`071`0O1`0300L700d700<01`L07`L00`07
1`0=1`0300L701h700<01`L03@L00`071`0O1`0300L700d700<01`L07`L00`071`0=1`0300L701H7
000?1`0300L701d700<01`L03`L00`071`0M1`0300L700l700<01`L07@L00`071`0>1`0300L701d7
00<01`L03`L00`071`0M1`0300L700l700<01`L05@L000l700<01`L07@L00`071`0?1`0300L701d7
00<01`L03`L00`071`0L1`0300L700l700<01`L07@L00`071`0?1`0300L701d700<01`L03`L00`07
1`0E1`0040L00`071`0K1`0300L7014700<01`L06`L00`071`0A1`0300L701X700<01`L04@L00`07
1`0K1`0300L7014700<01`L06`L00`071`0A1`0300L701@7000A1`0300L701T700<01`L04`L00`07
1`0I1`0300L701<700<01`L06@L00`071`0B1`0300L701T700<01`L04`L00`071`0I1`0300L701<7
00<01`L04`L0014700<01`L06@L00`071`0C1`0300L701T700<01`L04`L00`071`0H1`0300L701<7
00<01`L06@L00`071`0C1`0300L701T700<01`L04`L00`071`0C1`004PL00`071`0G1`0300L701D7
00<01`L05`L00`071`0E1`0300L701H700<01`L05@L00`071`0G1`0300L701D700<01`L05`L00`07
1`0E1`0300L70187000C1`0300L701D700<01`L05`L00`071`0E1`0300L701L700<01`L05@L00`07
1`0F1`0300L701D700<01`L05`L00`071`0E1`0300L701L700<01`L04@L001@700<01`L04`L00`07
1`0I1`0300L701<700<01`L06@L00`071`0C1`0300L701P700<01`L04`L00`071`0I1`0300L701<7
00<01`L06@L00`071`0@1`0050L00`071`0C1`0300L701T700<01`L04`L00`071`0I1`0300L70187
00<01`L06@L00`071`0C1`0300L701T700<01`L04`L00`071`0I1`0300L70107000E1`0300L70147
00<01`L06`L00`071`0A1`0300L701/700<01`L04@L00`071`0J1`0300L7014700<01`L06`L00`07
1`0A1`0300L701/700<01`L03`L001H700<01`L03`L00`071`0M1`0300L700l700<01`L07@L00`07
1`0?1`0300L701`700<01`L03`L00`071`0M1`0300L700l700<01`L07@L00`071`0>1`005PL00`07
1`0?1`0300L701d700<01`L03`L00`071`0M1`0300L700h700<01`L07@L00`071`0?1`0300L701d7
00<01`L03`L00`071`0M1`0300L700h7000G1`0300L700d700<01`L07`L00`071`0=1`0300L701l7
00<01`L03@L00`071`0N1`0300L700d700<01`L07`L00`071`0=1`0300L701l700<01`L03@L001P7
00<01`L02`L00`071`0Q1`0300L700/700<01`L08@L00`071`0;1`0300L7020700<01`L02`L00`07
1`0Q1`0300L700/700<01`L08@L00`071`0<1`006@L00`071`091`0300L702<700<01`L02@L00`07
1`0S1`0300L700T700<01`L08PL00`071`091`0300L702<700<01`L02@L00`071`0S1`0300L700/7
000I1`0300L700T700<01`L08`L00`071`091`0300L702<700<01`L020L00`071`0S1`0300L700T7
00<01`L08`L00`071`091`0300L702<700<01`L02`L001X700<01`L01`L00`071`0U1`0300L700L7
00<01`L09@L00`071`071`0300L702@700<01`L01`L00`071`0U1`0300L700L700<01`L09@L00`07
1`0:1`006`L00`071`051`0300L702L700<01`L01@L00`071`0W1`0300L700D700<01`L09PL00`07
1`051`0300L702L700<01`L01@L00`071`0W1`0300L700T7000K1`0300L700D700<01`L09`L00`07
1`051`0300L702L700<01`L010L00`071`0W1`0300L700D700<01`L09`L00`071`051`0300L702L7
00<01`L02@L001`700<01`L00`L00`071`0Y1`0300L700<700<01`L0:@L00`071`031`0300L702P7
00<01`L00`L00`071`0Y1`0300L700<700<01`L0:@L00`071`081`007@L01@071`L002d700D01`L7
000]1`0500L71`00;0L01@071`L002d700D01`L7000]1`0300L700L7000N1`0300L002l700<01`00
;`L00`07000^1`0300L002l700<01`00;`L00`071`061`007PL00`07000_1`0300L002l700<01`00
;PL00`07000_1`0300L002l700<01`L01PL001l700<01`L0;`L00`071`0_1`0300L702h700<01`L0
;`L00`071`0_1`0300L700D7000N1`0300L002l700<01`00;`L00`07000^1`0300L002l700<01`00
;`L00`071`061`007PL00`07000_1`0300L002l700<01`00;PL00`07000_1`0300L002l700<01`L0
1PL001d700D01`L7000]1`0500L71`00;@L01@071`L002`700D01`L7000]1`0500L71`00;@L00`07
1`071`0070L00`071`031`0300L702T700<01`L00`L00`071`0Y1`0300L700<700<01`L0:0L00`07
1`031`0300L702T700<01`L00`L00`071`0Y1`0300L700P7000K1`0300L700D700<01`L09`L00`07
1`051`0300L702L700<01`L01@L00`071`0V1`0300L700D700<01`L09`L00`071`051`0300L702L7
00<01`L02@L001/700<01`L01@L00`071`0W1`0300L700D700<01`L09`L00`071`051`0300L702H7
00<01`L01@L00`071`0W1`0300L700D700<01`L09`L00`071`091`006PL00`071`071`0300L702D7
00<01`L01`L00`071`0U1`0300L700L700<01`L090L00`071`071`0300L702D700<01`L01`L00`07
1`0U1`0300L700X7000I1`0300L700T700<01`L08`L00`071`091`0300L702<700<01`L02@L00`07
1`0R1`0300L700T700<01`L08`L00`071`091`0300L702<700<01`L02`L001P700<01`L02`L00`07
1`0Q1`0300L700/700<01`L08@L00`071`0:1`0300L7024700<01`L02`L00`071`0Q1`0300L700/7
00<01`L08@L00`071`0<1`0060L00`071`0;1`0300L7024700<01`L02`L00`071`0Q1`0300L700/7
00<01`L080L00`071`0;1`0300L7024700<01`L02`L00`071`0Q1`0300L700`7000G1`0300L700d7
00<01`L07`L00`071`0=1`0300L701l700<01`L03@L00`071`0N1`0300L700d700<01`L07`L00`07
1`0=1`0300L701l700<01`L03@L001H700<01`L03`L00`071`0M1`0300L700l700<01`L07@L00`07
1`0>1`0300L701d700<01`L03`L00`071`0M1`0300L700l700<01`L07@L00`071`0>1`005@L00`07
1`0A1`0300L701/700<01`L04@L00`071`0K1`0300L7010700<01`L06`L00`071`0A1`0300L701/7
00<01`L04@L00`071`0K1`0300L700l7000E1`0300L7014700<01`L06`L00`071`0A1`0300L701/7
00<01`L04@L00`071`0J1`0300L7014700<01`L06`L00`071`0A1`0300L701/700<01`L03`L001@7
00<01`L04`L00`071`0I1`0300L701<700<01`L06@L00`071`0C1`0300L701P700<01`L04`L00`07
1`0I1`0300L701<700<01`L06@L00`071`0@1`004`L00`071`0E1`0300L701L700<01`L05@L00`07
1`0G1`0300L701@700<01`L05`L00`071`0E1`0300L701L700<01`L05@L00`071`0G1`0300L70147
000C1`0300L701D700<01`L05`L00`071`0E1`0300L701L700<01`L05@L00`071`0F1`0300L701D7
00<01`L05`L00`071`0E1`0300L701L700<01`L04@L0018700<01`L05`L00`071`0E1`0300L701L7
00<01`L05@L00`071`0G1`0300L701@700<01`L05`L00`071`0E1`0300L701L700<01`L05@L00`07
1`0B1`004@L00`071`0I1`0300L701<700<01`L06@L00`071`0C1`0300L701P700<01`L04`L00`07
1`0I1`0300L701<700<01`L06@L00`071`0C1`0300L701<7000@1`0300L701/700<01`L04@L00`07
1`0K1`0300L7014700<01`L06PL00`071`0A1`0300L701/700<01`L04@L00`071`0K1`0300L70147
00<01`L050L0010700<01`L06`L00`071`0A1`0300L701/700<01`L04@L00`071`0K1`0300L70107
00<01`L06`L00`071`0A1`0300L701/700<01`L04@L00`071`0D1`003`L00`071`0M1`0300L700l7
00<01`L07@L00`071`0?1`0300L701d700<01`L03PL00`071`0M1`0300L700l700<01`L07@L00`07
1`0?1`0300L701D7000>1`0300L701l700<01`L03@L00`071`0O1`0300L700d700<01`L07PL00`07
1`0=1`0300L701l700<01`L03@L00`071`0O1`0300L700d700<01`L05PL000d700<01`L08@L00`07
1`0;1`0300L7024700<01`L02`L00`071`0P1`0300L700/700<01`L08@L00`071`0;1`0300L70247
00<01`L02`L00`071`0G1`003@L00`071`0Q1`0300L700/700<01`L08@L00`071`0;1`0300L70247
00<01`L02PL00`071`0Q1`0300L700/700<01`L08@L00`071`0;1`0300L701L7000<1`0300L702<7
00<01`L02@L00`071`0S1`0300L700T700<01`L08PL00`071`091`0300L702<700<01`L02@L00`07
1`0S1`0300L700T700<01`L060L000/700<01`L09@L00`071`071`0300L702D700<01`L01`L00`07
1`0T1`0300L700L700<01`L09@L00`071`071`0300L702D700<01`L01`L00`071`0I1`002PL00`07
1`0W1`0300L700D700<01`L09`L00`071`051`0300L702H700<01`L01@L00`071`0W1`0300L700D7
00<01`L09`L00`071`051`0300L701X7000:1`0300L702L700<01`L01@L00`071`0W1`0300L700D7
00<01`L09PL00`071`051`0300L702L700<01`L01@L00`071`0W1`0300L700D700<01`L06PL000T7
00<01`L0:@L00`071`031`0300L702T700<01`L00`L00`071`0X1`0300L700<700<01`L0:@L00`07
1`031`0300L702T700<01`L00`L00`071`0K1`0020L00`071`0[1`0500L71`00;@L01@071`L002`7
00D01`L7000]1`0500L71`00;@L01@071`L001h700071`0300L702d700<01`00;`L00`07000^1`03
00L002l700<01`00;`L00`07000O1`001`L00`071`0]1`0300L002l700<01`00;PL00`07000_1`03
00L002l700<01`007`L000H700<01`L0;`L00`071`0_1`0300L702h700<01`L0;`L00`071`0_1`03
00L701h700071`0300L702d700<01`00;`L00`07000^1`0300L002l700<01`00;`L00`07000O1`00
1`L00`071`0]1`0300L002l700<01`00;PL00`07000_1`0300L002l700<01`007`L000P700<01`L0
:`L01@071`L002d700D01`L7000/1`0500L71`00;@L01@071`L002d700D01`L7000N1`002@L00`07
1`0Y1`0300L700<700<01`L0:@L00`071`031`0300L702P700<01`L00`L00`071`0Y1`0300L700<7
00<01`L0:@L00`071`031`0300L701/7000:1`0300L702L700<01`L01@L00`071`0W1`0300L700D7
00<01`L09PL00`071`051`0300L702L700<01`L01@L00`071`0W1`0300L700D700<01`L06PL000X7
00<01`L09`L00`071`051`0300L702L700<01`L01@L00`071`0V1`0300L700D700<01`L09`L00`07
1`051`0300L702L700<01`L01@L00`071`0J1`002`L00`071`0U1`0300L700L700<01`L09@L00`07
1`071`0300L702@700<01`L01`L00`071`0U1`0300L700L700<01`L09@L00`071`071`0300L701T7
000<1`0300L702<700<01`L02@L00`071`0S1`0300L700T700<01`L08PL00`071`091`0300L702<7
00<01`L02@L00`071`0S1`0300L700T700<01`L060L000d700<01`L08@L00`071`0;1`0300L70247
00<01`L02`L00`071`0Q1`0300L700X700<01`L08@L00`071`0;1`0300L7024700<01`L02`L00`07
1`0G1`003@L00`071`0Q1`0300L700/700<01`L08@L00`071`0;1`0300L7020700<01`L02`L00`07
1`0Q1`0300L700/700<01`L08@L00`071`0;1`0300L701L7000>1`0300L701l700<01`L03@L00`07
1`0O1`0300L700d700<01`L07PL00`071`0=1`0300L701l700<01`L03@L00`071`0O1`0300L700d7
00<01`L05PL000l700<01`L07@L00`071`0?1`0300L701d700<01`L03`L00`071`0M1`0300L700h7
00<01`L07@L00`071`0?1`0300L701d700<01`L03`L00`071`0E1`0040L00`071`0K1`0300L70147
00<01`L06`L00`071`0A1`0300L701/700<01`L040L00`071`0K1`0300L7014700<01`L06`L00`07
1`0A1`0300L701@7000@1`0300L701/700<01`L04@L00`071`0K1`0300L7014700<01`L06PL00`07
1`0A1`0300L701/700<01`L04@L00`071`0K1`0300L7014700<01`L050L0014700<01`L06@L00`07
1`0C1`0300L701T700<01`L04`L00`071`0H1`0300L701<700<01`L06@L00`071`0C1`0300L701T7
00<01`L04`L00`071`0C1`004PL00`071`0G1`0300L701D700<01`L05`L00`071`0E1`0300L701L7
00<01`L050L00`071`0G1`0300L701D700<01`L05`L00`071`0E1`0300L70187000B1`0300L701L7
00<01`L05@L00`071`0G1`0300L701D700<01`L05PL00`071`0E1`0300L701L700<01`L05@L00`07
1`0G1`0300L701D700<01`L04PL001<700<01`L05@L00`071`0G1`0300L701D700<01`L05`L00`07
1`0D1`0300L701L700<01`L05@L00`071`0G1`0300L701D700<01`L05`L00`071`0A1`0050L00`07
1`0C1`0300L701T700<01`L04`L00`071`0I1`0300L701<700<01`L060L00`071`0C1`0300L701T7
00<01`L04`L00`071`0I1`0300L70107000E1`0300L7014700<01`L06`L00`071`0A1`0300L701/7
00<01`L04@L00`071`0J1`0300L7014700<01`L06`L00`071`0A1`0300L701/700<01`L03`L001D7
00<01`L04@L00`071`0K1`0300L7014700<01`L06`L00`071`0@1`0300L701/700<01`L04@L00`07
1`0K1`0300L7014700<01`L06`L00`071`0?1`005PL00`071`0?1`0300L701d700<01`L03`L00`07
1`0M1`0300L700h700<01`L07@L00`071`0?1`0300L701d700<01`L03`L00`071`0M1`0300L700h7
000G1`0300L700d700<01`L07`L00`071`0=1`0300L701l700<01`L03@L00`071`0N1`0300L700d7
00<01`L07`L00`071`0=1`0300L701l700<01`L03@L001P700<01`L02`L00`071`0Q1`0300L700/7
00<01`L08@L00`071`0;1`0300L7020700<01`L02`L00`071`0Q1`0300L700/700<01`L08@L00`07
1`0<1`0060L00`071`0;1`0300L7024700<01`L02`L00`071`0Q1`0300L700X700<01`L08@L00`07
1`0;1`0300L7024700<01`L02`L00`071`0Q1`0300L700`7000I1`0300L700T700<01`L08`L00`07
1`091`0300L702<700<01`L02@L00`071`0R1`0300L700T700<01`L08`L00`071`091`0300L702<7
00<01`L02`L001X700<01`L01`L00`071`0U1`0300L700L700<01`L09@L00`071`071`0300L702@7
00<01`L01`L00`071`0U1`0300L700L700<01`L09@L00`071`0:1`006`L00`071`051`0300L702L7
00<01`L01@L00`071`0W1`0300L700D700<01`L09PL00`071`051`0300L702L700<01`L01@L00`07
1`0W1`0300L700T7000K1`0300L700D700<01`L09`L00`071`051`0300L702L700<01`L01@L00`07
1`0V1`0300L700D700<01`L09`L00`071`051`0300L702L700<01`L02@L001`700<01`L00`L00`07
1`0Y1`0300L700<700<01`L0:@L00`071`031`0300L702P700<01`L00`L00`071`0Y1`0300L700<7
00<01`L0:@L00`071`081`007@L01@071`L002d700D01`L7000]1`0500L71`00;0L01@071`L002d7
00D01`L7000]1`0300L700L7000N1`0300L002l700<01`00;`L00`07000^1`0300L002l700<01`00
;`L00`071`061`007PL00`07000_1`0300L002l700<01`00;PL00`07000_1`0300L002l700<01`L0
1PL001l700<01`L0;`L00`071`0_1`0300L702h700<01`L0;`L00`071`0_1`0300L700D7000N1`03
00L002l700<01`00;`L00`07000^1`0300L002l700<01`00;`L00`071`061`007PL00`07000_1`03
00L002l700<01`00;PL00`07000_1`0300L002l700<01`L01PL001d700D01`L7000]1`0500L71`00
;@L01@071`L002`700D01`L7000]1`0500L71`00;@L00`071`071`0070L00`071`031`0300L702T7
00<01`L00`L00`071`0Y1`0300L700<700<01`L0:0L00`071`031`0300L702T700<01`L00`L00`07
1`0Y1`0300L700P7000K1`0300L700D700<01`L09`L00`071`051`0300L702L700<01`L01@L00`07
1`0V1`0300L700D700<01`L09`L00`071`051`0300L702L700<01`L02@L001/700<01`L01@L00`07
1`0W1`0300L700D700<01`L09`L00`071`051`0300L702H700<01`L01@L00`071`0W1`0300L700D7
00<01`L09`L00`071`091`006PL00`071`071`0300L702D700<01`L01`L00`071`0U1`0300L700L7
00<01`L090L00`071`071`0300L702D700<01`L01`L00`071`0U1`0300L700X7000I1`0300L700T7
00<01`L08`L00`071`091`0300L702<700<01`L02@L00`071`0R1`0300L700T700<01`L08`L00`07
1`091`0300L702<700<01`L02`L001P700<01`L02`L00`071`0Q1`0300L700/700<01`L08@L00`07
1`0:1`0300L7024700<01`L02`L00`071`0Q1`0300L700/700<01`L08@L00`071`0<1`0060L00`07
1`0;1`0300L7024700<01`L02`L00`071`0Q1`0300L700/700<01`L080L00`071`0;1`0300L70247
00<01`L02`L00`071`0Q1`0300L700`7000G1`0300L700d700<01`L07`L00`071`0=1`0300L701l7
00<01`L03@L00`071`0N1`0300L700d700<01`L07`L00`071`0=1`0300L701l700<01`L03@L001H7
00<01`L03`L00`071`0M1`0300L700l700<01`L07@L00`071`0>1`0300L701d700<01`L03`L00`07
1`0M1`0300L700l700<01`L07@L00`071`0>1`005@L00`071`0A1`0300L701/700<01`L04@L00`07
1`0K1`0300L7010700<01`L06`L00`071`0A1`0300L701/700<01`L04@L00`071`0K1`0300L700l7
000E1`0300L7014700<01`L06`L00`071`0A1`0300L701/700<01`L04@L00`071`0J1`0300L70147
00<01`L06`L00`071`0A1`0300L701/700<01`L03`L001@700<01`L04`L00`071`0I1`0300L701<7
00<01`L06@L00`071`0C1`0300L701P700<01`L04`L00`071`0I1`0300L701<700<01`L06@L00`07
1`0@1`004`L00`071`0E1`0300L701L700<01`L05@L00`071`0G1`0300L701@700<01`L05`L00`07
1`0E1`0300L701L700<01`L05@L00`071`0G1`0300L70147000C1`0300L701D700<01`L05`L00`07
1`0E1`0300L701L700<01`L05@L00`071`0F1`0300L701D700<01`L05`L00`071`0E1`0300L701L7
00<01`L04@L0018700<01`L05`L00`071`0E1`0300L701L700<01`L05@L00`071`0G1`0300L701@7
00<01`L05`L00`071`0E1`0300L701L700<01`L05@L00`071`0B1`004@L00`071`0I1`0300L701<7
00<01`L06@L00`071`0C1`0300L701P700<01`L04`L00`071`0I1`0300L701<700<01`L06@L00`07
1`0C1`0300L701<7000@1`0300L701/700<01`L04@L00`071`0K1`0300L7014700<01`L06PL00`07
1`0A1`0300L701/700<01`L04@L00`071`0K1`0300L7014700<01`L050L0010700<01`L06`L00`07
1`0A1`0300L701/700<01`L04@L00`071`0K1`0300L7010700<01`L06`L00`071`0A1`0300L701/7
00<01`L04@L00`071`0D1`003`L00`071`0M1`0300L700l700<01`L07@L00`071`0?1`0300L701d7
00<01`L03PL00`071`0M1`0300L700l700<01`L07@L00`071`0?1`0300L701D7000>1`0300L701l7
00<01`L03@L00`071`0O1`0300L700d700<01`L07PL00`071`0=1`0300L701l700<01`L03@L00`07
1`0O1`0300L700d700<01`L05PL000d700<01`L08@L00`071`0;1`0300L7024700<01`L02`L00`07
1`0P1`0300L700/700<01`L08@L00`071`0;1`0300L7024700<01`L02`L00`071`0G1`003@L00`07
1`0Q1`0300L700/700<01`L08@L00`071`0;1`0300L7024700<01`L02PL00`071`0Q1`0300L700/7
00<01`L08@L00`071`0;1`0300L701L7000<1`0300L702<700<01`L02@L00`071`0S1`0300L700T7
00<01`L08PL00`071`091`0300L702<700<01`L02@L00`071`0S1`0300L700T700<01`L060L000/7
00<01`L09@L00`071`071`0300L702D700<01`L01`L00`071`0T1`0300L700L700<01`L09@L00`07
1`071`0300L702D700<01`L01`L00`071`0I1`002PL00`071`0W1`0300L700D700<01`L09`L00`07
1`051`0300L702H700<01`L01@L00`071`0W1`0300L700D700<01`L09`L00`071`051`0300L701X7
000:1`0300L702L700<01`L01@L00`071`0W1`0300L700D700<01`L09PL00`071`051`0300L702L7
00<01`L01@L00`071`0W1`0300L700D700<01`L06PL000T700<01`L0:@L00`071`031`0300L702T7
00<01`L00`L00`071`0X1`0300L700<700<01`L0:@L00`071`031`0300L702T700<01`L00`L00`07
1`0K1`0020L00`071`0[1`0500L71`00;@L01@071`L002`700D01`L7000]1`0500L71`00;@L01@07
1`L001h700071`0300L702d700<01`00;`L00`07000^1`0300L002l700<01`00;`L00`07000O1`00
1`L00`071`0]1`0300L002l700<01`00;PL00`07000_1`0300L002l700<01`007`L000H700<01`L0
;`L00`071`0_1`0300L702h700<01`L0;`L00`071`0_1`0300L701h700071`0300L702d700<01`00
;`L00`07000^1`0300L002l700<01`00;`L00`071`0O1`001`L00`071`0]1`0300L002l700<01`00
;PL00`07000_1`0300L002l700<01`L07`L000P700<01`L0:`L01@071`L002d700D01`L7000/1`05
00L71`00;@L01@071`L002d700<01`L080L000T700<01`L0:@L00`071`031`0300L702T700<01`L0
0`L00`071`0X1`0300L700<700<01`L0:@L00`071`031`0300L702T700<01`L08@L000X700<01`L0
9`L00`071`051`0300L702L700<01`L01@L00`071`0V1`0300L700D700<01`L09`L00`071`051`03
00L702L700<01`L08PL000X700<01`L09`L00`071`051`0300L702L700<01`L01@L00`071`0V1`03
00L700D700<01`L09`L00`071`051`0300L702L700<01`L08PL000/700<01`L09@L00`071`071`03
00L702D700<01`L01`L00`071`0T1`0300L700L700<01`L09@L00`071`071`0300L702D700<01`L0
8`L000`700<01`L08`L00`071`091`0300L702<700<01`L02@L00`071`0R1`0300L700T700<01`L0
8`L00`071`091`0300L702<700<01`L090L000d700<01`L08@L00`071`0;1`0300L7024700<01`L0
2`L00`071`0Q1`0300L700X700<01`L08@L00`071`0;1`0300L7024700<01`L09@L000d700<01`L0
8@L00`071`0;1`0300L7024700<01`L02`L00`071`0P1`0300L700/700<01`L08@L00`071`0;1`03
00L7024700<01`L09@L000h700<01`L07`L00`071`0=1`0300L701l700<01`L03@L00`071`0N1`03
00L700d700<01`L07`L00`071`0=1`0300L701l700<01`L09PL000l700<01`L07@L00`071`0?1`03
00L701d700<01`L03`L00`071`0M1`0300L700h700<01`L07@L00`071`0?1`0300L701d700<01`L0
9`L0010700<01`L06`L00`071`0A1`0300L701/700<01`L04@L00`071`0K1`0300L7010700<01`L0
6`L00`071`0A1`0300L701/700<01`L0:0L0010700<01`L06`L00`071`0A1`0300L701/700<01`L0
4@L00`071`0J1`0300L7014700<01`L06`L00`071`0A1`0300L701/700<01`L0:0L0014700<01`L0
6@L00`071`0C1`0300L701T700<01`L04`L00`071`0H1`0300L701<700<01`L06@L00`071`0C1`03
00L701T700<01`L0:@L0018700<01`L05`L00`071`0E1`0300L701L700<01`L05@L00`071`0G1`03
00L701@700<01`L05`L00`071`0E1`0300L701L700<01`L0:PL0018700<01`L05`L00`071`0E1`03
00L701L700<01`L05@L00`071`0F1`0300L701D700<01`L05`L00`071`0E1`0300L701L700<01`L0
:PL001<700<01`L05@L00`071`0G1`0300L701D700<01`L05`L00`071`0D1`0300L701L700<01`L0
5@L00`071`0G1`0300L701D700<01`L0:`L001@700<01`L04`L00`071`0I1`0300L701<700<01`L0
6@L00`071`0C1`0300L701P700<01`L04`L00`071`0I1`0300L701<700<01`L0;0L001D700<01`L0
4@L00`071`0K1`0300L7014700<01`L06`L00`071`0A1`0300L701X700<01`L04@L00`071`0K1`03
00L7014700<01`L0;@L001D700<01`L04@L00`071`0K1`0300L7014700<01`L06`L00`071`0@1`03
00L701/700<01`L04@L00`071`0K1`0300L7014700<01`L0;@L001H700<01`L03`L00`071`0M1`03
00L700l700<01`L07@L00`071`0>1`0300L701d700<01`L03`L00`071`0M1`0300L700l700<01`L0
;PL001L700<01`L03@L00`071`0O1`0300L700d700<01`L07`L00`071`0=1`0300L701h700<01`L0
3@L00`071`0O1`0300L700d700<01`L0;`L001P700<01`L02`L00`071`0Q1`0300L700/700<01`L0
8@L00`071`0;1`0300L7020700<01`L02`L00`071`0Q1`0300L700/700<01`L0<0L001P700<01`L0
2`L00`071`0Q1`0300L700/700<01`L08@L00`071`0:1`0300L7024700<01`L02`L00`071`0Q1`03
00L700/700<01`L0<0L001T700<01`L02@L00`071`0S1`0300L700T700<01`L08`L00`071`091`03
00L7028700<01`L02@L00`071`0S1`0300L700T700<01`L0<@L001X700<01`L01`L00`071`0U1`03
00L700L700<01`L09@L00`071`071`0300L702@700<01`L01`L00`071`0U1`0300L700L700<01`L0
<PL001/700<01`L01@L00`071`0W1`0300L700D700<01`L09`L00`071`051`0300L702H700<01`L0
1@L00`071`0W1`0300L700D700<01`L0<`L001/700<01`L01@L00`071`0W1`0300L700D700<01`L0
9`L00`071`051`0300L702H700<01`L01@L00`071`0W1`0300L700D700<01`L0<`L001`700<01`L0
0`L00`071`0Y1`0300L700<700<01`L0:@L00`071`031`0300L702P700<01`L00`L00`071`0Y1`03
00L700<700<01`L0=0L001d700D01`L7000]1`0500L71`00;@L01@071`L002`700D01`L7000]1`05
00L71`00=`L001h700<01`00;`L00`07000_1`0300L002h700<01`00;`L00`07000h1`007PL00`07
000_1`0300L002l700<01`00;PL00`07000_1`0300L003P7000O1`0300L702l700<01`L0;`L00`07
1`0^1`0300L702l700<01`L0=`L0058700<01`L0;@L00`07000^1`0300L002l700<01`L0>0L00587
00<01`L0;@L00`07000^1`0300L002l700<01`L0>0L005<700<01`L0:`L01@071`L002`700D01`L7
000]1`0300L703T7001D1`0300L702T700<01`L00`L00`071`0X1`0300L700<700<01`L0:@L00`07
1`0j1`00E@L00`071`0W1`0300L700@700<01`L09`L00`071`051`0300L702L700<01`L0>`L005D7
00<01`L09`L00`071`051`0300L702H700<01`L01@L00`071`0W1`0300L703/7001F1`0300L702D7
00<01`L01`L00`071`0T1`0300L700L700<01`L09@L00`071`0l1`00E`L00`071`0S1`0300L700P7
00<01`L08`L00`071`091`0300L702<700<01`L0?@L005L700<01`L08`L00`071`091`0300L70287
00<01`L02@L00`071`0S1`0300L703d7001H1`0300L7024700<01`L02`L00`071`0P1`0300L700/7
00<01`L08@L00`071`0n1`00F@L00`071`0O1`0300L700d700<01`L07PL00`071`0=1`0300L701l7
00<01`L0?`L005X700<01`L07@L00`071`0>1`0300L701d700<01`L03`L00`071`0M1`0300L70407
001J1`0300L701d700<01`L03`L00`071`0L1`0300L700l700<01`L07@L00`071`101`00F`L00`07
1`0K1`0300L7014700<01`L06PL00`071`0A1`0300L701/700<01`L0@@L005`700<01`L06@L00`07
1`0B1`0300L701T700<01`L04`L00`071`0I1`0300L70487001L1`0300L701T700<01`L04`L00`07
1`0H1`0300L701<700<01`L06@L00`071`121`00G@L00`071`0G1`0300L701D700<01`L05PL00`07
1`0E1`0300L701L700<01`L0@`L005h700<01`L05@L00`071`0F1`0300L701D700<01`L05`L00`07
1`0E1`0300L704@7001O1`0300L701<700<01`L060L00`071`0C1`0300L701T700<01`L04`L00`07
1`151`00G`L00`071`0C1`0300L701T700<01`L04PL00`071`0I1`0300L701<700<01`L0A@L00607
00<01`L04@L00`071`0J1`0300L7014700<01`L06`L00`071`0A1`0300L704H7001Q1`0300L700l7
00<01`L070L00`071`0?1`0300L701d700<01`L03`L00`071`171`00H@L00`071`0?1`0300L701d7
00<01`L03PL00`071`0M1`0300L700l700<01`L0A`L0068700<01`L03@L00`071`0N1`0300L700d7
00<01`L07`L00`071`0=1`0300L704P7001S1`0300L700/700<01`L080L00`071`0;1`0300L70247
00<01`L02`L00`071`191`00I0L00`071`091`0300L7028700<01`L02@L00`071`0S1`0300L700T7
00<01`L0BPL006@700<01`L02@L00`071`0S1`0300L700P700<01`L08`L00`071`091`0300L704X7
001U1`0300L700L700<01`L090L00`071`071`0300L702D700<01`L01`L00`071`1;1`00IPL00`07
1`051`0300L702H700<01`L01@L00`071`0W1`0300L700D700<01`L0C0L006H700<01`L01@L00`07
1`0W1`0300L700@700<01`L09`L00`071`051`0300L704`7001W1`0300L700<700<01`L0:0L00`07
1`031`0300L702T700<01`L00`L00`071`1=1`00J0L01@071`L002`700D01`L7000]1`0500L71`00
D0L006T700<01`00;PL00`07000_1`0300L00547001Y1`0300L002h700<01`00;`L00`07001A1`00
JPL00`071`0^1`0300L702l700<01`L0D0L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287.25, 0}} -> {-8.88788, -8.93413, \
0.0621895, 0.0621895}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[171]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice43\  = 
      tiling2D[SphericalCut[N[Join[AL043, \ AL143, \ AL243, \ AL343]], 10], \ 
        rad43]\)], "Input",
  CellLabel->"In[172]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .98099 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.500008 0.0513662 0.490609 0.0513662 [
[ 0 0 0 0 ]
[ 1 .98099 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .98099 L
0 .98099 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.93838 .59973 m
.85902 .70897 L
s
.93838 .59973 m
.85902 .4905 L
s
.85902 .70897 m
.77965 .81821 L
s
.85902 .70897 m
.77965 .59973 L
s
.77965 .81821 m
.70029 .92744 L
s
.77965 .81821 m
.70029 .70897 L
s
.70029 .92744 m
.62092 .81821 L
s
.93838 .38126 m
.85902 .4905 L
s
.93838 .38126 m
.85902 .27202 L
s
.85902 .4905 m
.77965 .59973 L
s
.85902 .4905 m
.77965 .38126 L
s
.77965 .59973 m
.70029 .70897 L
s
.77965 .59973 m
.70029 .4905 L
s
.70029 .70897 m
.62092 .81821 L
s
.70029 .70897 m
.62092 .59973 L
s
.62092 .81821 m
.54156 .92744 L
s
.62092 .81821 m
.54156 .70897 L
s
.54156 .92744 m
.46219 .81821 L
s
.85902 .27202 m
.77965 .38126 L
s
.85902 .27202 m
.77965 .16279 L
s
.77965 .38126 m
.70029 .4905 L
s
.77965 .38126 m
.70029 .27202 L
s
.70029 .4905 m
.62092 .59973 L
s
.70029 .4905 m
.62092 .38126 L
s
.62092 .59973 m
.54156 .70897 L
s
.62092 .59973 m
.54156 .4905 L
s
.54156 .70897 m
.46219 .81821 L
s
.54156 .70897 m
.46219 .59973 L
s
.46219 .81821 m
.38283 .92744 L
s
.46219 .81821 m
.38283 .70897 L
s
.38283 .92744 m
.30346 .81821 L
s
.77965 .16279 m
.70029 .27202 L
s
.77965 .16279 m
.70029 .05355 L
s
.70029 .27202 m
.62092 .38126 L
s
.70029 .27202 m
.62092 .16279 L
s
.62092 .38126 m
.54156 .4905 L
s
.62092 .38126 m
.54156 .27202 L
s
.54156 .4905 m
.46219 .59973 L
s
.54156 .4905 m
.46219 .38126 L
s
.46219 .59973 m
.38283 .70897 L
s
.46219 .59973 m
.38283 .4905 L
s
.38283 .70897 m
.30346 .81821 L
s
.38283 .70897 m
.30346 .59973 L
s
.30346 .81821 m
.2241 .70897 L
s
.70029 .05355 m
.62092 .16279 L
s
.62092 .16279 m
.54156 .27202 L
s
.62092 .16279 m
.54156 .05355 L
s
.54156 .27202 m
.46219 .38126 L
s
.54156 .27202 m
.46219 .16279 L
s
.46219 .38126 m
.38283 .4905 L
s
.46219 .38126 m
.38283 .27202 L
s
.38283 .4905 m
.30346 .59973 L
s
.38283 .4905 m
.30346 .38126 L
s
.30346 .59973 m
.2241 .70897 L
s
.30346 .59973 m
.2241 .4905 L
s
.2241 .70897 m
.14473 .81821 L
s
.2241 .70897 m
.14473 .59973 L
s
.14473 .81821 m
.06537 .70897 L
s
.54156 .05355 m
.46219 .16279 L
s
.46219 .16279 m
.38283 .27202 L
s
.46219 .16279 m
.38283 .05355 L
s
.38283 .27202 m
.30346 .38126 L
s
.38283 .27202 m
.30346 .16279 L
s
.30346 .38126 m
.2241 .4905 L
s
.30346 .38126 m
.2241 .27202 L
s
.2241 .4905 m
.14473 .59973 L
s
.2241 .4905 m
.14473 .38126 L
s
.14473 .59973 m
.06537 .70897 L
s
.14473 .59973 m
.06537 .4905 L
s
.38283 .05355 m
.30346 .16279 L
s
.30346 .16279 m
.2241 .27202 L
s
.2241 .27202 m
.14473 .38126 L
s
.2241 .27202 m
.14473 .16279 L
s
.14473 .38126 m
.06537 .4905 L
s
.14473 .38126 m
.06537 .27202 L
s
.14473 .16279 m
.06537 .27202 L
s
.97619 .67878 m
.89683 .78801 L
s
.97619 .67878 m
.89683 .56954 L
s
.89683 .78801 m
.81746 .67878 L
s
.97619 .4603 m
.89683 .56954 L
s
.97619 .4603 m
.89683 .35107 L
s
.89683 .56954 m
.81746 .67878 L
s
.89683 .56954 m
.81746 .4603 L
s
.81746 .67878 m
.7381 .78801 L
s
.81746 .67878 m
.7381 .56954 L
s
.7381 .78801 m
.65873 .89725 L
s
.7381 .78801 m
.65873 .67878 L
s
.65873 .89725 m
.57937 .78801 L
s
.89683 .35107 m
.81746 .4603 L
s
.89683 .35107 m
.81746 .24183 L
s
.81746 .4603 m
.7381 .56954 L
s
.81746 .4603 m
.7381 .35107 L
s
.7381 .56954 m
.65873 .67878 L
s
.7381 .56954 m
.65873 .4603 L
s
.65873 .67878 m
.57937 .78801 L
s
.65873 .67878 m
.57937 .56954 L
s
.57937 .78801 m
.5 .89725 L
s
.57937 .78801 m
.5 .67878 L
s
.5 .89725 m
.42063 .78801 L
s
.81746 .24183 m
.7381 .35107 L
s
.81746 .24183 m
.7381 .13259 L
s
.7381 .35107 m
.65873 .4603 L
s
.7381 .35107 m
.65873 .24183 L
s
.65873 .4603 m
.57937 .56954 L
s
.65873 .4603 m
.57937 .35107 L
s
.57937 .56954 m
.5 .67878 L
s
.57937 .56954 m
.5 .4603 L
s
.5 .67878 m
.42063 .78801 L
s
.5 .67878 m
.42063 .56954 L
s
.42063 .78801 m
.34127 .89725 L
s
.42063 .78801 m
.34127 .67878 L
s
.34127 .89725 m
.2619 .78801 L
s
.7381 .13259 m
.65873 .24183 L
s
.7381 .13259 m
.65873 .02336 L
s
.65873 .24183 m
.57937 .35107 L
s
.65873 .24183 m
.57937 .13259 L
s
.57937 .35107 m
.5 .4603 L
s
.57937 .35107 m
.5 .24183 L
s
.5 .4603 m
.42063 .56954 L
s
.5 .4603 m
.42063 .35107 L
s
.42063 .56954 m
.34127 .67878 L
s
.42063 .56954 m
.34127 .4603 L
s
.34127 .67878 m
.2619 .78801 L
s
.34127 .67878 m
.2619 .56954 L
s
.2619 .78801 m
.18254 .67878 L
s
.65873 .02336 m
.57937 .13259 L
s
.57937 .13259 m
.5 .24183 L
s
.57937 .13259 m
.5 .02336 L
s
.5 .24183 m
.42063 .35107 L
s
.5 .24183 m
.42063 .13259 L
s
.42063 .35107 m
.34127 .4603 L
s
.42063 .35107 m
.34127 .24183 L
s
.34127 .4603 m
.2619 .56954 L
s
.34127 .4603 m
.2619 .35107 L
s
.2619 .56954 m
.18254 .67878 L
s
.2619 .56954 m
.18254 .4603 L
s
.18254 .67878 m
.10317 .78801 L
s
.18254 .67878 m
.10317 .56954 L
s
.10317 .78801 m
.02381 .67878 L
s
.5 .02336 m
.42063 .13259 L
s
.42063 .13259 m
.34127 .24183 L
s
.42063 .13259 m
.34127 .02336 L
s
.34127 .24183 m
.2619 .35107 L
s
.34127 .24183 m
.2619 .13259 L
s
.2619 .35107 m
.18254 .4603 L
s
.2619 .35107 m
.18254 .24183 L
s
.18254 .4603 m
.10317 .56954 L
s
.18254 .4603 m
.10317 .35107 L
s
.10317 .56954 m
.02381 .67878 L
s
.10317 .56954 m
.02381 .4603 L
s
.34127 .02336 m
.2619 .13259 L
s
.2619 .13259 m
.18254 .24183 L
s
.18254 .24183 m
.10317 .35107 L
s
.10317 .35107 m
.02381 .4603 L
s
.97619 .52069 m
.89683 .62992 L
s
.97619 .52069 m
.89683 .41145 L
s
.89683 .62992 m
.81746 .73916 L
s
.89683 .62992 m
.81746 .52069 L
s
.81746 .73916 m
.7381 .8484 L
s
.81746 .73916 m
.7381 .62992 L
s
.7381 .8484 m
.65873 .95763 L
s
.7381 .8484 m
.65873 .73916 L
s
.65873 .95763 m
.57937 .8484 L
s
.97619 .30221 m
.89683 .41145 L
s
.97619 .30221 m
.89683 .19298 L
s
.89683 .41145 m
.81746 .52069 L
s
.89683 .41145 m
.81746 .30221 L
s
.81746 .52069 m
.7381 .62992 L
s
.81746 .52069 m
.7381 .41145 L
s
.7381 .62992 m
.65873 .73916 L
s
.7381 .62992 m
.65873 .52069 L
s
.65873 .73916 m
.57937 .8484 L
s
.65873 .73916 m
.57937 .62992 L
s
.57937 .8484 m
.5 .95763 L
s
.57937 .8484 m
.5 .73916 L
s
.5 .95763 m
.42063 .8484 L
s
.89683 .19298 m
.81746 .30221 L
s
.81746 .30221 m
.7381 .41145 L
s
.81746 .30221 m
.7381 .19298 L
s
.7381 .41145 m
.65873 .52069 L
s
.7381 .41145 m
.65873 .30221 L
s
.65873 .52069 m
.57937 .62992 L
s
.65873 .52069 m
.57937 .41145 L
s
.57937 .62992 m
.5 .73916 L
s
.57937 .62992 m
.5 .52069 L
s
.5 .73916 m
.42063 .8484 L
s
.5 .73916 m
.42063 .62992 L
s
.42063 .8484 m
.34127 .95763 L
s
.42063 .8484 m
.34127 .73916 L
s
.34127 .95763 m
.2619 .8484 L
s
.7381 .19298 m
.65873 .30221 L
s
.7381 .19298 m
.65873 .08374 L
s
.65873 .30221 m
.57937 .41145 L
s
.65873 .30221 m
.57937 .19298 L
s
.57937 .41145 m
.5 .52069 L
s
.57937 .41145 m
.5 .30221 L
s
.5 .52069 m
.42063 .62992 L
s
.5 .52069 m
.42063 .41145 L
s
.42063 .62992 m
.34127 .73916 L
s
.42063 .62992 m
.34127 .52069 L
s
.34127 .73916 m
.2619 .8484 L
s
.34127 .73916 m
.2619 .62992 L
s
.2619 .8484 m
.18254 .73916 L
s
.65873 .08374 m
.57937 .19298 L
s
.57937 .19298 m
.5 .30221 L
s
.57937 .19298 m
.5 .08374 L
s
.5 .30221 m
.42063 .41145 L
s
.5 .30221 m
.42063 .19298 L
s
.42063 .41145 m
.34127 .52069 L
s
.42063 .41145 m
.34127 .30221 L
s
.34127 .52069 m
.2619 .62992 L
s
.34127 .52069 m
.2619 .41145 L
s
.2619 .62992 m
.18254 .73916 L
s
.2619 .62992 m
.18254 .52069 L
s
.18254 .73916 m
.10317 .62992 L
s
.5 .08374 m
.42063 .19298 L
s
.42063 .19298 m
.34127 .30221 L
s
.42063 .19298 m
.34127 .08374 L
s
.34127 .30221 m
.2619 .41145 L
s
.34127 .30221 m
.2619 .19298 L
s
.2619 .41145 m
.18254 .52069 L
s
.2619 .41145 m
.18254 .30221 L
s
.18254 .52069 m
.10317 .62992 L
s
.18254 .52069 m
.10317 .41145 L
s
.10317 .62992 m
.02381 .52069 L
s
.34127 .08374 m
.2619 .19298 L
s
.2619 .19298 m
.18254 .30221 L
s
.18254 .30221 m
.10317 .41145 L
s
.18254 .30221 m
.10317 .19298 L
s
.10317 .41145 m
.02381 .52069 L
s
.10317 .41145 m
.02381 .30221 L
s
.10317 .19298 m
.02381 .30221 L
s
.93463 .70897 m
.85527 .81821 L
s
.93463 .70897 m
.85527 .59973 L
s
.85527 .81821 m
.7759 .70897 L
s
.93463 .4905 m
.85527 .59973 L
s
.93463 .4905 m
.85527 .38126 L
s
.85527 .59973 m
.7759 .70897 L
s
.85527 .59973 m
.7759 .4905 L
s
.7759 .70897 m
.69654 .81821 L
s
.7759 .70897 m
.69654 .59973 L
s
.69654 .81821 m
.61717 .92744 L
s
.69654 .81821 m
.61717 .70897 L
s
.61717 .92744 m
.53781 .81821 L
s
.93463 .27202 m
.85527 .38126 L
s
.93463 .27202 m
.85527 .16279 L
s
.85527 .38126 m
.7759 .4905 L
s
.85527 .38126 m
.7759 .27202 L
s
.7759 .4905 m
.69654 .59973 L
s
.7759 .4905 m
.69654 .38126 L
s
.69654 .59973 m
.61717 .70897 L
s
.69654 .59973 m
.61717 .4905 L
s
.61717 .70897 m
.53781 .81821 L
s
.61717 .70897 m
.53781 .59973 L
s
.53781 .81821 m
.45844 .92744 L
s
.53781 .81821 m
.45844 .70897 L
s
.45844 .92744 m
.37908 .81821 L
s
.85527 .16279 m
.7759 .27202 L
s
.7759 .27202 m
.69654 .38126 L
s
.7759 .27202 m
.69654 .16279 L
s
.69654 .38126 m
.61717 .4905 L
s
.69654 .38126 m
.61717 .27202 L
s
.61717 .4905 m
.53781 .59973 L
s
.61717 .4905 m
.53781 .38126 L
s
.53781 .59973 m
.45844 .70897 L
s
.53781 .59973 m
.45844 .4905 L
s
.45844 .70897 m
.37908 .81821 L
s
.45844 .70897 m
.37908 .59973 L
s
.37908 .81821 m
.29971 .92744 L
s
.37908 .81821 m
.29971 .70897 L
s
.29971 .92744 m
.22035 .81821 L
s
.69654 .16279 m
.61717 .27202 L
s
.69654 .16279 m
.61717 .05355 L
s
.61717 .27202 m
.53781 .38126 L
s
.61717 .27202 m
.53781 .16279 L
s
.53781 .38126 m
.45844 .4905 L
s
.53781 .38126 m
.45844 .27202 L
s
.45844 .4905 m
.37908 .59973 L
s
.45844 .4905 m
.37908 .38126 L
s
.37908 .59973 m
.29971 .70897 L
s
.37908 .59973 m
.29971 .4905 L
s
.29971 .70897 m
.22035 .81821 L
s
.29971 .70897 m
.22035 .59973 L
s
.22035 .81821 m
.14098 .70897 L
s
.61717 .05355 m
.53781 .16279 L
s
.53781 .16279 m
.45844 .27202 L
s
.53781 .16279 m
.45844 .05355 L
s
.45844 .27202 m
.37908 .38126 L
s
.45844 .27202 m
.37908 .16279 L
s
.37908 .38126 m
.29971 .4905 L
s
.37908 .38126 m
.29971 .27202 L
s
.29971 .4905 m
.22035 .59973 L
s
.29971 .4905 m
.22035 .38126 L
s
.22035 .59973 m
.14098 .70897 L
s
.22035 .59973 m
.14098 .4905 L
s
.14098 .70897 m
.06162 .59973 L
s
.45844 .05355 m
.37908 .16279 L
s
.37908 .16279 m
.29971 .27202 L
s
.37908 .16279 m
.29971 .05355 L
s
.29971 .27202 m
.22035 .38126 L
s
.29971 .27202 m
.22035 .16279 L
s
.22035 .38126 m
.14098 .4905 L
s
.22035 .38126 m
.14098 .27202 L
s
.14098 .4905 m
.06162 .59973 L
s
.14098 .4905 m
.06162 .38126 L
s
.29971 .05355 m
.22035 .16279 L
s
.22035 .16279 m
.14098 .27202 L
s
.14098 .27202 m
.06162 .38126 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[172]:=",
  ImageSize->{273.938, 268.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004A000130P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l74PL00?l74PL00?l74PL00?l74PL00?l7
4PL00?l74PL005d700<01`L0:0L00`071`0X1`0300L705/7001L1`0300L002P700<01`00:0L00`07
001L1`00G0L00`07000X1`0300L002P700<01`00G0L005/700D01`L7000V1`0500L71`009PL01@07
1`L005/7001J1`0300L700<700<01`L08PL00`071`031`0300L7028700<01`L00`L00`071`1H1`00
F@L00`071`041`0300L7024700<01`L01@L00`071`0Q1`0300L700@700<01`L0E`L005T700<01`L0
1@L00`071`0P1`0300L700D700<01`L080L00`071`051`0300L705L7001H1`0300L700L700<01`L0
7PL00`071`071`0300L701h700<01`L01`L00`071`1F1`00D@L00`071`031`0300L700T700<01`L0
0PL00`071`0B1`0300L7008700<01`L02@L00`071`021`0300L7018700<01`L00PL00`071`091`03
00L700<700<01`L0C`L0050700<01`000`L00`071`0:1`0700L71`07000B1`0300L0008700<01`L0
2`L01P071`07018700<01`000`L00`071`0:1`0700L71`07001@1`00D0L00`0700031`0300L700/7
00H01`L01`0B1`0300L0008700<01`L02`L01P071`07018700<01`000PL00`071`0;1`0700L71`07
001@1`00C`L01`071`L01`003`L200<700<01`L03PL010071`L200l70P031`0300L700h700@01`L7
0P0?1`0300L000<700<01`L0C@L004h700<01`L00`L00`071`0>1`0300L700<700<01`L030L00`07
1`021`803`L200@700<01`L030L00`071`031`0300L700h700<01`L00`L00`071`1<1`00CPL00`07
1`021`0300L000h700<01`001@L00`071`0:1`0300L7008700<01`003`L00`0700041`0300L700X7
00<01`L00`L00`07000>1`0300L000@700<01`L0C0L004d700<01`L00`L00`07000>1`0400L700@7
00<01`L02PL00`071`021`0400L700d700@01`L010L00`071`0:1`0300L7008700@01`L03PL00`07
00051`0300L704/7001<1`0300L700<700D01`L7000<1`0500L71`001@L00`071`081`0300L70087
00<01`L00PL00`071`091`0300L7008700<01`L00PL00`071`081`0300L700<700D01`L7000<1`05
00L71`001@L00`071`1:1`00B`L00`071`031`0300L700<700<01`L020L00`071`031`0300L700<7
00<01`L01PL00`071`021`0300L700@700<01`L01`L00`071`041`0300L7008700<01`L01PL00`07
1`031`0300L700<700<01`L020L00`071`031`0300L700<700<01`L0B@L004/700<01`L00`L00`07
1`041`0300L7008700D01`L700071`0300L700<700<01`L010L00`071`031`0300L700@700<01`L0
0PL00`071`021`0300L700@700<01`L00`L00`071`041`0300L700<700<01`L01@L01@071`L000@7
00<01`L010L00`071`031`0300L704T7001:1`0300L700<700<01`L01@L01`071`L01`000PL00`07
1`061`0300L7008700<01`L010L00`071`021`0300L700H700H01`L01`021`0300L700H700<01`L0
0PL00`071`041`0300L7008700<01`L01PL01P071`0700<700<01`L01@L00`071`031`0300L704P7
00191`0300L700<700<01`L01`L00`0700021`0300L000T700<01`L00`L00`071`021`0300L70087
00<01`L020L200<70P0:1`0300L7008700<01`L00PL00`071`031`0300L700L700<01`000PL00`07
00091`0300L700<700<01`L0A`L004T700<01`L00PL00`071`091`800`L00`071`091`0300L700<7
00@01`L010L00`071`091`800`L200/700<01`L00PL010071`051`0300L700T700@01`L70P0;1`03
00L7008700<01`L0A`L004P700<01`L00`L00`071`091`800PL00`07000;1`0300L700<70P051`03
00L700T70P031`802`L00`071`031`801@L00`071`091`0300L000870P0;1`0300L700<700<01`L0
APL004L700<01`L00`L00`071`091`0300L0008700@01`L02PL00`071`031`8010L00`071`091`06
00L700L00PL00`071`091`0300L700870P051`0300L700P700@01`L00PL00`07000;1`0300L700<7
00<01`L0A@L004L700<01`L00PL00`071`091`0400L71`800`L00`071`091`0300L700870P031`03
00L700T700L01`L700L000<700<01`L02@L010071`L200@700<01`L02@L010071`L200<700<01`L0
2@L00`071`021`0300L704D700161`0300L7008700<01`L02PL010071`L200@700<01`L02@L01007
1`021`0300L000`700<01`L00PL00`071`021`0300L700X700<01`000PL010071`0;1`0300L70087
0P031`0300L700X700<01`L00PL00`071`141`00A@L00`071`031`0300L700T700<01`L00PL200D7
00<01`L020L010071`021`0300L000/700<01`L00PL00`0700041`0300L700T700<01`000PL01007
1`0:1`0300L700<70P041`0300L700T700<01`L00`L00`071`131`00A0L00`071`031`0300L700T7
00<01`L00PL010071`051`0300L700P70P041`0300L700T700<01`L00PL01@071`L000@700<01`L0
2@L00`071`021`802PL00`071`031`0400L700@700<01`L02@L00`071`031`0300L7048700141`03
00L7008700<01`L02@L00`071`021`0300L7008700<01`L00PL00`071`081`800`L00`0700091`03
00L700<700D01`L700051`0300L700L700<01`000`L200X700<01`L00PL00`071`021`0300L70087
00<01`L02@L00`071`021`0300L7048700131`0300L7008700<01`L02PL01@071`L000H700<01`L0
0PL00`071`061`0600L700L00`L00`071`061`0300L7008700<01`L00`L00`071`021`0300L700H7
00L01`L700L0008700<01`L01PL00`071`021`0300L700@700D01`L7000<1`0300L7008700<01`L0
@@L0048700<01`L00`L00`071`091`0300L7008700<01`L010L00`071`031`0300L700D700H01`L0
1`031`0300L700D700<01`L00PL00`071`051`0300L7008700<01`L01@L01`071`L01`000PL00`07
1`051`0300L700<700<01`L010L00`071`021`0300L700T700<01`L00`L00`071`101`00@PL00`07
1`021`0300L700T700<01`L00PL00`071`061`0300L7008700<01`L010L00`071`021`0300L700<7
00<01`L00`L00`071`031`0300L700D700<01`L00`L00`071`031`0300L700<700<01`L00PL00`07
1`041`0300L7008700<01`L01PL00`071`021`0300L700T700<01`L00PL00`071`101`00@@L00`07
1`021`0300L000T700<01`L00PL00`071`081`0300L7008700<01`L00PL00`071`021`0300L000D7
00D01`L700051`0300L700L700<01`L00`L01@071`L000D700<01`0010L00`071`021`0300L70087
00<01`L020L00`071`021`0300L700L700<01`0010L00`071`0o1`00@0L00`071`031`0300L000T7
00D01`L7000<1`0300L7008700@01`L01@L00`0700061`0400L700@700<01`L02@L00`071`021`04
00L700H700<01`001@L010071`041`0300L700X700D01`L700091`0300L000D700<01`L0?PL00407
00<01`L00PL01@071`L000L700<01`L00PL00`071`0:1`0300L700<700<01`0010L01@071`L000D7
00<01`001@L00`071`091`0300L700<700<01`001@L01@071`L000@700<01`001@L00`071`0:1`03
00L7008700<01`L01@L01@071`L000@700<01`L0?PL003l700<01`L00PL00`071`031`0300L700<7
00<01`L00PL00`071`0<1`0300L700870P041`0300L700<700<01`L00`L00`071`031`0300L700/7
00<01`L00`L00`071`031`0300L700<700<01`L00PL200@700<01`L030L00`071`021`0300L700<7
00<01`L00`L00`071`021`0300L703d7000n1`0300L7008700<01`L01@L01@071`L000@700<01`L0
3PL010071`L200@700<01`L010L01`071`L01`000`L00`071`0=1`0700L71`0700031`0300L700@7
00<01`L00PL200<700<01`L03PL00`071`021`0500L71`001`L00`071`021`0300L703`7000m1`03
00L700<700<01`L01@L01@071`L000<700<01`L040L00`0700021`0400L700L700D01`L700021`03
00L0014700<01`000PL01@071`L000L700@01`L00PL00`07000B1`0500L71`000`L00`071`051`03
00L700<700<01`L0>`L003d700<01`L00PL00`071`071`0300L000@700<01`L040L00`0700021`03
00L000T700<01`000`L00`07000A1`0300L000<700<01`002@L00`0700021`0300L0018700<01`L0
0PL00`0700091`0300L7008700<01`L0>`L002L700<01`L04PL00`071`021`0300L700T700<01`L0
0PL00`071`0B1`0300L7008700<01`L02@L00`071`031`0300L7014700<01`L00`L00`071`091`03
00L7008700<01`L04PL00`071`021`0300L700T700<01`L00PL00`071`0B1`0300L702D7000V1`03
00L0018700<01`000PL00`071`091`0300L0008700<01`004PL00`0700031`802@L00`0700031`03
00L0014700<01`000`L00`0700091`800`L00`07000B1`0300L0008700<01`002`L01P071`070187
00<01`009PL002H700<01`004PL00`0700021`0300L700T700<01`000PL00`07000B1`0300L00087
00@01`L020L00`0700031`0300L0014700<01`000`L00`0700081`0400L7008700<01`004PL00`07
00021`0300L000/700H01`L01`0B1`0300L002H7000U1`0500L71`0040L010071`L200/700@01`L7
0P031`0300L700h700@01`L70P031`0300L700D700L01`L700L000<700<01`L03@L01`071`L01`00
0`L00`071`051`0400L71`800`L00`071`0>1`0400L71`800`L00`071`091`800`L00`071`0>1`05
00L71`009@L002@700<01`L00`L00`071`0<1`0300L700870P0:1`0300L700870P041`0300L700`7
00<01`L00`L00`071`021`0300L700<700<01`L00`L00`071`031`0300L700/700<01`L00`L00`07
1`031`0300L700<700<01`L00PL00`071`031`0300L700`700<01`L00PL200@700<01`L020L200@7
00<01`L030L00`071`031`0300L70287000S1`0300L700D700<01`L02PL00`071`021`0300L000T7
00<01`L00`L00`0700041`0300L700X700<01`L00`L00`0700041`0500L71`001@L00`0700041`03
00L700/700<01`L00PL00`0700051`0500L71`0010L00`0700051`0300L700X700<01`L00PL00`07
00051`0300L700L700<01`0010L00`071`0:1`0300L700D700<01`L08@L002<700<01`L01@L00`07
1`0:1`0300L7008700@01`L020L00`071`021`0400L700@700<01`L02PL00`071`021`0400L700D7
00@01`L01@L00`0700051`0300L700T700<01`L00`L00`0700051`0400L700D700@01`L010L00`07
1`0:1`0300L7008700@01`L010L00`071`061`0400L700@700<01`L02PL00`071`051`0300L70247
000R1`0300L700L700<01`L020L00`071`021`0300L7008700<01`L010L00`071`021`0300L70087
00<01`L00PL00`071`081`0300L700<700D01`L700041`0300L000D700D01`L700051`0300L700L7
00<01`L00`L01@071`L000D700<01`0010L01@071`L000D700<01`L020L00`071`021`0300L70087
00<01`L00PL00`071`041`0300L7008700<01`L00PL00`071`081`0300L700L700<01`L080L001`7
00<01`L00PL00`071`091`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L00PL00`07
1`041`0300L7008700<01`L01PL00`071`031`0300L700<700<01`L00PL00`071`031`0300L700<7
00<01`L00`L00`071`051`0300L700<700<01`L00`L00`071`031`0300L7008700<01`L00`L00`07
1`031`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L00PL00`071`041`0300L70087
00<01`L01PL00`071`091`0300L7008700<01`L06PL001/700<01`000PL00`071`0;1`0300L700@7
00<01`L00`L00`071`041`0700L71`0700031`0300L700@700<01`L00`L00`071`041`0300L700<7
00<01`L01@L01P071`0700<700<01`L010L00`071`031`0300L700D700<01`L00`L00`071`041`07
00L71`0700021`0300L700D700<01`L00`L00`071`041`0300L700<700<01`L010L01`071`L01`00
0`L00`071`041`0300L700<700<01`L010L00`071`0;1`0600L700L06`L001/700<01`000PL00`07
1`0;1`0300L700@700<01`L00PL00`071`061`0600L700L00PL00`071`061`0300L7008700<01`L0
10L00`071`021`0300L700H700H01`L01`031`0300L700D700<01`L00`L00`071`031`0300L700<7
00<01`L01@L01`071`L01`000PL00`071`061`0300L7008700<01`L010L00`071`021`0300L700H7
00H01`L01`021`0300L700H700<01`L00PL00`071`041`0300L700/700H01`L01`0K1`006PL01007
1`L200l700<01`L00PL00`071`021`0300L700P70P031`802PL00`071`021`0300L7008700<01`L0
0`L00`071`071`800`L00`0700091`0300L700<700D01`L700051`0300L700L700<01`000`L200T7
00<01`L00`L00`071`021`0300L7008700<01`L020L200<70P0:1`0300L7008700<01`L00PL00`07
1`0=1`800`L00`071`0H1`006@L00`071`021`8040L010071`041`0300L700T700<01`L00`L00`07
1`091`0300L7008700@01`L01@L00`071`081`8010L00`071`091`0300L7008700D01`L700041`03
00L700T700<01`L00PL200X700<01`L00`L010071`041`0300L700T700<01`L00`L00`071`091`03
00L7008700@01`L040L200@700<01`L05`L001P700<01`L00PL00`07000A1`801@L00`071`081`03
00L000<700<01`002PL00`071`031`801@L00`071`091`0300L0008700<01`002PL00`071`031`03
00L000D700<01`L020L00`0700021`0300L000/700<01`L00`L200D700<01`L020L00`0700031`03
00L000X700<01`L00`L2014700<01`0010L00`071`0F1`0060L00`071`021`0400L701070P041`03
00L700T700H01`L01`021`0300L700T700<01`L00PL200D700<01`L020L010071`021`0300L000/7
00<01`L00`L00`071`031`0300L700T700<01`000PL010071`0:1`0300L700<70P041`0300L700T7
00H01`L01`021`0300L700T700<01`L00PL2010700@01`L010L00`071`0F1`005`L00`071`021`03
00L7008700<01`L03@L200<700<01`L02@L01`071`L01`000`L00`071`091`0400L71`8010L00`07
1`081`0300L700870P031`0300L700T700<01`L00PL00`071`021`0300L700T700@01`L70P041`03
00L700P700<01`L00PL200<700<01`L02@L01`071`L01`000`L00`071`091`0400L71`803`L00`07
1`021`0300L7008700<01`L05@L001H700<01`L00PL00`071`041`0300L700/700H01`L01`0;1`03
00L700<700<01`L00`L00`071`091`0300L0008700@01`L02PL00`071`031`8010L00`071`091`06
00L700L00PL00`071`091`0300L700870P051`0300L700P700@01`L00PL00`07000;1`0300L700<7
00<01`L00`L00`071`091`0300L0008700<01`L02`L00`071`041`0300L7008700<01`L050L001D7
00<01`L00`L00`071`041`0300L700/700H01`L01`0:1`0300L700<700<01`001@L00`071`081`03
00L0008700@01`L02PL00`071`031`801@L00`071`081`0300L000<700<01`002PL00`071`031`80
1@L00`071`081`0400L7008700<01`002PL00`071`031`0300L000D700<01`L020L00`0700021`03
00L700/700<01`L010L00`071`031`0300L701<7000E1`0300L7008700<01`L01PL00`071`091`03
00L7008700<01`L02@L00`071`021`0500L71`0010L00`071`091`0300L700870P0:1`0300L700<7
00@01`L010L00`071`091`0300L700<700<01`L02@L00`071`021`0400L700D700<01`L020L200@7
00<01`L02@L00`071`021`0500L71`0010L00`071`091`0300L7008700<01`L02@L00`071`061`03
00L7008700<01`L04`L001@700<01`L00PL00`071`081`0300L700L700<01`L00PL00`0700091`03
00L700<700D01`L700051`0300L700L700<01`000`L200T700<01`L00`L00`071`021`0300L70087
00<01`L020L200<70P0:1`0300L7008700<01`L00PL00`071`031`0300L700L70P031`0300L000T7
00<01`L00`L01@071`L000D700<01`L01`L00`0700041`0300L700L700<01`L020L00`071`021`03
00L70187000C1`0300L7008700<01`L02@L00`071`061`0300L7008700D01`L700071`0300L700<7
00<01`L00`L00`071`031`0300L700D700L01`L700L0008700<01`L01PL00`071`021`0300L700@7
00<01`L00PL00`071`061`0600L700L00PL00`071`061`0300L7008700<01`L010L00`071`021`03
00L700H700H01`L01`031`0300L700D700<01`L00`L00`071`031`0300L700<700<01`L01@L01@07
1`L000@700<01`L01PL00`071`091`0300L7008700<01`L04@L0018700<01`L00`L00`071`0:1`03
00L700D700<01`L00PL01@071`L000H700<01`L00`L00`071`051`0300L700<700<01`L010L01`07
1`L01`000PL00`071`051`0300L700<700<01`L010L00`071`031`0300L700@700L01`L700L000<7
00<01`L010L00`071`031`0300L700@700<01`L00`L00`071`051`0600L700L00`L00`071`041`03
00L700<700<01`L01@L00`071`031`0300L700@700D01`L700041`0300L700D700<01`L02PL00`07
1`031`0300L70107000B1`0300L7008700<01`L030L00`071`031`0300L7008700<01`L00`L00`07
1`031`0300L700<700<01`L01@L00`071`031`0300L700<700<01`L00`L00`071`021`0300L700<7
00<01`L00`L00`071`061`0300L7008700<01`L010L00`071`021`0300L7008700<01`L010L00`07
1`021`0300L700H700<01`L00`L00`071`031`0300L7008700<01`L00`L00`071`031`0300L700<7
00<01`L01@L00`071`031`0300L700<700<01`L00`L00`071`021`0300L700<700<01`L030L00`07
1`021`0300L70107000A1`0300L7008700<01`L03@L00`071`021`0300L7008700<01`001@L01@07
1`L000D700<01`L01`L00`071`031`0500L71`001@L00`0700041`0300L7008700<01`L00PL00`07
1`081`0300L7008700<01`L00PL00`071`021`0300L000@700<01`L00PL00`071`021`0300L700P7
00<01`L00PL00`071`021`0300L7008700<01`001@L01@071`L000D700<01`L01`L00`071`031`05
00L71`001@L00`0700041`0300L7008700<01`L03@L00`071`021`0300L700l7000@1`0300L70087
00<01`L03`L010071`051`0300L000H700<01`001@L00`071`091`0300L700<700<01`001PL00`07
00051`0400L700@700<01`L02PL00`071`021`0400L700D700<01`001@L010071`041`0300L700X7
00<01`L00PL010071`051`0300L000H700<01`001@L00`071`091`0300L700<700<01`001PL00`07
00051`0400L7014700<01`L00PL00`071`0>1`0040L00`071`021`0300L7010700<01`0010L01@07
1`L000D700<01`001@L00`071`091`0300L700<700<01`001@L01@071`L000@700<01`001@L00`07
1`0:1`0300L7008700@01`L010L01@071`L000@700@01`L010L00`071`0:1`0300L700<700<01`00
10L01@071`L000D700<01`001@L00`071`091`0300L700<700<01`001@L01@071`L000@700<01`00
4PL00`071`021`0300L700h7000?1`0300L7008700<01`L04PL00`071`021`0300L700<700<01`L0
0`L00`071`031`0300L700/700<01`L00`L00`071`031`0300L700<700<01`L00PL00`071`031`03
00L700`700<01`L00PL200@700<01`L00`L00`071`021`8010L00`071`0<1`0300L700<700<01`L0
0PL00`071`031`0300L700<700<01`L00`L00`071`0;1`0300L700<700<01`L00`L00`071`031`03
00L7008700<01`L04PL00`071`021`0300L700d7000>1`0300L7008700<01`L04PL200@700<01`L0
10L01`071`L01`000`L00`071`0=1`0700L71`0700031`0300L700@700<01`L00PL200<700<01`L0
3PL010071`L200<700<01`L01@L010071`L200<700<01`L03PL010071`L200@700<01`L010L01`07
1`L01`000`L00`071`0=1`0700L71`0700031`0300L700@700<01`L00PL201@700<01`L00PL00`07
1`0<1`003@L00`071`021`0300L7018700@01`L00PL00`071`051`0400L700<700<01`004@L00`07
00031`0400L700L700@01`L00PL00`07000B1`0300L0008700@01`L01`L010071`021`0300L00187
00<01`000PL010071`071`0400L700<700<01`004@L00`0700031`0400L700L700@01`L00PL00`07
1`0B1`0300L7008700<01`L02`L000d700<01`L00PL00`071`0B1`0400L71`802@L00`0700031`03
00L0014700<01`000`L00`0700091`800`L00`07000B1`0300L0008700<01`002@L00`0700021`03
00L0018700<01`000`L200T700<01`000`L00`07000A1`0300L000<700<01`002@L200<700<01`L0
4PL00`071`021`0300L700/7000<1`0300L7008700<01`L04PL00`071`021`0300L700T700<01`L0
0`L00`071`0A1`0300L700<700<01`L02@L00`071`021`0300L7018700<01`L00PL00`071`091`03
00L7008700<01`L04PL00`071`021`0300L700T700<01`L00`L00`071`0A1`0300L700<700<01`L0
2@L00`071`021`0300L7018700<01`L00PL00`071`0:1`002`L00`071`041`0300L7010700<01`00
0`L200T700<01`000`L00`07000A1`0300L000<700<01`002@L200<700<01`004PL00`0700021`03
00L000T700<01`000PL00`07000B1`0300L000<70P091`0300L000<700<01`004@L00`0700031`03
00L000T70P031`0300L0018700<01`L010L00`071`091`002PL00`071`051`0300L7010700<01`00
0PL010071`071`0400L700<700<01`004@L00`0700031`0400L700L700@01`L00PL00`07000B1`03
00L0008700@01`L01`L010071`021`0300L0018700<01`000PL010071`071`0400L700<700<01`00
4@L00`0700031`0400L700L700@01`L00PL00`07000B1`0300L700D700<01`L020L000X700<01`L0
1PL00`071`0>1`0400L71`800`L00`071`051`0700L71`0700031`0300L700d700L01`L700L000<7
00<01`L01@L010071`L200<700<01`L03PL010071`L200<700<01`L01@L010071`L200<700<01`L0
3PL010071`L200<700<01`L01@L01`071`L01`000`L00`071`0=1`0700L71`0700031`0300L700D7
00@01`L70P031`0300L700h700<01`L01PL00`071`081`002@L00`071`081`0300L700`700<01`L0
0`L00`071`021`0300L700<700<01`L00`L00`071`031`0300L700/700<01`L00`L00`071`031`03
00L700<700<01`L00PL00`071`031`0300L700`700<01`L00PL200@700<01`L00`L00`071`021`80
10L00`071`0<1`0300L700<700<01`L00PL00`071`031`0300L700<700<01`L00`L00`071`0;1`03
00L700<700<01`L00`L00`071`031`0300L7008700<01`L00`L00`071`0<1`0300L700P700<01`L0
1`L000P700<01`L02PL00`071`0:1`0300L700<700<01`0010L01@071`L000D700<01`0010L00`07
1`0;1`0300L7008700<01`001@L01@071`L000@700<01`001@L00`071`0:1`0300L7008700<01`00
1@L01@071`L000D700<01`0010L00`071`0:1`0300L700<700<01`0010L01@071`L000D700<01`00
10L00`071`0;1`0300L7008700<01`001@L01@071`L000@700<01`001@L00`071`0:1`0300L700X7
00<01`L01PL000L700<01`L02`L00`071`0:1`0300L7008700@01`L01@L00`0700061`0300L000D7
00<01`L02@L00`071`031`0300L000H700<01`001@L010071`041`0300L700X700<01`L00PL01007
1`051`0300L000D700@01`L010L00`071`0:1`0300L7008700@01`L01@L00`0700061`0300L000D7
00<01`L02@L00`071`031`0300L000H700<01`001@L010071`041`0300L700X700<01`L02`L00`07
1`051`001`L00`071`0<1`0300L700P700<01`L00`L01@071`L000@700<01`001@L01@071`L000D7
00<01`L01`L00`071`031`0500L71`001@L00`0700041`0500L71`001@L00`071`081`0300L70087
00<01`L00PL00`071`021`0300L000@700<01`L00PL00`071`021`0300L700P700<01`L00`L01@07
1`L000@700<01`001@L01@071`L000D700<01`L01`L00`071`031`0500L71`001@L00`0700041`05
00L71`001@L00`071`081`0300L700`700<01`L01@L000H700<01`L03PL00`071`061`0300L700<7
00<01`L00`L00`071`021`0300L700<700<01`L00`L00`071`031`0300L700D700<01`L00`L00`07
1`031`0300L700<700<01`L00PL00`071`031`0300L700<700<01`L01PL00`071`021`0300L700@7
00<01`L00PL00`071`021`0300L700@700<01`L00PL00`071`061`0300L700<700<01`L00`L00`07
1`021`0300L700<700<01`L00`L00`071`031`0300L700D700<01`L00`L00`071`031`0300L700<7
00<01`L00PL00`071`031`0300L700<700<01`L01PL00`071`0>1`0300L700@700071`0300L700h7
00<01`L010L00`071`031`0300L700D700H01`L01`031`0300L700@700<01`L00`L00`071`051`03
00L700<700<01`L010L01`071`L01`000PL00`071`051`0300L700<700<01`L010L00`071`031`03
00L700@700L01`L700L000<700<01`L010L00`071`031`0300L700@700<01`L00`L00`071`051`06
00L700L00`L00`071`041`0300L700<700<01`L01@L00`071`031`0300L700@700L01`L700L00087
00<01`L01@L00`071`031`0300L700@700<01`L03PL00`071`051`001`L00`071`0>1`0300L700@7
00<01`L00PL00`071`061`0600L700L00`L00`071`051`0300L700<700<01`L00`L00`071`031`03
00L700D700L01`L700L0008700<01`L01PL00`071`021`0300L700@700<01`L00PL00`071`061`06
00L700L00PL00`071`061`0300L7008700<01`L010L00`071`021`0300L700H700H01`L01`031`03
00L700D700<01`L00`L00`071`031`0300L700<700<01`L01@L01`071`L01`000PL00`071`061`03
00L7008700<01`L010L00`071`0>1`0300L700D700081`0300L700h700<01`L00PL00`071`031`03
00L700L70P031`0300L000T700<01`L00`L01@071`L000D700<01`L01`L00`0700031`802@L00`07
1`031`0300L7008700<01`L00PL00`071`081`800`L200X700<01`L00PL00`071`021`0300L700<7
00<01`L01`L200<700<01`002@L00`071`031`0500L71`001@L00`071`071`0300L000<70P091`03
00L700<700<01`L00PL00`071`0>1`0300L700H700091`0300L700h700@01`L01@L00`071`081`80
10L00`071`091`0300L7008700D01`L700041`0300L700T700<01`L00PL200X700<01`L00`L01007
1`041`0300L700T700<01`L00`L00`071`091`0300L7008700@01`L01@L00`071`081`8010L00`07
1`091`0300L7008700D01`L700041`0300L700T700<01`L00PL200X700<01`L00`L010071`0@1`03
00L700L7000:1`0300L700h70P051`0300L700T700<01`000PL00`07000:1`0300L700<700<01`00
1@L00`071`081`0300L0008700<01`002`L00`071`031`801@L00`071`081`0300L000<700<01`00
2PL00`071`031`801@L00`071`091`0300L0008700<01`002PL00`071`031`0300L000D700<01`L0
20L00`0700021`0300L000/700<01`L00`L2010700<01`L020L000X700<01`L03PL200D700<01`L0
20L010071`021`0300L000/700<01`L00`L00`071`031`0300L700T700<01`000PL010071`0:1`03
00L700<70P041`0300L700T700H01`L01`021`0300L700T700<01`L00PL200D700<01`L020L01007
1`021`0300L000/700<01`L00`L00`071`031`0300L700T700<01`000PL010071`0:1`0300L700<7
0P0@1`0300L700P7000;1`0300L700d70P041`0300L700P700<01`L00PL200<700<01`L02@L00`07
1`021`0300L7008700<01`L02@L010071`L200@700<01`L020L00`071`021`800`L00`071`091`07
00L71`0700031`0300L700T700@01`L70P041`0300L700P700<01`L00PL200<700<01`L02@L00`07
1`021`0300L7008700<01`L02@L010071`L200@700<01`L020L00`071`021`803`L00`071`091`00
30L00`071`0;1`0400L7008700<01`L020L00`071`031`8010L00`071`091`0600L700L00PL00`07
1`091`0300L700870P051`0300L700P700@01`L00PL00`07000;1`0300L700<700<01`L00`L00`07
1`091`0300L0008700@01`L02PL00`071`031`8010L00`071`091`0600L700L00PL00`071`091`03
00L700870P051`0300L700P700@01`L00PL00`071`0;1`0300L700X7000=1`0300L700X700@01`L0
0PL00`071`081`0300L700<70P051`0300L700P700<01`000`L00`07000:1`0300L700<70P051`03
00L700P700@01`L00PL00`07000:1`0300L700<700<01`001@L00`071`081`0300L0008700@01`L0
2PL00`071`031`801@L00`071`081`0300L000<700<01`002PL00`071`031`801@L00`071`081`04
00L7008700<01`L02PL00`071`0;1`003@L00`071`091`0300L700870P0:1`0300L700<700@01`L0
10L00`071`091`0300L700<700<01`L02@L00`071`021`0400L700D700<01`L020L200@700<01`L0
2@L00`071`021`0500L71`0010L00`071`091`0300L700870P0:1`0300L700<700@01`L010L00`07
1`091`0300L700<700<01`L02@L00`071`021`0400L700D700<01`L020L200@700<01`L02@L00`07
1`0;1`003PL00`071`071`0300L700<70P091`0300L700<700<01`L00PL00`071`021`0300L700P7
0P031`802PL00`071`021`0300L7008700<01`L00`L00`071`071`800`L00`0700091`0300L700<7
00D01`L700051`0300L700L700<01`000`L200T700<01`L00`L00`071`021`0300L7008700<01`L0
20L200<70P0:1`0300L7008700<01`L00PL00`071`031`0300L700L70P051`0300L700L700<01`L0
30L000l700<01`L01@L00`071`031`0400L700P700<01`L00PL00`071`041`0300L7008700<01`L0
1PL01P071`07008700<01`L01PL00`071`021`0300L700@700<01`L00PL00`071`061`0600L700L0
0`L00`071`051`0300L700<700<01`L00`L00`071`031`0300L700D700L01`L700L0008700<01`L0
1PL00`071`021`0300L700@700<01`L00PL00`071`061`0600L700L00PL00`071`061`0300L70087
00<01`L010L00`071`021`0300L700H700@01`L01@L00`071`051`0300L700d7000@1`0300L700@7
00<01`L00`L010071`071`0300L700<700<01`L010L00`071`031`0300L700@700L01`L700L000<7
00<01`L010L00`071`031`0300L700@700<01`L00`L00`071`051`0600L700L00`L00`071`041`03
00L700<700<01`L01@L00`071`031`0300L700@700L01`L700L0008700<01`L01@L00`071`031`03
00L700@700<01`L00`L00`071`041`0700L71`0700031`0300L700@700<01`L00`L00`071`041`03
00L700<700<01`L01@L010071`051`0300L700@700<01`L03PL0010700<01`L00`L00`071`031`03
00L7008700<01`L00`L00`071`031`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L0
0PL00`071`041`0300L7008700<01`L01PL00`071`031`0300L700<700<01`L00PL00`071`031`03
00L700<700<01`L00`L00`071`051`0300L700<700<01`L00`L00`071`031`0300L7008700<01`L0
0`L00`071`031`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L00PL00`071`041`03
00L7008700<01`L01PL00`071`031`0300L700<700<01`L00PL00`071`031`0300L700<700<01`L0
3PL0014700D01`L700051`0300L000@700<01`L00PL00`071`021`0300L700P700<01`L00PL00`07
1`021`0300L7008700<01`0010L00`071`021`0300L7008700<01`L020L00`071`021`0300L70087
00<01`L00PL00`0700051`0500L71`001@L00`071`071`0300L700<700D01`L700051`0300L000@7
00<01`L00PL00`071`021`0300L700P700<01`L00PL00`071`021`0300L7008700<01`0010L00`07
1`021`0300L7008700<01`L020L00`071`021`0300L7008700<01`L00PL00`0700051`0500L71`00
4@L0018700<01`001@L010071`051`0400L700@700<01`L02PL00`071`021`0400L700@700D01`L7
00041`0400L700@700<01`L02PL00`071`021`0400L700D700@01`L01@L00`0700051`0300L700T7
00<01`L00`L00`0700051`0400L700D700@01`L010L00`071`0:1`0300L7008700@01`L010L01@07
1`L000@700@01`L010L00`071`0:1`0300L7008700@01`L01@L010071`051`0300L00187000B1`03
00L000D700D01`L700041`0300L000D700<01`L02PL00`071`021`0400L700@700D01`L700041`04
00L700@700<01`L02PL00`071`031`0300L000@700D01`L700051`0300L000D700<01`L02@L00`07
1`031`0300L000D700D01`L700041`0300L000D700<01`L02PL00`071`021`0400L700@700D01`L7
00041`0400L700@700<01`L02PL00`071`031`0300L000@700D01`L700051`0300L00187000C1`03
00L700<700<01`L00`L00`071`021`0300L700<700<01`L030L00`071`021`8010L00`071`031`03
00L700870P041`0300L700`700<01`L00`L00`071`021`0300L700<700<01`L00`L00`071`031`03
00L700/700<01`L00`L00`071`031`0300L700<700<01`L00PL00`071`031`0300L700`700<01`L0
0PL200@700<01`L00`L00`071`021`8010L00`071`0<1`0300L700<700<01`L00PL00`071`031`03
00L700<700<01`L04@L0018700<01`000`L00`071`051`0400L71`800`L00`071`0>1`0400L71`80
0`L00`071`051`0400L71`800`L00`071`0>1`0400L71`800`L00`071`051`0700L71`0700031`03
00L700d700L01`L700L000<700<01`L01@L010071`L200<700<01`L03PL010071`L200<700<01`L0
1@L010071`L200<700<01`L03PL010071`L200<700<01`L01@L01`071`L01`004PL0014700L01`L7
00L000P700@01`L00PL00`07000B1`0300L0008700<01`002@L00`0700021`0300L0018700<01`00
0PL010071`081`0300L000<700<01`004@L00`0700031`0300L000P700@01`L00PL00`07000B1`03
00L0008700<01`002@L00`0700021`0300L0018700<01`000PL010071`081`0300L000<700<01`L0
3`L0014700L01`L700L000T70P031`0300L0018700<01`000PL00`0700091`0300L0008700<01`00
4PL00`0700031`802@L00`0700031`0300L0014700<01`000`L00`0700091`800`L00`07000B1`03
00L0008700<01`002@L00`0700021`0300L0018700<01`000`L200T700<01`000`L00`071`0?1`00
40L00`071`031`0300L700T700<01`L00PL00`071`0B1`0300L7008700<01`L02@L00`071`021`03
00L7018700<01`L00PL00`071`091`0300L700<700<01`L04@L00`071`031`0300L700T700<01`L0
0PL00`071`0B1`0300L7008700<01`L02@L00`071`021`0300L7018700<01`L00PL00`071`091`03
00L700<700<01`L03PL0014700L01`L700L000T700<01`000PL00`07000B1`0300L0008700<01`00
2@L00`0700021`0300L0018700<01`000PL00`0700091`0300L000<700<01`004@L00`0700031`03
00L000T700<01`000PL00`07000B1`0300L0008700<01`002@L00`0700021`0300L0018700<01`00
0PL00`0700091`0300L000<700<01`L03`L0014700@01`L00`L00`071`051`0400L7008700<01`00
4PL01@0700L000<700<01`L01@L02@071`L01`07000B1`0300L0008700@01`L01`L01@071`L00087
00<01`004@L00`0700021`0500L71`001`L010071`021`0300L0018700D01`0700031`0300L700D7
00T01`L700L01`004PL00`0700021`0400L700L700D01`L700021`0300L700l7000B1`0300L000<7
00<01`L01@L010071`L200<700<01`L03PL010071`L200<700<01`L01@L010071`L200<700<01`L0
3PL010071`L200<700<01`L01@L01`071`L01`000`L00`071`0=1`0700L71`0700031`0300L700D7
00@01`L70P031`0300L700h700@01`L70P031`0300L700D700@01`L70P031`0300L700h700@01`L7
0P031`0300L700D700L01`L700L00187000C1`0300L700<700<01`L00`L00`071`021`8010L00`07
1`0<1`0300L700870P041`0300L700<700<01`L00PL200@700<01`L030L00`071`021`8010L00`07
1`031`0300L700<700<01`L00`L00`071`0;1`0300L700<700<01`L00`L00`071`031`0300L70087
0P041`0300L700`700<01`L00PL200@700<01`L00`L00`071`021`8010L00`071`0<1`0300L70087
0P041`0300L700<700<01`L00`L00`071`0A1`004PL00`0700051`0500L71`0010L00`0700051`03
00L700X700<01`L00PL00`0700051`0500L71`001@L00`0700041`0300L700X700<01`L00`L00`07
00041`0500L71`001@L00`0700041`0300L700/700<01`L00PL00`0700051`0500L71`0010L00`07
00051`0300L700X700<01`L00PL00`0700051`0500L71`001@L00`0700041`0300L700X700<01`L0
0`L00`0700041`0500L71`001@L00`07000B1`004@L010071`061`0300L000D700@01`L010L00`07
1`0:1`0500L71`000`L00`071`031`0300L000D700D01`L700031`0300L700X700<01`L00PL01007
1`051`0300L000H700@01`L010L00`071`091`0300L7008700@01`L01PL00`0700051`0400L700@7
00<01`L02PL01@071`L000<700<01`L00`L00`0700051`0500L71`000`L00`071`0:1`0300L70087
00@01`L01@L00`0700061`0400L70147000A1`0500L71`001@L00`0700041`0300L7008700<01`L0
0PL00`071`081`0300L7008700<01`L00PL00`071`021`0300L000@700<01`L00PL00`071`021`03
00L700P700<01`L00PL00`071`021`0300L7008700<01`001@L01@071`L000D700<01`L01`L00`07
1`031`0500L71`001@L00`0700041`0300L7008700<01`L00PL00`071`081`0300L7008700<01`L0
0PL00`071`021`0300L000@700<01`L00PL00`071`021`0300L700P700<01`L00PL00`071`021`03
00L7008700<01`001@L01@071`L00147000@1`0300L700<700<01`L00`L00`071`021`0300L700@7
00<01`L00PL00`071`061`0300L7008700<01`L010L00`071`021`0300L7008700<01`L010L00`07
1`021`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L00`L00`071`031`0300L700<7
00<01`L01@L00`071`031`0300L700<700<01`L00`L00`071`021`0300L700@700<01`L00PL00`07
1`061`0300L7008700<01`L010L00`071`021`0300L7008700<01`L010L00`071`021`0300L700H7
00<01`L00PL00`071`041`0300L7008700<01`L00`L00`071`031`0300L700h7000?1`0300L700D7
00L01`L700L0008700<01`L01@L00`071`031`0300L700@700<01`L00PL00`071`051`0700L71`07
00031`0300L700D700<01`L00PL00`071`041`0300L700<700<01`L01@L01P071`0700<700<01`L0
1@L00`071`021`0300L700D700<01`L00PL00`071`051`0700L71`0700021`0300L700D700<01`L0
0`L00`071`041`0300L7008700<01`L01@L01`071`L01`000`L00`071`051`0300L7008700<01`L0
10L00`071`031`0300L700D700H01`L01`031`0300L700D700<01`L03@L000h700<01`L01PL01`07
1`L01`000PL00`071`061`0300L7008700<01`L010L01@071`L000T700H01`L01`021`0300L700L7
00D01`L700061`0300L7008700<01`L01PL01P071`0700<700<01`L01PL00`071`021`0300L700<7
00<01`L00PL00`071`061`0700L71`0700021`0300L700H700<01`L00PL00`071`041`0500L71`00
2@L01P071`07008700<01`L01`L01@071`L000H700<01`L00PL00`071`061`0600L700L00`L00`07
1`061`0300L700`7000>1`0300L700L700<01`000`L200X700<01`L00PL00`071`021`0300L70087
00<01`L020L200<70P0:1`0300L7008700<01`L00PL00`071`021`0300L700P70P031`0300L000T7
00<01`L00`L01@071`L000D700<01`L01`L00`0700031`802PL00`071`021`0300L7008700<01`L0
0PL00`071`081`800`L200X700<01`L00PL00`071`021`0300L7008700<01`L020L200<700<01`00
2@L00`071`0<1`003@L00`071`091`0300L700870P0:1`0300L700<700@01`L010L00`071`091`03
00L700<700<01`L02@L00`071`021`0400L700D700<01`L020L200@700<01`L02@L00`071`021`05
00L71`0010L00`071`091`0300L700870P0:1`0300L700<700@01`L010L00`071`091`0300L700<7
00<01`L02@L00`071`021`0400L700D700<01`L020L200@700<01`L02@L00`071`0;1`0030L00`07
1`091`0300L0008700<01`002`L00`071`031`8010L00`071`091`0300L000<700<01`002`L00`07
1`021`801@L00`071`091`0300L0008700<01`002`L00`071`021`0300L000@700<01`L02@L00`07
00021`0300L000/700<01`L00`L200@700<01`L02@L00`0700031`0300L000/700<01`L00PL200D7
00<01`L02@L00`0700021`0300L000/700<01`L02PL000/700<01`L02PL00`0700021`0400L700/7
00<01`L00PL200<700<01`L02PL01P071`07008700<01`L02PL010071`L200@700<01`L02@L01007
1`021`0300L000`700<01`L00PL00`071`021`0300L700X700<01`000PL010071`0;1`0300L70087
0P031`0300L700X700H01`L01`021`0300L700X700@01`L70P041`0300L700T700@01`L00PL00`07
000<1`0300L700T7000;1`0300L700T700@01`L70P041`0300L700T700@01`L70P031`0300L700T7
00L01`L700L000<700<01`L02@L010071`L200<700<01`L02@L00`071`021`800`L00`071`091`03
00L7008700<01`L00PL00`071`091`0400L71`8010L00`071`091`0400L71`800`L00`071`091`07
00L71`0700031`0300L700T700@01`L70P031`0300L700T700<01`L00PL200<700<01`L02@L00`07
1`091`002PL00`071`091`0300L700870P051`0300L700P700@01`L00PL00`07000;1`0300L700<7
00<01`L00`L00`071`091`0300L0008700@01`L02PL00`071`031`8010L00`071`091`0600L700L0
0PL00`071`091`0300L700870P051`0300L700P700@01`L00PL00`07000;1`0300L700<700<01`L0
0`L00`071`091`0300L0008700@01`L02PL00`071`031`8010L00`071`091`0300L700P700091`03
00L700T700<01`L00`L200D700<01`L02@L00`0700021`802`L00`071`031`0300L000D700<01`L0
2@L2008700<01`002`L00`071`031`801@L00`071`091`800`L200/700<01`L00`L200D700<01`L0
2@L00`0700021`802`L00`071`031`0300L000D700<01`L02@L2008700<01`002`L00`071`031`80
1@L00`071`091`0300L700L700081`0300L700X700<01`L00PL010071`051`0300L700T700@01`L7
0P0;1`0300L7008700D01`L700041`0300L700T70P031`0300L700T700<01`L00`L010071`041`03
00L700T70P031`802`L00`071`021`0400L700D700<01`L02@L010071`L200/700<01`L00PL01@07
1`L000@700<01`L02@L200<700<01`L02@L00`071`031`0400L700@700<01`L02PL00`071`061`00
20L00`071`091`0300L7008700<01`L00PL00`071`031`0300L700L700<01`000PL00`0700091`03
00L700<700D01`L700051`0300L700L700<01`000PL00`0700091`0300L700<700<01`L00PL00`07
1`021`0300L700P70P031`802PL00`071`021`0300L7008700<01`L00`L00`071`071`0300L00087
00<01`002@L00`071`031`0500L71`001@L00`071`071`0300L0008700<01`002@L00`071`031`03
00L7008700<01`L00PL00`071`091`0300L700H700071`0300L700T700<01`L00PL00`071`041`03
00L7008700<01`L01PL01P071`0700<700<01`L01@L00`071`031`0300L700<700<01`L00`L00`07
1`051`0700L71`0700021`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L01PL01P07
1`07008700<01`L01PL00`071`021`0300L700@700<01`L00PL00`071`061`0600L700L00`L00`07
1`051`0300L700<700<01`L00`L00`071`031`0300L700D700L01`L700L0008700<01`L01PL00`07
1`021`0300L700@700<01`L00PL00`071`091`0300L700D700061`0300L700T700<01`L00`L00`07
1`041`0300L700<700<01`L01@L01@071`L000@700<01`L010L00`071`031`0300L700D700<01`L0
0`L00`071`041`0300L7008700D01`L700071`0300L700<700<01`L010L00`071`031`0300L700@7
00<01`L00PL00`071`021`0300L700@700<01`L00`L00`071`041`0300L700<700<01`L01@L01@07
1`L000@700<01`L010L00`071`031`0300L700D700<01`L00`L00`071`041`0300L7008700D01`L7
00071`0300L700<700<01`L010L00`071`031`0300L700T700<01`L010L000L700<01`L020L00`07
1`021`0300L700H700<01`L00`L00`071`031`0700L71`0700041`0300L700<700<01`L00`L00`07
1`051`0300L700<700<01`L00`L00`071`021`0300L000<700<01`L00`L00`071`031`0300L700H7
00<01`L00PL00`071`041`0700L71`0700031`0300L700@700<01`L00PL00`071`061`0300L700<7
00<01`L00`L01`071`L01`0010L00`071`031`0300L700<700<01`L01@L00`071`031`0300L700<7
00<01`L00PL00`0700031`0300L700<700<01`L00`L00`071`061`0300L7008700<01`L020L00`07
1`051`001`L00`071`071`0300L7008700<01`L020L00`071`021`0300L7008700<01`L00PL00`07
00051`0500L71`001@L00`071`071`0300L700<700D01`L700051`0300L000@700<01`L00PL00`07
1`021`0300L700P700<01`L00PL00`071`021`0300L7008700<01`0010L00`071`021`0300L70087
00<01`L020L00`071`021`0300L7008700<01`L00PL00`0700051`0500L71`001@L00`071`071`03
00L700<700D01`L700051`0300L000@700<01`L00PL00`071`021`0300L700P700<01`L00PL00`07
1`071`0300L700D700081`0300L700D700<01`L00PL00`071`0:1`0300L7008700@01`L010L01@07
1`L000D700<01`001@L00`071`091`0300L700<700<01`001@L01@071`L000@700@01`L010L00`07
1`0:1`0300L7008700@01`L010L01@071`L000@700@01`L010L00`071`0:1`0300L7008700@01`L0
10L01@071`L000D700<01`001@L00`071`091`0300L700<700<01`001@L01@071`L000@700@01`L0
10L00`071`0:1`0300L7008700<01`L01@L00`071`061`002@L00`071`041`0300L7008700<01`L0
2PL00`071`031`0300L000<700<01`L00`L00`071`021`0300L000D700<01`L02@L00`071`031`03
00L000@700<01`L00`L01`071`L01`001@L00`071`0:1`0300L7008700@01`L00`L00`071`031`05
00L71`000PL00`071`021`0300L700X700<01`L00`L00`0700031`0300L700<700<01`L00PL00`07
00051`0300L700T700<01`L00`L00`0700041`0300L700<700L01`L700L000D700<01`L02PL00`07
1`021`0300L700@700<01`L01`L000X700<01`L00PL00`071`021`0300L700`700<01`L00`L00`07
1`021`0300L700@700<01`L00PL00`071`031`0300L700/700<01`L00`L00`071`021`0300L700@7
00<01`L00PL00`071`031`0300L700`700<01`L00PL200<700<01`L01@L010071`L200@700<01`L0
30L00`071`031`0300L7008700<01`L010L00`071`021`0300L700<700<01`L02`L00`071`031`03
00L7008700<01`L010L00`071`021`0300L700<700<01`L030L00`071`021`0300L7008700<01`L0
20L000X700D01`L700041`0300L700h700@01`L70P031`0300L700D700L01`L700L000<700<01`L0
3@L01`071`L01`000`L00`071`051`0400L71`800`L00`071`0>1`0400L71`800`L00`071`051`04
00L71`800`L00`071`0>1`0400L71`800`L00`071`051`0700L71`0700031`0300L700d700L01`L7
00L000<700<01`L01@L010071`L200<700<01`L03PL00`071`021`0500L71`002PL000/700<01`00
10L00`071`0@1`0300L0008700<01`002@L00`0700031`0300L0014700<01`000`L00`0700091`03
00L0008700<01`004PL00`0700021`0300L000T700<01`000PL00`07000B1`0300L0008700<01`00
2@L00`0700031`0300L0014700<01`000`L00`0700091`0300L0008700<01`004PL00`071`021`03
00L000/7000<1`8010L00`071`0@1`0300L000<700<01`L02@L200<700<01`004@L00`0700031`80
2`L01`071`L01`004PL00`0700021`802`L2008700<01`004PL00`0700031`0300L700T70P031`03
00L0014700<01`000`L200/700L01`L700L0018700<01`L00PL200`7000<1`800`L00`071`0B1`03
00L7008700<01`L02@L200@700<01`L04@L00`071`021`802`L00`071`021`0300L7018700@01`L7
0P0;1`800`L00`071`0B1`0300L7008700<01`L02@L200@700<01`L04@L00`071`021`802`L00`07
1`021`0300L7018700@01`L70P0<1`002`L00`0700041`0300L7010700<01`000PL00`0700091`03
00L000<700<01`004@L00`0700031`0300L000T700<01`000PL00`07000B1`0300L0008700<01`00
2@L00`0700021`0300L0018700<01`000PL00`0700091`0300L000<700<01`004@L00`0700031`03
00L000T700<01`000PL00`07000B1`0300L7008700<01`002`L000X700D01`L700041`0300L700h7
00@01`L70P031`0300L700D700L01`L700L0008700<01`L03`L01P071`0700<700<01`L01@L01007
1`L200<700<01`L03PL01P071`0700<700<01`L01@L01`071`L01`000PL00`071`0>1`0400L71`80
0`L00`071`051`0700L71`0700021`0300L700l700H01`L01`031`0300L700D700@01`L70P031`03
00L700h700<01`L00PL01@071`L000X7000:1`0300L7008700D01`L7000@1`0400L71`800`L00`07
1`051`0300L700870P031`0300L700d700@01`L70P041`0300L700D700@01`L70P031`0300L700h7
00D01`L700041`0300L700D700<01`L00PL01@071`L0010700@01`L70P031`0300L700D700<01`L0
0PL200<700<01`L03@L010071`L200@700<01`L01@L010071`L200<700<01`L03PL01@071`L000@7
00<01`L020L000T700<01`L010L01@071`L000h700<01`L00PL200@700<01`L00`L00`071`031`80
10L00`071`0;1`0300L700870P051`0300L700<700<01`L00PL200@700<01`L030L01`071`L01`00
10L00`071`031`0300L7008700<01`000`L00`071`0<1`0300L700870P041`0300L700<700<01`L0
0`L200@700<01`L02`L00`071`021`801@L00`071`031`0300L700870P041`0300L700`700D01`L7
00061`0300L700L700081`0300L700D700<01`L00PL00`071`0:1`0300L7008700@01`L010L01@07
1`L000D700<01`001@L00`071`091`0300L700<700<01`001@L01@071`L000@700@01`L010L00`07
1`0:1`0300L7008700@01`L010L01@071`L000@700@01`L010L00`071`0:1`0300L7008700@01`L0
10L01@071`L000D700<01`001@L00`071`091`0300L700<700<01`001@L01@071`L000@700@01`L0
10L00`071`0:1`0300L7008700<01`L01@L00`071`061`001`L00`071`071`0300L7008700<01`L0
20L00`071`031`0500L71`0010L00`0700051`0500L71`0010L00`071`091`0300L7008700D01`L7
00051`0300L000@700D01`L700051`0300L700P700<01`L00PL01@071`L000D700<01`001@L01@07
1`L000@700<01`L020L00`071`031`0500L71`0010L00`0700051`0500L71`0010L00`071`091`03
00L7008700D01`L700051`0300L000@700D01`L700051`0300L700P700<01`L00PL00`071`071`03
00L700D700071`0300L700P700D01`L7000:1`0300L7008700<01`L00PL00`071`021`0300L000D7
00<01`L00PL00`071`021`0300L700L700<01`L00PL00`071`021`0300L700<700<01`0010L00`07
1`021`0300L7008700<01`L020L01@071`L000D700<01`L00PL00`0700041`0300L700<700D01`L7
000:1`0300L7008700<01`L00PL00`071`021`0300L000D700<01`L00PL00`071`021`0300L700L7
00<01`L00PL00`071`021`0300L700<700<01`0010L00`071`021`0300L7008700<01`L020L01@07
1`L000X700<01`L01@L000H700<01`L02@L00`071`021`0300L700H700<01`L00PL00`071`041`03
00L7008700<01`L00`L00`071`031`0300L700<700<01`L01@L00`071`031`0300L700<700<01`L0
0`L00`071`021`0300L700@700<01`L00PL00`071`061`0300L7008700<01`L010L00`071`021`03
00L7008700<01`L010L00`071`021`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L0
0`L00`071`031`0300L700<700<01`L01@L00`071`031`0300L700<700<01`L00`L00`071`021`03
00L700@700<01`L00PL00`071`061`0300L7008700<01`L02@L00`071`041`001`L00`071`091`03
00L7008700<01`L010L00`071`021`0300L700H700H01`L01`031`0300L700D700<01`L00`L00`07
1`031`0300L700<700<01`L01@L01`071`L01`000PL00`071`061`0300L7008700<01`L010L00`07
1`021`0300L700H700H01`L01`021`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L0
1PL01P071`0700<700<01`L01@L00`071`031`0300L700<700<01`L00`L00`071`051`0700L71`07
00021`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L02@L00`071`051`001`L00`07
1`0:1`0300L7008700<01`L00PL00`071`031`0300L700L700D01`0700021`0300L700L700<01`L0
0PL00`071`031`0300L7008700<01`L01`L020071`0700L02@L00`071`031`0300L7008700<01`L0
0PL00`071`071`0600L700L00PL00`071`071`0300L7008700<01`L00PL00`071`031`0300L700L7
00D01`0700021`0300L700L700<01`L00PL00`071`031`0300L7008700<01`L01`L020071`0700L0
2@L00`071`031`0300L7008700<01`L00PL00`071`0:1`0300L700D700081`0300L700X700D01`L7
00041`0300L7008700<01`L020L200<700<01`002PL00`071`021`0500L71`0010L00`071`081`03
00L000<70P0:1`0300L7008700<01`L00PL01@071`L000/70P031`802`L01@071`L000@700<01`L0
0PL00`071`081`800`L00`07000:1`0300L7008700D01`L700041`0300L700P700<01`000`L200X7
00<01`L00PL00`071`021`0500L71`0030L00`071`061`002@L00`071`091`0300L7008700@01`L0
10L00`071`091`8010L00`071`091`0300L700<700<01`001@L00`071`091`0300L700870P0;1`03
00L7008700@01`L010L00`071`091`800`L200/700<01`L00PL010071`041`0300L700T70P041`03
00L700T700<01`L00`L00`0700051`0300L700T700<01`L00PL200/700<01`L00PL010071`041`03
00L700T700<01`L01`L000X700<01`L02@L00`071`021`801@L00`071`091`0300L0008700<01`00
2`L00`071`021`0300L000@700<01`L02@L00`0700021`0300L000/700<01`L00`L200@700<01`L0
2@L00`0700031`0300L000/700<01`L00PL200D700<01`L02@L00`0700021`0300L000/700<01`L0
0PL00`0700041`0300L700T700<01`000PL00`07000;1`0300L700<70P041`0300L700T700<01`L0
20L000X700<01`L02PL010071`L200@700<01`L02@L010071`L2008700<01`L02PL00`071`021`03
00L7008700<01`L02PL00`071`0200<700<01`L02@L00`071`021`800`L00`071`0:1`0600L700L0
0PL00`071`0:1`0400L71`8010L00`071`091`0400L71`800PL00`071`0:1`0300L7008700<01`L0
0PL00`071`0:1`0300L700800`L00`071`091`0300L700870P031`0300L700X700<01`L020L000/7
00<01`L02PL00`071`0200<700<01`L02@L00`071`021`800`L00`071`0:1`0600L700L00PL00`07
1`0:1`0400L71`8010L00`071`091`0400L71`800PL00`071`0:1`0300L7008700<01`L00PL00`07
1`0:1`0300L700800`L00`071`091`0300L700870P031`0300L700X700H01`L01`021`0300L700X7
00@01`L70P041`0300L700T700@01`L70P021`0300L700X700<01`L02@L000`700<01`L02@L00`07
00021`0400L700X700<01`L00`L200@700<01`L02@L00`0700031`0300L000/700<01`L00PL200D7
00<01`L020L010071`021`0300L000/700<01`L00PL00`0700041`0300L700T700<01`000PL01007
1`0:1`0300L700<70P041`0300L700T700<01`000`L00`07000;1`0300L700870P051`0300L700P7
00@01`L00PL00`07000;1`0300L700X7000=1`0300L700T700<01`L00PL200/700<01`L00PL01007
1`041`0300L700T70P031`802`L00`071`021`0400L700@700<01`L02@L200@700<01`L02@L00`07
1`031`0300L000D700<01`L02@L00`071`021`802`L00`071`021`0400L700@700<01`L02@L200<7
0P0;1`0300L7008700@01`L010L00`071`091`8010L00`071`091`0300L700/7000=1`0300L700P7
00<01`000`L200X700<01`L00PL00`071`021`0500L71`002`L200<70P0;1`0500L71`0010L00`07
1`021`0300L700P70P031`0300L000X700<01`L00PL01@071`L000@700<01`L020L00`0700031`80
2PL00`071`021`0300L7008700D01`L7000;1`800`L200/700D01`L700041`0300L7008700<01`L0
20L200<700<01`002PL00`071`0;1`003PL00`071`071`0800L700L01`091`0300L700<700<01`L0
0PL00`071`021`0300L700L700H01`L01`021`0300L700L700<01`L00PL00`071`021`0300L700<7
00<01`L01`L01@0700L0008700<01`L01`L00`071`021`0300L700<700<01`L00PL00`071`071`08
00L700L01`091`0300L700<700<01`L00PL00`071`021`0300L700L700H01`L01`021`0300L700L7
00<01`L00PL00`071`021`0300L700<700<01`L01`L01@0700L0008700<01`L01`L00`071`0<1`00
3`L00`071`051`0700L71`0700021`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L0
1PL01P071`07008700<01`L01PL00`071`021`0300L700@700<01`L00PL00`071`061`0600L700L0
0`L00`071`051`0300L700<700<01`L00`L00`071`031`0300L700D700L01`L700L0008700<01`L0
1PL00`071`021`0300L700@700<01`L00PL00`071`061`0600L700L00PL00`071`061`0300L70087
00<01`L010L00`071`021`0300L700H700H01`L01`031`0300L700D700<01`L03@L0010700<01`L0
0`L00`071`031`0300L7008700<01`L010L00`071`021`0300L700H700<01`L00PL00`071`041`03
00L7008700<01`L00PL00`071`041`0300L7008700<01`L01PL00`071`021`0300L700@700<01`L0
0PL00`071`031`0300L700<700<01`L00`L00`071`051`0300L700<700<01`L00`L00`071`031`03
00L7008700<01`L010L00`071`021`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L0
0PL00`071`041`0300L7008700<01`L01PL00`071`021`0300L700@700<01`L00PL00`071`031`03
00L700<700<01`L03PL0010700<01`L00PL00`071`031`0300L000@700<01`L00PL00`071`021`03
00L700P700D01`L700051`0300L7008700<01`0010L00`071`031`0500L71`002PL00`071`021`03
00L7008700<01`L00PL00`0700051`0300L7008700<01`L00PL00`071`071`0300L7008700<01`L0
0PL00`071`031`0300L000@700<01`L00PL00`071`021`0300L700P700D01`L700051`0300L70087
00<01`0010L00`071`031`0500L71`002PL00`071`021`0300L7008700<01`L00PL00`0700051`03
00L7008700<01`L03PL0014700D01`L700051`0300L000@700<01`L00PL00`071`021`0300L700P7
00<01`L00PL01@071`L000D700<01`001@L01@071`L000@700<01`L020L00`071`021`0300L70087
00<01`L00PL00`0700051`0500L71`0010L00`071`091`0300L7008700D01`L700051`0300L000@7
00<01`L00PL00`071`021`0300L700P700<01`L00PL01@071`L000D700<01`001@L01@071`L000@7
00<01`L020L00`071`021`0300L7008700<01`L00PL00`0700051`0500L71`004@L0018700<01`00
1@L01@071`L000@700@01`L010L00`071`0:1`0300L7008700@01`L010L01@071`L000@700@01`L0
10L00`071`0:1`0300L7008700@01`L010L01@071`L000D700<01`001@L00`071`091`0300L700<7
00<01`001@L01@071`L000@700@01`L010L00`071`0:1`0300L7008700@01`L010L01@071`L000@7
00@01`L010L00`071`0:1`0300L7008700@01`L010L01@071`L000D700<01`004PL001870P051`03
00L700<700<01`L00PL200@700<01`L030L01`071`L01`0010L00`071`031`0300L7008700<01`00
0`L00`071`0<1`0300L700870P041`0300L700<700<01`L00`L200@700<01`L02`L00`071`021`80
1@L00`071`031`0300L700870P041`0300L700`700L01`L700L000@700<01`L00`L00`071`021`03
00L000<700<01`L030L00`071`021`8010L00`071`031`0300L700<70P0B1`004PL200@700<01`L0
10L00`071`021`800`L00`071`0>1`0500L71`0010L00`071`051`0300L7008700D01`L7000@1`04
00L71`8010L00`071`041`0300L700870P031`0300L700d700@01`L70P041`0300L700@700<01`L0
0PL200<700<01`L03PL01@071`L000@700<01`L01@L00`071`021`0500L71`0040L010071`L200@7
00<01`L010L00`071`021`804PL0018700<01`000`L00`071`051`0400L71`800`L00`071`0>1`06
00L700L00`L00`071`051`0700L71`0700021`0300L700h700@01`L70P031`0300L700D700L01`L7
00L0008700<01`L03`L01P071`0700<700<01`L01@L010071`L200<700<01`L03PL01P071`0700<7
00<01`L01@L01`071`L01`000PL00`071`0>1`0400L71`800`L00`071`051`0700L71`07000B1`00
4@L01`071`L01`002@L00`0700021`0300L0018700<01`000PL00`0700091`0300L0008700<01`00
4PL00`0700021`0300L000T700<01`000`L00`07000A1`0300L000<700<01`002@L00`0700021`03
00L0018700<01`000PL00`0700091`0300L0008700<01`004PL00`0700021`0300L000T700<01`00
0`L00`071`0?1`0040L00`071`021`802`L00`071`021`0300L7018700@01`L70P0;1`800`L00`07
1`0B1`0300L7008700<01`L02@L200@700<01`L04@L00`071`021`802`L00`071`021`0300L70187
00@01`L70P0;1`800`L00`071`0B1`0300L7008700<01`L02@L200@700<01`L03PL0014700@01`L7
0P0;1`0700L71`07000B1`0300L000870P0;1`800PL00`07000B1`0300L000<700<01`L02@L200<7
00<01`004@L00`0700031`802`L01`071`L01`004PL00`0700021`802`L2008700<01`004PL00`07
00031`0300L700T70P031`0300L700l7000A1`0700L71`0700091`0300L0008700<01`004PL00`07
00021`0300L000T700<01`000PL00`07000B1`0300L0008700<01`002@L00`0700031`0300L00147
00<01`000`L00`0700091`0300L0008700<01`004PL00`0700021`0300L000T700<01`000PL00`07
000B1`0300L0008700<01`002@L00`0700031`0300L700l7000B1`0300L000<700<01`L01@L01007
1`L200<700<01`L03PL010071`L200<700<01`L01@L010071`L200<700<01`L03PL010071`L200<7
00<01`L01@L01`071`L01`000`L00`071`0=1`0700L71`0700031`0300L700D700@01`L70P031`03
00L700h700@01`L70P031`0300L700D700@01`L70P031`0300L700h700@01`L70P031`0300L700D7
00L01`L700L00187000C1`0300L7008700<01`L01@L01@071`L000D700<01`L030L00`071`021`80
0`L00`071`051`0400L71`8010L00`071`0<1`0300L700<700D01`L700071`0300L7008700<01`L0
0`L00`071`0;1`0300L700<700<01`L00PL00`071`051`0500L71`001@L00`071`0<1`0300L70087
0P031`0300L700D700@01`L70P041`0300L700`700<01`L00`L01@071`L000L700<01`L00PL00`07
1`0A1`004PL00`0700041`0300L700<700L01`L700L000D700<01`L02PL00`071`021`0300L000@7
00<01`L00`L00`071`021`0300L000@700<01`L02PL00`071`031`0300L000<700<01`L00`L00`07
1`021`0300L000@700<01`L02`L00`071`021`0300L000@700<01`L00`L01`071`L01`001@L00`07
1`0:1`0300L7008700<01`0010L00`071`031`0300L7008700<01`0010L00`071`0:1`0300L700<7
00<01`000`L00`071`031`0300L7008700<01`004PL0018700<01`001@L01@071`L000@700@01`L0
10L00`071`0:1`0300L7008700@01`L010L01@071`L000@700@01`L010L00`071`0:1`0300L70087
00@01`L010L01@071`L000D700<01`001@L00`071`091`0300L700<700<01`001@L01@071`L000@7
00@01`L010L00`071`0:1`0300L7008700@01`L010L01@071`L000@700@01`L010L00`071`0:1`03
00L7008700@01`L010L01@071`L000D700<01`004PL0014700D01`L700051`0300L000@700D01`L7
00051`0300L700P700<01`L00PL00`071`021`0300L7008700<01`0010L00`071`021`0300L70087
00<01`L020L00`071`031`0500L71`0010L00`0700051`0500L71`001@L00`071`071`0300L700<7
00D01`L700051`0300L000@700D01`L700051`0300L700P700<01`L00PL00`071`021`0300L70087
00<01`0010L00`071`021`0300L7008700<01`L020L00`071`031`0500L71`0010L00`0700051`05
00L71`004@L0010700<01`L00`L00`071`021`0300L000<700<01`L00`L00`071`031`0300L700H7
00<01`L00PL00`071`041`0700L71`0700031`0300L700@700<01`L00PL00`071`061`0300L700<7
00<01`L00`L01`071`L01`0010L00`071`031`0300L700<700<01`L01@L00`071`031`0300L700<7
00<01`L00PL00`0700031`0300L700<700<01`L00`L00`071`061`0300L7008700<01`L010L01`07
1`L01`000`L00`071`041`0300L7008700<01`L01PL00`071`031`0300L700<700L01`L700L000@7
00<01`L00`L00`071`0>1`0040L00`071`041`0300L7008700D01`L700071`0300L700<700<01`L0
10L00`071`031`0300L700@700<01`L00PL00`071`021`0300L700@700<01`L00`L00`071`041`03
00L700<700<01`L01@L01@071`L000@700<01`L010L00`071`031`0300L700D700<01`L00`L00`07
1`041`0300L7008700D01`L700071`0300L700<700<01`L010L00`071`031`0300L700@700<01`L0
0PL00`071`021`0300L700@700<01`L00`L00`071`041`0300L700<700<01`L01@L01@071`L000@7
00<01`L010L00`071`0>1`003`L00`071`051`0300L700<700@01`L020L00`071`021`0300L700@7
00<01`L00PL00`071`061`0600L700L00PL00`071`061`0300L7008700<01`L010L00`071`021`03
00L700H700H01`L01`031`0300L700D700<01`L00`L00`071`031`0300L700<700<01`L01@L01`07
1`L01`000PL00`071`061`0300L7008700<01`L010L00`071`021`0300L700H700H01`L01`021`03
00L700H700<01`L00PL00`071`041`0300L7008700<01`L01PL010071`051`0300L700D700<01`L0
3@L000h700<01`L01`L00`071`021`0300L000T700<01`L00`L00`071`021`0300L7008700<01`L0
20L01`0700L01`002PL00`071`021`0300L7008700<01`L00`L00`071`071`0500L01`000PL00`07
1`071`0300L700<700D01`L700051`0300L700L700P01`L01`0700T700<01`L00`L00`071`021`03
00L7008700<01`L020L01`0700L01`002PL00`071`021`0300L7008700<01`L00`L00`071`071`03
00L000@700<01`L01`L00`071`0<1`003@L00`071`091`0300L7008700<01`L02@L00`071`031`04
00L700@700<01`L02@L200<70P0;1`0300L7008700@01`L01@L00`071`091`0400L71`802`L00`07
1`021`0500L71`0010L00`071`091`800`L00`071`091`0300L700<700@01`L010L00`071`091`80
0`L200/700<01`L00PL010071`051`0300L700T700<01`L00PL00`071`091`0300L700/7000=1`03
00L700X700H01`L01`0;1`0300L700<70P051`0300L700T70P031`802`L00`071`031`801@L00`07
1`091`0300L000870P0;1`0300L700<700<01`001@L00`071`091`800PL00`07000;1`0300L700<7
0P051`0300L700T70P031`802`L00`071`031`801@L00`071`091`0300L0008700<01`L02PL00`07
1`0;1`0030L00`071`0;1`0600L700L02`L00`071`031`8010L00`071`091`0600L700L00PL00`07
1`091`0300L700870P051`0300L700T700<01`000PL00`07000;1`0300L700<700<01`L00`L00`07
1`091`0300L0008700<01`002`L00`071`031`8010L00`071`091`0600L700L00PL00`071`091`03
00L700870P051`0300L700T700<01`000PL00`071`0;1`0300L700X7000;1`0300L700d70P031`03
00L700T700<01`L00PL200<700<01`L02PL01P071`07008700<01`L02PL010071`L200@700<01`L0
2@L010071`L2008700<01`L02PL00`071`021`0300L7008700<01`L02PL00`071`0200<700<01`L0
2@L00`071`021`800`L00`071`0:1`0600L700L00PL00`071`0:1`0400L71`8010L00`071`091`04
00L71`803`L00`071`091`002PL00`071`0>1`8010L00`071`091`0400L7008700<01`0030L00`07
1`021`0300L7008700<01`L02PL00`0700021`0400L700/700<01`L00PL200<700<01`L02PL01P07
1`07008700<01`L02PL010071`L200@700<01`L02@L010071`021`0300L000`700<01`L00PL00`07
1`021`0300L700X700<01`000PL010071`0;1`0300L700870P0@1`0300L700P7000:1`0300L700h7
0P051`0300L700P700@01`L00PL00`07000;1`0300L7008700<01`0010L00`071`091`0300L00087
00@01`L02PL00`071`031`8010L00`071`091`0300L000<700<01`002`L00`071`021`801@L00`07
1`081`0400L7008700<01`002`L00`071`021`0300L000@700<01`L02@L00`0700021`0400L700X7
00<01`L00`L2010700<01`L020L000T700<01`L03PL010071`041`0300L700T70P041`0300L700T7
00<01`L00PL01@071`L000@700<01`L02@L00`071`021`802`L00`071`021`0400L700@700<01`L0
2@L00`071`031`0300L700T700<01`L00PL010071`041`0300L700T70P041`0300L700T700<01`L0
0PL01@071`L000@700<01`L02@L00`071`021`802`L00`071`021`0400L7010700<01`L01`L000P7
00<01`L03PL00`071`021`0300L7008700<01`L020L200<700<01`002PL00`071`021`0500L71`00
10L00`071`081`0300L000<70P0:1`0300L7008700<01`L00PL01@071`L000/70P031`802`L01@07
1`L000@700<01`L00PL00`071`081`800`L00`07000:1`0300L7008700D01`L700041`0300L700P7
00<01`000`L200X700<01`L00PL00`071`021`0300L700h700<01`L01PL000L700<01`L03PL00`07
1`041`0300L7008700<01`L01PL01P071`0700<700<01`L01PL00`071`021`0300L700<700<01`L0
0PL00`071`061`0700L71`0700021`0300L700H700<01`L00PL00`071`041`0500L71`002@L01P07
1`07008700<01`L01`L01@071`L000H700<01`L00PL00`071`061`0600L700L00`L00`071`061`03
00L7008700<01`L00`L00`071`021`0300L700H700L01`L700L0008700<01`L01PL00`071`021`03
00L700@700<01`L03PL00`071`051`001`L00`071`0>1`0300L700@700<01`L00PL00`071`061`06
00L700L00`L00`071`051`0300L7008700<01`L01@L00`071`021`0300L700D700L01`L700L00087
00<01`L01PL00`071`021`0300L700@700<01`L00PL00`071`051`0700L71`0700031`0300L700D7
00<01`L00PL00`071`041`0300L7008700<01`L01PL01P071`0700<700<01`L01@L00`071`021`03
00L700D700<01`L00PL00`071`051`0700L71`0700021`0300L700H700<01`L00PL00`071`041`03
00L700h700<01`L01@L000H700<01`L03PL00`071`061`0300L7008700<01`L010L00`071`021`03
00L700<700<01`L00`L00`071`031`0300L700D700<01`L00`L00`071`031`0300L700<700<01`L0
0PL00`071`041`0300L7008700<01`L01PL00`071`021`0300L700@700<01`L00PL00`071`021`03
00L700@700<01`L00PL00`071`061`0300L7008700<01`L010L00`071`021`0300L700<700<01`L0
0`L00`071`031`0300L700D700<01`L00`L00`071`031`0300L700<700<01`L00PL00`071`041`03
00L7008700<01`L01PL00`071`0>1`0300L700@700071`0300L700`700<01`L020L00`071`021`03
00L7008700<01`L00PL00`0700051`0300L7008700<01`L00PL00`071`071`0300L7008700<01`L0
0PL00`071`031`0300L000@700<01`L00PL00`071`021`0300L700P700D01`L700051`0300L70087
00<01`0010L00`071`031`0500L71`002PL00`071`021`0300L7008700<01`L00PL00`0700051`03
00L7008700<01`L00PL00`071`071`0300L7008700<01`L00PL00`071`031`0300L000@700<01`L0
0PL00`071`021`0300L700P700<01`L030L00`071`051`001`L00`071`0;1`0300L700X700D01`L7
00031`0300L700<700<01`001PL010071`041`0300L700T700<01`L00PL010071`061`0300L000D7
00D01`L700031`0300L700X700D01`L700031`0300L700<700<01`001@L01@071`L000<700<01`L0
2PL01@071`L000<700<01`L00`L00`0700061`0400L700@700<01`L02@L00`071`021`0400L700H7
00<01`001@L01@071`L000<700<01`L02PL00`071`0;1`0300L700D700081`0300L700X700<01`L0
2PL00`071`021`0400L700@700D01`L700051`0300L000D700<01`L02@L00`071`031`0300L000D7
00D01`L700041`0400L700@700<01`L02PL00`071`021`0400L700@700D01`L700041`0400L700@7
00<01`L02PL00`071`021`0400L700@700D01`L700051`0300L000D700<01`L02@L00`071`031`03
00L000D700D01`L700041`0400L700@700<01`L02PL00`071`0:1`0300L700H700091`0300L700P7
00<01`L030L00`071`021`8010L00`071`031`0300L700<70P041`0300L700/700<01`L00PL200D7
00<01`L00`L00`071`021`8010L00`071`0<1`0700L71`0700041`0300L700<700<01`L00PL00`07
00031`0300L700`700<01`L00PL200@700<01`L00`L00`071`031`8010L00`071`0;1`0300L70087
0P051`0300L700<700<01`L00PL200@700<01`L030L00`071`081`0300L700L7000:1`0300L700H7
00<01`L03PL010071`L200@700<01`L010L00`071`021`800`L00`071`0=1`0400L71`8010L00`07
1`041`0300L700870P031`0300L700h700D01`L700041`0300L700D700<01`L00PL01@071`L00107
00@01`L70P041`0300L700@700<01`L00PL200<700<01`L03@L010071`L200@700<01`L010L00`07
1`021`800`L00`071`0>1`0300L700H700<01`L020L000X700<01`L01@L00`071`0@1`0500L01`00
0`L00`071`051`0500L71`000PL00`07000A1`0300L0008700D01`L700071`0900L71`0700L00187
00D01`0700031`0300L700D700T01`L700L01`004PL01@0700L000<700<01`L01@L01@071`L00087
00<01`004@L00`0700021`0500L71`001`L02@071`L01`07000B1`0300L700D700<01`L020L000/7
00<01`L010L00`071`0@1`0300L0008700<01`002@L00`0700031`0300L0014700<01`000`L00`07
00091`0300L0008700<01`004PL00`0700021`0300L000T700<01`000PL00`07000B1`0300L00087
00<01`002@L00`0700031`0300L0014700<01`000`L00`0700091`0300L0008700<01`004PL00`07
1`041`0300L700T7000<1`0300L7008700<01`L04PL00`071`021`0300L700T70P041`0300L70147
00<01`L00PL200/700<01`L00PL00`071`0B1`0400L71`802`L200<700<01`L04PL00`071`021`03
00L700T70P041`0300L7014700<01`L00PL200/700<01`L00PL00`071`0B1`0300L7008700<01`L0
2PL000d700<01`L00PL00`071`0B1`0500L71`002`L200<700<01`004@L00`0700031`802`L01`07
1`L01`004PL00`0700021`802`L2008700<01`004PL00`0700031`0300L700T70P031`0300L00147
00<01`000`L200/700D01`L7000D1`0300L7008700<01`L02`L000d700<01`L00PL00`071`0B1`06
00L700L02@L00`0700031`0300L0014700<01`000`L00`0700091`0300L0008700<01`004PL00`07
00021`0300L000T700<01`000PL00`07000B1`0300L0008700<01`002@L00`0700031`0300L00147
00<01`000`L00`0700091`0300L0008700<01`L04PL00`071`021`0300L700/7000>1`0300L70087
00<01`L04PL200<700<01`L01@L01`071`L01`000`L00`071`0=1`0700L71`0700031`0300L700D7
00@01`L70P031`0300L700h700@01`L70P031`0300L700D700@01`L70P031`0300L700h700@01`L7
0P031`0300L700D700L01`L700L000<700<01`L03@L01`071`L01`000`L00`071`051`0400L71`80
50L00`071`021`0300L700`7000?1`0300L7008700<01`L04PL01@071`L000L700<01`L00PL00`07
1`031`0300L700/700<01`L00`L00`071`021`0300L700D700D01`L700051`0300L700`700<01`L0
0PL200<700<01`L01@L010071`L200@700<01`L030L00`071`031`0500L71`001`L00`071`021`03
00L700<700<01`L02`L00`071`031`0300L7008700<01`L01@L01@071`L001@700<01`L00PL00`07
1`0=1`0040L00`071`021`0300L7010700<01`000`L00`071`031`0300L7008700<01`0010L00`07
1`0;1`0300L7008700<01`0010L00`071`031`0700L71`0700051`0300L700X700<01`L00PL00`07
00041`0300L700<700<01`L00PL00`0700041`0300L700X700<01`L00`L00`0700031`0300L700<7
00<01`L00PL00`0700041`0300L700/700<01`L00PL00`0700041`0300L700<700L01`L700L00187
00<01`L00PL00`071`0>1`0040L00`071`021`0300L700l700@01`L010L01@071`L000D700<01`00
1@L00`071`091`0300L700<700<01`001@L01@071`L000@700@01`L010L00`071`0:1`0300L70087
00@01`L010L01@071`L000@700@01`L010L00`071`0:1`0300L7008700@01`L010L01@071`L000D7
00<01`001@L00`071`091`0300L700<700<01`001@L01@071`L000@700@01`L04@L00`071`021`03
00L700h7000A1`0300L7008700<01`L03PL01@071`L000@700<01`001@L01@071`L000D700<01`L0
1`L00`071`031`0500L71`001@L00`0700041`0500L71`001@L00`071`081`0300L7008700<01`L0
0PL00`071`021`0300L000@700<01`L00PL00`071`021`0300L700P700<01`L00`L01@071`L000@7
00<01`001@L01@071`L000D700<01`L01`L00`071`031`0500L71`001@L00`0700041`0500L71`00
40L00`071`021`0300L700l7000B1`0300L7008700<01`L030L00`071`031`0700L71`0700041`03
00L700<700<01`L00`L00`071`051`0300L700<700<01`L00`L00`071`021`0300L000<700<01`L0
0`L00`071`031`0300L700H700<01`L00PL00`071`041`0700L71`0700031`0300L700@700<01`L0
0PL00`071`061`0300L700<700<01`L00`L01`071`L01`0010L00`071`031`0300L700<700<01`L0
1@L00`071`031`0300L700<700<01`L00PL00`0700031`0300L700<700<01`L030L00`071`021`03
00L70107000B1`0300L700<700<01`L02PL00`071`051`0500L71`0010L00`071`041`0300L700<7
00<01`L01@L00`071`031`0300L700@700<01`L00PL01@071`L000L700<01`L00`L00`071`041`03
00L700<700<01`L010L00`071`021`0300L7008700<01`L010L00`071`031`0300L700@700<01`L0
0`L00`071`051`0500L71`0010L00`071`041`0300L700<700<01`L01@L00`071`031`0300L700@7
00<01`L00PL01@071`L000L700<01`L02PL00`071`031`0300L70107000C1`0300L7008700<01`L0
2@L00`071`061`0300L7008700D01`L700071`0300L700<700<01`L00`L00`071`031`0300L700D7
00L01`L700L0008700<01`L01PL00`071`021`0300L700@700<01`L00PL00`071`061`0600L700L0
0PL00`071`061`0300L7008700<01`L010L00`071`021`0300L700H700H01`L01`031`0300L700D7
00<01`L00`L00`071`031`0300L700<700<01`L01@L01@071`L000@700<01`L01PL00`071`091`03
00L7008700<01`L04@L001@700<01`L00PL00`071`081`0300L700L700<01`L00PL00`0700091`03
00L700<700D01`L700051`0300L700L700<01`000PL00`0700091`0300L700<700<01`L00PL00`07
1`021`0300L700P70P031`802PL00`071`021`0300L7008700<01`L00`L00`071`071`0300L00087
00<01`002@L00`071`031`0500L71`001@L00`071`071`0300L000@700<01`L01`L00`071`081`03
00L7008700<01`L04PL001D700<01`L00PL00`071`061`0300L700T700@01`L70P0;1`0300L70087
00D01`L700041`0300L700T70P031`0300L700T700<01`L00`L010071`041`0300L700T70P031`80
2`L00`071`021`0400L700D700<01`L02@L010071`L200/700<01`L00PL01@071`L000@700<01`L0
2@L200<700<01`L02@L00`071`061`0300L7008700<01`L04`L001D700<01`L00`L00`071`041`03
00L700/700<01`L00P0;1`0300L700<700<01`001@L00`071`091`800PL00`07000;1`0300L700<7
0P051`0300L700T70P031`802`L00`071`031`801@L00`071`091`0300L000870P0;1`0300L700<7
00<01`001@L00`071`091`800PL00`071`0;1`0300L700@700<01`L00`L00`071`0C1`005PL00`07
1`021`0300L700@700<01`L02`L01P071`0700/700<01`L00`L00`071`031`0300L700T700<01`00
0PL010071`0:1`0300L700<70P041`0300L700T700H01`L01`021`0300L700T700<01`L00PL200D7
00<01`L020L010071`021`0300L000/700<01`L00`L00`071`031`0300L700T700<01`000PL00`07
1`0;1`0300L700@700<01`L00PL00`071`0D1`005`L00`071`021`0300L7008700<01`L03@L200<7
00<01`L02@L00`071`021`0300L7008700<01`L02@L010071`L200<700<01`L02@L00`071`021`80
0`L00`071`091`0700L71`0700031`0300L700T700@01`L70P041`0300L700T700@01`L70P031`03
00L700T700<01`L00PL00`071`021`0300L700T700@01`L70P0?1`0300L7008700<01`L00PL00`07
1`0E1`0060L00`071`021`0400L701070P031`0300L700X700H01`L01`021`0300L700X700@01`L7
0P041`0300L700T700@01`L00PL00`07000<1`0300L7008700<01`L00PL00`071`0:1`0300L00087
00@01`L02`L00`071`021`800`L00`071`0:1`0600L700L00PL00`071`0:1`0400L71`8040L01007
1`041`0300L701H7000H1`0300L7008700@01`L040L200@700<01`L02@L00`0700031`0300L000/7
00<01`L00PL200D700<01`L020L010071`021`0300L000/700<01`L00PL00`0700041`0300L700T7
00<01`000PL010071`0:1`0300L700<70P041`0300L700T700<01`000`L00`07000;1`0300L70087
0P0@1`0400L700@700<01`L05PL001T700<01`L00PL2010700@01`L010L00`071`091`0300L700<7
00<01`L02@L00`071`021`0400L700D700<01`L020L200@700<01`L02@L00`071`021`0500L71`00
10L00`071`091`0300L700870P0:1`0300L700<700@01`L010L00`071`091`0300L700<700<01`L0
2@L00`071`021`0400L701070P041`0300L701L7000J1`0400L71`803`L00`071`021`0300L70087
00<01`L020L200<70P0:1`0300L7008700<01`L00PL00`071`021`0300L700P70P031`0300L000T7
00<01`L00`L01@071`L000D700<01`L01`L00`0700031`802PL00`071`021`0300L7008700<01`L0
0PL00`071`081`800`L200X700<01`L00PL00`071`021`0300L700d70P031`0300L701P7000K1`03
00L0008700<01`L02`L00`071`041`0500L71`002@L01P071`07008700<01`L01`L01@071`L000H7
00<01`L00PL00`071`061`0600L700L00`L00`071`061`0300L7008700<01`L00`L00`071`021`03
00L700H700L01`L700L0008700<01`L01PL00`071`021`0300L700@700D01`L700091`0600L700L0
0PL00`071`071`0500L71`001PL00`071`0;1`0600L700L06`L001/700<01`000PL00`071`0;1`03
00L700@700<01`L00PL00`071`051`0700L71`0700031`0300L700D700<01`L00PL00`071`041`03
00L700<700<01`L01@L01P071`0700<700<01`L01@L00`071`021`0300L700D700<01`L00PL00`07
1`051`0700L71`0700021`0300L700D700<01`L00`L00`071`041`0300L7008700<01`L01@L01`07
1`L01`000`L00`071`051`0300L7008700<01`L010L00`071`0;1`0600L700L06`L001`700<01`L0
0PL00`071`091`0300L700H700<01`L00PL00`071`041`0300L7008700<01`L00PL00`071`041`03
00L7008700<01`L01PL00`071`021`0300L700@700<01`L00PL00`071`031`0300L700<700<01`L0
0`L00`071`051`0300L700<700<01`L00`L00`071`031`0300L7008700<01`L010L00`071`021`03
00L700H700<01`L00PL00`071`041`0300L7008700<01`L00PL00`071`041`0300L7008700<01`L0
1PL00`071`091`0300L7008700<01`L06PL0028700<01`L01`L00`071`081`0300L7008700<01`L0
0PL00`071`041`0300L7008700<01`L00PL00`071`021`0300L700P700<01`L00PL00`071`021`03
00L7008700<01`001@L01@071`L000D700<01`L01`L00`071`031`0500L71`001@L00`0700041`03
00L7008700<01`L00PL00`071`081`0300L7008700<01`L00PL00`071`021`0300L700@700<01`L0
0PL00`071`021`0300L700P700<01`L01`L00`071`0P1`008`L00`071`051`0300L700X700D01`L7
00031`0300L700D700<01`L00`L01@071`L000<700<01`L02PL00`071`021`0400L700D700<01`00
1PL010071`041`0300L700T700<01`L00PL010071`061`0300L000D700@01`L010L00`071`0:1`05
00L71`000`L00`071`031`0300L700D700D01`L700031`0300L700X700<01`L01@L00`071`0Q1`00
8`L00`071`051`0300L700X700<01`L00PL010071`081`0300L7008700@01`L010L00`071`0:1`03
00L700<700<01`0010L01@071`L000D700<01`001@L00`071`091`0300L700<700<01`001@L01@07
1`L000@700<01`001@L00`071`0:1`0300L7008700@01`L010L00`071`061`0400L700@700<01`L0
2PL00`071`051`0300L70247000T1`0300L700<700<01`L030L00`071`021`802PL00`071`021`80
10L00`071`0<1`0300L700870P041`0300L700<700<01`L00`L00`071`031`0300L700/700<01`L0
0`L00`071`031`0300L700<700<01`L00PL200@700<01`L030L00`071`021`8010L00`071`081`80
10L00`071`0<1`0300L700<700<01`L08PL002D700D01`L7000@1`0400L71`802`L010071`L200<7
00<01`L03PL010071`L200@700<01`L010L01`071`L01`000`L00`071`0=1`0700L71`0700031`03
00L700@700<01`L00PL200<700<01`L03PL010071`L200<700<01`L02@L200<700<01`L03PL01@07
1`L002D7000V1`0300L0018700D01`07000;1`0900L71`0700L0018700<01`000PL010071`071`05
00L71`000PL00`07000A1`0300L0008700D01`L700071`0400L7008700<01`004PL01@0700L000<7
00<01`L02@L01@0700L0018700<01`009PL002H700<01`004PL00`0700021`0300L700T700<01`00
0PL00`07000B1`0300L0008700<01`002@L00`0700031`0300L0014700<01`000`L00`0700091`03
00L0008700<01`004PL00`0700021`0300L000/700H01`L01`0B1`0300L002H7000W1`0300L70187
00<01`L00PL00`071`091`0300L7008700<01`L04PL00`071`021`0300L700T700<01`L00`L00`07
1`0A1`0300L700<700<01`L02@L00`071`021`0300L7018700<01`L00PL00`071`091`0300L70087
00<01`L04PL00`071`0U1`00?@L00`071`021`0300L700L700<01`0010L00`071`0@1`0300L000<7
0P091`0300L000<700<01`004@L00`0700031`0300L000T70P031`0300L0018700<01`L00PL00`07
00091`0300L7008700<01`L0>`L003d700<01`L00PL00`071`071`0300L000@700<01`L040L00`07
00021`0400L700P700<01`000`L00`07000A1`0300L000<700<01`0020L010071`021`0300L00187
00<01`L00PL00`0700091`0300L7008700<01`L0>`L003h700<01`L00PL00`071`051`0500L71`00
10L00`071`0>1`0400L71`800`L00`071`051`0700L71`0700031`0300L700d700L01`L700L000<7
00<01`L01@L010071`L200<700<01`L03PL00`071`021`0500L71`001`L00`071`021`0300L703`7
000o1`0300L7008700<01`L00`L00`071`031`0300L7008700<01`L030L00`071`031`0300L70087
00<01`L00`L00`071`031`0300L700<700<01`L02`L00`071`031`0300L700<700<01`L00`L00`07
1`021`0300L700<700<01`L030L00`071`021`0300L700<700<01`L00`L00`071`021`0300L703d7
000o1`0300L700<700D01`L700071`0300L7008700<01`L02PL00`071`031`0300L000@700D01`L7
00051`0300L000@700<01`L02`L00`071`021`0300L000D700D01`L700041`0300L000D700<01`L0
2PL00`071`021`0300L700D700D01`L700051`0300L703d700101`0300L7008700D01`L700071`03
00L7008700<01`L02PL00`071`021`0400L700D700@01`L01@L00`0700051`0300L700T700<01`L0
0`L00`0700051`0400L700D700@01`L010L00`071`0:1`0300L7008700<01`L01@L01@071`L000@7
00<01`L0?PL0044700<01`L00PL00`0700091`0300L7008700<01`L020L00`071`031`0500L71`00
10L00`0700051`0500L71`001@L00`071`071`0300L700<700D01`L700051`0300L000@700D01`L7
00051`0300L700P700<01`L00PL00`071`071`0300L000@700<01`L0?`L0048700<01`L00PL00`07
1`091`0300L7008700<01`L01PL00`071`031`0300L700<700<01`L00PL00`071`031`0300L700<7
00<01`L00`L00`071`051`0300L700<700<01`L00`L00`071`031`0300L7008700<01`L00`L00`07
1`031`0300L700H700<01`L00PL00`071`091`0300L7008700<01`L0@0L0048700<01`L00`L00`07
1`081`0300L700<700<01`L010L00`071`031`0300L700D700H01`L01`031`0300L700@700<01`L0
0`L00`071`051`0300L700<700<01`L010L01`071`L01`000PL00`071`051`0300L700<700<01`L0
10L00`071`031`0300L700P700<01`L00`L00`071`101`00@`L00`071`021`0300L700T700<01`L0
0PL00`071`041`0300L7008700<01`L01PL01P071`0700<700<01`L01@L00`071`031`0300L700<7
00<01`L00`L00`071`051`0700L71`0700021`0300L700H700<01`L00PL00`071`041`0300L70087
00<01`L02@L00`071`021`0300L7044700141`0300L7008700<01`L02@L00`071`021`0300L70087
00<01`L00`L00`071`071`800`L00`0700091`0300L700<700D01`L700051`0300L700L700<01`00
0`L200T700<01`L00`L00`071`021`0300L7008700<01`L02@L00`071`021`0300L7048700141`03
00L700<700<01`L02@L00`071`021`0400L700D700<01`L020L200@700<01`L02@L00`071`021`05
00L71`0010L00`071`091`0300L700870P0:1`0300L700<700@01`L010L00`071`091`0300L700<7
00<01`L0@PL004D700<01`L00`L00`071`081`0300L700<70P051`0300L700T700<01`000PL00`07
000:1`0300L700<700<01`001@L00`071`081`0300L0008700<01`002`L00`071`031`801@L00`07
1`081`0300L700<700<01`L0@`L004H700<01`L00PL00`071`091`0300L700870P051`0300L700P7
00@01`L00PL00`07000;1`0300L700<700<01`L00`L00`071`091`0300L0008700@01`L02PL00`07
1`031`8010L00`071`091`0300L7008700<01`L0A0L004H700<01`L00`L00`071`091`0400L71`80
10L00`071`081`0300L700870P031`0300L700T700<01`L00PL00`071`021`0300L700T700@01`L7
0P041`0300L700P700<01`L00PL200<700<01`L02@L00`071`031`0300L704@700171`0300L700<7
00<01`L02@L00`0700021`0400L700X700<01`L00`L200@700<01`L02@L01P071`07008700<01`L0
2@L00`071`021`801@L00`071`081`0400L7008700<01`002`L00`071`031`0300L704D700181`03
00L700<700<01`L020L00`0700021`0400L700X700<01`L00`L200D700<01`L020L00`0700031`03
00L000X700<01`L00`L200D700<01`L020L010071`021`0300L000X700<01`L00`L00`071`161`00
B@L00`071`021`0300L700T700<01`L00PL200X700<01`L00`L010071`041`0300L700T700<01`L0
0`L00`071`091`0300L7008700@01`L01@L00`071`081`8010L00`071`091`0300L7008700<01`L0
A`L004T700<01`L00`L00`071`071`0300L000<70P091`0300L700<700<01`L00PL00`071`021`03
00L700P70P031`802PL00`071`021`0300L7008700<01`L00`L00`071`071`800`L00`0700091`03
00L700<700<01`L0A`L004X700<01`L00`L00`071`051`0700L71`0700021`0300L700H700<01`L0
0PL00`071`041`0300L7008700<01`L01PL01P071`07008700<01`L01PL00`071`021`0300L700@7
00<01`L00PL00`071`061`0600L700L00`L00`071`051`0300L700<700<01`L0B0L004/700<01`L0
0`L00`071`041`0700L71`0700021`0300L700D700<01`L00`L00`071`041`0300L700<700<01`L0
10L01`071`L01`000`L00`071`041`0300L700<700<01`L010L00`071`031`0300L700D700H01`L0
1`031`0300L700@700<01`L00`L00`071`191`00B`L00`071`031`0300L700<700<01`L00`L00`07
1`021`0300L700<700<01`L00`L00`071`061`0300L7008700<01`L010L00`071`021`0300L70087
00<01`L010L00`071`021`0300L700H700<01`L00`L00`071`031`0300L7008700<01`L00`L00`07
1`031`0300L700<700<01`L0B@L004`700<01`L00`L01@071`L000`700<01`L00PL00`071`021`03
00L700P700<01`L00PL00`071`021`0300L700T700<01`L00PL00`071`021`0300L700P700<01`L0
0PL00`071`021`0300L700X700D01`L700051`0300L704X7001=1`0300L700<700<01`003PL01007
1`041`0300L700X700<01`L00PL010071`0=1`0400L700@700<01`L02PL00`071`021`0400L700h7
00<01`001@L00`071`1;1`00C@L00`071`031`0300L000h700<01`001@L00`071`0:1`0300L70087
00@01`L03@L010071`041`0300L700X700<01`L00`L00`07000>1`0300L000D700<01`L0B`L004h7
00<01`L00`L00`071`0>1`0300L700<700<01`L030L00`071`021`803`L200@700<01`L030L00`07
1`031`0300L700h700<01`L00`L00`071`1<1`00C`L01`071`L01`003`L200<700<01`L03PL01007
1`L200l70P031`0300L700h700@01`L70P0?1`0300L000<700<01`L0C@L0050700<01`000`L00`07
1`0;1`0600L700L04PL00`0700021`0300L700/700H01`L01`0B1`0300L0008700<01`L02`L01`07
1`L01`00D0L0050700<01`000`L00`071`0:1`0700L71`07000B1`0300L0008700<01`L02`L01P07
1`07018700<01`000`L00`071`0:1`0700L71`07001@1`00D@L00`071`031`0300L700T700<01`L0
0PL00`071`0B1`0300L7008700<01`L02@L00`071`021`0300L7018700<01`L00PL00`071`091`03
00L700<700<01`L0C`L005P700<01`L01`L00`071`0N1`0300L700L700<01`L07PL00`071`071`03
00L705H7001I1`0300L700D700<01`L080L00`071`051`0300L7020700<01`L01@L00`071`1G1`00
F@L00`071`051`0300L7020700<01`L01@L00`071`0P1`0300L700D700<01`L0E`L005X700<01`L0
0`L00`071`0R1`0300L700<700<01`L08PL00`071`031`0300L705P7001K1`0500L71`009PL01@07
1`L002H700D01`L7001K1`00G0L00`07000X1`0300L002P700<01`00G0L005`700<01`00:0L00`07
000X1`0300L005`7001M1`0300L702P700<01`L0:0L00`071`1K1`00o`LB1`00o`LB1`00o`LB1`00
o`LB1`00o`LB1`00o`LB1`00\
\>"],
  ImageRangeCache->{{{0, 272.938}, {267.688, 0}} -> {-9.73642, -9.5512, \
0.0713443, 0.0713443}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[172]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["j = 5, k =1", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AL051, Axes \[Rule] True, Prolog \[Rule] PointSize[0.025], 
      PlotRange \[Rule] \ {{\(-20\), 20}, {\(-20\), 20}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[173]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.5 0.025 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -9 -9 ]
[.125 .4875 9 0 ]
[.25 .4875 -9 -9 ]
[.25 .4875 9 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -6 -9 ]
[.75 .4875 6 0 ]
[.875 .4875 -6 -9 ]
[.875 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -12 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -12 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-20)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-15)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-10)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(10)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(15)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(20)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-20)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-15)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-10)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(10)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(15)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(20)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.025 w
.17115 .73897 Mdot
.23365 .75927 Mdot
.29615 .77958 Mdot
.35865 .79989 Mdot
.42115 .8202 Mdot
.48365 .8405 Mdot
.54615 .86081 Mdot
.60865 .88112 Mdot
.67115 .90143 Mdot
.73365 .92173 Mdot
.79615 .94204 Mdot
.17115 .67325 Mdot
.23365 .69356 Mdot
.29615 .71386 Mdot
.35865 .73417 Mdot
.42115 .75448 Mdot
.48365 .77479 Mdot
.54615 .79509 Mdot
.60865 .8154 Mdot
.67115 .83571 Mdot
.73365 .85602 Mdot
.79615 .87632 Mdot
.17115 .60753 Mdot
.23365 .62784 Mdot
.29615 .64815 Mdot
.35865 .66846 Mdot
.42115 .68876 Mdot
.48365 .70907 Mdot
.54615 .72938 Mdot
.60865 .74969 Mdot
.67115 .76999 Mdot
.73365 .7903 Mdot
.79615 .81061 Mdot
.17115 .54182 Mdot
.23365 .56212 Mdot
.29615 .58243 Mdot
.35865 .60274 Mdot
.42115 .62305 Mdot
.48365 .64335 Mdot
.54615 .66366 Mdot
.60865 .68397 Mdot
.67115 .70428 Mdot
.73365 .72458 Mdot
.79615 .74489 Mdot
.17115 .4761 Mdot
.23365 .49641 Mdot
.29615 .51672 Mdot
.35865 .53702 Mdot
.42115 .55733 Mdot
.48365 .57764 Mdot
.54615 .59795 Mdot
.60865 .61825 Mdot
.67115 .63856 Mdot
.73365 .65887 Mdot
.79615 .67917 Mdot
.17115 .41038 Mdot
.23365 .43069 Mdot
.29615 .451 Mdot
.35865 .47131 Mdot
.42115 .49161 Mdot
.48365 .51192 Mdot
.54615 .53223 Mdot
.60865 .55254 Mdot
.67115 .57284 Mdot
.73365 .59315 Mdot
.79615 .61346 Mdot
.17115 .34467 Mdot
.23365 .36497 Mdot
.29615 .38528 Mdot
.35865 .40559 Mdot
.42115 .4259 Mdot
.48365 .4462 Mdot
.54615 .46651 Mdot
.60865 .48682 Mdot
.67115 .50713 Mdot
.73365 .52743 Mdot
.79615 .54774 Mdot
.17115 .27895 Mdot
.23365 .29926 Mdot
.29615 .31957 Mdot
.35865 .33987 Mdot
.42115 .36018 Mdot
.48365 .38049 Mdot
.54615 .4008 Mdot
.60865 .4211 Mdot
.67115 .44141 Mdot
.73365 .46172 Mdot
.79615 .48203 Mdot
.17115 .21323 Mdot
.23365 .23354 Mdot
.29615 .25385 Mdot
.35865 .27416 Mdot
.42115 .29446 Mdot
.48365 .31477 Mdot
.54615 .33508 Mdot
.60865 .35539 Mdot
.67115 .37569 Mdot
.73365 .396 Mdot
.79615 .41631 Mdot
.17115 .14752 Mdot
.23365 .16783 Mdot
.29615 .18813 Mdot
.35865 .20844 Mdot
.42115 .22875 Mdot
.48365 .24906 Mdot
.54615 .26936 Mdot
.60865 .28967 Mdot
.67115 .30998 Mdot
.73365 .33029 Mdot
.79615 .35059 Mdot
.17115 .0818 Mdot
.23365 .10211 Mdot
.29615 .12242 Mdot
.35865 .14272 Mdot
.42115 .16303 Mdot
.48365 .18334 Mdot
.54615 .20365 Mdot
.60865 .22395 Mdot
.67115 .24426 Mdot
.73365 .26457 Mdot
.79615 .28488 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[173]:=",
  ImageSize->{225.188, 225.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Q0000h@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc>47003Q1`00h@L00>47003Q1`00h@L006<7
10031`80M@L006<700<01`L00`L010071`1d1`00I0L00`071`021`0400L700@70P1^1`00G@L400@7
00D01`L700021`0300L7008700<01`L0K@L006H700@01`L00PL00`071`021`0300L706d7001S1`04
00L7008700@01`L010L00`071`1]1`00I0L200@70P051`0300L706d7001a1`80KPL0074700<01`L0
K@L0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L007470P1^1`00L@L00`071`1]1`00
L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00:`L4048700<01`L0K@L002/710121`80
KPL002/710121`0300L706d7000[1`@0@PL00`071`1]1`00>0L403D700<01`L0K@L003P7100e1`03
00L706d7000h1`@0=@L206h7000h1`@0=@L00`071`1]1`00A@L402P700<01`L0K@L004D7100J1`@0
0PL300D700<01`L0K@L004D7100L1`0300L700@700<01`L00PL00`071`1]1`00A@L401`700<01`L0
10L00`071`021`80KPL005d710041`0400L71`<01@L00`071`1]1`00DPL400l700D01`L700071`03
00L706d7000[1`@08`L400d70`031`0300L700D700<01`L0K@L002/7100S1`@03`L010071`L400@7
00<01`L0K@L002/7100S1`@06`L206h7000[1`@0<@L400d700<01`L0K@L003P7100T1`@03@L00`07
1`1]1`00>0L402@7100=1`0300L706d7000h1`@090L400d700<01`L0K@L003P7100a1`H0KPL004D7
100T1`D0K`L004D7100T1`D0K`L004D7100T1`D0K`L004D7100X1`0300L700H7101S1`00DPL401/7
00<01`L01PL406<7000[1`@08`L401/70P071`@0H`L002/7100S1`@06`L00`071`061`@0H`L002/7
100S1`@06`L00`071`1]1`00:`L4048700<01`L04`L405H7001P1`@03@L00`071`0C1`@0EPL003P7
100T1`@03@L201@7101F1`00>0L402@7100=1`0300L701<7101F1`00>0L402@7100=1`0300L70207
10191`00>0L402L710031`8000<700000`0R1`@0B@L004D7100L1`0500L71`000PL6028710191`00
A@L401`700D01`L700021`L08@L404T700151`@050L400@700D01`L700021`H0;`L403`700151`@0
70L01@071`L0008700<01`L00PL00`071`061`@08`L403`7001B1`@03@L300<700@01`L010L00`07
1`061`@08`L403`7000[1`@08`L400l700<01`L00PL200D700<01`L01PL402<7100l1`00:`L402<7
100K1`801`L40307100_1`00:`L402<7100K1`0300L701<7100S1`@0;`L002/7100a1`@03@L00`07
1`0C1`@08`L402l7000h1`@090L400d700<01`L04`L402<7100_1`00>0L402@7100=1`0300L701<7
101F1`00>0L402@7100=1`0300L706d7000h1`@0=@L2024710191`00K@L5028710191`00A@L402@7
1@0R1`@0B@L004D7100T1`D08PL404T700151`@090L502l7100l1`00A@L402P70P071`@08`L403`7
001B1`@06`L00`071`061`@08`L403`7000[1`@08`L401/700<01`L01PL402<7100l1`00:`L402<7
100K1`0300L700H7100`1`@0;`L002/7100S1`@06`L00`071`0C1`@08`L402l7000[1`@0<@L400d7
0P0D1`@08`L402l7000h1`@090L400d700<01`L04`L402<7100_1`00>0L402@7100=1`0300L701<7
101F1`00>0L402@710051`<01@L00`071`0P1`@0B@L003P7100`1`H08PL404T700151`@08`L70247
10191`00A@L401X710021`<000<700000`0R1`@0B@L004D7100P1`0400L71`D0K`L004D7100P1`03
00L700D700<01`L0;@L403`7001Y1`@010L00`071`061`@08`L403`7001B1`@06`L200L7100S1`@0
?0L002/7100S1`@06`L00`071`061`@08`L403`7000[1`@08`L401/700<01`L01PL40307100_1`00
:`L402<7100K1`0300L701<7100S1`@0;`L002/7100a1`@03@L00`071`0C1`@08`L402l7000h1`@0
90L400d700<01`L04`L402<7100_1`00>0L402@7100=1`8050L405H7000h1`@090L400d700<01`L0
80L404T7000h1`@0<@L5028710191`00A@L402@71@0R1`@0B@L004D7100T1`D08PL404T700151`@0
90L602h7100l1`001`L400<70P0A1`@00PL3014710031`8000<700000P0?1`<05PL00`071`061`@0
2`L301@71@021`804PL400870`0A1`@00`L200<700071`0300L700<700@01`L04PL00`071`041`03
00L7010700D01`L700021`0300L700/710051`0300L701<700<01`L01PL400h700<01`L04PL40005
1`071`004`L00`071`041`0300L700h700<01`L00`L010071`021`0020L00`071`021`0400L70187
00<01`L010L500h700D01`L700021`0300L700/710051`0300L701<700<01`L01PL400h700<01`L0
4PL400051`071`004`L00`071`041`0300L700l700<01`L00PL010071`021`0000<700000P041`05
00L71`000PL00`071`081`@010L010071`L300031`0000801PL400@700D01`L700021`0300L700/7
10021`<05PL00`071`061`@02`L301H700D01`L700021`0300L7014700@01`L70`0C1`0500L71`00
0PL100470@L000X700@01`L00PL00`071`0@1`0500L71`000`L400h700D01`L700021`0300L700/7
10021`0300L701H70P0F1`0300L701H700D01`L700021`0300L70087100;1`0500L71`005PL01007
1`021`400@L11`001`L010071`021`0400L701070`031`0400L71`@030L300<700@01`L04`L00`07
1`0F1`0300L701<7100E1`<00`L010071`041`@02@L300<700<01`L04@L010071`021`0400L70087
00081`8010L201<700@01`L7100B1`0300L700870P0D1`@010L400d700<01`L04`L601D700<01`L0
0PL200D7100;1`0400L71`@04@L200@70P031`00>0L402@7100=1`0300L701<7100S1`@0;`L003P7
100T1`@03@L00`071`0C1`@0EPL000T7dP061`002@L00`071`021`0300L7008700<01`L00PL00`07
1`021`0300L700<700<01`L00PL00`071`021`0300L7008700<01`L00`L400031`0700<700<01`L0
0PL00`071`021`0300L700<700<01`L00PL00`071`021`0300L7008700<01`L00`L00`071`021`H0
10L00`071`031`0300L7008700<01`L00PL00`071`021`0300L7008700@01`L710031`0300L70087
00<01`L00PL00`071`031`0300L7008700<01`L00PL00`071`021`0300L700<700<01`L00PL00`07
1`021`0300L7008700<01`L00PL00`071`031`0300L700@700091`0300L701L700<01`L05`L00`07
1`051`@03PL00`071`0C1`D06@L00`071`061`@03@L00`071`0H1`0300L701L700<01`L010L004D7
100T1`D08PL404T700151`@090L502l7100l1`00A@L402P700<01`L01PL402<7100l1`00DPL401/7
0P071`@08`L403`7000[1`@08`L401/700<01`L01PL402<7100l1`00:`L402<7100K1`0300L700H7
100`1`@0;`L002/7100S1`@06`L00`071`0C1`@08`L402l7000[1`@0<@L400d700<01`L04`L402<7
100_1`00>0L402@7100=1`8050L402<7100_1`00>0L402@7100=1`0300L701<7101F1`00>0L402@7
100=1`0300L706d7000h1`@0=@L00`071`0P1`@0B@L006d71@0R1`@0B@L004D7100T1`H08@L404T7
00151`@090L5028710191`00A@L402@71@0_1`@0?0L004D7100X1`0300L700H7100S1`@0?0L00587
100K1`0300L700H7100S1`@0?0L002/7100S1`@06`L200L7100S1`@0?0L002/7100S1`@06`L00`07
1`061`@0<0L402l7000[1`@08`L401/700<01`L04`L402<7100_1`00:`L40347100=1`0300L701<7
100S1`@0;`L003P7100T1`@01@L300D700<01`L04`L402<7100_1`00>0L402@710081`0300L70087
00<01`L04`L405H7000h1`@090L400P700<01`L00PL2024710191`00>0L402d70`000`L000030287
10191`00A@L4020700@01`L71@0R1`@0B@L004D7100P1`0400L71`D08PL404T700151`@080L906l7
00151`@0:0L202h7100l1`00L@L00`071`061`@08`L403`7001B1`@06`L00`071`061`@08`L403`7
000[1`@08`L401/700<01`L01PL402<7100l1`00:`L402<7100K1`0300L700H7100`1`@0;`L002/7
100S1`@06`L201@7100S1`@0;`L002/7100a1`@03@L00`071`0C1`@08`L402l7000h1`@090L400d7
00<01`L04`L402<7100_1`00>0L402@7100=1`0300L701<7101F1`00>0L402@7100=1`0300L70207
10191`00>0L403471P0Q1`@0B@L004D7100T1`D08PL404T700151`@090L5028710191`00A@L402@7
1@0_1`@0?0L004D7100X1`0300L700H7100S1`@0?0L00587100K1`801`L402<7100l1`00:`L402<7
100K1`0300L700H7100S1`@0?0L002/7100S1`@06`L00`071`061`@0H`L002/7100S1`@06`L00`07
1`0j1`@0;`L002/7100d1`@00`L200D700<01`L04`L402<7100_1`00H0L400031`07008700@01`L0
10L00`071`0C1`@08`L402l7000h1`@090L400031`07008700@01`L010L201@7100S1`@0;`L003P7
100T1`@000<700L00PL010071`041`0300L701<7101F1`00>0L402@710000`L01`021`0400L700@7
00<01`L080L404T7000h1`@09`L300<700<01`L01P0R1`@0B@L004D7100L1`0300L700870P000`L0
0003028710191`00A@L402@71P0Q1`@0B@L004D7100T1`D0;`L403`700151`@0:0L00`071`061`@0
8`L403`7001B1`@06`L00`071`061`@08`L403`7001B1`@06`L00`071`061`@08`L403`7001B1`@0
6`L200L7100`1`@0;`L00587100K1`0300L701<7100S1`@0;`L00607100=1`0300L701<7100S1`@0
;`L00607100=1`0300L701<7100S1`@0;`L00607100=1`0300L701<7101F1`00H0L400d70P1^1`00
L@L00`071`0P1`@0B@L006d71@0R1`@0B@L006d71@0R1`@0B@L006d71@0R1`@0B@L006d71@0_1`@0
?0L007470P071`@08`L403`7001a1`0300L700H7100S1`@0?0L0074700<01`L01PL402<7100l1`00
H`L400870`051`0300L700H7100`1`@0;`L006D700<01`L010L00`071`021`0300L701<7100S1`@0
;`L006D700<01`L010L00`071`021`8050L402<7100_1`00I@L010071`L300D700<01`L04`L402<7
100_1`00I@L01@071`L000L700<01`L04`L405H7001S1`<00`L00`071`051`0300L7020710191`00
I@L010071`L400@700<01`L080L404T7001a1`808@L404T7001a1`0300L7020710191`00L@L00`07
1`1]1`00L@L00`071`0]1`@0?0L0074700<01`L0;@L403`7001a1`80;PL403`7001a1`0300L702d7
100l1`00L@L00`071`0j1`@0;`L0074700<01`L0>PL402l7001a1`0300L703X7100_1`00L@L00`07
1`0j1`@0;`L007470P1^1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L00`07
1`1]1`00L@L206h7001a1`0300L706d7001a1`0300L706d7001S1`@00`L200D700<01`L0K@L006<7
00<01`L00`L010071`041`0300L706d7001T1`0300L7008700@01`L010L206h7001U1`0500L71`00
0PL00`071`1b1`00IPL010071`021`0300L70787001S1`0400L7008700@01`L0M0L006@70P041`80
M@L00>47003Q1`00h@L00001\
\>"],
  ImageRangeCache->{{{0, 224.188}, {224.188, 0}} -> {-21.7212, -21.4343, \
0.191218, 0.191218}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[173]="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(basis51 = 
      FullSimplify[{A[5, 1, \[Alpha]] /. {m \[Rule] 1, n \[Rule] 0}, 
          A[5, 1, \[Alpha]] /. {m \[Rule] 0, 
              n \[Rule] 1}}]\), "\[IndentingNewLine]", 
    \(orig\  = \ 
      FullSimplify[
        A[5, 1, \[Alpha]] /. {m \[Rule] 0, n \[Rule] 0}]\)}], "Input",
  CellLabel->"In[174]:="],

Cell[BoxData[
    \({{\(-0.6541039886902862`\), \(-2.151809699052849`\)}, \
{1.8458960113097138`, 1.2891451021250848`}}\)], "Output",
  CellLabel->"Out[174]="],

Cell[BoxData[
    \({\(-0.6541039886902862`\), 0.47684586154281877`}\)], "Output",
  CellLabel->"Out[175]="]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    \(\(rad51\  = \@\(\((basis51[\([1]\)]\  - \ orig)\) . \((basis51[\([1]\)]\
\  - \ orig)\)\);\)\)], "Input",
  CellLabel->"In[176]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AppendTo[basis51, orig], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-10\), 10}, {\(-10\), 10}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[177]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.46729 .39241 Mdot
.59229 .56446 Mdot
.46729 .52384 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[177]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L0088710031`80U@L008@700D01`L700021`0300L7098700241`0500L71`000PL00`07
1`031`80S@L007`710041`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`07
1`031`0300L708`700221`<00`L010071`051`0300L708`700241`0300L700870P061`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L007d700<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<7
00<01`L0S0L007h700<01`L02PL00`071`031`80S@L007H710041`0300L700L70`061`0300L708`7
001o1`0300L700H700<01`L01PL00`071`2<1`00O0L010071`081`0300L700H700<01`L0S0L007`7
10081`@01@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`700281`<01PL00`071`2<1`00R`L00`071`031`0300L708`7
002;1`0300L700<70P2=1`00PPL400870`061`0300L708`700281`0300L700H700<01`L0S0L008P7
00<01`L01PL00`071`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00O0L400<700<01`L00PL300H7
00<01`L0S0L007`700<01`L01PL700D700<01`L0S0L007d700<01`L00`L:00@70P2=1`00MPL400@7
00<01`L00PL:00@700<01`L0S0L007l700<01`L030031`0300L708`7001l1`0400L7008730031`03
00L708`7001m1`800`L<00<700<01`L0S0L0088730031`0300L708`700221``00`L00`071`2<1`00
PPL<00<70P2=1`00P`L:00@700<01`L0S0L008<72P041`0300L708`700251`H01PL00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L000L710031`805`L00`071`031`0300L700870`0I1`<0
6@L400<700<01`L00PL301P700<01`L05`L400<700<01`L00PL301T70`0J1`0300L700<700<01`L0
0PL301H710031`800`L000T700D01`L700021`0300L701@700<01`L02`L00`071`0I1`0300L701H7
00<01`L030L00`071`0E1`0300L701L700<01`L030L00`071`0I1`0300L701L700<01`L02`L00`07
1`0E1`0500L71`000PL100470@L000T700D01`L700021`0300L701D700<01`L02PL00`071`0I1`03
00L701L700<01`L02`L00`071`0E1`0300L701P700<01`L02`L00`071`0I1`0300L701P700<01`L0
2PL00`071`0E1`0500L71`000PL100470@L000031`00008010L01@071`L0008700<01`L03@L400@7
00<01`L01`L301<710021`<04`L400@700<01`L01`L301P70P0J1`0300L700L70`0I1`<06`L00`07
1`071`<060L01@071`L000870@011`4700091`0500L71`000PL00`071`0F1`0300L700H700<01`L0
6@L00`071`0L1`0300L700H700<01`L060L00`071`0J1`0300L700H700<01`L06@L00`071`0L1`03
00L700H700<01`L060L01@071`L000870@011`4700071`<00`L010071`0E1`0400L700P700<01`L0
6@L00`071`0I1`0400L700P700<01`L060L00`071`0G1`0400L700P700<01`L06@L00`071`0I1`04
00L700P700<01`L05PL300<700@01`L00PL000T700<01`L00PL201H710081`@060L401T70P091`@0
5`L00`071`0H1`802@L401P7100H1`@020L401L700<01`L00PL200<7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`700091ol04P061`002@L00`071`031`0300L700@700<01`L010L00`07
1`041`0300L700@700<01`L00`L00`071`041`0300L700@700<01`L010L00`071`041`0300L700<7
00<01`L010L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@700<01`L010L00`07
000500H700<01`L00`L00`071`041`0300L700@700<01`L010L00`071`041`0300L700<700<01`L0
10L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@700<01`L010L00`071`041`03
00L700@700<01`L00`L00`071`041`0300L700@700<01`L010L00`071`041`0300L700@700091`03
00L701l700<01`L07`L00`071`0O1`0300L701472P041`0300L701l700<01`L07`L00`071`0O1`03
00L701l700<01`L010L008<72P041`0300L708`700221``00`L00`071`2<1`00PPL<00<700<01`L0
S0L0088730031`0300L708`700221``00`L208d700221``00`L00`071`2<1`00PPL<00<700<01`L0
S0L008<72P041`0300L708`700231`X010L00`071`2<1`00Q@L600H700<01`L04`L607<7002A1`03
00L701472P1a1`00T@L201872P1a1`00T@L00`071`0@1``0L0L0094700<01`L040L<0707002A1`03
00L70107301`1`00T@L00`071`0@1``0L0L0094700<01`L040L<0707002A1`804@L<0707002A1`03
00L701472P1a1`00T@L00`071`0A1`X0L@L0094700<01`L04`L607<7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L007`710031`0300L700870`061`0300L708`7001l1`0300L700`700<01`L0
0`L00`071`2<1`00O@L00`071`0;1`0300L700<70P2=1`00OPL00`071`071`<01PL00`071`2<1`00
O`L00`071`061`0300L700H700<01`L0S0L007`700@01`L020L00`071`061`0300L708`7001m1`80
2@L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00R0L300H700<01`L0S0L008/700<01`L00`L00`071`2<1`00
R`L00`071`031`80S@L008P70`061`0300L708`700281`0300L700H700<01`L0S0L008P700<01`L0
1PL00`071`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00O@L00`071`031`0300L700870`061`03
00L708`7001m1`0300L700/700<01`L00`L00`071`2<1`00OPL00`071`0:1`0300L700<70P2=1`00
OPL00`071`071`<01PL00`071`2<1`00O`L00`071`061`0300L700H700<01`L0S0L007`700@01`L0
20L00`071`061`0300L708`7001l1`@020L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00PPL400<70P061`03
00L708`700241`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`071`031`80
S@L008@700D01`L700021`0300L7098700241`0500L71`000PL00`071`2B1`00PPL300<700@01`L0
U0L008@700<01`L00PL209D7003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.6619, -10.5516, 0.0735301, \
0.0735301}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[177]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice051\  = tiling2D[SphericalCut[N[AL051], 10], \ rad51]\)], "Input",\

  CellLabel->"In[178]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05146 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.46757 0.0544218 0.527102 0.0544218 [
[ 0 0 0 0 ]
[ 1 1.05146 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.05146 L
0 1.05146 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.15986 .89381 m
.29592 .93801 L
s
.15986 .89381 m
.15986 .75075 L
s
.29592 .93801 m
.43197 .98222 L
s
.29592 .93801 m
.29592 .79496 L
s
.43197 .98222 m
.56803 1.02643 L
s
.43197 .98222 m
.43197 .83916 L
s
.56803 1.02643 m
.56803 .88337 L
s
.02381 .70654 m
.15986 .75075 L
s
.02381 .70654 m
.02381 .56349 L
s
.15986 .75075 m
.29592 .79496 L
s
.15986 .75075 m
.15986 .60769 L
s
.29592 .79496 m
.43197 .83916 L
s
.29592 .79496 m
.29592 .6519 L
s
.43197 .83916 m
.56803 .88337 L
s
.43197 .83916 m
.43197 .69611 L
s
.56803 .88337 m
.70408 .92758 L
s
.56803 .88337 m
.56803 .74032 L
s
.70408 .92758 m
.70408 .78452 L
s
.02381 .56349 m
.15986 .60769 L
s
.02381 .56349 m
.02381 .42043 L
s
.15986 .60769 m
.29592 .6519 L
s
.15986 .60769 m
.15986 .46464 L
s
.29592 .6519 m
.43197 .69611 L
s
.29592 .6519 m
.29592 .50885 L
s
.43197 .69611 m
.56803 .74032 L
s
.43197 .69611 m
.43197 .55305 L
s
.56803 .74032 m
.70408 .78452 L
s
.56803 .74032 m
.56803 .59726 L
s
.70408 .78452 m
.84014 .82873 L
s
.70408 .78452 m
.70408 .64147 L
s
.84014 .82873 m
.84014 .68567 L
s
.02381 .42043 m
.15986 .46464 L
s
.02381 .42043 m
.02381 .27738 L
s
.15986 .46464 m
.29592 .50885 L
s
.15986 .46464 m
.15986 .32158 L
s
.29592 .50885 m
.43197 .55305 L
s
.29592 .50885 m
.29592 .36579 L
s
.43197 .55305 m
.56803 .59726 L
s
.43197 .55305 m
.43197 .41 L
s
.56803 .59726 m
.70408 .64147 L
s
.56803 .59726 m
.56803 .4542 L
s
.70408 .64147 m
.84014 .68567 L
s
.70408 .64147 m
.70408 .49841 L
s
.84014 .68567 m
.84014 .54262 L
s
.02381 .27738 m
.15986 .32158 L
s
.15986 .32158 m
.29592 .36579 L
s
.15986 .32158 m
.15986 .17853 L
s
.29592 .36579 m
.43197 .41 L
s
.29592 .36579 m
.29592 .22273 L
s
.43197 .41 m
.56803 .4542 L
s
.43197 .41 m
.43197 .26694 L
s
.56803 .4542 m
.70408 .49841 L
s
.56803 .4542 m
.56803 .31115 L
s
.70408 .49841 m
.84014 .54262 L
s
.70408 .49841 m
.70408 .35535 L
s
.84014 .54262 m
.97619 .58682 L
s
.84014 .54262 m
.84014 .39956 L
s
.97619 .58682 m
.97619 .44377 L
s
.15986 .17853 m
.29592 .22273 L
s
.29592 .22273 m
.43197 .26694 L
s
.29592 .22273 m
.29592 .07968 L
s
.43197 .26694 m
.56803 .31115 L
s
.43197 .26694 m
.43197 .12388 L
s
.56803 .31115 m
.70408 .35535 L
s
.56803 .31115 m
.56803 .16809 L
s
.70408 .35535 m
.84014 .39956 L
s
.70408 .35535 m
.70408 .2123 L
s
.84014 .39956 m
.97619 .44377 L
s
.84014 .39956 m
.84014 .2565 L
s
.29592 .07968 m
.43197 .12388 L
s
.43197 .12388 m
.56803 .16809 L
s
.56803 .16809 m
.70408 .2123 L
s
.56803 .16809 m
.56803 .02503 L
s
.70408 .2123 m
.84014 .2565 L
s
.70408 .2123 m
.70408 .06924 L
s
.56803 .02503 m
.70408 .06924 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[178]:=",
  ImageSize->{288, 302.812},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001;PP10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00:<70P1k1`00X`L00`07000207P7002S1`0300L700870`1e1`00X`L00`07
1`051`<0LPL00:<700<01`L020L306l7002S1`0300L700/70`1/1`00X`L00`071`0>1`<0J@L00:<7
00<01`L04@L306H7002S1`0300L701@70`1S1`00X`L00`071`0G1`<0H0L00:<700<01`L06PL305d7
002S1`0300L701d70`1J1`00X`L00`071`0P1`<0E`L00:<700<01`L08`L205D7002S1`0300L702@7
00<01`L0D`L00:<700<01`L090L00`071`1C1`00E0L204d700<01`L090L00`071`1C1`00E0L00`07
000204X700<01`L090L00`071`1C1`00E0L00`071`021`@0APL00`071`0T1`0300L705<7001D1`03
00L700H70`131`0300L702@700<01`L0D`L005@700<01`L02@L3040700<01`L090L00`071`1C1`00
E0L00`071`0<1`<0?@L00`071`0T1`0300L705<7001D1`0300L700l7100i1`0300L702@700<01`L0
D`L005@700<01`L04`L303H700<01`L090L00`071`1C1`00E0L00`071`0F1`<0<`L00`071`0T1`03
00L705<7001D1`0300L701T70`0`1`0300L702@700<01`L0D`L005@700<01`L070L402`700<01`L0
90L00`071`1C1`00E0L00`071`0P1`<0:@L00`071`0T1`0300L705<7001D1`0300L702<70`0V1`03
00L702@700<01`L0D`L005@700<01`L090L00`07000202<700<01`L090L00`071`1C1`00E0L00`07
1`0T1`0300L700870`0P1`0300L702@700<01`L0D`L005@700<01`L090L00`071`051`<07@L00`07
1`0T1`0300L705<7001D1`0300L702@700<01`L020L301X700<01`L090L00`071`1C1`00E0L00`07
1`0T1`0300L700/70`0G1`0300L702@700<01`L0D`L005@700<01`L090L00`071`0>1`<050L00`07
1`0T1`0300L705<7001D1`0300L702@700<01`L04@L4010700<01`L090L00`071`1C1`00E0L00`07
1`0T1`0300L701D70`0=1`0300L702@700<01`L0D`L005@700<01`L090L00`071`0H1`<02PL00`07
1`0T1`0300L705<7001D1`0300L702@700<01`L06`L300L700<01`L090L00`071`1C1`00E0L00`07
1`0T1`0300L701h70`041`0300L702@700<01`L0D`L005@700<01`L090L00`071`0Q1`<000<700L0
9@L00`071`1C1`00E0L00`071`0T1`0300L702@70`0U1`0300L705<7001D1`0300L702@700<01`L0
9@L00`070002028700<01`L0D`L005@700<01`L090L00`071`0U1`0300L700870`0O1`0300L705<7
000]1`809@L00`071`0T1`0300L702D700<01`L01@L301`700<01`L0D`L002d700<01`000P0R1`03
00L702@700<01`L09@L00`071`081`<06@L00`071`1C1`00;@L00`071`021`<07`L00`071`0T1`03
00L702D700<01`L02`L301H700<01`L0D`L002d700<01`L01@L301`700<01`L090L00`071`0U1`03
00L700h70`0C1`0300L705<7000]1`0300L700P70`0I1`0300L702@700<01`L09@L00`071`0A1`<0
40L00`071`1C1`00;@L00`071`0;1`<05PL00`071`0T1`0300L702D700<01`L050L300d700<01`L0
D`L002d700<01`L03PL301<700<01`L090L00`071`0U1`0300L701L70`0:1`0300L705<7000]1`03
00L701470`0@1`0300L702@700<01`L09@L00`071`0J1`<01`L00`071`1C1`00;@L00`071`0D1`<0
3@L00`071`0T1`0300L702D700<01`L07@L300@700<01`L0D`L002d700<01`L05`L300X700<01`L0
90L00`071`0U1`0300L702070`000`L01`1D1`00;@L00`071`0J1`<01`L00`071`0T1`0300L702D7
00<01`L08`L305@7000]1`0300L701d70`041`0300L702@700<01`L09@L00`071`0T1`0300L00080
D@L002d700<01`L080L300031`0702D700<01`L09@L00`071`0T1`0300L70087101=1`00;@L00`07
1`0S1`<09@L00`071`0U1`0300L702@700<01`L01PL304X7000]1`0300L702@700<01`000P0R1`03
00L702D700<01`L090L00`071`091`<0A`L002d700<01`L090L00`071`021`@07PL00`071`0U1`03
00L702@700<01`L030L304@7000]1`0300L702@700<01`L01PL301/700<01`L09@L00`071`0T1`03
00L700l710101`00;@L00`071`0T1`0300L700T70`0H1`0300L702D700<01`L090L00`071`0C1`<0
?@L002d700<01`L090L00`071`0<1`<05@L00`071`0U1`0300L702@700<01`L05PL303X7000]1`03
00L702@700<01`L03`L4014700<01`L09@L00`071`0T1`0300L701T70`0g1`00;@L00`071`0T1`03
00L701<70`0>1`0300L702D700<01`L090L00`071`0L1`@0<`L002d700<01`L090L00`071`0F1`<0
2`L00`071`0U1`0300L702@700<01`L080L30307000]1`0300L702@700<01`L06@L300P700<01`L0
9@L00`071`0T1`0300L702<70P0^1`00;@L00`071`0T1`0300L701`710041`0300L702D700<01`L0
90L00`071`0T1`0300L702`7000]1`0300L702@700<01`L080L300031`0702H700<01`L090L00`07
1`0T1`0300L702`7000]1`0300L702@700<01`L08`L302H700<01`L090L00`071`0T1`0300L702`7
000]1`0300L702@700<01`L090L00`07000202<700<01`L090L00`071`0T1`0300L702`7000]1`03
00L702@700<01`L090L00`071`021`<080L00`071`0T1`0300L702@700<01`L0;0L000H70P0U1`03
00L702@700<01`L090L00`071`051`<07@L00`071`0T1`0300L702@700<01`L0;0L000H700<01`00
0P0R1`0300L702@700<01`L090L00`071`081`<06PL00`071`0T1`0300L702@700<01`L0;0L000H7
00<01`L00PL301l700<01`L090L00`071`0T1`0300L700/70`0G1`0300L702@700<01`L090L00`07
1`0/1`001PL00`071`051`<070L00`071`0T1`0300L702@700<01`L03PL301@700<01`L090L00`07
1`0T1`0300L702`700061`0300L700P70`0I1`0300L702@700<01`L090L00`071`0A1`@040L00`07
1`0T1`0300L702@700<01`L0;0L000H700<01`L02`L301H700<01`L090L00`071`0T1`0300L701D7
0`0=1`0300L702@700<01`L090L00`071`0/1`001PL00`071`0>1`<04`L00`071`0T1`0300L702@7
00<01`L060L300X700<01`L090L00`071`0T1`0300L702`700061`0300L701470`0@1`0300L702@7
00<01`L090L00`071`0K1`<01`L00`071`0T1`0300L702@700<01`L0;0L000H700<01`L050L300d7
00<01`L090L00`071`0T1`0300L701h70`041`0300L702@700<01`L090L00`071`0/1`001PL00`07
1`0G1`<02PL00`071`0T1`0300L702@700<01`L08@L300031`0702D700<01`L090L00`071`0/1`00
1PL00`071`0J1`<01`L00`071`0T1`0300L702@700<01`L090L302D700<01`L090L00`071`0/1`00
1PL00`071`0M1`<010L00`071`0T1`0300L702@700<01`L09@L00`070002028700<01`L090L00`07
1`0/1`001PL00`071`0P1`<000<700L09@L00`071`0T1`0300L702D700<01`L00PL301l700<01`L0
90L00`071`0/1`001PL00`071`0S1`<09@L00`071`0T1`0300L702D700<01`L01@L301`700<01`L0
90L00`071`0/1`001PL00`071`0T1`0300L000808PL00`071`0T1`0300L702D700<01`L020L301T7
00<01`L090L00`071`0/1`001PL00`071`0T1`0300L700870`0O1`0300L702@700<01`L09@L00`07
1`0;1`<05PL00`071`0T1`0300L702`700061`0300L702@700<01`L01@L301`700<01`L090L00`07
1`0U1`0300L700h70`0C1`0300L702@700<01`L0;0L000H700<01`L090L00`071`081`<06@L00`07
1`0T1`0300L702D700<01`L04@L3010700<01`L090L00`071`0/1`001PL00`071`0T1`0300L700/7
0`0F1`0300L702@700<01`L09@L00`071`0D1`<03@L00`071`0T1`0300L702`700061`0300L702@7
00<01`L03PL301<700<01`L090L00`071`0U1`0300L701L70`0:1`0300L702@700<01`L0;0L000H7
00<01`L090L00`071`0A1`<040L00`071`0T1`0300L702D700<01`L06PL300L700<01`L090L00`07
1`0/1`001PL00`071`0T1`0300L701@70`0=1`0300L702@700<01`L09@L00`071`0M1`<010L00`07
1`0T1`0300L702`700061`0300L702@700<01`L05`L300X700<01`L090L00`071`0U1`0300L70207
0`000`L01`0U1`0300L702`700061`0300L702@700<01`L06PL300L700<01`L090L00`071`0U1`03
00L702<70`0U1`0300L702`700061`0300L702@700<01`L07@L300@700<01`L090L00`071`0U1`03
00L702@700<01`000P0R1`0300L702`700061`0300L702@700<01`L080L300031`0702D700<01`L0
9@L00`071`0T1`0300L70087100N1`0300L702`700061`0300L702@700<01`L08`L302D700<01`L0
9@L00`071`0T1`0300L700H70`0K1`0300L702`700061`0300L702@700<01`L090L00`0700020287
00<01`L09@L00`071`0T1`0300L700T70`0H1`0300L702`700061`0300L702@700<01`L090L00`07
1`021`@07PL00`071`0U1`0300L702@700<01`L030L301D700<01`L0;0L000H700<01`L090L00`07
1`0T1`0300L700H70`0K1`0300L702D700<01`L090L00`071`0?1`@04@L00`071`0/1`001PL00`07
1`0T1`0300L702@700<01`L02@L301P700<01`L09@L00`071`0T1`0300L701<70`0>1`0300L702`7
00061`0300L702@700<01`L090L00`071`0<1`<05@L00`071`0U1`0300L702@700<01`L05PL300/7
00<01`L0;0L000H700<01`L090L00`071`0T1`0300L700l7100A1`0300L702D700<01`L090L00`07
1`0I1`<020L00`071`0/1`001PL00`071`0T1`0300L702@700<01`L04`L300h700<01`L09@L00`07
1`0T1`0300L701`710041`0300L702`700061`0300L702@700<01`L090L00`071`0F1`<02`L00`07
1`0U1`0300L702@700<01`L080L300031`0702d700061`0300L702@700<01`L090L00`071`0I1`<0
20L00`071`0U1`0300L702@700<01`L08`L302d700061`0300L702@700<01`L090L00`071`0L1`@0
10L00`071`0U1`0300L702@700<01`L090L00`07000202X700061`0300L702@700<01`L090L00`07
1`0P1`<000<700L09PL00`071`0T1`0300L702@700<01`L00PL302L700061`0300L702@700<01`L0
90L00`071`0S1`<09PL00`071`0T1`0300L702@700<01`L01@L302@700061`0300L702@700<01`L0
90L00`071`0T1`0300L000808`L00`071`0T1`0300L702@700<01`L020L3024700061`0300L702@7
00<01`L090L00`071`0T1`0300L700870`0P1`0300L702@700<01`L090L00`071`0;1`<07PL000H7
0P0U1`0300L702@700<01`L090L00`071`051`<07@L00`071`0T1`0300L702@700<01`L03PL301/7
00061`0300L000808PL00`071`0T1`0300L702@700<01`L020L301X700<01`L090L00`071`0T1`03
00L701470`0H1`001PL00`071`021`<07`L00`071`0T1`0300L702@700<01`L02`L301L700<01`L0
90L00`071`0T1`0300L701@70`0E1`001PL00`071`051`<070L00`071`0T1`0300L702@700<01`L0
3PL301@700<01`L090L00`071`0T1`0300L701L70`0B1`001PL00`071`081`<06@L00`071`0T1`03
00L702@700<01`L04@L4010700<01`L090L00`071`0T1`0300L701X70`0?1`001PL00`071`0;1`<0
5PL00`071`0T1`0300L702@700<01`L05@L300d700<01`L090L00`071`0T1`0300L701d70`0<1`00
1PL00`071`0>1`<04`L00`071`0T1`0300L702@700<01`L060L300X700<01`L090L00`071`0T1`03
00L702070`091`001PL00`071`0A1`<040L00`071`0T1`0300L702@700<01`L06`L300L700<01`L0
90L00`071`0T1`0300L702<70P071`001PL00`071`0D1`<03@L00`071`0T1`0300L702@700<01`L0
7PL300@700<01`L090L00`071`0T1`0300L702@700<01`L01@L000H700<01`L05`L300X700<01`L0
90L00`071`0T1`0300L702470`000`L01`0U1`0300L702@700<01`L090L00`071`051`001PL00`07
1`0J1`<01`L00`071`0T1`0300L702@700<01`L090L302D700<01`L090L00`071`0T1`0300L700D7
00061`0300L701d70`041`0300L702@700<01`L090L00`071`0U1`0300L000808PL00`071`0T1`03
00L702@700<01`L01@L000H700<01`L080L300031`0702D700<01`L090L00`071`0U1`0300L70087
0`0O1`0300L702@700<01`L090L00`071`051`001PL00`071`0S1`<09@L00`071`0T1`0300L702D7
00<01`L01@L301`700<01`L090L00`071`0T1`0300L700D700061`0300L702@700<01`000P0R1`03
00L702@700<01`L09@L00`071`081`<06@L00`071`0T1`0300L702@700<01`L01@L000H700<01`L0
90L00`071`021`<07`L00`071`0T1`0300L702D700<01`L02`L301H700<01`L090L00`071`0T1`03
00L700D700061`0300L702@700<01`L01@L301`700<01`L090L00`071`0U1`0300L700h70`0C1`03
00L702@700<01`L090L00`071`051`001PL00`071`0T1`0300L700P70`0I1`0300L702@700<01`L0
9@L00`071`0A1`<040L00`071`0T1`0300L702@700<01`L01@L000H700<01`L090L00`071`0;1`<0
5PL00`071`0T1`0300L702D700<01`L050L300d700<01`L090L00`071`0T1`0300L700D700061`03
00L702@700<01`L03PL301<700<01`L090L00`071`0U1`0300L701L70`0:1`0300L702@700<01`L0
90L00`071`051`001PL00`071`0T1`0300L701470`0@1`0300L702@700<01`L09@L00`071`0J1`<0
1`L00`071`0T1`0300L702@700<01`L01@L000H700<01`L090L00`071`0D1`<03@L00`071`0T1`03
00L702D700<01`L07@L300@700<01`L090L00`071`0T1`0300L700D700061`0300L702@700<01`L0
5`L300X700<01`L090L00`071`0U1`0300L702070`000`L01`0U1`0300L702@700<01`L01@L000H7
00<01`L090L00`071`0J1`<01`L00`071`0T1`0300L702D700<01`L08`L302D700<01`L090L00`07
1`051`001PL00`071`0T1`0300L701d70`041`0300L702@700<01`L09@L00`071`0T1`0300L00080
8PL00`071`0T1`0300L700D700061`0300L702@700<01`L080L300031`0702D700<01`L09@L00`07
1`0T1`0300L70087100N1`0300L702@700<01`L01@L000H700<01`L090L00`071`0S1`<09@L00`07
1`0U1`0300L702@700<01`L01PL301/700<01`L090L00`071`051`001PL00`071`0T1`0300L702@7
00<01`000P0R1`0300L702D700<01`L090L00`071`091`<060L00`071`0T1`0300L700D700061`03
00L702@700<01`L090L00`071`021`@07PL00`071`0U1`0300L702@700<01`L030L301D700<01`L0
90L00`071`051`001PL00`071`0T1`0300L702@700<01`L01PL301/700<01`L09@L00`071`0T1`03
00L700l7100A1`0300L702@700<01`L01@L000H700<01`L090L00`071`0T1`0300L700T70`0H1`03
00L702D700<01`L090L00`071`0C1`<03PL00`071`0T1`0300L700D700061`0300L702@700<01`L0
90L00`071`0<1`<05@L00`071`0U1`0300L702@700<01`L05PL300/700<01`L090L00`071`051`00
1PL00`071`0T1`0300L702@700<01`L03`L4014700<01`L09@L00`071`0T1`0300L701T70`081`03
00L702@700<01`L01@L000H700<01`L090L00`071`0T1`0300L701<70`0>1`0300L702D700<01`L0
90L00`071`0L1`@010L00`071`0T1`0300L700D700061`0300L702@700<01`L090L00`071`0F1`<0
2`L00`071`0U1`0300L702@700<01`L080L300031`0702D700<01`L01@L000H700<01`L090L00`07
1`0T1`0300L701T70`081`0300L702D700<01`L090L00`071`0S1`<09@L00`071`051`001PL00`07
1`0T1`0300L702@700<01`L070L400@700<01`L09@L00`071`0T1`0300L702@700<01`000P0R1`03
00L700D700061`0300L702@700<01`L090L00`071`0P1`<000<700L09PL00`071`0T1`0300L702@7
00<01`L00PL301l700<01`L01@L000H700<01`L090L00`071`0T1`0300L702<70`0V1`0300L702@7
00<01`L090L00`071`051`<070L00`071`051`001PL00`071`0T1`0300L702@700<01`L090L00`07
000202<700<01`L090L00`071`0T1`0300L700P70`0I1`0300L700D700061`0300L702@700<01`L0
90L00`071`0T1`0300L700870`0P1`0300L702@700<01`L090L00`071`0;1`<05PL00`071`051`00
1PL202D700<01`L090L00`071`0T1`0300L700D70`0M1`0300L702@700<01`L090L00`071`0>1`<0
4`L00`071`051`001PL00`070002028700<01`L090L00`071`0T1`0300L700P70`0J1`0300L702@7
00<01`L090L00`071`0A1`<040L00`071`051`001PL00`071`021`<07`L00`071`0T1`0300L702@7
00<01`L02`L301L700<01`L090L00`071`0T1`0300L701@70`0=1`0300L700D700061`0300L700D7
0`0L1`0300L702@700<01`L090L00`071`0>1`<050L00`071`0T1`0300L702@700<01`L05`L300X7
00<01`L01@L000H700<01`L020L301T700<01`L090L00`071`0T1`0300L70147100@1`0300L702@7
00<01`L090L00`071`0J1`<01`L00`071`051`001PL00`071`0;1`<05PL00`071`0T1`0300L702@7
00<01`L05@L300d700<01`L090L00`071`0T1`0300L701d70`041`0300L700D700061`0300L700h7
0`0C1`0300L702@700<01`L090L00`071`0H1`<02PL00`071`0T1`0300L702@700<01`L080L30003
1`0700H700061`0300L701470`0@1`0300L702@700<01`L090L00`071`0K1`<01`L00`071`0T1`03
00L702@700<01`L08`L200L700061`0300L701@70`0=1`0300L702@700<01`L090L00`071`0N1`<0
10L00`071`0T1`0300L702@700<01`L0;0L000H700<01`L05`L300X700<01`L090L00`071`0T1`03
00L702470`000`L01`0U1`0300L702@700<01`L0;0L000H700<01`L06PL300L700<01`L090L00`07
1`0T1`0300L702@70`0U1`0300L702@700<01`L0;0L000H700<01`L07@L300@700<01`L090L00`07
1`0T1`0300L702D700<01`000P0R1`0300L702@700<01`L0;0L000H700<01`L080L300031`0702D7
00<01`L090L00`071`0U1`0300L700870`0O1`0300L702@700<01`L0;0L000H700<01`L08`L302D7
00<01`L090L00`071`0U1`0300L700D70`0L1`0300L702@700<01`L0;0L000H700<01`L090L00`07
0002028700<01`L090L00`071`0U1`0300L700P70`0I1`0300L702@700<01`L0;0L000H700<01`L0
90L00`071`021`<07`L00`071`0T1`0300L702D700<01`L02`L301H700<01`L090L00`071`0/1`00
1PL00`071`0T1`0300L700D70`0L1`0300L702@700<01`L09@L00`071`0>1`<04`L00`071`0T1`03
00L702`700061`0300L702@700<01`L020L301T700<01`L090L00`071`0U1`0300L701470`0@1`03
00L702@700<01`L0;0L000H700<01`L090L00`071`0;1`<05PL00`071`0T1`0300L702D700<01`L0
50L300d700<01`L090L00`071`0/1`001PL00`071`0T1`0300L700h70`0C1`0300L702@700<01`L0
9@L00`071`0G1`<02PL00`071`0T1`0300L702`700061`0300L702@700<01`L04@L3010700<01`L0
90L00`071`0U1`0300L701X70`071`0300L702@700<01`L0;0L000H700<01`L090L00`071`0D1`<0
3@L00`071`0T1`0300L702D700<01`L07@L300@700<01`L090L00`071`0/1`001PL00`071`0T1`03
00L701L70`0:1`0300L702@700<01`L09@L00`071`0P1`<000<700L09@L00`071`0/1`001PL00`07
1`0T1`0300L701X70`071`0300L702@700<01`L09@L00`071`0S1`<09@L00`071`0/1`001PL00`07
1`0T1`0300L701d70`041`0300L702@700<01`L09@L00`071`0T1`0300L000808PL00`071`0/1`00
1PL00`071`0T1`0300L702070`000`L01`0U1`0300L702D700<01`L090L00`071`021`@07PL00`07
1`0/1`001PL00`071`0T1`0300L702<70`0U1`0300L702D700<01`L090L00`071`061`<06`L00`07
1`0/1`001PL00`071`0T1`0300L702@700<01`000P0R1`0300L702D700<01`L090L00`071`091`<0
60L00`071`0/1`001PL00`071`0T1`0300L702@700<01`L00PL401h700<01`L09@L00`071`0T1`03
00L700`70`0E1`0300L702`700061`0300L702@700<01`L090L00`071`061`<06`L00`071`0U1`03
00L702@700<01`L03`L4014700<01`L0;0L000H700<01`L090L00`071`0T1`0300L700T70`0H1`03
00L702D700<01`L090L00`071`0C1`<03PL00`071`0/1`001PL00`071`0T1`0300L702@700<01`L0
30L301D700<01`L09@L00`071`0T1`0300L701H70`0;1`0300L702`700061`0300L702@700<01`L0
90L00`071`0?1`@04@L00`071`0U1`0300L702@700<01`L06@L300P700<01`L0;0L000H700<01`L0
90L00`071`0T1`0300L701<70`0>1`0300L702D700<01`L090L00`071`0L1`@010L00`071`0/1`00
1PL00`071`0T1`0300L702@700<01`L05PL300/700<01`L09@L00`071`0T1`0300L702070`000`L0
1`0]1`001PL00`071`0T1`0300L702@700<01`L06@L300P700<01`L09@L00`071`0T1`0300L702<7
0P0^1`001PL00`071`0T1`0300L702@700<01`L070L400@700<01`L09@L00`071`0T1`0300L702@7
00<01`L0;0L000H700<01`L090L00`071`0T1`0300L702070`000`L01`0V1`0300L702@700<01`L0
90L00`071`0/1`001PL00`071`0T1`0300L702@700<01`L08`L302H700<01`L090L00`071`0T1`03
00L702`700061`0300L702@700<01`L090L00`071`0T1`0300L000808`L00`071`0T1`0300L702@7
00<01`L0;0L000H700<01`L090L00`071`0T1`0300L702@700<01`L00PL3020700<01`L090L00`07
1`0T1`0300L702`700061`809@L00`071`0T1`0300L702@700<01`L01@L301d700<01`L090L00`07
1`0T1`0300L702`700081`<08PL00`071`0T1`0300L702@700<01`L020L301X700<01`L090L00`07
1`0T1`0300L702`7000;1`<07`L00`071`0T1`0300L702@700<01`L02`L301L700<01`L090L00`07
1`0T1`0300L702`7000>1`<070L00`071`0T1`0300L702@700<01`L03PL301@700<01`L090L00`07
1`0T1`0300L702`7000A1`<06@L00`071`0T1`0300L702@700<01`L04@L4010700<01`L090L00`07
1`0T1`0300L702`7000D1`<05PL00`071`0T1`0300L702@700<01`L05@L300d700<01`L090L00`07
1`0T1`0300L702`7000G1`<04`L00`071`0T1`0300L702@700<01`L060L300X700<01`L090L00`07
1`0T1`0300L702`7000J1`<040L00`071`0T1`0300L702@700<01`L06`L300L700<01`L090L00`07
1`0T1`0300L702`7000M1`<03@L00`071`0T1`0300L702@700<01`L07PL300@700<01`L090L00`07
1`0T1`0300L702`7000P1`<02PL00`071`0T1`0300L702@700<01`L08@L300031`0702D700<01`L0
90L00`071`0/1`008`L300L700<01`L090L00`071`0T1`0300L702@70`0U1`0300L702@700<01`L0
;0L002H70`041`0300L702@700<01`L090L00`071`0U1`0300L000808PL00`071`0T1`0300L702`7
000Y1`<000<700L09@L00`071`0T1`0300L702D700<01`L00PL301l700<01`L090L00`071`0/1`00
;0L302D700<01`L090L00`071`0U1`0300L700D70`0L1`0300L702@700<01`L0;0L002d700<01`00
0P0R1`0300L702@700<01`L09@L00`071`081`<06@L00`071`0T1`0300L702`7000]1`0300L70087
0`0O1`0300L702@700<01`L09@L00`071`0;1`<05PL00`071`0T1`0300L702`7000]1`0300L700D7
0`0L1`0300L702@700<01`L09@L00`071`0>1`<04`L00`071`0T1`0300L702`7000]1`0300L700P7
0`0I1`0300L702@700<01`L09@L00`071`0A1`<040L00`071`0T1`0300L702`7000]1`0300L700/7
0`0F1`0300L702@700<01`L09@L00`071`0D1`<03@L00`071`0T1`0300L702`7000]1`0300L700h7
0`0C1`0300L702@700<01`L09@L00`071`0G1`<02PL00`071`0T1`0300L702`7000]1`0300L70147
0`0@1`0300L702@700<01`L09@L00`071`0J1`<01`L00`071`0T1`0300L702`7000]1`0300L701@7
0`0=1`0300L702@700<01`L09@L00`071`0M1`<010L00`071`0T1`0300L702`7000]1`0300L701L7
0`0:1`0300L702@700<01`L09@L00`071`0P1`<000<700L09@L00`071`0/1`00;@L00`071`0J1`<0
1`L00`071`0T1`0300L702D700<01`L08`L302D700<01`L0;0L002d700<01`L07@L300@700<01`L0
90L00`071`0U1`0300L702@700<01`000P0R1`0300L702`7000]1`0300L702070`000`L01`0U1`03
00L702D700<01`L090L00`071`021`<07`L00`071`0/1`00;@L00`071`0S1`<09@L00`071`0U1`03
00L702@700<01`L01@L301`700<01`L0;0L002d700<01`L090L00`070002028700<01`L09@L00`07
1`0T1`0300L700P70`0I1`0300L702`7000]1`0300L702@700<01`L00PL301l700<01`L09@L00`07
1`0T1`0300L700/70`0F1`0300L702`7000]1`0300L702@700<01`L01@L301`700<01`L09@L00`07
1`0T1`0300L700h70`0C1`0300L702`7000]1`0300L702@700<01`L020L301T700<01`L09@L00`07
1`0T1`0300L701470`0@1`0300L702`7000]1`0300L702@700<01`L02`L301H700<01`L09@L00`07
1`0T1`0300L701@70`0=1`0300L702`7000]1`0300L702@700<01`L03PL301<700<01`L09@L00`07
1`0T1`0300L701L70`0:1`0300L702`7000]1`0300L702@700<01`L04@L3010700<01`L09@L00`07
1`0T1`0300L701X70`071`0300L702`7000]1`0300L702@700<01`L050L300d700<01`L09@L00`07
1`0T1`0300L701d70`041`0300L702`7000]1`0300L702@700<01`L05`L300X700<01`L09@L00`07
1`0T1`0300L702070`000`L01`0]1`00;@L00`071`0T1`0300L701X70`071`0300L702D700<01`L0
90L00`071`0S1`80;PL002d700<01`L090L00`071`0M1`<010L00`071`0U1`0300L702@700<01`L0
D`L002d700<01`L090L00`071`0P1`<000<700L09PL00`071`0T1`0300L705<7000]1`0300L702@7
00<01`L08`L302H700<01`L090L00`071`1C1`00;@L00`071`0T1`0300L702@700<01`000P0S1`03
00L702@700<01`L0D`L002d700<01`L090L00`071`0T1`0300L70087100O1`0300L702@700<01`L0
D`L002d700<01`L090L00`071`0T1`0300L700H70`0L1`0300L702@700<01`L0D`L002d700<01`L0
90L00`071`0T1`0300L700T70`0I1`0300L702@700<01`L0D`L002d700<01`L090L00`071`0T1`03
00L700`7100E1`0300L702@700<01`L0D`L002d700<01`L090L00`071`0T1`0300L701070`0B1`03
00L702@700<01`L0D`L002d700<01`L090L00`071`0T1`0300L701<70`0?1`0300L702@700<01`L0
D`L002d700<01`L090L00`071`0T1`0300L701H7100;1`0300L702@700<01`L0D`L002d700<01`L0
90L00`071`0T1`0300L701X70`081`0300L702@700<01`L0D`L002d700<01`L090L00`071`0T1`03
00L701d70`051`0300L702@700<01`L0D`L002d700<01`L090L00`071`0T1`0300L7020710000`L0
1`0U1`0300L705<7000]1`0300L702@700<01`L090L00`071`0T1`<09@L00`071`1C1`00;@L00`07
1`0T1`0300L702@700<01`L09@L00`070002028700<01`L0D`L002d700<01`L090L00`071`0T1`03
00L702D700<01`L00PL301l700<01`L0D`L002d70P0U1`0300L702@700<01`L09@L00`071`051`<0
70L00`071`1C1`00;`L3028700<01`L090L00`071`0U1`0300L700P70`0I1`0300L705<7000b1`<0
7`L00`071`0T1`0300L702D700<01`L02`L301H700<01`L0D`L003D70`0L1`0300L702@700<01`L0
9@L00`071`0>1`<04`L00`071`1C1`00>0L301T700<01`L090L00`071`0U1`0300L701470`0@1`03
00L705<7000k1`<05PL00`071`0T1`0300L702D700<01`L050L300d700<01`L0D`L003h70`0C1`03
00L702@700<01`L09@L00`071`0G1`<02PL00`071`1C1`00@@L3010700<01`L090L00`071`0U1`03
00L701X70`071`0300L705<700141`<03@L00`071`0T1`0300L702D700<01`L07@L300@700<01`L0
D`L004L70`0:1`0300L702@700<01`L09@L00`071`0P1`<000<700L0E0L004X70`071`0300L702@7
00<01`L09@L00`071`0S1`80E@L004d70`041`0300L702@700<01`L09@L00`071`1j1`00D0L30003
1`0702D700<01`L09@L00`071`1j1`00D`L302D700<01`L09@L00`071`1j1`00EPL3028700<01`L0
9@L00`071`1j1`00F@L301l700<01`L09@L00`071`1j1`00G0L301`700<01`L09@L00`071`1j1`00
G`L301T700<01`L09@L00`071`1j1`00HPL301H700<01`L09@L00`071`1j1`00I@L301<700<01`L0
9@L00`071`1j1`00J0L3010700<01`L09@L00`071`1j1`00J`L300d700<01`L09@L00`071`1j1`00
KPL300X700<01`L09@L00`071`1j1`00L@L300L700<01`L09@L00`071`1j1`00M0L300@700<01`L0
9@L00`071`1j1`00M`L300031`0702H700<01`L0NPL007X70`0V1`0300L707X7001m1`<08`L00`07
1`1j1`00P0L401l700<01`L0NPL008@70`0L1`0300L707X700271`<06@L00`071`1j1`00RPL401D7
00<01`L0NPL008h70`0B1`0300L707X7002A1`<03`L00`071`1j1`00U0L400/700<01`L0NPL009P7
0`081`0300L707X7002K1`<01@L00`071`1j1`00WPL400031`0707/7002R1`80O0L00?l78@L00?l7
8@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {301.812, 0}} -> {-8.59169, -9.68698, \
0.064025, 0.064025}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[178]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice51\  = 
      tiling2D[SphericalCut[N[Join[AL051, \ AL151, \ AL251, \ AL351]], 10], \ 
        rad51]\)], "Input",
  CellLabel->"In[179]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9557 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.49998 0.0493231 0.477784 0.0493231 [
[ 0 0 0 0 ]
[ 1 .9557 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .9557 L
0 .9557 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.2211 .81013 m
.34441 .8502 L
s
.2211 .81013 m
.2211 .68048 L
s
.34441 .8502 m
.46772 .89026 L
s
.34441 .8502 m
.34441 .72055 L
s
.46772 .89026 m
.59103 .93033 L
s
.46772 .89026 m
.46772 .76061 L
s
.59103 .93033 m
.59103 .80068 L
s
.09779 .64042 m
.2211 .68048 L
s
.09779 .64042 m
.09779 .51076 L
s
.2211 .68048 m
.34441 .72055 L
s
.2211 .68048 m
.2211 .55083 L
s
.34441 .72055 m
.46772 .76061 L
s
.34441 .72055 m
.34441 .59089 L
s
.46772 .76061 m
.59103 .80068 L
s
.46772 .76061 m
.46772 .63096 L
s
.59103 .80068 m
.71433 .84074 L
s
.59103 .80068 m
.59103 .67102 L
s
.71433 .84074 m
.71433 .71109 L
s
.09779 .51076 m
.2211 .55083 L
s
.09779 .51076 m
.09779 .38111 L
s
.2211 .55083 m
.34441 .59089 L
s
.2211 .55083 m
.2211 .42117 L
s
.34441 .59089 m
.46772 .63096 L
s
.34441 .59089 m
.34441 .46124 L
s
.46772 .63096 m
.59103 .67102 L
s
.46772 .63096 m
.46772 .5013 L
s
.59103 .67102 m
.71433 .71109 L
s
.59103 .67102 m
.59103 .54137 L
s
.71433 .71109 m
.83764 .75115 L
s
.71433 .71109 m
.71433 .58143 L
s
.83764 .75115 m
.83764 .6215 L
s
.09779 .38111 m
.2211 .42117 L
s
.09779 .38111 m
.09779 .25145 L
s
.2211 .42117 m
.34441 .46124 L
s
.2211 .42117 m
.2211 .29152 L
s
.34441 .46124 m
.46772 .5013 L
s
.34441 .46124 m
.34441 .33158 L
s
.46772 .5013 m
.59103 .54137 L
s
.46772 .5013 m
.46772 .37165 L
s
.59103 .54137 m
.71433 .58143 L
s
.59103 .54137 m
.59103 .41172 L
s
.71433 .58143 m
.83764 .6215 L
s
.71433 .58143 m
.71433 .45178 L
s
.83764 .6215 m
.83764 .49185 L
s
.09779 .25145 m
.2211 .29152 L
s
.2211 .29152 m
.34441 .33158 L
s
.2211 .29152 m
.2211 .16187 L
s
.34441 .33158 m
.46772 .37165 L
s
.34441 .33158 m
.34441 .20193 L
s
.46772 .37165 m
.59103 .41172 L
s
.46772 .37165 m
.46772 .242 L
s
.59103 .41172 m
.71433 .45178 L
s
.59103 .41172 m
.59103 .28206 L
s
.71433 .45178 m
.83764 .49185 L
s
.71433 .45178 m
.71433 .32213 L
s
.83764 .49185 m
.96095 .53191 L
s
.83764 .49185 m
.83764 .36219 L
s
.96095 .53191 m
.96095 .40226 L
s
.2211 .16187 m
.34441 .20193 L
s
.34441 .20193 m
.46772 .242 L
s
.34441 .20193 m
.34441 .07228 L
s
.46772 .242 m
.59103 .28206 L
s
.46772 .242 m
.46772 .11234 L
s
.59103 .28206 m
.71433 .32213 L
s
.59103 .28206 m
.59103 .15241 L
s
.71433 .32213 m
.83764 .36219 L
s
.71433 .32213 m
.71433 .19247 L
s
.83764 .36219 m
.96095 .40226 L
s
.83764 .36219 m
.83764 .23254 L
s
.34441 .07228 m
.46772 .11234 L
s
.46772 .11234 m
.59103 .15241 L
s
.59103 .15241 m
.71433 .19247 L
s
.59103 .15241 m
.59103 .02275 L
s
.71433 .19247 m
.83764 .23254 L
s
.71433 .19247 m
.71433 .06282 L
s
.59103 .02275 m
.71433 .06282 L
s
.23634 .89288 m
.35965 .93294 L
s
.23634 .89288 m
.23634 .76322 L
s
.35965 .93294 m
.35965 .80329 L
s
.11304 .72316 m
.23634 .76322 L
s
.11304 .72316 m
.11304 .59351 L
s
.23634 .76322 m
.35965 .80329 L
s
.23634 .76322 m
.23634 .63357 L
s
.35965 .80329 m
.48296 .84335 L
s
.35965 .80329 m
.35965 .67364 L
s
.48296 .84335 m
.60627 .88342 L
s
.48296 .84335 m
.48296 .7137 L
s
.60627 .88342 m
.60627 .75377 L
s
.11304 .59351 m
.23634 .63357 L
s
.11304 .59351 m
.11304 .46385 L
s
.23634 .63357 m
.35965 .67364 L
s
.23634 .63357 m
.23634 .50392 L
s
.35965 .67364 m
.48296 .7137 L
s
.35965 .67364 m
.35965 .54398 L
s
.48296 .7137 m
.60627 .75377 L
s
.48296 .7137 m
.48296 .58405 L
s
.60627 .75377 m
.72957 .79383 L
s
.60627 .75377 m
.60627 .62411 L
s
.72957 .79383 m
.72957 .66418 L
s
.11304 .46385 m
.23634 .50392 L
s
.11304 .46385 m
.11304 .3342 L
s
.23634 .50392 m
.35965 .54398 L
s
.23634 .50392 m
.23634 .37426 L
s
.35965 .54398 m
.48296 .58405 L
s
.35965 .54398 m
.35965 .41433 L
s
.48296 .58405 m
.60627 .62411 L
s
.48296 .58405 m
.48296 .45439 L
s
.60627 .62411 m
.72957 .66418 L
s
.60627 .62411 m
.60627 .49446 L
s
.72957 .66418 m
.85288 .70424 L
s
.72957 .66418 m
.72957 .53452 L
s
.85288 .70424 m
.85288 .57459 L
s
.11304 .3342 m
.23634 .37426 L
s
.11304 .3342 m
.11304 .20455 L
s
.23634 .37426 m
.35965 .41433 L
s
.23634 .37426 m
.23634 .24461 L
s
.35965 .41433 m
.48296 .45439 L
s
.35965 .41433 m
.35965 .28468 L
s
.48296 .45439 m
.60627 .49446 L
s
.48296 .45439 m
.48296 .32474 L
s
.60627 .49446 m
.72957 .53452 L
s
.60627 .49446 m
.60627 .36481 L
s
.72957 .53452 m
.85288 .57459 L
s
.72957 .53452 m
.72957 .40487 L
s
.85288 .57459 m
.85288 .44494 L
s
.11304 .20455 m
.23634 .24461 L
s
.23634 .24461 m
.35965 .28468 L
s
.23634 .24461 m
.23634 .11496 L
s
.35965 .28468 m
.48296 .32474 L
s
.35965 .28468 m
.35965 .15502 L
s
.48296 .32474 m
.60627 .36481 L
s
.48296 .32474 m
.48296 .19509 L
s
.60627 .36481 m
.72957 .40487 L
s
.60627 .36481 m
.60627 .23515 L
s
.72957 .40487 m
.85288 .44494 L
s
.72957 .40487 m
.72957 .27522 L
s
.85288 .44494 m
.97619 .485 L
s
.85288 .44494 m
.85288 .31528 L
s
.97619 .485 m
.97619 .35535 L
s
.23634 .11496 m
.35965 .15502 L
s
.35965 .15502 m
.48296 .19509 L
s
.35965 .15502 m
.35965 .02537 L
s
.48296 .19509 m
.60627 .23515 L
s
.48296 .19509 m
.48296 .06543 L
s
.60627 .23515 m
.72957 .27522 L
s
.60627 .23515 m
.60627 .1055 L
s
.72957 .27522 m
.85288 .31528 L
s
.72957 .27522 m
.72957 .14556 L
s
.85288 .31528 m
.97619 .35535 L
s
.85288 .31528 m
.85288 .18563 L
s
.35965 .02537 m
.48296 .06543 L
s
.48296 .06543 m
.60627 .1055 L
s
.60627 .1055 m
.72957 .14556 L
s
.72957 .14556 m
.85288 .18563 L
s
.14712 .77007 m
.27043 .81013 L
s
.14712 .77007 m
.14712 .64042 L
s
.27043 .81013 m
.39373 .8502 L
s
.27043 .81013 m
.27043 .68048 L
s
.39373 .8502 m
.51704 .89026 L
s
.39373 .8502 m
.39373 .72055 L
s
.51704 .89026 m
.64035 .93033 L
s
.51704 .89026 m
.51704 .76061 L
s
.64035 .93033 m
.64035 .80068 L
s
.02381 .60035 m
.14712 .64042 L
s
.02381 .60035 m
.02381 .4707 L
s
.14712 .64042 m
.27043 .68048 L
s
.14712 .64042 m
.14712 .51076 L
s
.27043 .68048 m
.39373 .72055 L
s
.27043 .68048 m
.27043 .55083 L
s
.39373 .72055 m
.51704 .76061 L
s
.39373 .72055 m
.39373 .59089 L
s
.51704 .76061 m
.64035 .80068 L
s
.51704 .76061 m
.51704 .63096 L
s
.64035 .80068 m
.76366 .84074 L
s
.64035 .80068 m
.64035 .67102 L
s
.76366 .84074 m
.76366 .71109 L
s
.02381 .4707 m
.14712 .51076 L
s
.14712 .51076 m
.27043 .55083 L
s
.14712 .51076 m
.14712 .38111 L
s
.27043 .55083 m
.39373 .59089 L
s
.27043 .55083 m
.27043 .42117 L
s
.39373 .59089 m
.51704 .63096 L
s
.39373 .59089 m
.39373 .46124 L
s
.51704 .63096 m
.64035 .67102 L
s
.51704 .63096 m
.51704 .5013 L
s
.64035 .67102 m
.76366 .71109 L
s
.64035 .67102 m
.64035 .54137 L
s
.76366 .71109 m
.88696 .75115 L
s
.76366 .71109 m
.76366 .58143 L
s
.88696 .75115 m
.88696 .6215 L
s
.14712 .38111 m
.27043 .42117 L
s
.14712 .38111 m
.14712 .25145 L
s
.27043 .42117 m
.39373 .46124 L
s
.27043 .42117 m
.27043 .29152 L
s
.39373 .46124 m
.51704 .5013 L
s
.39373 .46124 m
.39373 .33158 L
s
.51704 .5013 m
.64035 .54137 L
s
.51704 .5013 m
.51704 .37165 L
s
.64035 .54137 m
.76366 .58143 L
s
.64035 .54137 m
.64035 .41172 L
s
.76366 .58143 m
.88696 .6215 L
s
.76366 .58143 m
.76366 .45178 L
s
.88696 .6215 m
.88696 .49185 L
s
.14712 .25145 m
.27043 .29152 L
s
.27043 .29152 m
.39373 .33158 L
s
.27043 .29152 m
.27043 .16187 L
s
.39373 .33158 m
.51704 .37165 L
s
.39373 .33158 m
.39373 .20193 L
s
.51704 .37165 m
.64035 .41172 L
s
.51704 .37165 m
.51704 .242 L
s
.64035 .41172 m
.76366 .45178 L
s
.64035 .41172 m
.64035 .28206 L
s
.76366 .45178 m
.88696 .49185 L
s
.76366 .45178 m
.76366 .32213 L
s
.88696 .49185 m
.88696 .36219 L
s
.27043 .16187 m
.39373 .20193 L
s
.39373 .20193 m
.51704 .242 L
s
.39373 .20193 m
.39373 .07228 L
s
.51704 .242 m
.64035 .28206 L
s
.51704 .242 m
.51704 .11234 L
s
.64035 .28206 m
.76366 .32213 L
s
.64035 .28206 m
.64035 .15241 L
s
.76366 .32213 m
.88696 .36219 L
s
.76366 .32213 m
.76366 .19247 L
s
.88696 .36219 m
.88696 .23254 L
s
.39373 .07228 m
.51704 .11234 L
s
.51704 .11234 m
.64035 .15241 L
s
.64035 .15241 m
.76366 .19247 L
s
.64035 .15241 m
.64035 .02275 L
s
.76366 .19247 m
.88696 .23254 L
s
.76366 .19247 m
.76366 .06282 L
s
.64035 .02275 m
.76366 .06282 L
s
.28567 .89288 m
.40897 .93294 L
s
.28567 .89288 m
.28567 .76322 L
s
.40897 .93294 m
.40897 .80329 L
s
.16236 .72316 m
.28567 .76322 L
s
.16236 .72316 m
.16236 .59351 L
s
.28567 .76322 m
.40897 .80329 L
s
.28567 .76322 m
.28567 .63357 L
s
.40897 .80329 m
.53228 .84335 L
s
.40897 .80329 m
.40897 .67364 L
s
.53228 .84335 m
.65559 .88342 L
s
.53228 .84335 m
.53228 .7137 L
s
.65559 .88342 m
.65559 .75377 L
s
.03905 .55344 m
.16236 .59351 L
s
.03905 .55344 m
.03905 .42379 L
s
.16236 .59351 m
.28567 .63357 L
s
.16236 .59351 m
.16236 .46385 L
s
.28567 .63357 m
.40897 .67364 L
s
.28567 .63357 m
.28567 .50392 L
s
.40897 .67364 m
.53228 .7137 L
s
.40897 .67364 m
.40897 .54398 L
s
.53228 .7137 m
.65559 .75377 L
s
.53228 .7137 m
.53228 .58405 L
s
.65559 .75377 m
.7789 .79383 L
s
.65559 .75377 m
.65559 .62411 L
s
.7789 .79383 m
.7789 .66418 L
s
.03905 .42379 m
.16236 .46385 L
s
.16236 .46385 m
.28567 .50392 L
s
.16236 .46385 m
.16236 .3342 L
s
.28567 .50392 m
.40897 .54398 L
s
.28567 .50392 m
.28567 .37426 L
s
.40897 .54398 m
.53228 .58405 L
s
.40897 .54398 m
.40897 .41433 L
s
.53228 .58405 m
.65559 .62411 L
s
.53228 .58405 m
.53228 .45439 L
s
.65559 .62411 m
.7789 .66418 L
s
.65559 .62411 m
.65559 .49446 L
s
.7789 .66418 m
.90221 .70424 L
s
.7789 .66418 m
.7789 .53452 L
s
.90221 .70424 m
.90221 .57459 L
s
.16236 .3342 m
.28567 .37426 L
s
.16236 .3342 m
.16236 .20455 L
s
.28567 .37426 m
.40897 .41433 L
s
.28567 .37426 m
.28567 .24461 L
s
.40897 .41433 m
.53228 .45439 L
s
.40897 .41433 m
.40897 .28468 L
s
.53228 .45439 m
.65559 .49446 L
s
.53228 .45439 m
.53228 .32474 L
s
.65559 .49446 m
.7789 .53452 L
s
.65559 .49446 m
.65559 .36481 L
s
.7789 .53452 m
.90221 .57459 L
s
.7789 .53452 m
.7789 .40487 L
s
.90221 .57459 m
.90221 .44494 L
s
.16236 .20455 m
.28567 .24461 L
s
.28567 .24461 m
.40897 .28468 L
s
.28567 .24461 m
.28567 .11496 L
s
.40897 .28468 m
.53228 .32474 L
s
.40897 .28468 m
.40897 .15502 L
s
.53228 .32474 m
.65559 .36481 L
s
.53228 .32474 m
.53228 .19509 L
s
.65559 .36481 m
.7789 .40487 L
s
.65559 .36481 m
.65559 .23515 L
s
.7789 .40487 m
.90221 .44494 L
s
.7789 .40487 m
.7789 .27522 L
s
.90221 .44494 m
.90221 .31528 L
s
.28567 .11496 m
.40897 .15502 L
s
.40897 .15502 m
.53228 .19509 L
s
.40897 .15502 m
.40897 .02537 L
s
.53228 .19509 m
.65559 .23515 L
s
.53228 .19509 m
.53228 .06543 L
s
.65559 .23515 m
.7789 .27522 L
s
.65559 .23515 m
.65559 .1055 L
s
.7789 .27522 m
.90221 .31528 L
s
.7789 .27522 m
.7789 .14556 L
s
.40897 .02537 m
.53228 .06543 L
s
.53228 .06543 m
.65559 .1055 L
s
.65559 .1055 m
.7789 .14556 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[179]:=",
  ImageSize->{273.812, 261.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004A00011@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l74PL00?l74PL00?l74PL00?l74PL00?l7
4PL00?l74PL00:470P0;1`80H@L006870P0;1`80<0L00`07000200P700<01`000P1N1`00HPL00`07
000200P700<01`000P0]1`0300L700870`051`0300L700870`1K1`00HPL00`071`021`<01@L00`07
1`021`<0:PL00`071`051`<00PL00`071`051`<0F0L0068700<01`L01@L3008700<01`L01@L302L7
00<01`L020L300X70`1E1`00HPL00`071`081`<02PL302@700<01`L02PL400X70`1B1`00HPL00`07
1`0:1`@02PL3024700<01`L02PL010071`L300X7101>1`00HPL00`071`0:1`0400L71`<02PL401d7
00<01`L02PL00`071`041`<02`L304/7001R1`0300L700X700<01`L010L300/70`0J1`0300L700X7
00<01`L01`L300/70`181`00HPL00`071`0:1`0300L700L70`0;1`<05`L00`071`0:1`0300L700X7
0`0;1`<0A@L0068700<01`L02PL00`071`0:1`<02`L301@700<01`L02PL00`071`0=1`<02`L30487
001R1`0300L700X700<01`L03@L300/70`0A1`0300L700X700<01`L040L200`70P101`00HPL00`07
1`0:1`0300L701070`0;1`<03PL00`071`0:1`0300L7014700<01`L02`L00`071`0n1`00HPL00`07
1`0:1`0300L7014700<01`000P091`0300L000802`L00`071`0:1`0300L7014700<01`L02`L00`07
1`0n1`00G@L200<700<01`L01PL2008700<01`L04@L00`071`021`<01PL00`071`021`<020L00`07
1`0:1`0300L7014700<01`L02`L00`071`0n1`00G@L00`07000300P700<01`000P0C1`0300L700D7
0`031`0300L700D70`051`0300L700X700<01`L04@L00`071`0;1`0300L703h7001M1`0300L70087
0`061`0400L71`@040L00`071`081`@02PL3008700<01`L02PL00`071`0A1`0300L700/700<01`L0
?PL005d700<01`L00PL00`071`0300<700D01`L700031`<03@L00`071`0;1`<02`L300`700<01`L0
4@L00`071`0;1`0300L703h7001M1`0300L7008700<01`L00`L400<700<01`L010L300X700<01`L0
2`L00`071`0400T710091`0300L7014700<01`L02`L00`071`0n1`00G@L00`071`021`0300L700H7
0`000`L01`081`<01`L00`071`0;1`0300L700@70`061`0400L71`<01PL00`071`0A1`0300L700/7
00<01`L0?PL005d700<01`L00PL00`071`061`0300L700@02PL400<700<01`L02`L00`071`071`<0
0`L00`071`041`<00`L00`071`0A1`0300L700/700<01`L0?PL005d700<01`L00PL00`071`061`05
00L71`000PL300/7100=1`0300L700X710091`@04`L00`071`0;1`0300L703h7001M1`0300L70087
00<01`L01PL01@071`L000D70`0;1`<02`L00`071`0=1`<02PL3014700<01`L02`L00`071`0n1`00
G@L00`071`021`0300L700H700D01`L700081`<020L00`071`0300P700<01`L03@L00`071`0300L7
00<01`L00`0>1`0300L700/700<01`L0?PL005d700<01`L00PL00`071`061`0500L71`002`L300D7
00<01`L00`L300D700<01`L03@L01P071`L01`<010L01P071`L01`<02`L00`071`0;1`0300L703h7
00101`802`L200h700<01`L00PL00`071`061`0500L71`003PL3008700<01`L01PL3008700<01`L0
3@L01@071`L000@70`000`L01`021`0300L700870`081`0300L700/700<01`L0?PL0040700<01`00
0P081`0300L000802`L00`071`021`0300L700H700D01`L7000?1`0300L000<020L00`07000200l7
00D01`L700071`<00PL00`071`051`<01@L00`071`0;1`0300L703h700101`0300L700870`051`03
00L700870`081`0300L7008700<01`L01PL01@071`L000l700H01`L700L300D700@01`L71@0;1`05
00L71`0020L00`07000200X70`021`0300L700/700<01`L0?PL0040700<01`L01@L3008700<01`L0
1@L300D700<01`L00PL00`071`061`0500L71`003`L01@071`L000@70`021`0500L71`0010L300P7
00D01`L700081`0400L71`@02PL300d700<01`L0?PL0040700<01`L020L300X70`021`0300L70087
00<01`L01PL01@071`L000l700D01`L700071`@00PL00`071`051`<01@L01@071`L000P700D01`L7
00031`@020L500T700<01`L0?PL0040700<01`L02PL400X70`041`0300L700H700D01`L7000?1`05
00L71`002@L00`07000200X710000`L01`021`0300L700H700D01`L700071`<01@L00`071`021`<0
1PL00`071`0n1`00@0L00`071`0:1`0400L71`@020L600P700D01`L7000?1`0500L71`002@L01007
1`L500X70`021`0300L700H700D01`L7000:1`<00PL00`071`051`<00`L00`071`0n1`00@0L00`07
1`0:1`0300L700D70`051`0300L700870`061`0500L71`003`L01@071`L000T700D01`L700041`<0
20L00`07000200P700D01`L7000=1`<02PL4040700101`0300L700X700<01`L020L3008700<01`L0
0PL00`071`0300<700D01`L7000?1`0500L71`002@L01@071`L000L70`051`0400L71`D010L01@07
1`L000l7100:1`<0?PL0040700<01`L02PL00`071`0;1`<010L00`071`031`@00`L00`071`0=1`05
00L71`002@L01@071`L000X710000`L01`021`0300L700870`000`L01`021`0300L700d700@01`L7
0`071`0300L70080?0L0040700<01`L02PL00`071`0=1`@000<700L01`L300031`0700h700D01`L7
00091`0500L71`003PL3008700<01`L01@L3008700<01`L03@L00`071`021`0300L0008010L01@07
1`L003`700101`0300L700X700<01`L03@L010071`L300L700<01`L00`0>1`0500L71`002@L01@07
1`L000l700<01`000P081`0300L000803`L00`071`021`0300L700871@031`0300L703X700101`03
00L700X700<01`L03@L00`071`021`0300L0008010L01P071`L01`<02`L01@071`L000T700D01`L7
000?1`0400L71`@01@L010071`L400`700<01`L00PL00`071`061`<000<700L0>`L003`70P021`03
00L700H70P021`0300L700d700<01`L00PL00`071`021`<000<700L00PL00`071`021`<020L01@07
1`L000T700D01`L7000?1`0500L71`000`L3008700D01`L700031`<02@L00`071`021`0300L700H7
00<01`L00`0k1`00?0L00`07000200P700<01`000P0?1`0300L7008700<01`L01@L3008700<01`L0
1@L300D700D01`L700091`0500L71`003`L01@071`L000H70`031`0300L700@70`061`0300L70087
00<01`L01PL01P071`L01`@0=`L003`700@01`L710051`0400L71`@030L00`071`021`0300L700H7
00<01`000P0:1`<00PL01@071`L000T700D01`L7000?1`0500L71`0020L500T70`031`0300L70087
00<01`L01PL01@071`L000D70`0d1`00?0L01@071`L000<70`021`0500L71`000`L300T700<01`L0
0PL00`071`061`0400L71`@02PL300<700<01`L01`L01@071`L000l700D01`L700081`0400L71`<0
2PL400@700<01`L01PL01@071`L000P70`0a1`00?0L01@071`L000H70`031`0300L700@70`061`03
00L7008700<01`L01PL01@071`L000<70`091`D02@L01@071`L000l700D01`L700081`0500L71`00
0PL300X710000`L01`071`0500L71`002`L402d7000l1`0500L71`0020L500T70`031`0300L70087
00<01`L01PL01@071`L000H70`061`0400L71`@01PL01@071`L000l700D01`L700081`0500L71`00
1@L300L700@01`L70`071`0500L71`003`L302X7000l1`0500L71`0020L010071`L300X710041`03
00L700H700D01`L700091`<00`L01@071`L000<70`031`0500L71`003`L01@071`L000P700D01`L7
00081`<010L00`071`021`0300L0008010L01@071`L001870P0X1`00?0L01@071`L000P700D01`L7
00021`<02PL400031`0700L700D01`L7000<1`@00`L00`071`041`@00`L00`071`0=1`0500L71`00
20L01@071`L000/70`000`L01`031`0300L700870`000`L01`021`0300L7014700<01`L09PL003`7
00D01`L700081`0500L71`001@L300L700@01`L70`071`0500L71`003`L300031`0700P70`000`L0
1`0>1`0500L71`0020L01@071`L000h70`031`0300L700D70`021`0300L7014700<01`L09PL003`7
00D01`L700081`0500L71`0020L300@700<01`L00PL00`07000200@700D01`L7000?1`0300L700<0
20L00`071`0300h700D01`L700081`0500L71`003`L00`07000300P700<01`000P0C1`0300L702H7
000l1`0500L71`0020L01@071`L000/70`000`L01`031`0300L700870`000`L01`021`0300L700d7
00H01`L700L300D700H01`L700L300/700D01`L700081`0500L71`003`L00`071`021`<01PL01007
1`L4010700<01`L09PL003`700D01`L700081`0500L71`003PL300<700<01`L01@L3008700<01`L0
3@L01@071`L000@70`021`0500L71`0010L300P700D01`L700081`0500L71`003`L00`071`021`03
00L700<00`L01@071`L000<70`0=1`0300L702H7000N1`8030L200h700D01`L700081`0500L71`00
3`L00`07000300P700<01`000P0?1`0500L71`001`L300<700<01`L01@L300D700D01`L700081`05
00L71`003`L00`071`021`0300L700<710031`0300L700@70`0:1`0300L702H7000N1`0300L00080
2@L00`07000200/700D01`L700081`0500L71`003`L00`071`021`<01PL010071`L400`700D01`L7
00091`D02PL3008700D01`L700081`0500L71`003`L00`071`021`0300L700H70`000`L01`081`<0
1`L00`071`0V1`007PL00`071`021`<01PL00`071`021`<020L01@071`L000P700D01`L7000?1`03
00L7008700<01`L00`031`0500L71`000`L300T700D01`L700091`0400L71`<02`L300<700<01`L0
1PL01@071`L000l700<01`L00PL00`071`061`0300L700@02PL300@700<01`L09PL001h700<01`L0
1@L300<700<01`L01@L300D700D01`L700081`0500L71`003`L00`071`021`0300L700<710031`03
00L700@70`061`0500L71`002@L01@071`L0008710091`D020L01@071`L000l700<01`L00PL00`07
1`061`0500L71`000PL300X70`000`L01`0W1`007PL00`071`081`@02PL3008700D01`L700081`05
00L71`003`L00`071`021`0300L700H70`000`L01`081`<00`L01@071`L000T700D01`L700061`<0
1PL010071`L300H700D01`L7000?1`0300L7008700<01`L01PL01@071`L000D70`0:1`<09`L001h7
00<01`L02`L300/70`031`0300L700H700D01`L7000?1`0300L7008700<01`L01PL00`071`0400X7
10031`0300L700L700D01`L700091`<00`L01@071`L000870`031`0500L71`003`L00`071`021`03
00L700H700D01`L700081`<020L00`07000202@7000N1`0300L700/700<01`L010091`D020L01@07
1`L000l700<01`L00PL00`071`061`0500L71`000PL300X71@091`0500L71`0030L400<700<01`L0
0`L400<700<01`L03@L00`071`021`0300L700H700D01`L7000;1`<01@L00`071`021`<08@L001h7
00<01`L02`L00`071`041`<01PL010071`L300H700D01`L7000?1`0300L7008700<01`L01PL01@07
1`L000D70`071`0400L71`<01`L01@071`L000l70`000`L01`071`<000<700L03PL00`071`021`03
00L700H700D01`L7000>1`800`L00`071`051`807`L001h700<01`L02`L00`071`071`<00`L01@07
1`L000870`031`0500L71`003`L00`071`021`0300L700H700D01`L700081`<010L01@071`L00087
0`041`0500L71`003`L00`071`0300L700<01`L00`0>1`0300L7008700<01`L01PL01@071`L000l7
00D01`L700081`0300L701d7000N1`0300L700/700<01`L02PL400<700<01`L00`L400<700<01`L0
3@L00`071`021`0300L700H700D01`L7000;1`<000<700L00PL00`071`031`<000<700L00PL00`07
1`0=1`0600L71`070`041`0600L71`070`0;1`0300L7008700<01`L01PL01@071`L000l700D01`L7
00081`0300L701d7000N1`0300L700/700<01`L03@L300031`0700L70`000`L01`0>1`0300L70087
00<01`L01PL01@071`L000h70`021`0300L700H70`021`0300L700d700D01`L700041`<000<700L0
0PL00`071`021`<020L00`071`021`0300L700H700D01`L7000?1`0500L71`0020L00`071`0M1`00
7PL00`071`0;1`0300L700d700<01`L00`071`0300L700<03PL00`071`021`0300L700H700D01`L7
000?1`0300L000802@L00`07000200l700D01`L700071`<00PL00`071`051`<01@L00`071`021`03
00L700H700D01`L7000?1`0500L71`0020L00`071`0M1`006PL2008700<01`L01`L2008700<01`L0
3@L01P071`L01`<010L01P071`L01`<02`L00`071`021`0300L700H700D01`L7000?1`0400L71`@0
1PL010071`L400`700D01`L700081`0300L000802PL3008700<01`L00PL00`071`061`0500L71`00
3`L01@071`L000P700<01`L07@L001X700<01`000P091`0300L000803`L01@071`L000@70`000`L0
1`021`0300L700870`081`0300L7008700<01`L01PL01@071`L000l700D01`L700031`<00`L01@07
1`L000<70`091`0500L71`0020L010071`L400X70`041`0300L700H700D01`L7000?1`0500L71`00
20L00`071`0M1`006PL010071`L400H700@01`L7100<1`0500L71`001`L3008700<01`L01@L300D7
00<01`L00PL00`071`061`0500L71`003`L01@071`L000H710031`0300L700@70`061`0500L71`00
20L01@071`L000<710081`H020L01@071`L000l700D01`L700081`0300L701d7000J1`0500L71`00
0`L300<700D01`L700031`<02@L01@071`L000P700<01`000P0:1`<00PL00`071`021`0300L700H7
00D01`L7000?1`0500L71`002@L300031`0700P70`031`0500L71`0020L01@071`L000L70`051`03
00L700870`061`0500L71`003`L01@071`L000P700<01`L07@L001X700D01`L700061`@00`L00`07
1`041`<01PL01@071`L000P700@01`L7100:1`<010L00`071`061`0500L71`003`L01@071`L000T7
00<01`L0100:1`@00`L00`071`061`0500L71`002PL3008700<01`L00PL00`071`0300<700D01`L7
000?1`0500L71`0020L00`071`0M1`006PL01@071`L000T70`000`L01`081`<00`L01@071`L000P7
00D01`L700031`@020L600P700D01`L7000?1`0500L71`002@L01@071`L000870`0:1`<000<700L0
1`L01@071`L000d70`041`0300L700<710031`0300L700d700D01`L700081`0300L701d7000J1`05
00L71`002@L00`071`0400X710031`0300L700H700D01`L700071`<01@L00`071`021`<01PL01@07
1`L000l700D01`L700091`0500L71`001@L300L700<01`L00`071`0500L71`003`L400031`0700L7
0`000`L01`0>1`0500L71`0020L00`071`0M1`006PL01@071`L000T700D01`L700021`<02PL30003
1`0700L700D01`L7000:1`<00PL00`071`021`0300L700<00`L01@071`L000l700D01`L700091`05
00L71`0020L300@700H01`L700L300@700D01`L7000?1`0400L71`<01`L00`071`0300h700D01`L7
00081`0300L701d7000J1`0500L71`002@L01@071`L000D70`071`0300L700<01`L01@071`L000d7
0`041`0300L700<710031`0300L700d700D01`L700091`0500L71`002`L300031`07008700<01`L0
0PL300031`07008700<01`L03@L00`071`021`0300L0008010L01P071`L01`<02`L01@071`L000P7
00<01`L07@L001X700D01`L700091`0500L71`0020L300@700H01`L700L300@700D01`L7000?1`@0
00<700L01`L300031`0700h700D01`L700091`0500L71`003PL3008700<01`L01@L3008700<01`L0
3@L00`071`021`0300L700870`000`L01`021`0300L700870`081`0500L71`0020L00`071`0M1`00
6PL01@071`L000T700D01`L7000;1`<000<700L00PL00`071`021`<000<700L00PL00`071`0=1`04
00L71`<01`L00`071`0300h700D01`L700091`0500L71`003`L00`07000200P700<01`000P0?1`03
00L7008700<01`L01@L3008700<01`L01@L300D700D01`L700081`0300L701d7000J1`0500L71`00
2@L01@071`L000h70`021`0300L700D70`021`0300L700d700<01`L00PL00`07000200@700H01`L7
00L400X700D01`L700091`0500L71`003`L010071`L400D700@01`L7100<1`0300L7008700<01`L0
1PL00`07000200X70`021`0500L71`0020L00`071`0M1`006PL01@071`L000T700D01`L7000?1`03
00L0008020L00`07000200l700<01`L00PL00`071`021`D00`L00`071`031`<01`L01@071`L000T7
00D01`L7000?1`0500L71`000`L3008700D01`L700031`<02@L00`071`021`0300L700H700@01`L7
100:1`<00`L00`071`061`0300L701d7000J1`0500L71`002@L01@071`L000l700@01`L710051`04
00L71`@030L00`071`021`0300L700H70`000`L01`071`<010L01@071`L000T700D01`L7000?1`05
00L71`001PL300<700<01`L010L300H700<01`L00PL00`071`061`0500L71`000`L300T71@081`03
00L701d7000J1`0500L71`002@L01@071`L000l700D01`L700031`<00PL01@071`L000<70`091`03
00L7008700<01`L01PL00`071`0300X71@031`0300L700L700D01`L7000?1`0500L71`0020L500T7
0`031`0300L7008700<01`L01PL01@071`L000H70`061`0400L71`@01@L00`071`0M1`006PL01@07
1`L000T700D01`L7000?1`0500L71`001PL300<700<01`L010L300H700<01`L00PL00`071`061`06
00L71`07100:1`<000<700L020L01@071`L000l700D01`L700081`0400L71`<02PL400@700<01`L0
1PL01@071`L000T70`031`0500L71`000`L3008700<01`L07@L001X700D01`L700091`0500L71`00
3`L01@071`L000P71@091`<00`L00`071`021`0300L700H700D01`L700051`<01`L00`071`0400L7
00D01`L7000?1`0500L71`0020L01@071`L000870`0:1`@000<700L01`L01@071`L000`710031`03
00L700@70`0O1`006PL01@071`L000T700D01`L7000?1`0500L71`0020L010071`L300X710041`03
00L700H700D01`L700081`<010L01@071`L000870`041`0500L71`003`L01@071`L000P700D01`L7
00051`<01`L010071`L300L700D01`L7000?1`<000<700L01`L401`7000J1`0500L71`002@L01@07
1`L000l700D01`L700081`0500L71`000PL300X710000`L01`071`0500L71`002`L500<700<01`L0
0`L300031`07008700<01`L03@L01@071`L000P700D01`L700081`<010L00`071`021`0300L00080
10L01@071`L000l700<01`L00`071`0400L71`806PL001X700D01`L700091`0500L71`003`L01@07
1`L000P700D01`L700051`<01`L010071`L300L700D01`L7000?1`<000<700L01`L400031`0700h7
00D01`L700081`0500L71`002`L300031`0700<700<01`L00PL300031`07008700<01`L03@L01P07
1`L01`<010L00`071`021`0300L701P7000J1`0500L71`002@L01@071`L000l700D01`L700081`05
00L71`0020L300@700<01`L00PL00`07000200@700D01`L7000?1`0300L700<020L00`071`0300h7
00D01`L700081`0500L71`003PL300<700<01`L01@L3008700<01`L03@L01@071`L000@70`000`L0
1`031`0300L701P7000J1`0500L71`002@L01@071`L000l700D01`L700081`0500L71`002`L30003
1`0700<700<01`L00PL300031`07008700<01`L03@L01P071`L01`<01@L01P071`L01`<02`L01@07
1`L000P700D01`L7000?1`0300L000<020L00`07000200l700D01`L700071`<00`L00`071`0H1`00
6PL01@071`L000T700D01`L7000?1`0500L71`0020L01@071`L000h70`031`0300L700D70`021`03
00L700d700D01`L700041`<00PL01@071`L000@70`081`0500L71`0020L01@071`L000l700<01`L0
0PL300H700@01`L7100<1`0500L71`0020L00`07000301X7000J1`0400L71`8020L010071`L200h7
00D01`L700081`0500L71`003`L00`07000300P700<01`000P0?1`0500L71`001`L300<700<01`L0
1@L300D700D01`L700081`0500L71`003`L00`071`021`0300L700<00`L01@071`L000<70`091`05
00L71`0020L00`071`021`<060L001X700H01`L700L300D700H01`L700L300/700D01`L700081`05
00L71`003`L00`071`021`<01PL010071`L400`700D01`L700091`D02PL3008700D01`L700081`05
00L71`003`L00`071`021`0300L700<710031`0300L700@70`061`0500L71`0020L00`071`021`03
00L700@050L001X700D01`L700041`<00PL01@071`L000@70`081`0500L71`0020L01@071`L000l7
00<01`L00PL00`071`0300<700D01`L700031`<02@L01@071`L000T700@01`L70`0;1`<00`L00`07
1`061`0500L71`003`L00`071`021`0300L700H70`000`L01`081`<00`L01@071`L000P700<01`L0
0PL00`071`041`<04@L001X700D01`L700071`<00`L00`071`051`<01@L01@071`L000P700D01`L7
000?1`0300L7008700<01`L00`L400<700<01`L010L300H700D01`L700091`0500L71`000PL400T7
1@081`0500L71`003`L00`071`021`0300L700H700<01`L0100:1`@00`L00`071`061`0300L70087
00<01`L01`L300h7000J1`0500L71`002@L500X70`021`0500L71`0020L01@071`L000l700<01`L0
0PL00`071`061`<000<700L020L300<700D01`L700091`0500L71`001PL300H700@01`L70`061`05
00L71`003`L00`071`021`0300L700H700D01`L700021`<02PL300031`0700L700<01`L00PL00`07
1`0:1`<02`L001X700D01`L700091`0400L71`<02`L300<700<01`L01PL01@071`L000l700<01`L0
0PL00`071`061`0300L700@02PL400<700<01`L01`L01@071`L000T70`031`0500L71`000PL300<7
00D01`L7000?1`0300L7008700<01`L01PL01@071`L000D70`071`0300L700<01`L00`071`021`03
00L700d70`081`006PL01@071`L000T700D01`L700021`@02@L500P700D01`L7000?1`0300L70087
00<01`L01PL01@071`L000870`0:1`D02@L01@071`L000`710031`0300L700<710031`0300L700d7
00<01`L00PL00`071`061`0500L71`0020L300@700H01`L700L300@700<01`L00PL00`071`0@1`80
1PL001X700D01`L700091`0500L71`001PL300H700@01`L70`061`0500L71`003`L00`071`021`03
00L700H700D01`L700051`<01`L010071`L300L700D01`L7000?1`<000<700L01`L300031`0700h7
00<01`L00PL00`071`061`0500L71`002`L300031`07008700<01`L00PL300031`0700<700<01`L0
4@L00`071`041`006PL01@071`L000T700D01`L700091`<00`L01@071`L000870`031`0500L71`00
3`L00`071`021`0300L700H700D01`L700081`<010L01@071`L000870`041`0500L71`003`L00`07
1`0300L700<01`L00`0>1`0300L7008700<01`L01PL01@071`L000h70`021`0300L700D70P041`03
00L7014700<01`L010L001X700D01`L700091`0500L71`0030L400<700<01`L00`L400<700<01`L0
3@L00`071`021`0300L700H700D01`L7000;1`<000<700L00PL00`071`031`<000<700L00PL00`07
1`0=1`0600L71`070`041`0600L71`070`0;1`0300L7008700<01`L01PL01@071`L000l700<01`00
0P081`0300L7008700<01`L04@L00`071`041`006PL01@071`L000T700D01`L7000?1`<000<700L0
1`L300031`0700h700<01`L00PL00`071`061`0500L71`003PL3008700<01`L01PL3008700<01`L0
3@L01@071`L000@70`000`L01`021`0300L700870`081`0300L7008700<01`L01PL01@071`L000l7
00@01`L710051`0300L7008700<01`L04@L00`071`041`006PL01@071`L000T700D01`L7000?1`03
00L700<01`L00`071`0300h700<01`L00PL00`071`061`0500L71`003`L00`07000200T700<01`00
0P0?1`0500L71`001`L3008700<01`L01@L300D700<01`L00PL00`071`061`0500L71`003`L01@07
1`L000<70`021`0300L7008700<01`L04@L00`071`041`006PL01@071`L000T700D01`L7000?1`06
00L71`070`041`0600L71`070`0;1`0300L7008700<01`L01PL01@071`L000l700@01`L710061`04
00L71`@030L01@071`L000P700<01`000P0:1`<00PL00`071`021`0300L700H700D01`L7000?1`05
00L71`001PL300@700<01`L04@L00`071`041`006PL2008700<01`L01`L2008700<01`L03@L01@07
1`L000@70`000`L01`021`0300L700870`081`0300L7008700<01`L01PL01@071`L000l700D01`L7
00031`<00`L01@071`L000<70`091`0500L71`0020L010071`L400X70`041`0300L700H700D01`L7
000?1`0500L71`0020L400031`07018700<01`L010L001X700<01`000P091`0300L000803`L01@07
1`L000L70`021`0300L700D70`051`0300L7008700<01`L01PL01@071`L000l700D01`L700061`@0
0`L00`071`041`<01PL01@071`L000P700D01`L700031`@020L600P700D01`L7000?1`0500L71`00
20L010071`L4014700<01`L010L001X700@01`L710061`0400L71`@030L01@071`L000P700<01`00
0P0:1`<00PL00`071`021`0300L700H700D01`L7000?1`0500L71`002@L300031`0700P70`031`05
00L71`0020L01@071`L000L70`051`0300L700870`061`0500L71`003`L01@071`L000P700<01`L0
0PL00`071`0300h700<01`L010L001X700D01`L700031`<00`L01@071`L000<70`091`0500L71`00
20L010071`L400X70`041`0300L700H700D01`L7000?1`0500L71`002@L00`071`0400X710031`03
00L700H700D01`L7000:1`<00PL00`071`021`0300L700<00`L01@071`L000l700D01`L700081`03
00L7008700<01`L00`L300/700<01`L010L001X700D01`L700061`@00`L00`071`041`<01PL01@07
1`L000P700D01`L700031`@020L600P700D01`L7000?1`0500L71`002@L01@071`L000870`0:1`<0
00<700L01`L01@071`L000d70`041`0300L700<710031`0300L700d700D01`L700081`0300L70087
00<01`L01PL300P700<01`L010L001X700D01`L700091`<000<700L020L300<700D01`L700081`05
00L71`001`L300D700<01`L00PL300H700D01`L7000?1`0500L71`002@L01@071`L000D70`071`03
00L700<01`L01@071`L000l710000`L01`071`<000<700L03PL01@071`L000P700<01`L00PL00`07
1`091`<01@L00`071`041`006PL01@071`L000T700<01`L0100:1`@00`L00`071`061`0500L71`00
2PL3008700<01`L00PL00`071`0300<700D01`L7000?1`0500L71`002@L01@071`L000P70`041`06
00L71`070`041`0500L71`003`L010071`L300L700<01`L00`0>1`0500L71`0020L00`071`021`03
00L700`70P031`0300L700@7000J1`0500L71`002@L01@071`L000870`0:1`<000<700L01`L01@07
1`L000d70`041`0300L700<710031`0300L700d700D01`L700091`0500L71`002`L300031`070087
00<01`L00PL300031`07008700<01`L03@L00`071`021`0300L0008010L01P071`L01`<02`L01@07
1`L000P700<01`L00PL00`071`0=1`0500L71`001PL001X700D01`L700091`0500L71`001@L300L7
00<01`L00`071`0500L71`003`L400031`0700L70`000`L01`0>1`0500L71`002@L01@071`L000h7
0`021`0300L700D70`021`0300L700d700<01`L00PL00`071`021`<000<700L00PL00`071`021`<0
20L01@071`L000P700<01`L00PL00`071`0=1`0500L71`001PL001X700D01`L700091`0500L71`00
20L300@700H01`L700L300@700D01`L7000?1`0400L71`<01`L00`071`0300h700D01`L700091`05
00L71`003`L00`07000200P700<01`000P0?1`0300L7008700<01`L01@L3008700<01`L01@L300D7
00D01`L700081`0300L7008700<01`L03@L01@071`L000H7000J1`0500L71`002@L01@071`L000/7
0`000`L01`021`0300L700870`000`L01`021`0300L700d700<01`L00PL00`07000200@700H01`L7
00L300/700D01`L700091`0500L71`003`L010071`L400D700@01`L7100<1`0300L7008700<01`L0
1PL00`07000200X70`021`0500L71`0020L00`071`021`0300L700d700D01`L700061`002PL200h7
00D01`L700091`0500L71`003PL3008700<01`L01@L3008700<01`L03@L00`071`021`0300L70087
0`000`L01`021`0300L700870`081`0500L71`002@L01@071`L000l700D01`L700031`<00PL01@07
1`L000<70`091`0300L7008700<01`L01PL010071`L400X70`031`0300L700H700<01`L00PL00`07
1`0=1`0500L71`001PL000X700<01`000P0;1`0500L71`002@L01@071`L000l700<01`000P081`03
00L000803`L00`071`021`0300L700D70`021`0300L700D70`051`0500L71`002@L01@071`L000l7
00D01`L700061`<00`L00`071`041`<01PL00`071`021`0300L700H700D01`L700031`<02@L500P7
00<01`L00PL00`071`0=1`0500L71`001PL000X700<01`L00PL300P700D01`L700091`0500L71`00
3`L010071`L400D700@01`L7100<1`0300L7008700<01`L01PL00`07000200X70`021`0500L71`00
2@L01@071`L000l700D01`L700081`D02@L300<700<01`L00PL00`071`061`0500L71`001PL300H7
00@01`L710051`0300L7008700<01`L03@L01@071`L000H7000:1`0300L700D70`051`0500L71`00
2@L01@071`L000l700D01`L700031`<00PL01@071`L000<70`091`0300L7008700<01`L01PL01007
1`L400X70`031`0300L700L700D01`L7000?1`0500L71`0020L010071`L300X710041`0300L700H7
00D01`L700091`<00`L01@071`L000<70`021`0300L7008700<01`L03@L01@071`L000H7000:1`03
00L700P70`021`0500L71`002@L01@071`L000l700D01`L700061`<00`L00`071`041`<01PL00`07
1`021`0300L700H700D01`L700031`<02@L500T700D01`L7000?1`0500L71`0020L01@071`L00087
0`0:1`@000<700L01`L01@071`L000`710031`0300L700@70`041`0300L700d700D01`L700061`00
2PL00`071`0;1`<00`L00`071`071`0500L71`003`L01@071`L000P71@091`<00`L00`071`021`03
00L700H700D01`L700061`<01PL010071`L400H700D01`L7000?1`0500L71`0020L01@071`L000D7
0`071`0400L71`<01`L01@071`L000l70`000`L01`071`@000<700L03PL01@071`L000H7000:1`03
00L700d71@091`0500L71`003`L01@071`L000P700@01`L70`0:1`@010L00`071`061`0500L71`00
2@L300<700D01`L700031`<00`L01@071`L000l700D01`L700081`0500L71`0020L300@700<01`L0
0PL00`07000200@700D01`L7000?1`0300L700<01`L010071`L200l700D01`L700061`002PL00`07
1`0=1`0400L71`@01PL01@071`L000l700D01`L700081`0500L71`000PL300X710000`L01`071`05
00L71`0030L400<700<01`L010L400<700<01`L03@L01@071`L000P700D01`L7000;1`<000<700L0
0`L00`071`021`<000<700L00PL00`071`0=1`0600L71`070`041`0300L7008700<01`L03@L01@07
1`L000H7000:1`0300L700d700D01`L700031`<00`L01@071`L000l700D01`L700081`0500L71`00
1@L300L700@01`L70`071`0500L71`003`L300031`0700P70`000`L01`0>1`0500L71`0020L01@07
1`L000h70`031`0300L700D70`021`0300L700d700D01`L700041`<000<700L00`L00`071`0=1`05
00L71`001PL000X700<01`L03@L01@071`L000H710031`0300L700d700D01`L700081`0500L71`00
20L300@700<01`L00PL00`07000200@700D01`L7000?1`0300L700<020L00`071`0300h700D01`L7
00081`0500L71`003`L00`07000300P700<01`000P0?1`0500L71`001`L300<700<01`L03@L01@07
1`L000H7000:1`0300L700d700D01`L700091`<000<700L03PL01@071`L000P700D01`L7000;1`<0
00<700L00`L00`071`021`<000<700L00PL00`071`0=1`0600L71`070`051`0600L71`070`0;1`05
00L71`0020L01@071`L000l700<01`L00PL300H700@01`L7100<1`0500L71`0020L00`07000300l7
00D01`L700061`002PL00`071`0=1`0400L71`8020L00`071`0300h700D01`L700081`0500L71`00
3PL300<700<01`L01@L3008700<01`L03@L01@071`L000@70`021`0500L71`0010L300P700D01`L7
00081`0500L71`003`L00`071`021`0300L700<00`L01@071`L000<70`091`0500L71`0020L00`07
1`021`<03@L01@071`L000H7000:1`0300L700d700H01`L700L300D700H01`L700L300/700D01`L7
00081`0500L71`003`L00`07000300P700<01`000P0?1`0500L71`001`L300<700<01`L01@L300D7
00D01`L700081`0500L71`003`L00`071`021`0300L700<710031`0300L700@70`061`0500L71`00
20L00`071`021`0300L700@02@L01@071`L000H700061`800PL00`071`0=1`0500L71`0010L30087
00D01`L700041`<020L01@071`L000P700D01`L7000?1`0300L700870`061`0400L71`@030L01@07
1`L000T71@0:1`<00PL01@071`L000P700D01`L7000?1`0300L7008700<01`L01PL300031`0700P7
0`031`0500L71`0020L00`071`021`0300L700@70`061`0500L71`001PL000H700<01`000P0?1`05
00L71`001`L300<700<01`L01@L300D700D01`L700081`0500L71`003`L00`071`021`0300L700<0
0`L01@071`L000<70`091`0500L71`002@L010071`L300/70`031`0300L700H700D01`L7000?1`03
00L7008700<01`L01PL00`071`0400X710031`0300L700H700<01`L00PL00`071`071`<00`L01@07
1`L000H700061`0400L71`@030L01@071`L000T71@0:1`<00PL01@071`L000P700D01`L7000?1`03
00L7008700<01`L00`L400<700<01`L010L300H700D01`L700091`0500L71`000PL400T71@081`05
00L71`003`L00`071`021`0300L700H700D01`L700021`<02PL300031`0700L700<01`L00PL00`07
1`0:1`@00`L00`071`041`001PL01@071`L000<70`091`0500L71`002@L010071`L300/70`031`03
00L700H700D01`L7000?1`0300L7008700<01`L01PL300031`0700P70`031`0500L71`002@L01@07
1`L000H70`061`0400L71`<01PL01@071`L000l700<01`L00PL00`071`061`0500L71`001@L300L7
00<01`L00`071`0300L7008700<01`L03@L300031`0700D700061`0500L71`001PL300H700D01`L7
00091`0500L71`000PL400T71@081`0500L71`003`L00`071`021`0300L700H700<01`L0100:1`@0
0`L00`071`071`0500L71`002@L300<700D01`L700021`<00`L01@071`L000l700<01`L00PL00`07
1`061`0500L71`0020L300@700H01`L700L300@700<01`L00PL00`071`0=1`0300L700801PL000H7
00D01`L700091`<00`L01@071`L000T700D01`L700061`<01PL010071`L300H700D01`L7000?1`03
00L7008700<01`L01PL01@071`L000870`0:1`D02@L01@071`L000`710031`0300L700<710031`03
00L700d700<01`L00PL00`071`061`0500L71`002`L300031`07008700<01`L00PL300031`0700<7
00<01`L03@L00`071`081`001PL01@071`L000`710031`0300L700L700D01`L700091`<00`L01@07
1`L000870`031`0500L71`003`L00`071`021`0300L700H700D01`L700051`<01`L010071`L300L7
00D01`L7000?1`<000<700L01`L300031`0700h700<01`L00PL00`071`061`0500L71`003PL30087
00<01`L01@L200@700<01`L03@L00`071`081`001PL01@071`L000l71@091`0500L71`0030L400<7
00<01`L00`L400<700<01`L03@L00`071`021`0300L700H700D01`L700081`<010L01@071`L00087
0`041`0500L71`003`L00`071`0300L700<01`L00`0>1`0300L7008700<01`L01PL01@071`L000l7
00<01`000P081`0300L7008700<01`L03@L00`071`081`001PL01@071`L000l700@01`L70`071`05
00L71`003`L300031`0700L70`000`L01`0>1`0300L7008700<01`L01PL01@071`L000/70`000`L0
1`021`0300L700<70`000`L01`021`0300L700d700H01`L700L300@700H01`L700L300/700<01`L0
0PL00`071`061`0500L71`003`L010071`L400D700<01`L00PL00`071`0=1`0300L700P700061`05
00L71`003`L01@071`L000870`041`0500L71`003`L00`071`0300L700<01`L00`0>1`0300L70087
00<01`L01PL01@071`L000h70`021`0300L700H70`021`0300L700d700D01`L700041`<000<700L0
0PL00`071`021`<020L00`071`021`0300L700H700D01`L7000?1`0500L71`000`L3008700<01`L0
0PL00`071`0=1`0300L700P700061`0500L71`003`L01@071`L000D70`000`L01`021`0300L700d7
00H01`L700L300@700H01`L700L300/700<01`L00PL00`071`061`0500L71`003`L00`07000200T7
00<01`000P0?1`0500L71`001`L3008700<01`L01@L300D700<01`L00PL00`071`061`0500L71`00
3`L01@071`L000H70`041`0300L700d700<01`L020L000H700D01`L7000?1`800PL00`071`061`<0
0PL00`071`0=1`0500L71`0010L300031`07008700<01`L00PL300P700<01`L00PL00`071`061`05
00L71`003`L010071`L400H700@01`L7100<1`0500L71`0020L00`07000200X70`021`0300L70087
00<01`L01PL01@071`L000l700D01`L700081`@000<700L03PL00`071`081`001PL01@071`L000l7
00<01`000P091`0300L000803`L01@071`L000L70`021`0300L700D70`051`0300L7008700<01`L0
1PL01@071`L000l700D01`L700031`<00`L01@071`L000<70`091`0500L71`0020L010071`L400X7
0`041`0300L700H700D01`L7000?1`0500L71`0020L010071`L400d700<01`L020L000H700D01`L7
000?1`0400L71`@01PL010071`L400`700D01`L700081`0300L000802PL3008700<01`L00PL00`07
1`061`0500L71`003`L01@071`L000H710031`0300L700@70`061`0500L71`0020L01@071`L000<7
10081`H020L01@071`L000l700D01`L700081`0300L7008700<01`L00`0:1`0300L700P700061`05
00L71`003`L01@071`L000<70`031`0500L71`000`L300T700D01`L700081`0400L71`@02PL300@7
00<01`L01PL01@071`L000l700D01`L700091`<000<700L020L300<700D01`L700081`0500L71`00
1`L300D700<01`L00PL300H700D01`L7000?1`0500L71`0020L00`071`021`0300L700<70`071`03
00L700P700061`0500L71`003`L01@071`L000H710031`0300L700@70`061`0500L71`0020L01@07
1`L000<710081`H020L01@071`L000l700D01`L700091`0300L700@02PL400<700<01`L01PL01@07
1`L000X70`021`0300L7008700<01`L00`031`0500L71`003`L01@071`L000P700<01`L00PL00`07
1`061`<010L00`071`081`001PL01@071`L000l700D01`L700091`<000<700L020L300<700D01`L7
00081`0500L71`001`L300D700<01`L00PL300H700D01`L7000?1`0500L71`002@L01@071`L00087
0`0:1`<000<700L01`L01@071`L000d70`041`0300L700<710031`0300L700d700D01`L700081`03
00L7008700<01`L02@L300031`0700T700061`0500L71`003`L01@071`L000T700<01`L0100:1`@0
0`L00`071`061`0500L71`002PL3008700<01`L00PL00`071`0300<700D01`L7000?1`0500L71`00
2@L01@071`L000D70`071`0300L700<01`L01@071`L000l710000`L01`071`<000<700L03PL01@07
1`L000P700<01`L00PL00`071`0<1`802PL000H700D01`L7000?1`0500L71`002@L01@071`L00087
0`0:1`<000<700L01`L01@071`L000d70`041`0300L700<710031`0300L700d700D01`L700091`05
00L71`0020L300@700H01`L700L300@700D01`L7000?1`0400L71`<01`L00`071`0300h700D01`L7
00081`0300L7008700<01`L060L000H700D01`L7000?1`0500L71`002@L01@071`L000D70`071`03
00L700<01`L01@071`L000l710000`L01`071`<000<700L03PL01@071`L000T700D01`L7000;1`<0
00<700L00PL00`071`021`<000<700L00PL00`071`0=1`0300L7008700<01`000P041`0600L71`07
0`0;1`0500L71`0020L00`071`021`0300L701P700061`0500L71`003`L01@071`L000T700D01`L7
00081`<010L01P071`L01`<010L01@071`L000l700@01`L70`071`0300L700<03PL01@071`L000T7
00D01`L7000>1`<00PL00`071`051`<00PL00`071`0=1`0300L7008700<01`L00PL300031`070087
00<01`L00PL300P700D01`L700081`0300L7008700<01`L060L000H700D01`L7000?1`0500L71`00
2@L01@071`L000/70`000`L01`021`0300L700870`000`L01`021`0300L700d700<01`L00PL00`07
000200@700H01`L700L300/700D01`L700091`0500L71`003`L00`07000200P700<01`000`0>1`03
00L7008700<01`L01@L3008700<01`L01@L300D700D01`L700081`0300L7008700<01`L060L000H7
00D01`L7000?1`0500L71`002@L01@071`L000h70`021`0300L700D70`021`0300L700d700<01`L0
0PL00`071`021`<000<700L00PL00`071`021`<020L01@071`L000T700D01`L7000?1`0400L71`D0
10L01P071`L01`<02`L00`071`021`0300L700H700<01`000P0:1`<00PL01@071`L000P700<01`L0
0PL00`071`0H1`001PL010071`L200h700D01`L700091`0500L71`003`L00`07000200P700<01`00
0P0?1`0300L7008700<01`L01@L3008700<01`L01@L300D700D01`L700091`0500L71`003`L01@07
1`L000@70`000`L01`021`0300L700870`081`0300L7008700<01`L01PL010071`L400X70`031`03
00L700H700<01`L00PL00`071`0H1`001PL00`071`031`<02`L01@071`L000T700D01`L7000?1`04
00L71`@01@L010071`L400`700<01`L00PL00`071`061`0300L000802PL3008700D01`L700091`05
00L71`003`L01@071`L000L70`021`0300L700D710041`0300L7008700<01`L01PL01@071`L000<7
0`091`D020L00`071`021`0300L701P700061`0300L700H70`081`0500L71`002@L01@071`L000l7
00D01`L700031`<00PL01@071`L000<70`091`0300L7008700<01`L01PL010071`L400X70`031`03
00L700L700D01`L7000?1`0500L71`0020L00`07000300X70`000`L01`031`0300L700H700D01`L7
00061`<01PL010071`L400D700<01`L00PL00`071`0H1`001PL00`071`091`<01@L01@071`L000T7
00D01`L7000?1`0500L71`001PL300<700<01`L010L300H700<01`L00PL00`071`061`0500L71`00
0`L300T71@091`0500L71`003`L01@071`L000P700H01`L700L300X710021`0300L700H700D01`L7
00091`<00`L01@071`L000<70`021`0300L7008700<01`L060L000H700<01`L030L3008700D01`L7
00091`0500L71`003`L01@071`L000P71@091`<00`L00`071`021`0300L700H700D01`L700061`<0
1PL010071`L400H700D01`L7000?1`0500L71`0020L01@071`L000@70`081`0300L700<020L01@07
1`L000`710031`0300L700@70`041`0300L701P700061`0300L700l70`031`0300L700L700D01`L7
000?1`0500L71`0020L010071`L300X710041`0300L700H700D01`L700091`<00`L01@071`L000<7
0`031`0500L71`003`L01@071`L000P700D01`L700071`@010L00`071`021`@01@L01@071`L000l7
0`000`L01`071`@000<700L06@L000H700<01`L04@L500T700D01`L7000?1`0500L71`0020L01@07
1`L000870`0:1`@000<700L01`L01@071`L000`710031`0300L700@710031`0300L700d700D01`L7
00081`0500L71`002`L300031`0700<700@01`L710000`L01`021`0300L700d700<01`L00P081`04
00L71`806PL000H700<01`L04@L010071`L400H700D01`L7000?1`0500L71`0020L01@071`L000D7
0`071`0400L71`<01`L01@071`L000l70`000`L01`081`<000<700L03PL01@071`L000P700D01`L7
000>1`<00`L00`071`051`<00PL00`071`0=1`0500L71`0020L00`071`021`0300L701P700061`03
00L7014700D01`L700031`<00`L01@071`L000l700D01`L700081`0500L71`0020L300@700<01`L0
0PL00`07000200@700D01`L7000?1`0300L700<020L00`071`0300h700D01`L700081`0500L71`00
3`L00`07000300P700<01`000P0?1`0500L71`0020L00`071`021`0300L701P700061`0300L70147
00D01`L700061`@00`L00`071`0=1`0500L71`0020L01@071`L000/70`000`L01`031`0300L70087
0`000`L01`021`0300L700d700H01`L700L300D700H01`L700L300/700D01`L700081`0500L71`00
3`L00`071`021`<01PL010071`L400`700D01`L700081`0300L7008700<01`L060L000H700<01`L0
4@L01@071`L000T70`000`L01`0>1`0500L71`0020L01@071`L000h70`031`0300L700D70`021`03
00L700d700D01`L700041`<00PL01@071`L000@70`081`0500L71`0020L01@071`L000l700<01`L0
0PL00`071`0300<700D01`L700031`<02@L01@071`L000P700<01`L00PL00`071`0H1`001PL00`07
1`0A1`0400L71`8020L00`071`0300h700D01`L700081`0500L71`003`L00`07000300P700<01`00
0P0?1`0500L71`001`L300<700<01`L01@L300D700D01`L700081`0500L71`003`L00`071`021`03
00L700<710031`0300L700@70`061`0500L71`0020L00`071`021`0300L701P700061`0300L70147
00H01`L700L300D700H01`L700L300/700D01`L700081`0500L71`003`L00`071`021`<01PL01007
1`L400`700D01`L700091`D02PL3008700D01`L700081`0500L71`003`L00`071`021`0300L700H7
0`000`L01`081`<00`L01@071`L000P700<01`L00PL00`071`0H1`001PL2018700D01`L700041`<0
0PL01@071`L000@70`081`0500L71`0020L01@071`L000l700<01`L00PL00`071`0300<700D01`L7
00031`<02@L01@071`L000T700@01`L70`0;1`<00`L00`071`061`0500L71`003`L00`071`021`03
00L700H700<01`L0100:1`@00`L00`071`061`0300L7008700<01`L060L000P70`0?1`0500L71`00
1`L300<700<01`L01@L300D700D01`L700081`0500L71`003`L00`071`021`0300L700<710031`03
00L700@70`061`0500L71`002@L01@071`L0008710091`D020L01@071`L000l700<01`L00PL00`07
1`061`0500L71`000PL300X70`000`L01`071`0300L7008700<01`L060L000/70`0<1`0500L71`00
2@L500X70`021`0500L71`0020L01@071`L000l700<01`L00PL00`071`061`<000<700L020L300<7
00D01`L700091`0500L71`001PL300H700@01`L70`061`0500L71`003`L00`071`021`0300L700H7
00D01`L700051`<01`L00`071`0300L700<01`L00PL00`071`0H1`003PL300T700D01`L700091`04
00L71`<02`L300<700<01`L01PL01@071`L000l700<01`L00PL00`071`061`0300L700@02PL400<7
00<01`L01`L01@071`L000T70`031`0500L71`000PL300<700D01`L7000?1`0300L7008700<01`L0
1PL01@071`L000P70`041`0600L71`070`041`0300L7008700<01`L060L001470`061`0500L71`00
2@L01@071`L0008710091`D020L01@071`L000l700<01`L00PL00`071`061`0500L71`000PL300X7
1@091`0500L71`0030L400<700<01`L00`L400<700<01`L03@L00`071`021`0300L700H700D01`L7
000;1`<000<700L00PL00`071`021`<000<700L00`L00`071`0H1`0050L300<700D01`L700091`05
00L71`001PL300H700@01`L70`061`0500L71`003`L00`071`021`0300L700H700D01`L700051`<0
1`L010071`L300L700D01`L7000?1`<000<700L01`L300031`0700h700<01`L00PL00`071`061`05
00L71`003PL200<700<01`L01@L200@700<01`L060L001L710031`0300L700L700D01`L700091`<0
0`L01@071`L000870`031`0500L71`003`L00`071`021`0300L700H700D01`L700081`<010L01@07
1`L000870`041`0500L71`003`L00`071`0300L700<01`L00`0>1`0300L7008700<01`L01PL01@07
1`L000l700D01`L700081`0300L7008700<01`L060L001X71@091`0500L71`0030L400<700<01`L0
0`L400<700<01`L03@L00`071`021`0300L700H700D01`L7000;1`<000<700L00PL00`071`031`<0
00<700L00PL00`071`0=1`0600L71`070`041`0600L71`070`0;1`0300L7008700<01`L01PL01@07
1`L000l700D01`L700081`0300L7008700<01`L060L001X700@01`L70`071`0500L71`003`L30003
1`0700L70`000`L01`0>1`0300L7008700<01`L01PL01@071`L000h70`021`0300L700H70`021`03
00L700d700D01`L700041`<000<700L00PL00`071`021`<020L00`071`021`0300L700H700D01`L7
000?1`0500L71`0020L00`071`021`0300L701P7000J1`0500L71`000PL300@700D01`L7000?1`03
00L700<01`L00`071`0300h700<01`L00PL00`071`061`0500L71`003`L00`07000200T700<01`00
0P0?1`0500L71`001`L3008700<01`L01@L300D700<01`L00PL00`071`061`0500L71`003`L01@07
1`L000P700<01`L00PL00`071`0H1`006PL01@071`L000D70`000`L01`021`0300L700d700H01`L7
00L300@700H01`L700L300/700<01`L00PL00`071`061`0500L71`003`L010071`L400H700@01`L7
100<1`0500L71`0020L00`07000200X70`021`0300L7008700<01`L01PL01@071`L000l700D01`L7
00081`0300L7008700<01`L060L001X70P021`0300L700H70`021`0300L700d700D01`L700041`<0
00<700L00PL00`071`021`<020L00`071`021`0300L700H700D01`L7000?1`0500L71`000`L300<7
00D01`L700031`<02@L01@071`L000P700@01`L7100:1`<010L00`071`061`0500L71`003`L01@07
1`L000P700<01`L00PL00`071`0H1`0070L400P700<01`000P0?1`0500L71`001`L3008700<01`L0
1@L300D700<01`L00PL00`071`061`0500L71`003`L01@071`L000H710031`0300L700@70`061`05
00L71`0020L01@071`L000<710081`H020L01@071`L000l700D01`L700081`0300L7008700<01`L0
60L001h700<01`000P051`0400L71`D02`L01@071`L000P700<01`000P0:1`<00PL00`071`021`03
00L700H700D01`L7000?1`0500L71`002@L300031`0700P70`031`0500L71`0020L01@071`L000L7
0`051`0300L700870`061`0500L71`003`L01@071`L000P700<01`L00PL00`071`0H1`007PL00`07
1`021`<00PL01@071`L000@70`081`0500L71`0020L010071`L400X70`041`0300L700H700D01`L7
000?1`0500L71`002@L00`071`0400X710031`0300L700H700D01`L7000:1`<00PL00`071`021`03
00L700<00`L01@071`L000l700D01`L700081`0300L7008700<01`L060L001h700<01`L01@L40087
00<01`L01@L300D700D01`L700081`0500L71`000`L400P71P081`0500L71`003`L01@071`L000T7
00D01`L700021`<02PL300031`0700L700D01`L7000=1`<010L00`071`031`@00`L00`071`0=1`05
00L71`0020L00`071`021`0300L701P7000N1`0300L700L700<01`000P0:1`@000<700L00PL00`07
1`061`0500L71`001`L300D700<01`L00PL300H700D01`L7000?1`0500L71`002@L01@071`L000D7
0`071`0300L700<01`L01@071`L000l710000`L01`071`<000<700L03PL01@071`L000P700<01`L0
0PL00`071`0H1`007PL00`071`071`0400L71`D02PL3008700<01`L01PL01@071`L000X70`021`03
00L7008700<01`L00`031`0500L71`003`L01@071`L000T700D01`L700081`<010L01P071`L01`<0
10L01@071`L000l700@01`L70`071`0300L700<03PL01@071`L000P700<01`L00PL00`071`0H1`00
7PL00`071`071`0500L71`0010L300P700<01`000P081`0500L71`003@L300@700<01`L00`L400<7
00<01`L03@L01@071`L000T700D01`L7000;1`<000<700L00PL00`071`021`<000<700L00PL00`07
1`0=1`0300L7008700<01`000P041`0600L71`070`0;1`0500L71`0020L00`071`021`0300L701P7
000N1`0300L700L700D01`L700071`<01@L010071`L500@700D01`L7000?1`@000<700L01`L30003
1`0700h700D01`L700091`0500L71`003PL3008700<01`L01@L3008700<01`L03@L00`071`021`03
00L700870`000`L01`021`0300L700870`081`0500L71`0020L00`071`021`0300L701P7000N1`03
00L700L700D01`L7000:1`@000<700L00PL00`071`021`<000<700L00PL00`071`0=1`0400L71`<0
1`L00`071`0300h700D01`L700091`0500L71`003`L00`07000200P700<01`000P0?1`0300L70087
00<01`L01@L3008700<01`L01@L300D700D01`L700081`0300L7008700<01`L060L001h700<01`L0
1`L01@071`L000h70`021`0300L700D70`021`0300L700d700<01`L00PL00`07000200@700H01`L7
00L300/700D01`L700091`0500L71`003`L010071`L400D700@01`L7100<1`0300L7008700<01`L0
1PL00`07000200X70`021`0500L71`0020L00`071`021`0300L701P7000N1`0300L700L700D01`L7
000?1`0300L0008020L00`07000200l700<01`L00PL00`071`021`<000<700L00PL00`071`021`<0
20L01@071`L000T700D01`L7000?1`0500L71`000`L3008700D01`L700031`<02@L00`071`021`03
00L700H700@01`L7100:1`<00`L00`071`061`0300L7008700<01`L060L001h700<01`L01`L01@07
1`L000l700@01`L710051`0400L71`@030L00`071`021`0300L700D70`021`0300L700D70`051`05
00L71`002@L01@071`L000l700D01`L700061`<00`L00`071`041`<01PL00`071`021`0300L700H7
00D01`L700031`<02@L500P700<01`L00PL00`071`0H1`007PL00`071`071`0500L71`003`L01@07
1`L000<70`021`0500L71`000`L300T700<01`L00PL00`071`061`0300L000802PL3008700D01`L7
00091`0500L71`003`L01@071`L000P71@091`<00`L00`071`021`0300L700H700D01`L700061`<0
1PL010071`L400D700<01`L00PL00`071`0H1`007PL00`071`071`0500L71`003`L01@071`L000H7
0`031`0300L700@70`061`0300L7008700<01`L01PL010071`L400X70`031`0300L700L700D01`L7
000?1`0500L71`0020L010071`L300X710041`0300L700H700D01`L700091`<00`L01@071`L000<7
0`021`0300L7008700<01`L060L001h700<01`L01`L01@071`L000l700D01`L700081`D02@L300<7
00<01`L00PL00`071`061`0500L71`000`L300T71@091`0500L71`003`L01@071`L000P700D01`L7
00021`<02PL400031`0700L700D01`L7000<1`@00`L00`071`041`<010L00`071`0H1`007PL00`07
1`071`0500L71`003`L01@071`L000P700@01`L70`0:1`@010L00`071`061`0500L71`001PL300H7
00@01`L710061`0500L71`003`L01@071`L000P700D01`L700051`<01`L010071`L300L700D01`L7
000?1`<000<700L01`L400031`0701T7000N1`0300L700L700D01`L7000?1`0500L71`0020L01@07
1`L000870`0:1`@000<700L01`L01@071`L000T70`031`0500L71`000`L300<700D01`L7000?1`05
00L71`0020L01@071`L000P70`041`0300L7008700<01`000P041`0500L71`003`L00`071`0200P7
00@01`L70P0J1`007PL00`071`071`0500L71`003`L01@071`L000P700D01`L700051`<01`L01007
1`L300L700D01`L7000<1`@00`L00`071`041`@00`L00`071`0=1`0500L71`0020L01@071`L000/7
0`000`L01`031`0300L700870`000`L01`021`0300L700d700<01`L02PL00`071`0M1`007PL00`07
1`071`0500L71`003`L01@071`L000P700D01`L700081`<010L00`071`021`0300L0008010L01@07
1`L000l70`000`L01`081`<000<700L03PL01@071`L000P700D01`L7000>1`<00`L00`071`051`<0
0PL00`071`0=1`0300L700X700<01`L07@L001h700<01`L01`L01@071`L000l700D01`L700081`05
00L71`002`L300031`0700<700<01`L00PL300031`07008700<01`L03@L00`071`0300P700<01`L0
0`0>1`0500L71`0020L01@071`L000l700<01`000`081`0300L000803`L00`071`0:1`0300L701d7
000N1`0300L700L700D01`L7000?1`0500L71`0020L01@071`L000h70`031`0300L700D70`021`03
00L700d700H01`L700L400@700H01`L700L300/700D01`L700081`0500L71`003`L00`071`021`<0
1PL010071`L400`700<01`L02PL00`071`0M1`007PL200P700@01`L70P0>1`0500L71`0020L01@07
1`L000l700<01`000`081`0300L000803`L01@071`L000D70`000`L01`021`0300L7008710071`05
00L71`0020L01@071`L000l700<01`L00PL00`071`0300<700D01`L700031`<02@L00`071`0:1`03
00L701d7000P1`<01@L00`071`031`<02`L01@071`L000P700D01`L7000?1`0300L700870`061`04
00L71`@030L01@071`L000P70`021`0300L700H70`041`0500L71`0020L01@071`L000l700<01`L0
0PL00`071`031`@00`L00`071`041`<01PL00`071`0:1`0300L701d7000S1`<00PL00`071`061`<0
20L01@071`L000P700D01`L7000?1`0300L7008700<01`L00`031`0500L71`000`L300T700D01`L7
00091`0300L000<02PL300031`07008700<01`L01PL01@071`L000l700<01`L00PL00`071`061`<0
00<700L020L300<700<01`L02PL00`071`0M1`009PL300/70`051`0500L71`0020L01@071`L000l7
00<01`L00PL00`071`031`@00`L00`071`041`<01PL01@071`L000T700H01`L700L300X710000`L0
1`071`0500L71`003`L00`071`021`0300L700H700<01`L0100:1`@030L00`071`0M1`00:0L400/7
0`021`0500L71`0020L01@071`L000l700<01`L00PL00`071`061`<000<700L020L300<700D01`L7
00091`0500L71`0010L400L700<01`L00`071`0500L71`003`L00`071`021`0300L700H700D01`L7
00021`<02PL300X700<01`L07@L002P700@01`L70`0;1`<00`L00`071`061`0500L71`003`L00`07
1`021`0300L700H700<01`L0100:1`@00`L00`071`071`0500L71`0020L300@700H01`L700L300@7
00D01`L7000?1`0300L7008700<01`L01PL01@071`L000D70`071`0300L700<01`L00`071`0M1`00
:0L00`071`041`@02@L500P700D01`L7000?1`0300L7008700<01`L01PL01@071`L000870`0:1`D0
2@L01@071`L000/70`000`L01`021`0300L700871@031`0300L700d700<01`L00PL00`071`061`05
00L71`0020L300@700<01`L00`L300@700<01`L07@L002P700<01`L020L300H700@01`L70`061`05
00L71`003`L00`071`021`0300L700H700D01`L700051`<01`L010071`L300L700D01`L7000>1`@0
00<700L01`L300031`0700h700<01`L00PL00`071`061`0500L71`002`L300031`0700L70`000`L0
1`0N1`00:0L00`071`0;1`<00`L01@071`L000870`031`0500L71`003`L00`071`021`0300L700H7
00D01`L700081`<010L01@071`L000870`041`0500L71`003`L00`071`0300L700<01`L00`0>1`03
00L7008700<01`L01PL01@071`L000h70P0;1`807`L002P700<01`L03PL400<700<01`L00`L400<7
00<01`L03@L00`071`021`0300L700H700D01`L7000;1`<000<700L00PL00`071`031`<000<700L0
0PL00`071`0=1`0600L71`070`041`0600L71`070`0;1`0300L7008700<01`L01PL01@071`L003`7
000X1`0300L701470`000`L01`071`<000<700L03PL00`071`021`0300L700H700D01`L7000>1`<0
0PL00`071`061`<00PL00`071`0=1`0500L71`0010L300031`07008700<01`L00PL300P700<01`L0
0PL00`071`061`0500L71`00?0L002P700<01`L04@L00`071`0300L700<01`L00`0>1`0300L70087
00<01`L01PL01@071`L000l700<01`000P091`0300L000803`L01@071`L000L70`021`0300L700D7
0`051`0300L7008700<01`L01PL01@071`L003`7000X1`0300L7014700H01`L700L300@700H01`L7
00L300/700<01`L00PL00`071`061`0500L71`003`L010071`L400H700@01`L7100<1`0500L71`00
20L00`07000200X70`021`0300L7008700<01`L01PL01@071`L003`7000X1`804PL01@071`L000@7
0`000`L01`021`0300L700870`081`0300L7008700<01`L01PL01@071`L000l700D01`L700031`<0
0`L01@071`L000<70`091`0500L71`0020L010071`L400X70`041`0300L700H700D01`L7000l1`00
:PL300l700D01`L700071`<00PL00`071`051`<01@L00`071`021`0300L700H700D01`L7000?1`05
00L71`001PL400<700<01`L010L300H700D01`L700081`0500L71`000`L400P71P081`0500L71`00
?0L002d70`0<1`0500L71`0020L00`07000200X70`021`0300L7008700<01`L01PL01@071`L000l7
00D01`L700091`<000<700L020L300<700D01`L700081`0500L71`001`L300D700<01`L00PL300H7
00D01`L7000l1`00<0L300T700D01`L700081`0400L71`@02PL300@700<01`L01PL01@071`L000l7
00D01`L700091`0300L700@02PL400<700<01`L01PL01@071`L000X70`021`0300L7008700<01`L0
0`031`0500L71`00?0L003<70`061`0500L71`0020L01@071`L000<710081`H020L01@071`L000l7
00D01`L700091`0500L71`000PL300X70`000`L01`071`0500L71`003@L300@700<01`L00`L400<7
00<01`L0>PL003H70`031`0500L71`0020L01@071`L000L70`051`0300L700870`061`0500L71`00
3`L01@071`L000T700D01`L700051`<01`L00`071`0300L700D01`L7000?1`@000<700L01`L30003
1`0703/7000i1`@00`L00`071`061`0500L71`002PL3008700<01`L00PL00`071`0300<700D01`L7
000?1`0500L71`002@L01@071`L000P70`041`0600L71`070`041`0500L71`003`L010071`L200P7
00<01`L00P0l1`00?0L300031`0700L700D01`L7000=1`<010L00`071`031`@00`L00`071`0=1`05
00L71`002@L01@071`L000/70`000`L01`021`0300L700870`000`L01`021`0300L700d700<01`L0
2`L00`071`0n1`00?0L00`071`0300L700D01`L7000?1`@000<700L01`L300031`0700h700D01`L7
00091`0500L71`003PL3008700<01`L01@L3008700<01`L03@L00`071`0;1`0300L703h7000l1`06
00L71`070`041`0500L71`003`L010071`L300L700<01`L00`0>1`0500L71`002@L01@071`L000l7
00<01`000P081`0300L000803`L00`071`0;1`0300L703h7000l1`0500L71`0010L300031`070087
00<01`L03@L00`071`021`0300L0008010L01P071`L01`<02`L01@071`L000T700D01`L7000?1`04
00L71`@01@L010071`L400`700<01`L02`L00`071`0n1`00?0L2008700<01`L01@L3008700<01`L0
3@L00`071`021`0300L700870`000`L01`021`0300L700870`081`0500L71`002@L01@071`L000l7
00D01`L700031`<00PL01@071`L000<70`091`0300L700/700<01`L0?PL003h70`0:1`<03`L00`07
1`021`0300L700D70`021`0300L700D70`051`0500L71`002@L01@071`L000l700D01`L700061`<0
0`L00`071`041`<01PL00`071`0;1`0300L703h700101`@02@L400`700<01`L00PL00`071`061`03
00L000802PL3008700D01`L700091`0500L71`003`L01@071`L000P71@091`<00`L00`071`0;1`03
00L703h700101`0400L71`<01PL010071`L300T700<01`L00PL00`071`061`0400L71`@02PL300<7
00<01`L01`L01@071`L000l700D01`L700081`0400L71`<02PL400d700<01`L0?PL0040700<01`L0
10L300<700<01`L010L300H700<01`L00PL00`071`061`0500L71`000`L300T71@091`0500L71`00
3`L01@071`L000P700D01`L700021`<02PL400X700<01`L0?PL0040700<01`L01`L400T70`031`03
00L7008700<01`L01PL01@071`L000H70`061`0400L71`@01PL01@071`L000l700D01`L700081`05
00L71`001@L300L700@01`L70`071`0300L703h700101`0300L700X70`0:1`@010L00`071`061`05
00L71`002@L300<700D01`L700031`<00`L01@071`L000l700D01`L700081`0500L71`0020L300@7
00<01`L010L300@700<01`L0?PL0040700<01`L02PL00`071`0300X710000`L01`071`0500L71`00
30L400<700<01`L010L400<700<01`L03@L01@071`L000P700D01`L7000;1`<000<700L020L30003
1`0703l700101`0300L700X700<01`L00`L300L700@01`L70`071`0500L71`003`L300031`0700P7
0`000`L01`0>1`0500L71`0020L01@071`L000h70P0<1`80@0L0040700<01`L02PL00`071`061`<0
10L00`071`021`0300L0008010L01@071`L000l700<01`L00`081`0300L700<03PL01@071`L000P7
00D01`L7001N1`00@0L00`071`0:1`0300L700T70`000`L01`031`0300L700870`000`L01`021`03
00L700d700<01`L00`L300D700<01`L00`L300/700D01`L700081`0500L71`00GPL0040700<01`L0
2PL00`071`0<1`<00`L00`071`051`<00PL00`071`0=1`0300L700H70`021`0300L700H70`081`05
00L71`0020L01@071`L005h700101`0300L700X700<01`L03`L400X70`0?1`0300L700T70`0;1`<0
1@L01@071`L000P700D01`L7001N1`00@0L00`071`0:1`0300L701870`0:1`@030L00`071`0;1`@0
2`L3008700D01`L700081`0500L71`00GPL0040700<01`L02PL00`071`0B1`0300L700<01`L01007
1`L300T700<01`L02`L010071`L300/70`031`0300L700H700D01`L7001N1`00@0L00`071`0:1`03
00L7018700<01`L00`L300@700<01`L010L300H700<01`L02`L00`071`041`@02@L500P700D01`L7
001N1`00@0L00`071`0:1`0300L7018700<01`L01PL300031`0700P70`031`0300L700/700<01`L0
20L300H700@01`L70`061`0500L71`00GPL0040700<01`L02PL00`071`0B1`0300L700T7100:1`@0
3@L00`071`0;1`<00`L01@071`L000870`031`0500L71`00GPL0040700<01`L02PL00`071`0B1`03
00L700X700<01`L00`0:1`@02PL00`071`0>1`@00`L00`071`031`@00`L00`071`1L1`00@0L00`07
1`0:1`0300L7018700<01`L02PL00`071`031`<01`L010071`L300L700<01`L04@L300031`0700L7
0`000`L01`1M1`00@0L00`071`0:1`0300L7018700<01`L02PL00`071`061`<010L00`071`041`<0
10L00`071`0A1`0300L7008020L00`071`0205h700101`0300L700X700<01`L04PL00`071`0:1`03
00L700T70`000`L01`081`<000<700L04PL00`071`0:1`0300L7060700101`802`L201<700<01`L0
2PL00`071`0<1`<02`L3018700<01`L02PL00`071`1P1`00@PL300X70`0@1`0300L700X700<01`L0
3`L300/70`0?1`0300L700X700<01`L0H0L004D70`0:1`<03@L00`071`0:1`0300L701870`0;1`<0
30L00`071`0:1`0300L7060700181`<02PL300X700<01`L02PL00`071`0E1`<02`L300T700<01`L0
2PL00`071`1P1`00B`L300X70`071`0300L700X700<01`L060L300/70`061`0300L700X700<01`L0
H0L004h70`0:1`<010L00`071`0:1`0300L701/70`0;1`<00`L00`071`0:1`0300L70607001A1`@0
2@L500`700<01`L07PL400X7100<1`0300L70607001E1`<02PL300X700<01`L08PL300X70`0:1`03
00L70607001H1`<01`L00`071`0300L700<01`L09@L300L700<01`L00`071`0300L70607001K1`<0
10L00`071`031`<010L00`071`0X1`<010L00`071`031`<010L00`071`1P1`00GPL300031`0700L7
0`000`L01`0/1`<000<700L01`L300031`070647001Q1`802`L203070P0;1`80HPL00?l74PL00?l7
4PL00?l74PL00?l74PL00?l74PL00?l74PL00001\
\>"],
  ImageRangeCache->{{{0, 272.812}, {260.625, 0}} -> {-10.1408, -9.68682, \
0.0743456, 0.0743456}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[179]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["j = 5, k =2", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AL052, Axes \[Rule] True, Prolog \[Rule] PointSize[0.025], 
      PlotRange \[Rule] \ {{\(-20\), 20}, {\(-20\), 20}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[180]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.5 0.025 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -9 -9 ]
[.125 .4875 9 0 ]
[.25 .4875 -9 -9 ]
[.25 .4875 9 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -6 -9 ]
[.75 .4875 6 0 ]
[.875 .4875 -6 -9 ]
[.875 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -12 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -12 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-20)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-15)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-10)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(10)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(15)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(20)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-20)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-15)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-10)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(10)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(15)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(20)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.025 w
.08774 .69717 Mdot
.18887 .73003 Mdot
.28999 .76289 Mdot
.39112 .79574 Mdot
.49225 .8286 Mdot
.08774 .63145 Mdot
.18887 .66431 Mdot
.28999 .69717 Mdot
.39112 .73003 Mdot
.49225 .76289 Mdot
.59338 .79574 Mdot
.08774 .56574 Mdot
.18887 .5986 Mdot
.28999 .63145 Mdot
.39112 .66431 Mdot
.49225 .69717 Mdot
.59338 .73003 Mdot
.6945 .76289 Mdot
.08774 .50002 Mdot
.18887 .53288 Mdot
.28999 .56574 Mdot
.39112 .5986 Mdot
.49225 .63145 Mdot
.59338 .66431 Mdot
.6945 .69717 Mdot
.79563 .73003 Mdot
.08774 .4343 Mdot
.18887 .46716 Mdot
.28999 .50002 Mdot
.39112 .53288 Mdot
.49225 .56574 Mdot
.59338 .5986 Mdot
.6945 .63145 Mdot
.79563 .66431 Mdot
.89676 .69717 Mdot
.08774 .36859 Mdot
.18887 .40145 Mdot
.28999 .4343 Mdot
.39112 .46716 Mdot
.49225 .50002 Mdot
.59338 .53288 Mdot
.6945 .56574 Mdot
.79563 .5986 Mdot
.89676 .63145 Mdot
.99788 .66431 Mdot
.08774 .30287 Mdot
.18887 .33573 Mdot
.28999 .36859 Mdot
.39112 .40145 Mdot
.49225 .4343 Mdot
.59338 .46716 Mdot
.6945 .50002 Mdot
.79563 .53288 Mdot
.89676 .56574 Mdot
.99788 .5986 Mdot
.18887 .27001 Mdot
.28999 .30287 Mdot
.39112 .33573 Mdot
.49225 .36859 Mdot
.59338 .40145 Mdot
.6945 .4343 Mdot
.79563 .46716 Mdot
.89676 .50002 Mdot
.99788 .53288 Mdot
.28999 .23716 Mdot
.39112 .27001 Mdot
.49225 .30287 Mdot
.59338 .33573 Mdot
.6945 .36859 Mdot
.79563 .40145 Mdot
.89676 .4343 Mdot
.99788 .46716 Mdot
.39112 .2043 Mdot
.49225 .23716 Mdot
.59338 .27001 Mdot
.6945 .30287 Mdot
.79563 .33573 Mdot
.89676 .36859 Mdot
.99788 .40145 Mdot
.49225 .17144 Mdot
.59338 .2043 Mdot
.6945 .23716 Mdot
.79563 .27001 Mdot
.89676 .30287 Mdot
.99788 .33573 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[180]:=",
  ImageSize->{225.188, 225.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Q0000h@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc>47003Q1`00h@L00>47003Q1`00h@L006<7
10031`80M@L006<700<01`L00`L010071`1d1`00I0L00`071`021`0400L700@70P1^1`00G@L400@7
00D01`L700021`0300L7008700<01`L0K@L006H700@01`L00PL00`071`021`0300L706d7001S1`04
00L7008700@01`L010L00`071`1]1`00I0L200@70P051`0300L706d7001a1`80KPL0074700<01`L0
K@L0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L007470P1^1`00L@L00`071`1]1`00
L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L206h7001a1`03
00L706d7001a1`0300L706d7001a1`0300L706d7001a1`0300L706d7001a1`80KPL0074700<01`L0
K@L0074700<01`L0K@L006<710021`<01@L00`071`1]1`00I@L00`071`041`0300L7008700<01`L0
K@L006D700<01`L010L00`071`021`80KPL005d710041`0400L71`<01@L00`071`1]1`00I@L01@07
1`L000L700<01`L0K@L006<70`031`0300L700D700<01`L0K@L006D700@01`L710041`0300L706d7
001a1`80KPL0074700<01`L0K@L0074700<01`L0K@L006h7101_1`00KPL406l7001^1`D0KPL006h7
101_1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00F@L401@700<01`L040L405T7
001I1`@050L20147101I1`00F@L401@700<01`L040L405T7001I1`@050L00`071`0@1`@0F@L00747
00<01`L0K@L0074700<01`L0K@L004@7100V1`D09PL404@700141`@09PL402L710141`00A0L402H7
100W1`@0A0L004@7100K1`@00`L20087100W1`@0A0L006D700D01`L700021`0300L7008700<01`L0
K@L006D700D01`L700021`0300L700870P1^1`00G@L400@700D01`L700021`0300L7008700<01`L0
K@L002l7100V1`@020L01@071`L0008700<01`L00PL00`071`0@1`@09PL402l7000_1`@09PL400H7
0`031`0400L700@700<01`L040L402H7100_1`00;`L402H710081`0300L700870P051`0300L70107
100V1`@0;`L002l7100V1`@050L20147100V1`@0;`L0074700<01`L0K@L0074700<01`L0K@L00747
00<01`L0K@L001X7100V1`@09PL402L7100V1`@06PL001X7100V1`@09PL402L7100V1`@06PL001X7
100V1`@09PL502H7100V1`@06PL001X7100V1`@09PL402L7100V1`@06PL0074700<01`L0K@L00747
00<01`L0K@L0074700<01`L0K@L002l7100V1`@050L20147100V1`@09PL400D7000_1`@09PL401@7
00<01`L040L402H7100V1`@01@L002l7100V1`@050L00`071`0@1`@09PL402H710051`00;`L402H7
100D1`0300L70107100V1`@09PL400D7001a1`0300L706d7001a1`80KPL0074700<01`L0K@L001X7
100V1`@09PL402L7100V1`@06PL001X7100V1`@08@L30087100W1`@09PL401X7000J1`@09PL402@7
00<01`000`0W1`@09PL401X7000J1`@09PL402@700<01`00100V1`@09PL401X7001S1`@00PL300D7
00<01`L0K@L006T700<01`L01@L00`071`1]1`00J@L00`071`051`0300L706d7000_1`@09PL400`7
10041`0300L70107100V1`@09PL400D7000_1`@09PL401@70P0A1`@09PL402H710051`00;`L402H7
100D1`0300L70107100V1`@09PL400D7000_1`@09PL401@700<01`L040L402H7100V1`@01@L00747
00<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L001X7100V1`@09PL502H7100V1`@06PL001X7
100V1`@09PL402L7100V1`@06PL001X7100V1`@09PL402L7100V1`@06PL001X7100V1`@09PL402L7
100V1`@06PL0074700<01`L0K@L007470P1^1`001`L400<70P0A1`@00PL3014710031`8050L301H7
00<01`L05@L301@710031`804PL400870`0A1`@00`L200<700071`0300L700<700@01`L04PL00`07
1`041`0300L70087100:1`0500L71`000PL00`071`0B1`@050L00`071`0@1`@010L00`071`0C1`05
00L71`000PL00`071`021`@02`L00`071`041`0300L700h700<01`L010021`400@L11`0020L00`07
1`021`0400L7018700<01`L010L00`071`021`@02PL01@071`L0008700<01`L04PL401@700<01`L0
40L400@700<01`L04`L01@071`L0008700<01`L00PL400/700<01`L010L00`071`0?1`0300L000<0
0PL100470@L000031`00008010L01@071`L0008700<01`L020L400@700@01`L70`051`@00PL400@7
00D01`L700021`0300L700/710021`D050L00`071`0@1`@000@700005PL01@071`L0008700<01`L0
0PL400/700@01`L70`0C1`D00PL100470@L000X700@01`L00PL00`071`0@1`0500L71`001`L400X7
00D01`L700021`0300L701471@0D1`804@L400031`0701L700D01`L700021`0300L70087100;1`05
00L71`005PL400870@011`4700071`0400L7008700@01`L040L300<700<01`L04@L300<700@01`L0
4`L00`071`0F1`0300L701D700<01`L050L300<700@01`L04@L300<700<01`L04@L010071`021`04
00L7008700081`8010L201<700@01`L7100B1`0300L700870P0D1`@05@L00`071`0E1`@05@L00`07
1`021`8050L010071`L401470P041`800`L001X7100V1`@09PL402L7100V1`@06PL001X7100V1`@0
9PL402L7100V1`@06PL000T7dP061`002@L00`071`021`0300L7008700<01`L00PL00`07000300D7
00<01`L00PL00`071`021`0300L7008700<01`L00`L00`071`021`0300L7008700<01`000`041`03
00L700<700<01`L00PL00`071`021`0300L7008700<01`L00`L00`071`021`0300L000<010L00`07
1`031`0300L7008700<01`L00PL00`071`021`0300L7008700<01`L00`L00`071`0400<700<01`L0
0PL00`071`031`0300L7008700<01`L00PL00`071`021`0300L700<700<01`L010031`0300L70087
00<01`L00PL00`071`031`0300L700@700091`0300L701L700<01`L05`L00`071`0G1`0300L701L7
00<01`L05`L00`071`0G1`0300L701P700<01`L05`L00`071`041`00L@L00`071`1]1`00L@L00`07
1`1]1`00;`L402H7100D1`0300L70107100V1`@09PL400D7000_1`@09PL401@70P0A1`@09PL402H7
10051`00;`L402H7100D1`0300L70107100V1`@09PL400D7000_1`@09PL401@700<01`L040L402H7
100V1`@01@L0074700<01`L0K@L0074700<01`L0K@L007470P1^1`006PL402H7100V1`@09`L402H7
100J1`006PL402H7100V1`@09`L402H7100J1`006PL402H7100V1`@09`L402H7100J1`006PL402H7
100V1`@09`L402H7100J1`00L@L206h7001a1`0300L706d7001a1`0300L706d7000_1`@09PL401@7
00<01`L040L402H7100V1`@01@L002l7100V1`@050L00`071`0@1`@09PL402H710051`00;`L402H7
100D1`804@L402H7100V1`@01@L002l7100V1`@050L00`071`0@1`@09PL402H710051`00L@L00`07
1`1]1`00L@L00`071`1]1`00J@L300D700<01`L0K@L001X7100V1`@090L00`07000302L7100V1`@0
6PL001X7100V1`@090L00`07000402H7100V1`@06PL001X7100V1`@08@L30087100W1`@09PL401X7
000J1`@09PL4024700<01`L00PL402L7100V1`@06PL006T700<01`L01@L00`071`1]1`00J@L400@7
00<01`L0K@L007470P1^1`00;`L402H7100D1`0300L70107100V1`@09PL400D7000_1`@09PL401@7
00<01`L040L402H7100V1`@01@L002l7100V1`@050L00`071`0@1`@09PL402H710051`00;`L402H7
100D1`0300L70107100V1`@09PL400D7001a1`80KPL0074700<01`L0K@L0074700<01`L0K@L001X7
100V1`@09PL402L7100V1`@06PL001X7100V1`@09PL402L7100V1`@06PL001X7100V1`@09PL502H7
100V1`@06PL001X7100V1`@09PL402L7100V1`@06PL0074700<01`L0K@L0074700<01`L0K@L00747
00<01`L0K@L002l7100V1`@050L20147100V1`@0;`L002l7100V1`@050L00`071`0@1`@09PL402l7
000_1`@09PL401@700<01`L040L402H7100_1`00;`L402H7100D1`0300L70107100V1`@0;`L006<7
10031`801@L00`071`1]1`00I@L01@071`L0008700<01`L00PL00`071`1]1`00A0L401d700D01`L7
00021`0300L000@09PL404@700141`@07@L01@071`L0008700<01`000`0W1`@0A0L004@7100M1`05
00L71`000PL00`07000302L710141`00A0L401/70`031`0500L700L0100W1`@0A0L006D700<01`L0
0PL200D700<01`L0K@L007470P1^1`00L@L00`071`1]1`00F@L401@700<01`L040L405T7001I1`@0
50L00`071`0@1`@0F@L005T7100D1`0300L70107101I1`00F@L401@70P0A1`@0F@L0074700<01`L0
K@L0074700<01`L0K@L0074700<01`L0K@L006h7101_1`00KPL506h7001^1`@0K`L006h7101_1`00
L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L206h7001a1`0300L706d7001a1`03
00L706d7001S1`@00PL300D700<01`L0K@L006D700<01`L010L00`071`021`0300L706d7001U1`03
00L700@700<01`L00PL206h7001U1`0400L71`<01@L00`071`1]1`00I@L01@071`L000L700<01`L0
K@L006<70`031`0300L700D700<01`L0K@L006D700@01`L710041`0300L706d7001a1`80KPL00747
00<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L007470P1^1`00L@L00`07
1`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L206h7
001a1`0300L706d7001a1`0300L706d7001a1`0300L706d7001a1`0300L706d7001a1`80KPL00747
00<01`L0K@L0074700<01`L0K@L006<710031`801@L00`071`1]1`00H`L00`071`031`0400L700@7
00<01`L0K@L006@700<01`L00PL010071`041`80KPL006D700D01`L700021`0300L70787001V1`04
00L7008700<01`L0LPL006<700@01`L00PL010071`1d1`00I0L200@70P1e1`00h@L00>47003Q1`00
\
\>"],
  ImageRangeCache->{{{0, 224.188}, {224.188, 0}} -> {-21.7212, -21.4343, \
0.191218, 0.191218}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[180]="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(basis52 = 
      FullSimplify[{A[5, 2, \[Alpha]] /. {m \[Rule] 1, n \[Rule] 0}, 
          A[5, 2, \[Alpha]] /. {m \[Rule] 0, 
              n \[Rule] 1}}]\), "\[IndentingNewLine]", 
    \(orig\  = \ 
      FullSimplify[
        A[5, 2, \[Alpha]] /. {m \[Rule] 0, n \[Rule] 0}]\)}], "Input",
  CellLabel->"In[181]:="],

Cell[BoxData[
    \({{3.7350089605054153`, \(-1.3134857051607396`\)}, {3.7350089605054153`, 
        1.3151698554349285`}}\)], "Output",
  CellLabel->"Out[181]="],

Cell[BoxData[
    \({\(-0.31007601136932234`\), 0.0008420751370943891`}\)], "Output",
  CellLabel->"Out[182]="]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    \(\(rad52\  = \@\(\((basis52[\([1]\)]\  - \ orig)\) . \((basis52[\([1]\)]\
\  - \ orig)\)\);\)\)], "Input",
  CellLabel->"In[183]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AppendTo[basis52, orig], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-10\), 10}, {\(-10\), 10}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[184]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.68675 .43433 Mdot
.68675 .56576 Mdot
.4845 .50004 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[184]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L0088710031`80U@L008@700D01`L700021`0300L7098700241`0500L71`000PL00`07
1`031`80S@L007`710041`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`07
1`031`0300L708`700221`<00`L010071`051`0300L708`700241`0300L700870P061`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L007d700<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<7
00<01`L0S0L007h700<01`L02PL00`071`031`80S@L007H710041`0300L700L70`061`0300L708`7
001o1`0300L700H700<01`L01PL00`071`2<1`00O0L010071`081`0300L700H700<01`L0S0L007`7
10081`@01@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`700281`<01PL00`071`2<1`00R`L00`071`031`0300L708`7
002;1`0300L700<70P2=1`00PPL400870`061`0300L708`700281`0300L700H700<01`L0S0L008P7
00<01`L01PL00`071`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00O0L400<700<01`L00PL300H7
00<01`L0S0L007`700<01`L030L00`071`031`0300L708`7001m1`0300L700/700<01`L00`L208d7
001f1`@010L00`071`071`<01PL00`071`2<1`00O`L00`071`061`0300L700H700<01`L0S0L007`7
00@01`L020L00`071`061`0300L708`7001m1`802@L400D700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`0]1`H0F@L00947
00<01`L0:`L:05L7002A1`0300L702/72P1G1`00T@L00`071`0Z1``0EPL009470P0[1``0EPL00947
00<01`L0:PL<05H7002A1`0300L702X7301F1`00T@L00`071`0Z1``0EPL0094700<01`L0:PL<05H7
002A1`0300L702/72P1G1`00T@L202`72P1G1`00T@L00`071`0]1`H0F@L0094700<01`L0S0L00947
00<01`L0S0L000L710031`805`L00`071`031`0300L700870`0I1`<06@L400<700<01`L00PL301P7
00<01`L05`L400<700<01`L00PL301T70`0J1`0300L700<700<01`L00PL301H710031`800`L000T7
00D01`L700021`0300L701@700<01`L02`L00`071`0I1`0300L701H700<01`L030L00`071`0E1`03
00L701L700<01`L030L00`071`0I1`0300L701L700<01`L02`L00`071`0E1`0500L71`000PL10047
0@L000T700D01`L700021`0300L701D700<01`L02PL00`071`0I1`0300L701L700<01`L02`L00`07
1`0E1`0300L701P700<01`L02`L00`071`0I1`0300L701P700<01`L02PL00`071`0E1`0500L71`00
0PL100470@L000031`00008010L01@071`L0008700<01`L03@L400@700<01`L01`L301<710021`<0
4`L400@700<01`L01`L301P70P0J1`0300L700L70`0I1`<06`L00`071`071`<060L01@071`L00087
0@011`4700091`0500L71`000PL00`071`0F1`0300L700H700<01`L06@L00`071`0L1`0300L700H7
00<01`L04@L600031`0701/700<01`L01PL00`071`0I1`0300L701`700<01`L01PL00`071`0H1`05
00L71`000PL100470@L000L70`031`0400L701D700@01`L020L00`071`0I1`0300L701T700@01`L0
20L00`071`0?1`X06@L010071`081`0300L701T700<01`L06@L010071`081`0300L701H70`031`04
00L7008700091`0300L700870P0F1`@020L401P7100I1`802@L400h72P0J1`802@L401P7100H1`@0
20L401L700<01`L00PL200<700271``0S@L008L7302=1`00Q`L<08d700091ol04P061`002@L00`07
1`031`0300L700@700<01`L010L00`071`041`0300L700@700<01`L00`L00`071`041`0300L700@7
00<01`L010L00`071`041`0300L700<700<01`L010L00`071`041`0300L700@700<01`L010L00`07
1`031`0300L700@700<01`L010L010071`L<00@700<01`L010L00`071`041`0300L700@700<01`L0
10L00`071`031`0300L700@700<01`L010L00`071`041`0300L700@700<01`L00`L00`071`041`03
00L700@700<01`L010L00`071`041`0300L700<700<01`L010L00`071`041`0300L700@700<01`L0
10L00`071`041`002@L00`071`0O1`0300L701l700<01`L07`L00`071`0E1``080L00`071`0O1`03
00L701l700<01`L07`L00`071`041`00R0L:08h700281`X0SPL008X71P000`L01`2=1`00T@L00`07
1`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L702d71P1I1`00T@L00`071`0[1`X0E`L009470P0/1`X0E`L0094700<01`L0:PL<05H7
002A1`0300L702X7301F1`00T@L00`071`0Z1``0EPL0094700<01`L0:PL<05H7002A1`0300L702X7
301F1`00T@L202/7301F1`00T@L00`071`0[1`X0E`L0094700<01`L0:`L:05L7002A1`0300L702d7
1P1I1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7001l1`@00`L00`071`021`<01PL00`07
1`2<1`00O0L00`071`0<1`0300L700<700<01`L0S0L007d700<01`L02`L00`071`031`80S@L007h7
00<01`L01`L300H700<01`L0S0L007l700<01`L01PL00`071`061`0300L708`7001l1`0400L700P7
00<01`L01PL00`071`2<1`00O@L200T710051`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L008P70`061`0300L708`7
002;1`0300L700<700<01`L0S0L008/700<01`L00`L208d700281`<01PL00`071`2<1`00R0L00`07
1`061`0300L708`700281`0300L700H700<01`L0S0L008P710051`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L007d7
00<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<700<01`L0S0L007h7
00<01`L02PL00`071`031`80S@L007h700<01`L01`L300H700<01`L0S0L007l700<01`L01PL00`07
1`061`0300L708`7001l1`0400L700P700<01`L01PL00`071`2<1`00O0L400P710051`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0088710031`801PL00`071`2<1`00Q0L01@071`L0008700<01`L00`L00`071`2<1`00
Q0L01@071`L0008700<01`L00`L208d700241`0500L71`000PL00`071`2B1`00Q0L01@071`L00087
00<01`L0TPL008870`031`0400L709@700241`0300L700870P2E1`00o`LQ1`00o`LQ1`00o`LQ1`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.6619, -10.5516, 0.0735301, \
0.0735301}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[184]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice052\  = tiling2D[SphericalCut[N[AL052], 10], \ rad52]\)], "Input",\

  CellLabel->"In[185]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.13722 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.518251 0.0588604 0.56856 0.0588604 [
[ 0 0 0 0 ]
[ 1 1.13722 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.13722 L
0 1.13722 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .87806 m
.2619 .95542 L
s
.02381 .87806 m
.2619 .80069 L
s
.2619 .95542 m
.5 1.03278 L
s
.2619 .95542 m
.5 .87806 L
s
.5 1.03278 m
.7381 1.11014 L
s
.5 1.03278 m
.7381 .95542 L
s
.02381 .72333 m
.2619 .80069 L
s
.02381 .72333 m
.2619 .64597 L
s
.2619 .80069 m
.5 .87806 L
s
.2619 .80069 m
.5 .72333 L
s
.5 .87806 m
.7381 .95542 L
s
.5 .87806 m
.7381 .80069 L
s
.7381 .95542 m
.97619 .87806 L
s
.02381 .56861 m
.2619 .64597 L
s
.02381 .56861 m
.2619 .49125 L
s
.2619 .64597 m
.5 .72333 L
s
.2619 .64597 m
.5 .56861 L
s
.5 .72333 m
.7381 .80069 L
s
.5 .72333 m
.7381 .64597 L
s
.7381 .80069 m
.97619 .87806 L
s
.7381 .80069 m
.97619 .72333 L
s
.02381 .41389 m
.2619 .49125 L
s
.02381 .41389 m
.2619 .33652 L
s
.2619 .49125 m
.5 .56861 L
s
.2619 .49125 m
.5 .41389 L
s
.5 .56861 m
.7381 .64597 L
s
.5 .56861 m
.7381 .49125 L
s
.7381 .64597 m
.97619 .72333 L
s
.7381 .64597 m
.97619 .56861 L
s
.02381 .25916 m
.2619 .33652 L
s
.02381 .25916 m
.2619 .1818 L
s
.2619 .33652 m
.5 .41389 L
s
.2619 .33652 m
.5 .25916 L
s
.5 .41389 m
.7381 .49125 L
s
.5 .41389 m
.7381 .33652 L
s
.7381 .49125 m
.97619 .56861 L
s
.7381 .49125 m
.97619 .41389 L
s
.2619 .1818 m
.5 .25916 L
s
.2619 .1818 m
.5 .10444 L
s
.5 .25916 m
.7381 .33652 L
s
.5 .25916 m
.7381 .1818 L
s
.7381 .33652 m
.97619 .41389 L
s
.7381 .33652 m
.97619 .25916 L
s
.5 .10444 m
.7381 .1818 L
s
.5 .10444 m
.7381 .02708 L
s
.7381 .1818 m
.97619 .25916 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[185]:=",
  ImageSize->{288, 327.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001A`P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00?l78@L00=870P1<1`00c`L304h7003<1`<0D@L00<T70`1D1`00aPL305L7
00321`@0FPL00;l70`1N1`00_0L30647002i1`<0I0L00;H70`1W1`00/`L306X7002`1`<0K@L00:d7
0`1`1`00ZPL307<7002W1`<0MPL00:@70`1i1`00X0L407`7002M1`<0P0L009X70`231`00U`L308H7
002D1`<0R@L009470`2<1`00SPL308l7002;1`<00`L308`700281`<02@L308T700251`<03`L308H7
00221`<05@L308<7001n1`@06`L30807001k1`<08PL407`7001h1`<0:@L307T7001e1`<0;`L307H7
001b1`<0=@L307<7001_1`<0>`L30707001/1`<0@@L306d7001Y1`<0A`L306X7001V1`<0C@L306L7
001S1`<0D`L306@7001P1`<0F@L30647001L1`@0G`L305h7001I1`<0IPL405X7001F1`<0K@L305L7
001C1`<0L`L305@7001@1`<0N@L30547001=1`<0O`L304h7001:1`<0Q@L304/700171`<00`L307l7
0`031`<0B0L004@70`091`<0N@L300T70`151`00@@L300l70`1c1`<03`L30487000m1`@05@L306d7
0`0E1`@0?PL003X70`0L1`<0IPL401`70`0k1`00=`L30287101O1`<08`L303P7000d1`<0:@L305T7
0`0Y1`<0=@L003470`0_1`<0D`L302l70`0b1`00;PL303D70`1=1`<0=@L302l7000[1`<0>`L304L7
0`0k1`<0;0L002L710111`<0@@L30447100X1`0090L304P70`0k1`<0B0L302D7000Q1`<0CPL303D7
0`1>1`<08PL001h70`1D1`<0;`L305@70`0O1`006`L305X70`0Y1`<0FPL301`7000H1`<0H0L30287
101P1`<06@L001D70`1V1`@06`L306L70`0F1`004@L406d70`0E1`<0K@L40187000>1`<0M0L300l7
0`1d1`<03`L000/70`1j1`<02@L307X70`0<1`0020L308070`031`<0P0L300T700061`80QPL308H7
0P071`0020L308070`031`<0P0L300T7000;1`<0NPL300T70`1j1`<030L000h70`1d1`<03`L307@7
0`0?1`004@L306h70`0E1`<0KPL30187000D1`<0J0L301/70`1X1`<05@L001L70`1R1`<08@L30687
0`0H1`006PL305`70`0W1`<0G0L301/7000M1`<0EPL302d70`1F1`<07PL002070`1@1`<0<`L30507
0`0Q1`008`L304X70`0i1`<0BPL302@7000V1`<0A0L303l70P151`<09`L002T70`0o1`80A0L303l7
0`0Z1`00;0L303T70`191`<0>@L302d7000_1`<0<`L304l70`0c1`<0<0L003870`0]1`<0E@L302d7
0`0c1`00=@L302L70`1K1`<09`L303H7000h1`<08@L306470`0Q1`<0>@L003/70`0K1`<0I`L301/7
0`0l1`00?PL301D70`1]1`<05@L303l700111`<03`L307<70`0?1`<0@PL004@70`091`<0N@L300T7
0`151`00A`L300<70`1o1`<00`L304P7001:1`<0Q@L304/700171`<00`L307l70`031`<0B0L004@7
0`091`<0N@L300T70`151`00@@L300l70`1c1`<03`L30487000m1`@05@L306d70`0E1`@0?PL003X7
0`0L1`<0IPL401`70`0k1`00=`L30287101O1`<08`L303P7000d1`<0:@L305T70`0Y1`<0=@L00347
0`0_1`<0D`L302l70`0b1`00;PL303D70`1=1`<0=@L302l7000[1`<0>`L304L70`0k1`<0;0L002L7
10111`<0@@L30447100X1`0090L304P70`0k1`<0B0L302D7000Q1`<0CPL303D70`1>1`<08PL001h7
0`1D1`<0;`L305@70`0O1`006`L305X70`0Y1`<0FPL301`7000H1`<0H0L30287101P1`<06@L001D7
0`1V1`@06`L306L70`0F1`004@L406d70`0E1`<0K@L40187000>1`<0M0L300l70`1d1`<03`L000/7
0`1j1`<02@L307X70`0<1`0020L308070`031`<0P0L300T700061`80QPL308H70P071`0020L30807
0`031`<0P0L300T7000;1`<0NPL300T70`1j1`<030L000h70`1d1`<03`L307@70`0?1`004@L406d7
0`0E1`<0K@L40187000E1`<0IPL401/70`1W1`<05PL001P70`1P1`<08PL406070`0I1`006`L305X7
0`0Y1`<0FPL301`7000N1`<0E0L302l70`1D1`<07`L002470`1>1`<0=@L304h70`0R1`0090L304P7
0`0k1`<0B0L302D7000W1`@0@@L304470`111`@0:0L002/70`0k1`<0A`L303/70`0/1`00;PL303D7
0`1=1`<0=@L302l7000a1`<0;`L305<70`0_1`<0<PL003@70`0Y1`<0F@L302T70`0e1`00=`L30287
101O1`<08`L303P7000j1`<070L306H7100L1`<0>`L003d7100E1`<0K@L301D7100n1`00@@L300l7
0`1c1`<03`L3048700141`<02@L307T70`091`<0A@L004L70`031`<0O`L300<70`181`00BPL308D7
0`1;1`00A`L300<70`1o1`<00`L304P700141`<02@L307T70`091`<0A@L004470`0?1`<0L`L300l7
0`121`00?@L401D70`1]1`<05@L403h7000j1`<070L306H7100L1`<0>`L003L70`0R1`@0G`L302<7
0`0h1`00=0L302T70`1I1`<0:@L303D7000a1`<0;`L305<70`0_1`<0<PL002h70`0e1`<0C@L303D7
0`0_1`00:`L303/70`171`<0>`L302`7000W1`@0@@L304470`111`@0:0L002@70`181`<0>`L304P7
0`0U1`008@L304h70`0e1`<0CPL30287000N1`<0E0L302l70`1D1`<07`L001/70`1J1`<0:@L305X7
0`0L1`0060L306070`0R1`@0H0L301T7000E1`<0IPL401/70`1W1`<05PL00147101]1`<05@L306d7
100B1`003PL307@70`0?1`<0M0L300l7000;1`<0NPL300T70`1j1`<030L000P70`201`<00`L30807
0`091`001PL208H70`261`801`L000P70`201`<00`L308070`091`002`L307X70`091`<0NPL300`7
000>1`<0M0L300l70`1d1`<03`L00147101]1`<05@L306d7100B1`005@L306H7100K1`<0I`L301H7
000H1`<0H0L30287101P1`<06@L001/70`1J1`<0:@L305X70`0L1`007PL305@70`0_1`<0E0L301l7
000Q1`<0CPL303D70`1>1`<08PL002@70`181`<0>`L304P70`0U1`009`L404470`111`<0@@L402P7
000[1`<0>`L304L70`0k1`<0;0L002h70`0e1`<0C@L303D70`0_1`00<@L302l70`1C1`<0;`L30387
000d1`<0:@L305T70`0Y1`<0=@L003L70`0R1`@0G`L302<70`0h1`00>PL301`70`1V1`@070L303/7
000m1`@05@L306d70`0E1`@0?PL004470`0?1`<0L`L300l70`121`00A0L300T70`1i1`<02@L304D7
00171`<00`L307l70`031`<0B0L004X70`251`<0B`L004L70`031`<0O`L300<70`181`00A0L300T7
0`1i1`<02@L304D700111`<03`L307<70`0?1`<0@PL003h70`0E1`<0K@L301D70`0o1`00>`L301/7
0`1W1`<06`L303`7000h1`<08@L306470`0Q1`<0>@L003D70`0W1`<0F`L302L70`0f1`00<PL302d7
0`1E1`<0;@L303<7000_1`<0<`L304l70`0c1`<0<0L002`70`0i1`<0B@L303T70`0]1`00:@L303l7
0P141`<0?`L302X7000V1`<0A0L303l70P151`<09`L002<70`1:1`<0>@L304X70`0T1`0080L30507
0`0c1`<0D0L30247000M1`<0EPL302d70`1F1`<07PL001X70`1L1`<09`L305`70`0K1`005`L30687
0`0Q1`<0HPL301P7000D1`<0J0L301/70`1X1`<05@L001470`1^1`<05@L306h70`0B1`003PL307@7
0`0?1`<0M0L300l7000;1`<0NPL300T70`1j1`<030L000P70`201`<00`L308070`091`001PL208H7
0`261`801`L000P70`201`<00`L308070`091`002`L307X70`091`<0NPL300`7000>1`<0M0L300l7
0`1d1`<03`L00147101]1`<05@L306d7100B1`005@L306H7100K1`<0I`L301H7000H1`<0H0L30287
101P1`<06@L001/70`1J1`<0:@L305X70`0L1`007PL305@70`0_1`<0E0L301l7000Q1`<0CPL303D7
0`1>1`<08PL002@70`181`<0>`L304P70`0U1`009`L404470`111`<0@@L402P7000[1`<0>`L304L7
0`0k1`<0;0L002h70`0e1`<0C@L303D70`0_1`00<@L302l70`1C1`<0;`L30387000d1`<0:@L305T7
0`0Y1`<0=@L003L70`0R1`@0G`L302<70`0h1`00>PL301`70`1V1`@070L303/7000m1`@05@L306d7
0`0E1`@0?PL004470`0?1`<0L`L300l70`121`00A0L300T70`1i1`<02@L304D700171`<00`L307l7
0`031`<0B0L004X70`251`<0B`L004L70`031`<0O`L300<70`181`00A0L300T70`1i1`<02@L304D7
00111`<03`L307<70`0?1`<0@PL003d7100E1`<0K@L301D7100n1`00>PL301`70`1V1`@070L303/7
000g1`<08PL405l70`0S1`<0>0L003@70`0Y1`<0F@L302T70`0e1`00<@L302l70`1C1`<0;`L30387
000^1`<0=@L304d70`0e1`<0;`L002/70`0k1`<0A`L303/70`0/1`009`L404470`111`<0@@L402P7
000T1`<0B0L303/70`181`<09@L002470`1>1`<0=@L304h70`0R1`007PL305@70`0_1`<0E0L301l7
000K1`<0FPL302T70`1J1`<070L001P70`1P1`<08PL406070`0I1`005@L306H7100K1`<0I`L301H7
000A1`@0K@L301D70`1]1`@04PL000h70`1d1`<03`L307@70`0?1`002`L307X70`091`<0NPL300`7
00081`<0P0L300<70`201`<02@L000H70P261`<0QPL200L700081`<0P0L300<70`201`<02@L000/7
0`1j1`<02@L307X70`0<1`003PL307@70`0?1`<0M0L300l7000A1`@0K@L301D70`1]1`@04PL001D7
0`1V1`@06`L306L70`0F1`0060L306070`0R1`@0H0L301T7000K1`<0FPL302T70`1J1`<070L001h7
0`1D1`<0;`L305@70`0O1`008@L304h70`0e1`<0CPL30287000T1`<0B0L303/70`181`<09@L002L7
10111`<0@@L30447100X1`00:`L303/70`171`<0>`L302`7000^1`<0=@L304d70`0e1`<0;`L00347
0`0_1`<0D`L302l70`0b1`00=0L302T70`1I1`<0:@L303D7000g1`<08PL405l70`0S1`<0>0L003X7
0`0L1`<0IPL401`70`0k1`00?@L401D70`1]1`<05@L403h700111`<03`L307<70`0?1`<0@PL004@7
0`091`<0N@L300T70`151`00A`L300<70`1o1`<00`L304P7001:1`<0Q@L304/7001=1`<0O`L304h7
001@1`<0N@L30547001C1`<0L`L305@7001F1`<0K@L305L7001I1`<0IPL405X7001L1`@0G`L305h7
001P1`<0F@L30647001S1`<0D`L306@7001V1`<0C@L306L7001Y1`<0A`L306X7001/1`<0@@L306d7
001_1`<0>`L30707001b1`<0=@L307<7001e1`<0;`L307H7001h1`<0:@L307T7001k1`<08PL407`7
001n1`@06`L3080700221`<05@L308<700251`<03`L308H700281`<02@L308T7002;1`<00`L308`7
002>1`<0S`L009470`2<1`00U0L308T7002G1`<0QPL009X70`231`00W@L30807002P1`<0O@L00:<7
0`1j1`00YPL307L7002Y1`<0M0L00:`70`1a1`00[`L206l7002a1`<0K0L00;@70`1Y1`00]`L306H7
002j1`<0H`L00;d70`1P1`00`0L305d700331`<0FPL00<H70`1G1`00b@L305@7003<1`<0D@L00<l7
0`1>1`00dPL204`7003o1b47003o1b47003o1b47003o1b47003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {326.5, 0}} -> {-8.80483, -9.66305, 0.0591969, \
0.0591969}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[185]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice52\  = 
      tiling2D[SphericalCut[N[Join[AL052, \ AL152, \ AL252, \ AL352]], 10], \ 
        rad52]\)], "Input",
  CellLabel->"In[186]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.13863 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.50006 0.0566948 0.569267 0.0566948 [
[ 0 0 0 0 ]
[ 1 1.13863 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.13863 L
0 1.13863 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .86738 m
.25314 .94189 L
s
.02381 .86738 m
.25314 .79286 L
s
.02381 .86738 m
.04133 .62323 L
s
.25314 .94189 m
.48248 1.01641 L
s
.25314 .94189 m
.48248 .86738 L
s
.25314 .94189 m
.27066 .69775 L
s
.48248 1.01641 m
.71182 1.09092 L
s
.48248 1.01641 m
.71182 .94189 L
s
.48248 1.01641 m
.5 .77227 L
s
.71182 1.09092 m
.72934 .84678 L
s
.02381 .71835 m
.25314 .79286 L
s
.02381 .71835 m
.25314 .64383 L
s
.02381 .71835 m
.04133 .4742 L
s
.25314 .79286 m
.48248 .86738 L
s
.25314 .79286 m
.48248 .71835 L
s
.25314 .79286 m
.27066 1.037 L
s
.25314 .79286 m
.27066 .54872 L
s
.48248 .86738 m
.71182 .94189 L
s
.48248 .86738 m
.71182 .79286 L
s
.48248 .86738 m
.5 1.11152 L
s
.48248 .86738 m
.5 .62323 L
s
.71182 .94189 m
.94115 .86738 L
s
.71182 .94189 m
.72934 .69775 L
s
.02381 .56931 m
.25314 .64383 L
s
.02381 .56931 m
.25314 .4948 L
s
.02381 .56931 m
.04133 .81346 L
s
.02381 .56931 m
.04133 .32517 L
s
.25314 .64383 m
.48248 .71835 L
s
.25314 .64383 m
.48248 .56931 L
s
.25314 .64383 m
.27066 .88797 L
s
.25314 .64383 m
.27066 .39969 L
s
.48248 .71835 m
.71182 .79286 L
s
.48248 .71835 m
.71182 .64383 L
s
.48248 .71835 m
.5 .96249 L
s
.48248 .71835 m
.5 .4742 L
s
.71182 .79286 m
.94115 .86738 L
s
.71182 .79286 m
.94115 .71835 L
s
.71182 .79286 m
.72934 1.037 L
s
.71182 .79286 m
.72934 .54872 L
s
.94115 .86738 m
.95867 .62323 L
s
.02381 .42028 m
.25314 .4948 L
s
.02381 .42028 m
.25314 .34577 L
s
.02381 .42028 m
.04133 .66443 L
s
.25314 .4948 m
.48248 .56931 L
s
.25314 .4948 m
.48248 .42028 L
s
.25314 .4948 m
.27066 .73894 L
s
.25314 .4948 m
.27066 .25066 L
s
.48248 .56931 m
.71182 .64383 L
s
.48248 .56931 m
.71182 .4948 L
s
.48248 .56931 m
.5 .81346 L
s
.48248 .56931 m
.5 .32517 L
s
.71182 .64383 m
.94115 .71835 L
s
.71182 .64383 m
.94115 .56931 L
s
.71182 .64383 m
.72934 .88797 L
s
.71182 .64383 m
.72934 .39969 L
s
.94115 .71835 m
.95867 .4742 L
s
.02381 .27125 m
.25314 .34577 L
s
.02381 .27125 m
.25314 .19674 L
s
.02381 .27125 m
.04133 .51539 L
s
.25314 .34577 m
.48248 .42028 L
s
.25314 .34577 m
.48248 .27125 L
s
.25314 .34577 m
.27066 .58991 L
s
.25314 .34577 m
.27066 .10163 L
s
.48248 .42028 m
.71182 .4948 L
s
.48248 .42028 m
.71182 .34577 L
s
.48248 .42028 m
.5 .66443 L
s
.48248 .42028 m
.5 .17614 L
s
.71182 .4948 m
.94115 .56931 L
s
.71182 .4948 m
.94115 .42028 L
s
.71182 .4948 m
.72934 .73894 L
s
.71182 .4948 m
.72934 .25066 L
s
.94115 .56931 m
.95867 .81346 L
s
.94115 .56931 m
.95867 .32517 L
s
.25314 .19674 m
.48248 .27125 L
s
.25314 .19674 m
.48248 .12222 L
s
.25314 .19674 m
.27066 .44088 L
s
.48248 .27125 m
.71182 .34577 L
s
.48248 .27125 m
.71182 .19674 L
s
.48248 .27125 m
.5 .51539 L
s
.48248 .27125 m
.5 .02711 L
s
.71182 .34577 m
.94115 .42028 L
s
.71182 .34577 m
.94115 .27125 L
s
.71182 .34577 m
.72934 .58991 L
s
.71182 .34577 m
.72934 .10163 L
s
.94115 .42028 m
.95867 .66443 L
s
.48248 .12222 m
.71182 .19674 L
s
.48248 .12222 m
.71182 .04771 L
s
.48248 .12222 m
.5 .36636 L
s
.71182 .19674 m
.94115 .27125 L
s
.71182 .19674 m
.72934 .44088 L
s
.94115 .27125 m
.95867 .51539 L
s
.71182 .04771 m
.72934 .29185 L
s
.27066 1.037 m
.5 1.11152 L
s
.27066 1.037 m
.5 .96249 L
s
.27066 1.037 m
.28818 .79286 L
s
.5 1.11152 m
.72934 1.037 L
s
.5 1.11152 m
.51752 .86738 L
s
.04133 .81346 m
.27066 .88797 L
s
.04133 .81346 m
.27066 .73894 L
s
.04133 .81346 m
.05885 .56931 L
s
.27066 .88797 m
.5 .96249 L
s
.27066 .88797 m
.5 .81346 L
s
.27066 .88797 m
.28818 .64383 L
s
.5 .96249 m
.72934 1.037 L
s
.5 .96249 m
.72934 .88797 L
s
.5 .96249 m
.51752 .71835 L
s
.72934 1.037 m
.74686 .79286 L
s
.04133 .66443 m
.27066 .73894 L
s
.04133 .66443 m
.27066 .58991 L
s
.04133 .66443 m
.05885 .42028 L
s
.27066 .73894 m
.5 .81346 L
s
.27066 .73894 m
.5 .66443 L
s
.27066 .73894 m
.28818 .4948 L
s
.5 .81346 m
.72934 .88797 L
s
.5 .81346 m
.72934 .73894 L
s
.5 .81346 m
.51752 .56931 L
s
.72934 .88797 m
.95867 .81346 L
s
.72934 .88797 m
.74686 .64383 L
s
.04133 .51539 m
.27066 .58991 L
s
.04133 .51539 m
.27066 .44088 L
s
.04133 .51539 m
.05885 .27125 L
s
.27066 .58991 m
.5 .66443 L
s
.27066 .58991 m
.5 .51539 L
s
.27066 .58991 m
.28818 .34577 L
s
.5 .66443 m
.72934 .73894 L
s
.5 .66443 m
.72934 .58991 L
s
.5 .66443 m
.51752 .42028 L
s
.72934 .73894 m
.95867 .81346 L
s
.72934 .73894 m
.95867 .66443 L
s
.72934 .73894 m
.74686 .4948 L
s
.95867 .81346 m
.97619 .56931 L
s
.04133 .36636 m
.27066 .44088 L
s
.04133 .36636 m
.27066 .29185 L
s
.27066 .44088 m
.5 .51539 L
s
.27066 .44088 m
.5 .36636 L
s
.27066 .44088 m
.28818 .19674 L
s
.5 .51539 m
.72934 .58991 L
s
.5 .51539 m
.72934 .44088 L
s
.5 .51539 m
.51752 .27125 L
s
.72934 .58991 m
.95867 .66443 L
s
.72934 .58991 m
.95867 .51539 L
s
.72934 .58991 m
.74686 .34577 L
s
.95867 .66443 m
.97619 .42028 L
s
.27066 .29185 m
.5 .36636 L
s
.27066 .29185 m
.5 .21733 L
s
.27066 .29185 m
.28818 .04771 L
s
.5 .36636 m
.72934 .44088 L
s
.5 .36636 m
.72934 .29185 L
s
.5 .36636 m
.51752 .12222 L
s
.72934 .44088 m
.95867 .51539 L
s
.72934 .44088 m
.95867 .36636 L
s
.72934 .44088 m
.74686 .19674 L
s
.95867 .51539 m
.97619 .27125 L
s
.27066 .14282 m
.5 .21733 L
s
.27066 .14282 m
.5 .0683 L
s
.5 .21733 m
.72934 .29185 L
s
.5 .21733 m
.72934 .14282 L
s
.72934 .29185 m
.95867 .36636 L
s
.5 .0683 m
.72934 .14282 L
s
.27066 .99581 m
.5 1.07033 L
s
.27066 .99581 m
.5 .9213 L
s
.5 1.07033 m
.72934 .99581 L
s
.04133 .77227 m
.27066 .84678 L
s
.04133 .77227 m
.27066 .69775 L
s
.27066 .84678 m
.5 .9213 L
s
.27066 .84678 m
.5 .77227 L
s
.27066 .84678 m
.28818 1.09092 L
s
.5 .9213 m
.72934 .99581 L
s
.5 .9213 m
.72934 .84678 L
s
.04133 .62323 m
.27066 .69775 L
s
.04133 .62323 m
.27066 .54872 L
s
.04133 .62323 m
.05885 .86738 L
s
.27066 .69775 m
.5 .77227 L
s
.27066 .69775 m
.5 .62323 L
s
.27066 .69775 m
.28818 .94189 L
s
.5 .77227 m
.72934 .84678 L
s
.5 .77227 m
.72934 .69775 L
s
.5 .77227 m
.51752 1.01641 L
s
.72934 .84678 m
.95867 .77227 L
s
.04133 .4742 m
.27066 .54872 L
s
.04133 .4742 m
.27066 .39969 L
s
.04133 .4742 m
.05885 .71835 L
s
.27066 .54872 m
.5 .62323 L
s
.27066 .54872 m
.5 .4742 L
s
.27066 .54872 m
.28818 .79286 L
s
.5 .62323 m
.72934 .69775 L
s
.5 .62323 m
.72934 .54872 L
s
.5 .62323 m
.51752 .86738 L
s
.72934 .69775 m
.95867 .77227 L
s
.72934 .69775 m
.95867 .62323 L
s
.72934 .69775 m
.74686 .94189 L
s
.04133 .32517 m
.27066 .39969 L
s
.04133 .32517 m
.27066 .25066 L
s
.04133 .32517 m
.05885 .56931 L
s
.27066 .39969 m
.5 .4742 L
s
.27066 .39969 m
.5 .32517 L
s
.27066 .39969 m
.28818 .64383 L
s
.5 .4742 m
.72934 .54872 L
s
.5 .4742 m
.72934 .39969 L
s
.5 .4742 m
.51752 .71835 L
s
.72934 .54872 m
.95867 .62323 L
s
.72934 .54872 m
.95867 .4742 L
s
.72934 .54872 m
.74686 .79286 L
s
.95867 .62323 m
.97619 .86738 L
s
.27066 .25066 m
.5 .32517 L
s
.27066 .25066 m
.5 .17614 L
s
.27066 .25066 m
.28818 .4948 L
s
.5 .32517 m
.72934 .39969 L
s
.5 .32517 m
.72934 .25066 L
s
.5 .32517 m
.51752 .56931 L
s
.72934 .39969 m
.95867 .4742 L
s
.72934 .39969 m
.95867 .32517 L
s
.72934 .39969 m
.74686 .64383 L
s
.95867 .4742 m
.97619 .71835 L
s
.27066 .10163 m
.5 .17614 L
s
.27066 .10163 m
.5 .02711 L
s
.27066 .10163 m
.28818 .34577 L
s
.5 .17614 m
.72934 .25066 L
s
.5 .17614 m
.72934 .10163 L
s
.5 .17614 m
.51752 .42028 L
s
.72934 .25066 m
.95867 .32517 L
s
.72934 .25066 m
.74686 .4948 L
s
.95867 .32517 m
.97619 .56931 L
s
.5 .02711 m
.72934 .10163 L
s
.5 .02711 m
.51752 .27125 L
s
.72934 .10163 m
.74686 .34577 L
s
.28818 1.09092 m
.51752 1.01641 L
s
.05885 .86738 m
.28818 .94189 L
s
.05885 .86738 m
.28818 .79286 L
s
.28818 .94189 m
.51752 1.01641 L
s
.28818 .94189 m
.51752 .86738 L
s
.51752 1.01641 m
.74686 .94189 L
s
.05885 .71835 m
.28818 .79286 L
s
.05885 .71835 m
.28818 .64383 L
s
.28818 .79286 m
.51752 .86738 L
s
.28818 .79286 m
.51752 .71835 L
s
.51752 .86738 m
.74686 .94189 L
s
.51752 .86738 m
.74686 .79286 L
s
.74686 .94189 m
.97619 .86738 L
s
.05885 .56931 m
.28818 .64383 L
s
.05885 .56931 m
.28818 .4948 L
s
.28818 .64383 m
.51752 .71835 L
s
.28818 .64383 m
.51752 .56931 L
s
.51752 .71835 m
.74686 .79286 L
s
.51752 .71835 m
.74686 .64383 L
s
.74686 .79286 m
.97619 .86738 L
s
.74686 .79286 m
.97619 .71835 L
s
.05885 .42028 m
.28818 .4948 L
s
.05885 .42028 m
.28818 .34577 L
s
.28818 .4948 m
.51752 .56931 L
s
.28818 .4948 m
.51752 .42028 L
s
.51752 .56931 m
.74686 .64383 L
s
.51752 .56931 m
.74686 .4948 L
s
.74686 .64383 m
.97619 .71835 L
s
.74686 .64383 m
.97619 .56931 L
s
.05885 .27125 m
.28818 .34577 L
s
.05885 .27125 m
.28818 .19674 L
s
.28818 .34577 m
.51752 .42028 L
s
.28818 .34577 m
.51752 .27125 L
s
.51752 .42028 m
.74686 .4948 L
s
.51752 .42028 m
.74686 .34577 L
s
.74686 .4948 m
.97619 .56931 L
s
.74686 .4948 m
.97619 .42028 L
s
.28818 .19674 m
.51752 .27125 L
s
.28818 .19674 m
.51752 .12222 L
s
.51752 .27125 m
.74686 .34577 L
s
.51752 .27125 m
.74686 .19674 L
s
.74686 .34577 m
.97619 .42028 L
s
.74686 .34577 m
.97619 .27125 L
s
.28818 .04771 m
.51752 .12222 L
s
.51752 .12222 m
.74686 .19674 L
s
.74686 .19674 m
.97619 .27125 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[186]:=",
  ImageSize->{273.812, 311.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004A0001=`P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l74PL00?l74PL00?l74PL00?l74PL00?l7
4PL00?l74PL00?l74PL008L70`271`00Q0L300031`0700<0Q0L008470`041`0300L700870`211`00
OPL300L700<01`L01@L307h7001k1`<02PL00`071`081`<0N`L007P70`0=1`0300L700/70`1h1`00
CPL202D70`0@1`0300L700h70`0U1`80CPL004h700<01`000P0O1`<04PL00`07000B1`<07`L30003
1`0704d7001>1`0300L700870`0I1`<05@L00`07000E1`<06@L300@700<01`L0C0L004h700<01`L0
1@L401870`0H1`0300L001P70`0B1`@01`L00`071`1<1`00CPL00`071`091`<030L301/700<01`00
6`L200d70`0;1`0300L704`7001>1`0300L700`70`061`<07PL301d70`071`<03PL00`071`1<1`00
CPL00`071`0?1`H07PL400031`0000807@L300041`00014700<01`L0C0L004d700<01`L040L601/7
0`031`0300L000<70`0K1`D04PL00`071`1<1`00C@L00`071`0=1`<01PL301D70`061`0300L000H7
0`0E1`<01@L300l700<01`L0C0L004d700<01`L02PL300`70`0?1`<02@L00`0700091`<03`L300/7
0`0=1`0300L704/7001=1`0300L700L70`0B1`@020L300`700<01`0030L300P7100A1`<02PL00`07
1`1;1`00C@L00`071`041`<06@L300870`0?1`0300L000l70`021`<060L300L700<01`L0B`L004d7
00@01`L70`0N1`@04@L00`07000A1`@07@L300@700<01`L0B`L004d7100N1`<010L300h700<01`00
3PL300@70`0M1`<000<700L0C0L004/70`0N1`<02PL300/700<01`002`L300X70`0M1`<0C0L004T7
0P021`0300L701T70`0@1`<01`L01@071`L000L70`0@1`8070L01007001:1`00B@L00`07000201P7
0`0F1`<010L01@071`L000@70`0E1`<060L300031`0704T700191`0400L71`@04PL301`71@031`D0
6`L301870`001@L01`L004X700191`0500L71`000`L400/70`0S1`D08PL300`70`041`0400L704X7
00191`0500L71`001`L300D70`0U1`<000@7000090L300H70`071`0400L704X700191`0400L700/7
1@0U1`<000<700L00PL00`07000202@71P0:1`0400L704X700191`0400L700X70`0010L0000Q1`<0
00<700L00`001`L0000700L00`0P1`<000@700002PL010071`1:1`00B@L200031`0700H70`071`<0
6`L300@700<01`L01@021`0300L700870`0J1`<01`L300L700<01`L00P191`00B@L200031`0700<7
0`0=1`<05@L300H71@031`D01PL301@70`0=1`<010L00`071`0204T700181`0600L01`070`0C1`<0
3`L300H70`001@L01`L000<700D01`L01`0300H70`0>1`<04`L300061`0700L0B@L004P700<01`00
0`0I1`@01`L400H70`041`0400L700<700@01`L010L300H710071`<06@L400031`0704P700181`<0
00<700L07@L300041`0000L70`071`0400L700<700@01`L01`L300L70`0010L0000N1`@0B@L004P7
00<01`000`0N1`D01@L300/700<01`000`L00`07000;1`<01@L501d710000`L01`181`00B0L01P07
00L01`<060L300D71@0>1`801@L200h71@051`<05`L300870P000`L01`181`00B0L01@0700L000@7
100A1`<01`L300041`0000d70P051`803@L300041`0000L70`0A1`<01@L200031`0704P700181`05
00L01`0020L300/70`061`@01`L300X70P051`802@L400L710061`<02`L300P70P000`L01`181`00
B0L01@0700L000/70`051`<01PL300h70`071`801@L200H70`0?1`<01PL300@7100;1`8000<700L0
B0L004P700D01`07000>1`D01PL301@710031`801@L200<70`0E1`<01PL400l70P000`L01`181`00
B0L01@0700L000d70`0010L000021`<06`L500D71@0K1`<000@700000PL300d70P000`L01`181`00
B0L01007000;1`<01PL402070`031`<07`L500H70`0:1`8000<700L0B0L004P700@01`L01`L400H7
0`041`<07@L200051`0000L00P0L1`<01@L300H710061`800PL00`071`161`00B0L010071`041`<0
1`L300X7100I1`<000<700L00`0I1`<02`L300L70`031`800PL00`071`161`00B0L01@071`0700<0
1PL401470`0C1`D00PL00`071`0501<70`0A1`@01PL5008700<01`L0APL004P700<01`000P061`<0
60L300`710031`800PL00`071`0200<70`0=1`<060L300H70`000`L01`171`00A`L300031`0700<7
0`0N1`<01PL300L70P021`0300L700801PL300L70`0N1`<00`L200041`0004L700141`@00`L00`07
000202@71P0:1`800PL00`071`0200T71`0T1`@00`L00`07000204@700111`<000<700L01P000`L0
1`0302471P0:1`800PL00`071`0200T71`0Q1`<000<700L01P000`L01`030447000n1`<010L00`07
000500031`0700<70`0K1`<01PL300L70P001@L01`0700801PL300L70`0K1`<010L00`0700050003
1`0700<70`0n1`00>`L300H710031`0300L000801PL301D70`0<1`@00`L200051`0700L00P031`<0
3@L301D70`061`D00PL00`07000200H70`0k1`00>0L300H70`0010L01`031`0500L700L00`061`<0
3`L301<71@001@L01`0700D04`L300l70`061`<000<700L00P021`0500L700L00`061`<0>0L003D7
0`061`<010L00`0700031`0400L700@70`061`<020L401T710000`L0000201T70`091`<01PL300@7
00@01`000PL010071`041`<01PL303D7000b1`<01PL300L700<01`000`L010071`071`<01PL30087
0`0M1`8000D700001`0201`70`031`<01PL300L700@01`000PL010071`071`<01PL30387000_1`<0
1PL300X700<01`000PL200031`0700X70`051`@07`L400031`0000807`L300H70`0:1`0400L00087
00<01`002`L300H70`0_1`00;0L300H70`0=1`0300L000870P000`L01`0=1`D010L301T71@001@L0
1`0700D06@L300<71P0=1`0400L0008700<01`003PL300H70`0/1`00:@L300H70`0A1`800PL01007
000=1`<000@700001PL3018710031`8000D700L01`0200<70`0C1`<01PL600h70`031`804@L300H7
0`0Y1`009PL300H70`0D1`800PL01007000:1`<01`L200L70`0<1`<01`L200051`0700L00P061`<0
3@L300H70`061`@02PL300<70P0D1`801`L302H7000S1`<01`L201L70P021`0400L000L70`0<1`<0
1`L300H70`0:1`8000D700L01`0200T710061`<01`L200d70`071`<00`L201H70`071`<08`L00207
0`071`<06@L2008700@01`000`L401870`071`H03@L200051`0700L00P0=1`H01`L301870`041`<0
0`L201T70`071`<080L001d70`071`<070L2008700<01`00100I1`<010L600d70P001@L01`070080
3@L600@70`0H1`<000@700000`L201`70`071`<07@L001X70`071`<07`L20087100O1`@01PL300X7
00D01`001`0200031`0700T70`061`@07PL400<70P0O1`<01`L301X7000G1`<01`L302871@000`L0
000M1`<00PL300L70`061`0400L700<700@01`L01PL300L70`021`<07@L500031`0002870`071`<0
5`L001@70`071`<090L300031`0000<06@L400P70`071`<00`L010071`031`0400L700<70`071`<0
20L301T71@0010L0000U1`<01`L301@7000A1`<01`L302@70`0010L01`L200031`0000<04`L300l7
0`071`@00PL01@071`L0008710071`<03PL301<70`000`L01`0200871@0U1`<01`L30147000>1`<0
1`L302@70`041`0300L7008000<700000`L300d70`0E1`<01`L400<710071`<050L300d70`041`04
00L700870P031`<09@L300L70`0>1`002`L300L70`0T1`<01`L00`071`0200031`0000H70`071`<0
6`L300@700<01`L01@021`0300L700870`0J1`<01`L300L700@01`L00PL200H70`0U1`<01`L300/7
00081`<01`L302@70`0:1`0400L700870P091`<000@700008@L300031`0700<000L700001`0700<0
80L300041`0000X700@01`L00PL200T70`0U1`<01`L300P700061`8020L202@70`0=1`0400L70087
00<01`L02@L502D70`000`L01`021`0300L0008090L600X700@01`L00PL00`071`0;1`<09@L200P7
0P061`001PL00`07000200D700<01`000P0N1`<040L00`071`0200031`0000L70`051`<07`L30003
1`0700<000L700001`0700<07PL300H70`071`0300L7008000<700003`L301l70`000`L01`041`<0
00<700L01@L000H700<01`L00PL3008700<01`L00PL301P70`0C1`0300L7008000<700000`L400/7
0`0I1`<010L00`071`05008700<01`L00PL301P70`0<1`<010L00`071`0200031`0001870`0I1`<0
10L00`071`0300@700<01`L010L000H700<01`L01@L400H70`0B1`<05PL00`07000200031`0000<0
4PL301<70`061`D00`L500H70`0B1`<04PL300031`0700<000<700005@L301<70`061`@01`L00`07
1`041`001PL00`071`071`0300L000801PL300`70`0I1`0300L000D060L300d70`061`<000D700L7
00031`0500L700L00`061`<030L301P71P000`L0000H1`<03@L300H70`000`L01`081`0300L700@7
00061`0300L700L700<01`L00PL300H710061`8070L500031`0001/70`061`@01PL300@700@01`L0
0`L010071`041`<01PL400H70P0L1`D000<700006`L300H710061`<010L00`071`071`0300L700@7
00061`0300L700L700<01`L01@L300L71P0M1`@000<700000P0N1`H01`L300L700<01`L00P000`L0
00021`0300L700D70`071`H07@L400031`0000807PL600L70`071`0300L700L700<01`L010L000L7
00<01`L01@L00`071`091`<010L601X70`001`L0000700L01@0K1`H010L300/700D01`001`020003
1`0700X70`041`H06PL300071`0000L01`0501/71P041`<02`L00`071`051`0300L700D700071`03
00L700D700<01`L030L400H70`0D1`<010L300031`0700800`L301D70`061`@03PL200051`0700L0
0P0>1`@01PL301@70`041`<000<700L00P031`<05@L300H7100>1`0300L700D700<01`L01@L000L7
00<01`L01@L00`071`0:1`<00PL300L70`0>1`<01`L300031`0700801PL300l70`071`<00PL300`7
0P001@L01`07008030L300870`071`<03PL300L70`000`L01`0200H70`0?1`<01`L300870`0<1`03
00L700D700<01`L01@L000L700<01`L01@L00`071`071`<020L400H70`081`<02PL300031`070080
2@L300T70`061`@020L300T70P001@L01`0700802@L300P710061`<020L300X70`000`L01`0200T7
0`091`<01PL400P70`091`0300L700D700<01`L01@L000L700<01`L01@L00`071`041`<03`L300H7
0`021`<03@L300031`07008030L300<70`061`<03`L300H70P001@L01`0700801PL300l70`061`<0
0PL300d70`000`L01`0200`70`031`<01PL300l70`061`0300L700D700<01`L01@L000L700<01`L0
1@L010071`L301D70`051`@03PL01`07000700L00P0?1`<01PL301D70`031`8000D700L01`0200<7
0`0E1`<01@L400h700L01`001`0700803`L300H70`0E1`<00`L00`071`051`0300L700D700071`03
00L700D7100K1`D010L300/700D01`001`0200031`0700/70`031`H06`L500051`0700L01@0K1`D0
10L300/700D01`001`0200031`0700/70`031`H06`L400L700<01`L01@L000L700<01`L00`L301d7
0`0010L000061`<020L01@07000700800PL00`071`061`<01PL601h710000`L0000201d70`0010L0
00061`<020L01@07000700800PL00`071`061`<01PL601h70`051`0300L700D700071`0400L71`80
0PL00`071`0H1`<01`L300H710041`0400L0008700@01`L010L400H70`061`<06`L200051`0000L0
0P0J1`<01`L300H710041`0400L0008700@01`L010L400H70`061`<06`L00`071`0200<700<01`L0
1@L000L700H01`L700L301P70P0=1`<01`L300031`0700800PL01@071`0700<01`L300`70`0H1`T0
60L200d70`071`<000<700L00P021`0500L700L00`071`<030L301P70`000`L01`021`0300L700D7
00071`0500L71`000`L401870`0B1`@01PL5008700<01`000P061`@04PL301871@001@L0000700D0
4PL3018710061`D00PL00`07000200H7100B1`<04PL400<700D01`L700071`001`L01@071`L000<7
00@01`L70`0<1`<06@L300@700<01`001@000`L01`031`<06@L300/710031`8000D700001`0200<7
0`0<1`<06@L300@700<01`001@000`L01`031`<06@L300/710031`0500L71`000`L00`071`051`00
1`L01@071`L000<700<01`L010L300H70`0O1`<000<700L01P000`L01`0301l70`051`<01`L20005
1`0000L00P061`<01PL301l70`000`L01`0600031`0700<07`L300D70`071`0500L71`000`L00`07
1`051`0020L010071`021`0300L700P71P0U1`@00`L00`07000202D71@0;1`0400L7008700<01`L0
20L602D710031`0300L000809@L500/700@01`L00PL00`071`061`0020L010071`021`0300L700P7
0`0010L0000Q1`<000<700L01P000`L01`0302470`0010L000091`800PL00`071`0200T70`0010L0
000Q1`<000<700L01P000`L01`0302470`0010L0000:1`0400L7008700<01`L01PL000P700L01`07
00L000L70`071`<06`L300@700<01`001@000`L01`031`<06`L300L70`061`8000D700001`0200H7
0`071`<06`L300@700<01`001@000`L01`031`<06`L300L70`071`0700L01`0700081`0020L01`07
00L01`0010L300d70`0D1`@01PL5008700<01`000P061`@050L300d70`031`8000D700001`0200<7
0`0=1`<050L400H71@021`0300L000801PL401@70`0=1`<010L01`0700L01`0020L000P700P01`07
00L01`<04`L300h70`071`<000<700L00P021`0500L700L00`071`<03PL301<71@001@L0000700D0
4`L300h70`071`<000<700L00P021`0500L700L00`071`<03PL301<70`0020L01`0700L020L000P7
00@01`07100I1`<020L300H710041`0400L0008700@01`L010L400H70`071`@06@L901T70`081`<0
1PL400@700@01`000PL010071`041`@01PL300L7100I1`@000@700L020L000P700<01`000P000`L0
1`0L1`<00PL300H70`081`0500L000L00P021`0300L700H70`061`<000@700007@L200051`0000L0
0P0L1`<00PL300H70`081`0500L000L00P021`0300L700H70`061`<000@700007PL00`0700020003
1`0700L700081`0400L01`@07PL400D70`0;1`0500L000L00P000`L01`0;1`<010L501h710000`L0
000201h710051`<02`L01@070007008000<700L02`L300@71@0N1`@000@700L020L000P700P01`07
00L01`<060L300@71@0>1`0700L000L01`0200l710051`<060L500051`0700L01@0H1`<010L500h7
00L01`001`0700803`L400D70`0H1`<000P700L01`0700P700081`0700L01`0700041`<04PL300H7
0`0010L0000>1`<000<700L00P0=1`<00PL300H70`0A1`@00`L200051`0700L00P031`<04PL300H7
0`0010L0000>1`<000<700L00P0=1`<00PL300H70`0A1`@010L01`0700L01`0020L000P700L01`07
00L000L70`0;1`@01PL300L7100:1`<000<700L00P0:1`<020L300H7100:1`<01`L200051`0700L0
0P061`<02`L400H70`071`@02PL300031`0700802PL300P70`061`@02PL300P700L01`0700L000P7
00081`0700L01`07000:1`@010L300L70`0>1`<01`L300031`0700801`L300h70`071`<010L300X7
0P001@L01`0700802@L400@70`071`<03PL300L70`000`L01`0200L70`0>1`<01`L300@70`0;1`07
00L01`0700081`0020L01`0700L01`003PL400L70`0D1`<010L300031`0700800`L401@70`071`@0
3@L200051`0700L00P0=1`@01`L301@70`041`<000<700L00P031`@050L300L7100>1`0700L01`07
00081`0020L01`0700L01`0030L300870`021`<06PL300071`0000L01`0501/70`021`<00PL300/7
0P001@L01`0700802`L300870`021`<06PL300071`0000L01`0501/70`021`<00PL300`700L01`07
00L000P700091`8000<700002PL300L7100O1`@000<700000P0P1`@01`L300L700<01`L00P000`L0
00021`0300L700D70`071`@07`L400031`00008080L400L70`0:1`8000<700002@L000T700D01`L7
00071`<01PL400@70`0M1`D000<700007@L300@710061`<010L010071`031`0400L700@70`061`@0
10L301d71@000`L0000M1`<010L400H70`071`0500L71`002@L000T700D01`L700041`<01PL300/7
0`0I1`T06@L400/70`061`<000D700L700031`0500L700L00`061`<02`L301T72@0I1`@02`L300H7
0`041`0500L71`002@L000T700@01`L71@061`<04@L301<70`000`L01`0300031`0000<04`L30187
0`061`D00`L500H70`0A1`<04`L300031`0700<000<700000`0C1`<04PL300H71@031`0300L700L7
00091`0300L000801`L301L70`0=1`<010L00`071`0200031`0000<7100<1`<060L300@700<01`L0
1@021`0300L700870`0G1`<03@L300@700<01`L00P000`L000031`@030L301P70`071`<000<700L0
20L000P70`021`0300L700870`0M1`<01`L300L700<01`L00P000`L000071`<01PL301h70`000`L0
1`0300071`0000L01`0301d70`071`<01`L00`071`0200031`0000L70`061`<07PL300@700<01`L0
0`081`001PL200031`07008700<01`L00P0S1`L02PL010071`021`802PL602@70`000`L01`021`03
00L000808`L700X700@01`L00PL200X71P0T1`800PL01P071`L01`801PL000H700<01`000P021`05
00L700L00`0P1`L02PL010071`021`802PL602470`000`L01`0300071`0000L01`0302071`0:1`04
00L700870P0:1`H08@L300051`071`000PL300031`0700D700061`0500L700L00`021`0300L70087
0`0J1`<01`L300L700<01`L00P000`L000071`<01PL301/70`041`0300L700D00PL00`071`021`<0
6PL300L70`071`0300L7008000<700001`L300H70`0K1`<010L00`071`0300051`071`001PL000H7
00@01`L00`L400L70`0D1`<03@L300@700<01`L00P000`L000031`@030L301D70`071`@00`L400L7
0`0D1`<03@L300@700<01`L00P000`L000031`@030L301D70`071`@00`L010071`061`001PL01007
1`031`0300L700@01`L300h70`0C1`<000<700L00`000`L0000301<70`0?1`<01`L4008700D01`L7
00021`@01`L300h70`0C1`<000<700L00`000`L0000301<70`0?1`<01`L4008700D01`L700021`03
00L700@700061`0400L700<700@01`L00`L300L70`081`<06@L901T710081`<01`L300<700@01`L0
0`L010071`031`<01`L300P70`0I1`T06@L400P70`071`<00`L010071`031`0400L700H700061`04
00L700<700@01`L01PL300L70`021`<07@L500031`0001d70`021`<01`L300H700@01`L00`L01007
1`061`<01`L300870`0M1`D000<700007@L300870`071`<01PL010071`031`0400L700H700071`05
00L000L00P000`L01`091`<01PL401h710000`L0000201l710061`<02PL01@070007008000<700L0
2@L300H7100N1`@000<700000P0O1`@01PL300X700D01`001`0200031`0700H700071`0500L000L0
0P000`L01`0<1`H010L301P70`001`L0000700L01@0I1`<010L600d700D01`001`0200031`0700`7
1P041`<060L300071`0000L01`0501T70`041`H03@L01@070007008000<700L01PL000L70P001@L0
1`0700803@L600L70`0B1`<010L300031`0700800`L401870`071`H03@L200051`0700L00P0=1`H0
1`L301870`041`<000<700L00P031`@04PL300L71P0=1`8000D700L01`0200L700071`8000D700L0
1`0200T710061`<01`L200d70`071`<000<700L00P071`<030L300L70`061`<02PL200051`0700L0
0P091`@01PL300L70P0=1`<01`L300031`0700801`L300`70`071`<01PL300X70P001@L01`070080
1`L000L70P001@L01`0700801PL300d70`061`<01PL400X70`000`L01`0200X70`071`801`L300`7
0`071`8000D700L01`0200H70`0=1`<01PL300H7100:1`<000<700L00P0:1`<01`L200L70`0<1`<0
1`L200051`0700L00P071`001`L200051`0700L00P031`<04`L300H71P0>1`<000<700L00P0=1`<0
00@700001PL3018710031`8000D700L01`0200<70`0C1`<01PL600h70`000`L01`0200d70`0010L0
00061`<04PL400<70P001@L01`0700801`L000L70P001@L01`0700D06@L300<71P0=1`0700L000L0
1`0200h71@041`<06@L500051`0700L01@0I1`<00`L600d700L01`001`0700803PL500@70`0I1`D0
00D700L01`0200L700071`8000<700L0100O1`<01PL300X700D01`001`0200031`0700X70`051`@0
7`L400031`0000807`L300H70`0:1`0500L000L00P000`L01`0:1`<01@L401l710000`L01`0200L7
00071`8000D700001`0201`70`031`<01PL300L700@01`000PL010071`071`<01PL300870`0M1`80
00D700001`0201`70`031`<01PL300L700@01`000PL010071`071`<01PL300870`0M1`8000D70000
1`0200L700071`8000<70000100I1`<02@L300H70`041`0400L0008700@01`L010L300H70`081`@0
6@L901T70`091`<01PL300@700@01`000PL010071`041`<01PL300P7100I1`H000<700001`L000L7
0P001@L0000700D04`L300l70`061`<000<700L00P021`0500L700L00`061`<03`L301<71@001@L0
000700D04`L300l70`061`<000<700L00P021`0500L700L00`061`<03`L301<71@001@L000070080
1`L000L70P001@L0000700800`L300d70`0E1`<01PL5008700<01`000P061`<05@L300d70`031`80
00D700001`0200<70`0=1`<05@L300H71@021`0300L000801PL301D70`0=1`<00`L200051`0000L0
0P071`001`L200051`0000L00P061`<01`L301/70`041`0300L000D000<700L00`L301/70`071`<0
1PL200051`0000L00P061`<01`L301/70`041`0300L000D000<700L00`L301/70`071`<01PL20005
1`0000L00P071`001`L2008700<01`L00P091`<000@700008@L300031`0700H000<700L00`0Q1`<0
00@700002@L2008700<01`L00P091`<000@700008@L300031`0700H000<700L00`0Q1`<000@70000
2@L2008700<01`L00P071`0020L010071`021`0300L700P71P0U1`@00`L00`07000202D71@0;1`04
00L7008700<01`L020L602D710031`0300L000809@L500/700@01`L00PL00`071`061`001`L20005
1`0000L00P061`<01PL301l70`000`L01`0600031`0700<07`L300D70`071`8000D700001`0200H7
0`061`<07`L300031`0700H000<700L00`0O1`<01@L300L70P001@L0000700801`L000L70P001@L0
000700800`L300`70`0I1`<010L00`07000500031`0700<70`0I1`<02`L400<70P001@L000070080
0`L300`70`0I1`<010L00`07000500031`0700<70`0I1`<02`L400<70P001@L0000700801`L000L7
0P001@L0000700D04PL3018710061`D00PL00`07000200H7100B1`<04PL500051`0000L01@0B1`<0
4PL400H71@021`0300L000801PL401870`0B1`D000D700001`0200L700071`8000<70000100H1`80
3@L300L70`000`L01`02008700D01`L01`0300L70`0<1`<060L901P70P0=1`<01`L300031`070080
0PL01@071`0700<01`L300`70`0H1`H000<700001`L000L70P001@L0000700806PL300L70`061`@0
10L0100700021`0400L700@710061`<01PL301/70P001@L0000700806PL300L70`061`@010L01007
00021`0400L700@710061`<01PL301/70P001@L0000700801`L000L70P000`L01`0401d70`0010L0
00061`<020L01@07000700800PL00`071`061`<01PL601h710000`L0000201d70`0010L000061`<0
20L01@07000700800PL00`071`061`<01PL601h710000`L01`0200L700071`8000D700L01`0501/7
1@041`<02`L01@070007008000<700L02`L300<71P0K1`D000D700L01`0501/71@041`<02`L01@07
0007008000<700L02`L300<71P0K1`D000D700L01`0200L700071`8000D700L01`0200<70`0E1`<0
1@L400h700L01`001`0700803`L300H70`0E1`<00`L200051`0700L00P031`<05@L300D7100>1`07
00L000L01`0200l70`061`<05@L300<70P001@L01`0700801`L000L70P001@L01`0700801PL300l7
0`061`<00PL300d70`000`L01`0200`70`031`<01PL300l70`061`8000D700L01`0200H70`0?1`<0
1PL300870`0=1`<000<700L00P0<1`<00`L300H70`0?1`<01PL200051`0700L00P071`001`L20005
1`0700L00P091`<020L400H70`081`<02PL300031`0700802@L300T70`061`@020L300T70P001@L0
1`0700802@L300P710061`<020L300X70`000`L01`0200T70`091`<01PL400P70`091`8000D700L0
1`0200L700071`8000D700L01`0200`70`021`<01`L300h70`071`<000<700L00P061`<03`L300L7
0`021`<030L200051`0700L00P0<1`<00PL300L70`0>1`<01`L300031`0700801PL300l70`071`<0
0PL300`70P001@L01`0700801`L000L70P001@L01`0700803PL400H70`0D1`<010L300031`070080
0`L301D70`061`@03PL200051`0700L00P0>1`@01PL301@70`041`<000<700L00P031`<05@L300H7
100>1`8000D700L01`0200L700071`0500L000L00P000`L01`0:1`<010L601X70`001`L0000700L0
1@0K1`H010L300/700D01`001`0200031`0700X70`041`H06PL300071`0000L01`0501/71P041`<0
2`L01@070007008000<700L01PL000H700<01`L00P000`L000021`0300L700D70`071`H07@L40003
1`0000807PL600L70`071`0300L7008000<700000PL00`071`051`<01`L601d710000`L0000201h7
1P071`<01`L00`071`0200031`00008700<01`L010L000H700@01`L00`L010071`041`<01PL400H7
0P0L1`D000<700006`L300H710061`<010L010071`031`0400L700@70`061`@01PL201`71@000`L0
000K1`<01PL400H70`041`0400L700<700@01`L01PL000H700@01`L00`L01@071`0700<01PL300`7
0`0H1`T060L300d70`061`<000D700L700031`0500L700L00`061`<030L301P72@0H1`<03@L300H7
0`001@L01`L000<700@01`L01PL000H700@01`L00`L500H70`0B1`<04PL300031`0700<000<70000
0`0B1`<04`L300H71@031`D01PL301870`0B1`<000<700L00`000`L0000301870`0C1`<01PL500<7
00@01`L01PL000H700D01`L01`03008700<01`L00PL301P70`0<1`<010L00`071`0200031`0000<7
100;1`<06@L300@700<01`L01@021`0300L700870`0H1`<030L300@700<01`L00P000`L000031`@0
2`L301T70`041`0300L700<000D700L700061`001PL00`070002008700D01`L01`0301h70`061`<0
1`L00`071`0200031`0000L70`051`<07`L300031`0700<000L700001`0700<07PL300H70`071`03
00L7008000<700001`L300D70`0O1`<000D700L700021`<000<700L01@L000H70P000`L01`021`03
00L7008090L600X700@01`L00PL00`071`091`D09@L300031`07008700<01`000P0T1`H02PL01007
1`021`0300L700T71@0U1`800PL01P071`L01`801PL000H700<01`000P021`0500L700L00`0P1`<0
00@700002PL010071`021`802@L300041`0002470`000`L01`0300071`0000L01`0302070`0010L0
000:1`0400L700870P091`<000@700008@L300051`071`000PL300031`0700D700061`0500L700L0
0`021`0300L700870`0J1`<01`L300L700<01`L00P000`L000061`<01`L301/70`041`0300L700D0
0PL00`071`021`<06PL300L70`071`0300L7008000<700001PL300L70`0K1`<010L00`071`030005
1`071`001PL000H700@01`L00`L500H70`0D1`<03@L300@700<01`L00P000`L000031`<03@L301D7
0`061`D00`L500H70`0D1`<03@L300@700<01`L00P000`L000031`<03@L301D70`061`D00`L01007
1`061`001PL010071`031`0500L700L00`061`<03PL301<70`000`L01`0300031`0000<04`L300l7
0`061`<000D700L700031`0500L700L00`061`<03PL301<70`000`L01`0300031`0000<04`L300l7
0`061`<000D700L700031`0400L700H700061`0400L700<700@01`L010L300H710071`<06@L901T7
10071`@01PL300@700@01`L00`L010071`041`<01PL400L70`0I1`T06@L400L710061`<010L01007
1`031`0400L700H700061`0300L7008000<700000PL00`071`051`<01`L300041`0001d71@000`L0
000M1`<000@700001`L300L700<01`L00P000`L000021`0300L700D70`071`<000@700007@L50003
1`0001d70`0010L000071`<01`L00`071`0200031`00008700<01`L010L000L700D01`001`020003
1`0700X70`051`D07@L400031`0000807PL500D70`0;1`0500L000L00P000`L01`0:1`<01@L501d7
10000`L0000201h71@051`<02`L01@070007008000<700L01PL000L70P001@L01`0700803PL500D7
0`0G1`<000L700001`0700D060L300D71@0>1`8000D700L01`0200h71@051`<05`L300071`0000L0
1`0501P70`051`D03PL200051`0700L00P071`001`L200051`0700L00P0=1`<000@700001`L30147
0`041`<000<700L00P031`@04@L300L70`0010L0000=1`8000D700L01`0200d70`0010L000071`<0
4@L300@70`000`L01`0200<7100A1`<01`L300041`0000d70P001@L01`0700801`L000L70P001@L0
1`0700802@L400L710061`<02`L300L70`000`L01`0200L70`0;1`<01PL400L70`0:1`8000D700L0
1`0200T710071`@01PL300/70`071`<000<700L00P071`<02`L300H710071`<02PL200051`0700L0
0P071`001`L200051`0700L00P061`<03`L300H70`041`@02PL300031`0700802PL300D70`061`<0
3PL300L70P001@L01`0700801PL300l70`061`<010L400X70`000`L01`0200X70`051`<01PL300h7
0`071`8000D700L01`0200L700071`8000D700L01`0200<70`0E1`<01PL400d700L01`001`070080
3@L500H70`0D1`@00`L200051`0700L00P031`<05@L300H7100=1`0700L000L01`0200d71@061`<0
50L400<70P001@L01`0700801`L000L70P001@L01`0700D06`L300041`0000870`0;1`0700L000L0
1`0200`70`0010L000021`<06`L500051`0700L01@0K1`<000@700000PL300/700L01`001`070080
30L300041`0000870`0K1`D000D700L01`0200L700071`8000<700L0100O1`D01PL300P700D01`00
1`02008700<01`L01PL300H7100P1`@000<700000P0O1`D01PL300P700D01`001`02008700<01`L0
1PL300H7100P1`@000<700L00P071`001`L200051`0000L00P0L1`<01@L300H710041`0400L00087
00@01`L010L400H70`041`<07@L200051`0000L00P0L1`<01@L300H710041`0400L0008700@01`L0
10L400H70`041`<07@L200051`0000L00P071`001`L200031`0000@06@L300/70`071`<000<700L0
0P021`0500L700L00`071`<02PL401T72@0I1`<02`L300L70`000`L01`02008700D01`L01`0300L7
0`0:1`@06@L600031`0000L700071`8000D700001`0501<70`0A1`@01PL5008700<01`000P061`@0
4@L301<71@001@L0000700D04`L3014710061`D00PL00`07000200H7100A1`<04`L500051`0000L0
0P071`001`L200051`0000L00P031`<03@L301P70`041`0300L000D000<700L00`L301P70`0<1`@0
0`L200051`0000L00P031`<03@L301P70`041`0300L000D000<700L00`L301P70`0<1`@00`L20005
1`0000L00P071`001`L200051`0000L00P061`<01`L301h70`000`L01`0600031`0700<07PL300H7
0`071`8000D700001`0200H70`071`<07PL300031`0700H000<700L00`0N1`<01PL300L70P001@L0
000700801`L000L70P021`0300L700802@L702@710031`0300L0008090L600X70P021`0300L70080
2@L702@710031`0300L0008090L600X70P021`0300L700801`L000L70P021`0300L700802@L70247
0`000`L01`0600031`0700<08@L600X70P021`0300L700802@L702470`000`L01`0600031`0700<0
8@L600X70P021`0300L700801`L000L70P001@L0000700801PL300L70`0K1`<010L00`0700050003
1`0700<70`0K1`<01PL300L70P001@L0000700801PL300L70`0K1`<010L00`07000500031`0700<7
0`0K1`<01PL300L70P001@L0000700801`L000L70P001@L0000700800`L300d70`0E1`<01PL50087
00<01`000P061`<05@L300`710031`8000D700001`0200<70`0=1`<05@L300H71@021`0300L00080
1PL301D70`0<1`@00`L200051`0000L00P071`001`L200051`0000L01@0C1`<03`L300H70`000`L0
1`02008700D01`L01`0300H70`0?1`<04`L500051`0000L01@0C1`<03`L300H70`000`L01`020087
00D01`L01`0300H70`0?1`<04`L500051`0000L00P071`001`L200031`0000@06@L300T70`061`<0
10L0100700021`0400L700@70`061`<020L401T72@0I1`<02@L300H70`041`0400L0008700@01`L0
10L300H70`081`@06@L600031`0000L700071`8000D700001`0201`70`031`<01PL300L700@01`00
0PL010071`071`<01PL300870`0M1`8000D700001`0201`70`031`<01PL300L700@01`000PL01007
1`071`<01PL300870`0M1`8000D700001`0200L700071`8000<700L0100O1`<01PL300X700D01`00
1`0200031`0700X70`051`@07`L400031`0000807`L300H70`0:1`0500L000L00P000`L01`0:1`<0
1@L401l710000`L01`0200L700071`8000D700L01`0501T70`031`H03@L01@070007008000<700L0
3@L500@70`0I1`D000D700L01`0501T70`031`H03@L01@070007008000<700L03@L500@70`0I1`D0
00D700L01`0200L700071`8000D700L01`0200<70`0C1`<01PL600h70`000`L01`0200d70`0010L0
00061`<04PL400<70P001@L01`0700800`L301<70`061`H03PL300031`0700803@L300041`0000H7
0`0B1`@00`L200051`0700L00P071`001`L200051`0700L00P061`<03@L300H70`061`@02PL30003
1`0700802PL300L70P071`<030L300L70P001@L01`0700801PL300d70`061`<01PL400X70`000`L0
1`0200X70`071`801`L300`70`071`8000D700L01`0200L700071`8000D700L01`0200T710061`<0
1`L200d70`071`<000<700L00P071`<030L300L70`061`<02PL200051`0700L00P091`@01PL300L7
0P0=1`<01`L300031`0700801`L300`70`071`<01PL300X70P001@L01`0700801`L000L70P001@L0
1`0700803@L600L70`0B1`<010L300031`0700800`L401870`071`H03@L200051`0700L00P0=1`H0
1`L301870`041`<000<700L00P031`@04PL300L71P0=1`8000D700L01`0200L700071`8000D700L0
1`0200d71P041`<060L300071`0000L01`0501T70`041`H03@L200051`0700L00P0=1`H010L301P7
0`001`L0000700L01@0I1`<010L600d70P001@L01`0700801`L000L700D01`001`0200031`0700T7
0`061`@07PL400031`0000807`L400H70`0:1`0500L000L00P000`L01`091`<01PL401h710000`L0
000201l710061`<02PL01@070007008000<700L01PL000H700@01`L00`L010071`061`<01`L30087
0`0M1`D000<700007@L300870`071`<01PL010071`031`0400L700H70`071`<00PL301d71@000`L0
000M1`<00PL300L70`061`0400L700<700@01`L01PL000H700@01`L00`L010071`031`<01`L300P7
0`0I1`T06@L400P70`071`<00`L010071`031`0400L700<70`071`<020L301T72@0I1`@020L300L7
0`031`0400L700<700@01`L01PL000H700@01`L00`L00`071`0400L70`0>1`<04`L300031`0700<0
00<700000`0C1`<03`L300L710021`0500L71`000PL400L70`0>1`<04`L300031`0700<000<70000
0`0C1`<03`L300L710021`0500L71`000PL00`071`041`001PL010071`031`@01`L301@70`0=1`<0
10L00`071`0200031`0000<7100<1`<05@L300L710031`@01`L301@70`0=1`<010L00`071`020003
1`0000<7100<1`<05@L300L710031`0400L700H700061`0500L700L00`021`0300L700870`0J1`<0
1`L300L700<01`L00P000`L000071`<01PL301/70`041`0300L700D00PL00`071`021`<06PL300L7
0`071`0300L7008000<700001`L300H70`0K1`<010L00`071`0300051`071`001PL000H700<01`00
0P021`0500L700L00`0P1`L02PL010071`021`802PL602470`000`L01`0300071`0000L01`030207
1`0:1`0400L700870P0:1`H08@L300051`071`000PL300031`0700D700061`8000<700L00PL00`07
1`0202<71`0:1`0400L7008700<01`L02@L602@70`000`L01`021`0300L000808`L700X700@01`L0
0PL00`071`091`H090L2008700H01`L700L200H700081`<00PL00`071`021`<07@L300L70`071`03
00L7008000<700001`L300H70`0N1`<000<700L00`001`L0000700L00`0M1`<01`L300L700<01`L0
0P000`L000071`<01PL301h70`041`0300L700<020L000T700<01`000P071`<05`L300d70`041`03
00L7008000<700000`L400`70`0H1`<010L00`071`05008700<01`L00PL301L70`0=1`<010L00`07
1`0200031`0000<7100<1`<060L300L70`000`L01`081`002@L010071`L500H70`0A1`<04`L30003
1`0700<000<700000`0C1`<04PL300H71@031`D01PL301470`0C1`<000<700L00`000`L0000301<7
0`0B1`<01PL500<700<01`L01`L000T700D01`L700041`<01PL300/70`0I1`T06@L400/70`061`<0
00D700L700031`0500L700L00`061`<02`L301T72@0I1`@02`L300H70`041`0500L71`002@L000T7
00D01`L700071`<01PL400@70`0M1`D000<700007@L300@710061`<010L010071`031`0400L700@7
0`061`@010L301d71@000`L0000M1`<010L400H70`071`0500L71`002@L000T70P000`L0000:1`<0
1`L401l710000`L00002020710071`<01`L00`071`0200031`00008700<01`L01@L300L7100O1`@0
00<700000P0P1`@01`L300X70P000`L000091`002@L200031`0000d70`021`<00PL301X70`001`L0
000700L01@0K1`<00PL300870`0;1`0500L000L00P000`L01`0:1`<00PL300870`0J1`<000L70000
1`0700D06`L300870`021`<03@L200031`0000T700081`0700L01`07000>1`@01`L301@70`041`<0
00<700L00P031`<05@L300L7100=1`8000D700L01`0200d710071`<050L300@70`000`L01`0200<7
0`0E1`<01`L400h700L01`0700L000P700081`0700L01`07000:1`@010L300L70`0>1`<01`L30003
1`0700801PL300l70`071`<010L300X70P001@L01`0700802@L400@70`071`<03PL300L70`000`L0
1`0200H70`0?1`<01`L300@70`0;1`0700L01`0700081`0020L01`0700L01`001`L300/710061`<0
20L300X70`000`L01`0200T70`091`<01PL400X70`071`8000D700L01`0200H70`0;1`@01PL300P7
0`0:1`<000<700L00P091`<02@L300H7100:1`<020L01`0700L01`0020L000P700L01`0700L000@7
0`0B1`<01PL300870`0=1`<000<700L00P0<1`<00`L300H70`0A1`@00`L200051`0700L00P031`<0
4PL300H70`021`<03@L300031`07008030L300<70`061`<04@L400@700L01`0700L000P700081`08
00L01`0700L301P70`051`@03PL01`07000700L00P0?1`<01PL301P71@001@L01`0700D060L300D7
100>1`0700L000L01`0200l70`061`<060L300081`0700L01`081`0020L0100700L401h71@041`<0
2`L01@070007008000<700L02`L300<71P0N1`@000<700000P0N1`D010L300/700D01`001`020003
1`0700/70`031`H07PL400041`0700P700081`0300L0008000<700L07@L300041`0000H70`081`05
00L000L00P021`0300L700H70`061`H07PL200051`0000L00P0M1`<000@700001PL300P700D01`00
1`02008700<01`L01PL300H71P0O1`0300L0008000<700L01`L000P700@01`07100J1`<01`L300H7
10041`0400L0008700@01`L010L400H70`061`<06`L901X70`071`<01PL400@700@01`000PL01007
1`041`@01PL300H70`0K1`@000@700L020L000P700P01`0700L01`<05@L200d70`071`<000<700L0
0P021`0500L700L00`071`<030L301D71@001@L0000700D05@L200d70`071`<000<700L00P021`05
00L700L00`071`<030L301D70`0020L01`0700L020L000P700L01`0700L000@70`0?1`<04PL400H7
1@021`0300L000801PL401870`0?1`<00`L200051`0000L00P031`<03`L3018710061`D00PL00`07
000200H7100B1`<03`L300@700L01`0700L000P700081`0700L01`0700071`<02@L301T70`041`03
00L000D000<700L00`L301T70`091`<01PL200051`0000L00P061`<02@L301T70`041`0300L000D0
00<700L00`L301T70`091`<01`L01`0700L01`0020L000P700L01`0700L000X70`031`<07`L30003
1`0700H000<700L00`0O1`<00`L300T70P001@L0000700802@L300<70`0O1`<000<700L01P000`L0
1`0301l70`031`<02PL01`0700L01`0020L000P700@01`L00PL00`071`0;1`<09@L400<700<01`00
0P0U1`<03@L010071`021`0300L700/70`0U1`@00`L00`07000202D70`0=1`0400L7008700<01`L0
1PL000L700D01`L700031`0300L700L70`031`<07`L300031`0700H000<700L00`0O1`<00`L300T7
0P001@L0000700802@L300<70`0O1`<000<700L01P000`L01`0301l70`031`<02@L01@071`L000<7
00<01`L01@L000L700D01`L700031`0300L700@70`091`<06@L300@700<01`001@000`L01`031`<0
6@L300T70`061`8000D700001`0200H70`091`<06@L300@700<01`001@000`L01`031`<06@L300T7
0`061`0500L71`000`L00`071`051`001`L01@071`L000<700@01`L70`0?1`<04PL400H71@021`03
00L000801PL401870`0?1`<00`L200051`0000L00P031`<03`L3018710061`D00PL00`07000200H7
100B1`<03`L300<700D01`L700031`0300L700D700071`0500L71`000`L401D70P0=1`<01`L30003
1`0700800PL01@071`0700<01`L300`70`0E1`D000D700001`0501D70P0=1`<01`L300031`070080
0PL01@071`0700<01`L300`70`0E1`@00`L01@071`L000L700071`0600L71`070`0J1`<01`L300H7
10041`0400L0008700@01`L010L400H70`061`<06`L901X70`071`<01PL400@700@01`000PL01007
1`041`@01PL300H70`0K1`<000<700L00PL00`071`051`001`L010071`L2008700<01`L06`L30004
1`0000H70`081`0500L000L00P021`0300L700H70`061`H07PL200051`0000L00P0M1`<000@70000
1PL300P700D01`001`02008700<01`L01PL300H71P0N1`0300L700800`L00`071`051`001`L00`07
1`031`<07PL500@70`0;1`0500L000L00P000`L01`0;1`<00`L601h710000`L0000201h71@041`<0
2`L01@070007008000<700L02`L300<71P0N1`<01@L00`071`051`001`L00`071`051`@060L300D7
100>1`0700L000L01`0200l70`061`<060L500051`0700L01@0H1`<01@L400h700L01`001`070080
3`L300H70`0H1`@01`L00`071`051`001`L00`071`051`0400L71`<04PL300H70`021`<03@L30003
1`07008030L300<70`061`<04@L400<70P001@L01`0700800`L301870`061`<00PL300d70`000`L0
1`0200`70`031`<01PL3014710031`0300L700D700<01`L01@L000L700<01`L01@L00`071`041`<0
2`L400H70`081`<02PL300031`0700802@L300T70`061`@02PL300L70P001@L01`0700801PL300/7
10061`<020L300X70`000`L01`0200T70`091`<01PL400X70`071`0300L700D700<01`L01@L000L7
00<01`L01@L00`071`071`@010L300L70`0>1`<01`L300031`0700801PL300l70`071`<010L300X7
0P001@L01`0700802@L400@70`071`<03PL300L70`000`L01`0200H70`0?1`<01`L300@70`0:1`03
00L700D700<01`L01@L000L700<01`L01@L00`071`0;1`@01`L301@70`041`<000<700L00P031`<0
5@L300L7100=1`8000D700L01`0200d710071`<050L300@70`000`L01`0200<70`0E1`<01`L400d7
00<01`L01@L00`071`051`001`L00`071`051`0300L700T70`021`<00PL301X70`001`L0000700L0
1@0K1`<00PL300870`0;1`8000D700L01`0200/70`021`<00PL301X70`001`L0000700L01@0K1`<0
0PL300870`0;1`0300L700D700<01`L01@L000H700<01`L01`L00`071`051`<01`L401l710000`L0
0002020710071`<01`L00`071`0200031`00008700<01`L01@L300L7100O1`@000<700000P0P1`@0
1`L300L700<01`L01`L00`071`041`001PL00`071`071`0300L700870`061`@010L301d71@000`L0
000M1`<010L400H70`041`0400L700<700@01`L010L300H710041`<07@L500031`0001d70`041`@0
1PL300@700<01`L01`L00`071`041`001PL00`071`071`0300L000801PL300/70`0J1`0300L000D0
6@L400/70`061`<000D700L700031`0500L700L00`061`<02`L301T71P000`L0000I1`@02`L300H7
0`000`L01`081`0300L700@700061`0300L700D710061`<04@L301L700<01`000P000`L0000301<7
0`0B1`<01PL500<71@061`<04@L301<70`000`L01`0300031`0001H70`0B1`<01PL400L700<01`L0
10L000H700<01`L00PL3008700<01`L00PL301L70`0D1`0300L7008000<700000`L400`70`0H1`<0
10L00`071`05008700<01`L00PL301L70`0=1`<010L00`071`0200031`0001<70`0H1`<010L00`07
1`0300@700<01`L010L000H700<01`000P051`0300L000807@L3014700<01`L00P000`L000071`<0
1PL301h70`000`L01`0300071`0000L01`0301d70`071`<01`L00`071`0200031`0001070`0N1`<0
00<700L010L300031`0700D700061`8020L202<70`0>1`0400L700870P0:1`H090L300031`070087
00<01`000P0S1`L02PL010071`021`803@L302@70P081`801PL000P70`071`<08`L400X700@01`L0
0PL200X71P0Q1`<000<700L00`001`L0000700L00`0P1`L02PL010071`021`802PL302@70`071`<0
20L000/70`071`<090L300L700<01`L00P000`L000071`<01PL301/70`041`0300L700D00PL00`07
1`021`<06PL300L70`071`0400L700870P071`<090L300L70`0;1`003PL300L70`0T1`<010L00`07
1`0200031`0000<7100<1`<05@L300L710031`@01`L301@70`0=1`<010L010071`021`800`L402@7
0`071`<03PL001470`071`<090L300041`071`8000<700000`0C1`<03`L300L710021`0500L71`00
0PL400L70`0>1`<04`L300031`0700800PL502D70`071`<04@L001@70`071`<090L300031`0000<0
6@L400P70`071`<00`L010071`031`0400L700<70`071`<020L301T71@0010L0000U1`<01`L301@7
000G1`<01`L302871@000`L0000M1`<00PL300L70`061`0400L700<700@01`L01PL300L70`021`<0
7@L500031`0002870`071`<05`L001X70`071`<07`L20087100O1`@01PL300X700D01`001`020003
1`0700T70`061`@07PL400<70P0O1`<01`L301X7000M1`<01`L301`70P021`0300L000@06@L300@7
1P0=1`8000D700L01`0200d71P041`<060L300041`0000<70P0L1`<01`L301d7000P1`<01`L301T7
0P021`0400L000<7100B1`<01`L600d70P001@L01`0700803@L600L70`0B1`<010L300<70P0I1`<0
1`L30207000S1`<01`L201L70P021`0400L000L70`0<1`<01`L300H70`0:1`8000D700L01`0200T7
10061`<01`L200d70`071`<00`L201H70`071`<08`L002H70`061`<050L2008700@01`002PL300L7
0P071`<030L300L70P001@L01`0700801PL300d70`061`<01PL400X70`031`8050L200L70`0V1`00
:@L300H70`0A1`800PL01007000=1`<000@700001PL3018710031`8000D700L01`0200<70`0C1`<0
1PL600h70`031`804@L300H70`0Y1`00;0L300H70`0=1`0300L0008700@01`003PL500@70`0I1`D0
00D700L01`0501T70`031`H03@L0100700031`803PL300H70`0/1`00;`L300H70`0:1`0300L00087
0P000`L01`0:1`<01@L401l710000`L0000201l70`061`<02PL0100700021`0300L000/70`061`<0
;`L003870`061`<01`L00`0700031`0400L700L70`061`<00PL301d70P001@L00007008070L300<7
0`061`<01`L0100700021`0400L700L70`061`<0<PL003D70`061`<010L00`0700031`0400L700@7
0`061`<020L401T710000`L0000201T70`091`<01PL300@700@01`000PL010071`041`<01PL303D7
000h1`<01PL300041`0700<700D01`L01`0300H70`0?1`<04`L500051`0700L01@0C1`<03`L300H7
0`000`L01`02008700D01`L01`0300H70`0h1`00>`L300H710031`0300L000801PL301D70`0<1`@0
0`L200051`0700L00P031`<03@L301D70`061`D00PL00`07000200H70`0k1`00?PL300@700<01`00
1@000`L01`031`<06`L300H70`071`8000D700L01`0200H70`071`<06`L300@700<01`001@000`L0
1`031`<0?PL004470`000`L01`0600031`0700<08@L600X70P021`0300L700802@L702470`000`L0
1`0600031`0700<0@@L004@710031`0300L0008090L600X70P021`0300L700802@L702@710031`03
00L00080A0L004L70`000`L01`031`<07PL300H70`071`800PL00`071`0200H70`071`<07PL300<7
0P0010L000171`00B0L00`07000200H70`0H1`<030L400<70P021`0300L700800`L300d70`0H1`<0
1PL300031`0704L700181`0500L700L00`061`@04@L301<71@021`0300L700D04`L3014710061`D0
0PL00`071`161`00B0L010071`041`<01`L300X7100I1`<000<700L00`0I1`<02`L300L70`031`80
0PL00`071`161`00B0L010071`071`@01PL300@70`0M1`8000D700001`0201`70`051`<01PL400H7
0P021`0300L704H700181`0400L000/70`061`@080L300<70`0O1`D01PL300X70P000`L01`181`00
B0L01007000>1`<000@700000PL301/71@051`D06`L300041`0000870`0=1`8000<700L0B0L004P7
00D01`07000>1`D01PL301D70`031`801@L200<70`0E1`<01PL400l70P000`L01`181`00B0L01@07
00L000/70`051`<01PL300l70`061`801@L200H70`0?1`<01PL300@7100;1`8000<700L0B0L004P7
00D01`0700081`<02`L300H710081`<02@L200D70P091`<020L400H70`0;1`<020L200031`0704P7
00181`0500L01`0010L401470`071`<00PL300`70P051`8030L300870`071`<04@L300D70P000`L0
1`181`00B0L01P0700L01`<060L300H7100>1`801@L200h710061`<05`L300870P000`L01`181`00
B0L00`07000301h71P041`<02`L00`0700031`0300L000/70`041`H07@L400031`0704P700181`<0
00<700L07PL600L70`071`0400L700<700@01`L01`L300L71P0O1`@0B@L004P700<01`000`0K1`<0
1PL400H70`041`0400L700<700@01`L010L300H710061`806`L400031`0704P700181`0600L01`07
0`0E1`<03@L300H70`001@L01`L000<700D01`L01`0300H70`0<1`<05@L300061`0700L0B@L004P7
00D01`0700041`<03`L301<70`061`D00`L500H70`0B1`<03`L300@700D01`0700191`00B@L20003
1`0700H70`091`<06@L300@700<01`L01@021`0300L700870`0H1`<02@L300L700<01`L00P191`00
B@L200031`0700T70`031`<07`L300031`0700<000L700001`0700<07PL300<70`0:1`0300L70080
B@L004T700@01`L03@L302D70`000`L01`021`0300L0008090L300d700@01`L0BPL004T700D01`L7
00091`<00`L302D70`0010L0000T1`<00`L300X700@01`L0BPL004T700D01`L700061`<02@L302<7
1@0R1`<02@L300L700@01`L0BPL004T700D01`L700031`<03`L301`71@031`D06`L300l70`041`04
00L704X700191`0400L71`@05@L301H70`041`0500L71`0010L301D70`0E1`<000D700L7001:1`00
B@L00`07000201/70`0@1`<01`L01@071`L000L70`0@1`806`L300031`0704T700191`800PL00`07
1`0L1`<02PL300/700<01`002`L300X70`0N1`0400L004X7001;1`<08@L300@70`0>1`0300L000h7
0`041`<080L304`7001=1`@08@L4014700<01`004@L402070`000`L01`1<1`00C@L010071`L401/7
0`021`<03`L00`07000?1`<00PL301/70`041`0300L704/7001=1`0300L700D70`0D1`@020L300`7
00<01`0030L300P7100D1`<01`L00`071`1;1`00C@L00`071`081`<03PL300l70`091`0300L000T7
0`0?1`<03@L400X700<01`L0B`L004d700<01`L02`L300P70`0E1`<01PL00`0700061`<05@L300L7
0`0=1`0300L704`7001=1`0300L700h70`021`<06`L300<700<01`000`L301/70`0010L0000@1`03
00L704`7001>1`0300L700l7100P1`@000<700000P0O1`D04@L00`071`1<1`00CPL00`071`0<1`<0
10L302070`0O1`<01@L300h700<01`L0C0L004h700<01`L02@L300X7100L1`0300L001`70`0;1`<0
2`L00`071`1<1`00CPL00`071`051`@04@L301T700<01`006@L3014710071`0300L704`7001>1`03
00L700870`0H1`<05PL00`07000F1`<060L300@700<01`L0C0L004h700<01`000P0N1`<04`L00`07
000C1`<07PL300031`0704d7001>1`8090L3014700<01`L03`L302@70P1>1`00M`L300h700<01`L0
2`L407L7001j1`<02`L00`071`081`<0N`L007d710071`0300L700D70`1n1`00P@L300@700<01`L0
0PL3084700241`<000<700L00`241`00Q`L308L7003o1a87003o1a87003o1a87003o1a87003o1a87
003o1a87003o1a870000\
\>"],
  ImageRangeCache->{{{0, 272.812}, {310.75, 0}} -> {-8.8203, -10.0448, \
0.0646542, 0.0646542}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[186]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["j = 5, k =3", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AL053, Axes \[Rule] True, Prolog \[Rule] PointSize[0.025], 
      PlotRange \[Rule] \ {{\(-20\), 20}, {\(-20\), 20}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[187]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.5 0.025 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -9 -9 ]
[.125 .4875 9 0 ]
[.25 .4875 -9 -9 ]
[.25 .4875 9 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -6 -9 ]
[.75 .4875 6 0 ]
[.875 .4875 -6 -9 ]
[.875 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -12 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -12 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-20)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-15)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-10)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(10)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(15)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(20)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-20)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-15)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-10)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(10)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(15)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(20)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.025 w
.91995 .96757 Mdot
.81883 .93471 Mdot
.7177 .90186 Mdot
.61657 .869 Mdot
.51544 .83614 Mdot
.41432 .80328 Mdot
.31319 .77042 Mdot
.95858 .91441 Mdot
.85745 .88155 Mdot
.75633 .84869 Mdot
.6552 .81583 Mdot
.55407 .78297 Mdot
.45294 .75012 Mdot
.35182 .71726 Mdot
.25069 .6844 Mdot
.99721 .86124 Mdot
.89608 .82838 Mdot
.79495 .79552 Mdot
.69383 .76267 Mdot
.5927 .72981 Mdot
.49157 .69695 Mdot
.39044 .66409 Mdot
.28932 .63123 Mdot
.18819 .59838 Mdot
.93471 .77522 Mdot
.83358 .74236 Mdot
.73245 .7095 Mdot
.63133 .67664 Mdot
.5302 .64378 Mdot
.42907 .61093 Mdot
.32794 .57807 Mdot
.22682 .54521 Mdot
.12569 .51235 Mdot
.97333 .72205 Mdot
.87221 .68919 Mdot
.77108 .65634 Mdot
.66995 .62348 Mdot
.56883 .59062 Mdot
.4677 .55776 Mdot
.36657 .5249 Mdot
.26544 .49204 Mdot
.16432 .45919 Mdot
.06319 .42633 Mdot
.91083 .63603 Mdot
.80971 .60317 Mdot
.70858 .57031 Mdot
.60745 .53745 Mdot
.50633 .5046 Mdot
.4052 .47174 Mdot
.30407 .43888 Mdot
.20294 .40602 Mdot
.10182 .37316 Mdot
.00069 .3403 Mdot
.94946 .58286 Mdot
.84833 .55 Mdot
.74721 .51715 Mdot
.64608 .48429 Mdot
.54495 .45143 Mdot
.44383 .41857 Mdot
.3427 .38571 Mdot
.24157 .35285 Mdot
.14044 .32 Mdot
.03932 .28714 Mdot
.88696 .49684 Mdot
.78583 .46398 Mdot
.68471 .43112 Mdot
.58358 .39826 Mdot
.48245 .36541 Mdot
.38133 .33255 Mdot
.2802 .29969 Mdot
.17907 .26683 Mdot
.07794 .23397 Mdot
.82446 .41081 Mdot
.72333 .37796 Mdot
.62221 .3451 Mdot
.52108 .31224 Mdot
.41995 .27938 Mdot
.31883 .24652 Mdot
.2177 .21367 Mdot
.11657 .18081 Mdot
.01544 .14795 Mdot
.76196 .32479 Mdot
.66083 .29193 Mdot
.55971 .25907 Mdot
.45858 .22622 Mdot
.35745 .19336 Mdot
.25633 .1605 Mdot
.1552 .12764 Mdot
.05407 .09478 Mdot
.69946 .23877 Mdot
.59833 .20591 Mdot
.49721 .17305 Mdot
.39608 .14019 Mdot
.29495 .10733 Mdot
.19383 .07448 Mdot
.0927 .04162 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[187]:=",
  ImageSize->{225.188, 225.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Q0000h@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc>47003Q1`00h@L00>47003Q1`00h@L006<7
10031`80M@L006<700<01`L00`L010071`1d1`00I0L00`071`021`0400L700@70P1^1`00G@L400@7
00D01`L700021`0300L7008700<01`L0K@L006H700@01`L00PL00`071`021`0300L706d7001S1`04
00L7008700@01`L010L00`071`1]1`00I0L200@70P051`0300L706d7001a1`80KPL0074700<01`L0
K@L001/7101B1`0300L706d7000K1`@0DPL00`071`1]1`006`L4058700<01`L0K@L001/7101B1`80
KPL0074700<01`L0K@L0074700<01`L0K@L00307100m1`0300L706d7000`1`@0?@L00`071`1]1`00
<0L403d700<01`L0K@L00307100m1`80KPL0074700<01`L0K@L001<7101J1`0300L706d7000C1`@0
FPL00`071`1]1`004`L402h7100X1`0300L706d7000C1`@0;PL402P70P1^1`00A@L402P700<01`L0
K@L004D7100X1`0300L706d7001S1`@00PL300D700<01`L0K@L002P7100i1`0300L700@700<01`L0
0PL00`071`1]1`00:0L403T700<01`L010L00`071`021`80KPL002P7100^1`L010L010071`L300D7
00<01`L0K@L002P7100^1`@01`L01@071`L000L700<01`L0K@L000/7101;1`@01@L300<700<01`L0
1@L00`071`1]1`002`L404/710071`0400L71`@010L00`071`1]1`002`L402h7100`1`80KPL000/7
100^1`@0<0L00`071`1]1`00?@L4030700<01`L0K@L003d7100^1`@0KPL006l7101^1`0080L404/7
101^1`0080L404/7101^1`0080L402h7100K1`0300L706d7000P1`@0;PL401/700<01`L0K@L00587
100K1`0300L706d7001B1`@06`L00`071`0A1`@0F0L007470P0B1`@0F0L003D7100h1`0300L70147
101H1`00=@L403P700<01`L04@L405P7000e1`@0;PL400H700<01`L0K@L003D7100^1`@01PL00`07
1`1]1`0060L404/710061`80KPL001P7101;1`@01PL00`071`0V1`@0@`L001P7100^1`@08`L00`07
1`0V1`@0@`L001P7100^1`@05@L400<70P051`0300L702H710131`00BPL401L700D01`L700021`03
00L7008700<01`L09PL404<7001:1`@05`L01@071`L0008700<01`L00PL200X7101P1`00G@L400@7
00D01`L700021`0300L7008700<01`L02@L40607000]1`@0=0L01@071`L0008700<01`L00PL00`07
1`091`@0H0L002d7100b1`<00`L010071`041`0300L700T7101P1`00;@L402h710021`0300L70087
0P051`0300L706d7000]1`@0;PL400h70P1^1`0040L404/7100>1`0300L706d7000@1`@0B`L400h7
00<01`L07PL404/7000@1`@0G@L00`071`0N1`@0B`L00107100^1`@0:`L00`071`0N1`@0B`L00487
100[1`0300L701h7101;1`00@PL402/70P000`L0000206T700121`@0:`L00`071`0406T7000U1`@0
B0L00`071`0406T7000U1`@0B0L00`071`0402l7100f1`009@L402h7100F1`0300L703<7100f1`00
9@L402h7100F1`80=0L403H700081`@0B`L401H700<01`L0<`L403H700081`@0B`L401H700<01`L0
5PL405<700081`@0I@L00`071`0F1`@0D`L000P7100^1`@0<`L00`071`0F1`@0D`L003X7100c1`80
5`L405<7000j1`@0;PL400031`0706h7000j1`@0;PL400031`0706h7000M1`@0B0L700031`0706h7
000M1`@0B`L400031`0702`7100n1`007@L404/700<01`L00PL202`7100n1`007@L402h7100@1`@0
0PL300D700<01`L0:`L403h7001?1`@05PL00`071`051`0300L702/7100n1`00C`L401H700<01`L0
1@L00`071`0>1`@0F`L004l7100F1`@010L00`071`0>1`@0F`L00387100k1`803`L405/7000b1`@0
>`L00`071`0>1`@0;PL402T7000b1`@0;PL400T700<01`L0@0L402T7000b1`@0;PL400T700<01`L0
@0L402T7000E1`@0B`L400T700<01`L0@0L402T7000E1`@0B`L400T700<01`L08`L404H7000E1`@0
F0L202@710161`005@L402h7100V1`0300L702<710161`00A`L402H700<01`L08`L404H700171`@0
9PL00`071`051`@0I0L004L7100V1`0300L700D7101T1`00:PL404<70P061`@0I0L000L710031`80
4@L400871`0=1`@00`L201@70`0F1`0300L700D7100<1`<050L400<70P031`@02`L400870`0A1`@0
0`L200<700071`0300L700<700@01`L04PL00`071`041`@03`L01@071`L0008700<01`L050L00`07
1`0C1`0300L701P700<01`L04`L01@071`L0008700<01`L0100=1`0300L700@700<01`L03PL00`07
1`031`0400L7008700081`0300L7008700@01`L04PL00`071`041`@03`L01@071`L0008700<01`L0
50L5014700<01`L060L00`071`0C1`0500L71`000PL00`071`0400d700<01`L010L00`071`0?1`03
00L7008700@01`L00PL000031`00008010L01@071`L0008700<01`L020L400@700@01`L70`0;1`@0
10L01@071`L0008700<01`L02`L400870`000`L00002014700<01`L05@L301H700D01`L700021`03
00L700@03@L010071`L301<700D01`L700021`400@L11`002PL010071`021`0300L7010700D01`L7
000E1`0500L71`000PL00`071`0A1`0400L71`@04@L201H700<01`L00`L400l700D01`L700021`03
00L7014700D01`L7000F1`0400L700870@011`4700071`0400L7008700@01`L040L300<700<01`L0
4@L300<700@01`L04`L010071`L4014700<01`L05@L00`071`031`@03@L300<700@01`L04@L300<7
00<01`L04@L010071`021`0400L7008700081`8010L201<700@01`L7100B1`0300L000@050L401D7
00<01`L05@L40087100?1`0300L700870P0D1`0400L71`@04@L200@70P031`00?`L402h700<01`L0
6`L402h7100L1`00?`L402h7101<1`@070L000T7dP061`002@L00`071`021`0300L7008700<01`L0
0PL00`071`021`0300L7008710021`0300L7008700<01`L00PL00`071`031`0300L7008700<01`L0
0PL00`071`021`0300L7008700<01`L00`L00`071`021`0300L7008700<01`L00PL00`071`031`03
00L7008700<01`L00PL400031`0700@700<01`L00PL00`071`021`0300L7008700<01`L00PL00`07
1`031`0300L7008700<01`L00PL00`071`021`0300L700<700<01`L00PL00`071`021`0300L70087
00<01`L00`L600@700<01`L00PL00`071`021`0300L700<700<01`L010L000T700<01`L05PL401L7
00<01`L05`L00`071`0G1`@05PL00`071`0F1`@060L00`071`0G1`0300L700@7000R1`@0B`L00`07
1`0`1`@0>@L00287100^1`@06@L00`071`0`1`@0>@L005@7100I1`0300L70307100i1`00E0L401T7
0P0D1`@0EPL005@7100I1`0300L701<7101F1`00=`L403H700<01`L04`L405H7000g1`@0=PL00`07
1`0C1`@0;PL402@7000g1`@0=PL00`071`151`@090L003L7100^1`@010L204H7100T1`00J@L400@7
00<01`L0A@L402@7001Y1`@010L00`071`0X1`@0@@L006T710041`0300L702P710111`00C0L40247
00<01`L0:0L40447001<1`@08@L202T7100^1`@03`L004`7100Q1`0300L700X7101<1`@03`L004`7
100Q1`0300L700X7101<1`@03`L002l7100n1`0300L700X7101<1`@03`L002l7100n1`0300L700X7
100_1`@0;0L002l7100n1`80?PL402`7000_1`@0;PL400`700<01`L0?@L402`7001Q1`@030L00`07
1`0m1`@0;0L00647100<1`0300L7020710191`00H@L400@70`051`0300L7020710191`00A0L402@7
00<01`L00PL00`071`0P1`@0B@L004@7100T1`0300L700870P0Q1`@0;PL401L700141`@08@L300D7
00<01`L0DPL401L700141`@08@L00`071`051`0300L70087101<1`@05`L006T700<01`L01@L00`07
1`021`@0C0L401L7001Y1`@010L00`071`021`@0;`L403@7001a1`800`L402l7100d1`00F@L401@7
00<01`L0=@L403@7001I1`@050L00`071`0e1`@0=0L005T7100D1`0300L701P7101A1`00F@L401@7
00<01`L060L40547000l1`@0<@L201T7101A1`00?0L4034700<01`L060L402h7100O1`00?0L40347
00<01`L0BPL401l7000l1`@0;PL404`7100O1`00KPL404`7100O1`00KPL502h7100l1`00KPL402l7
100l1`00D@L401`700<01`L0;@L403`7001A1`@070L00`071`0]1`@0;PL400X7001A1`@070L00`07
1`1O1`@02PL00547100L1`8040L404`7100:1`00L@L00`071`0?1`@0C0L400X7001a1`0300L700l7
100_1`@09`L0074700<01`L03`L402l7100W1`00H`L900D700<01`L0@PL402L7001U1`D00PL00`07
1`021`0300L70487100W1`00I@L5008700<01`L00PL202H710141`00I@L5008700<01`L00PL00`07
1`0U1`@0A0L004T7100H1`0500L71`000PL00`071`021`0300L702D710141`00B@L401H70`031`04
00L700@700<01`L09@L402h7100B1`00B@L401P700<01`L00PL200D700<01`L0E`L4018700191`@0
90L200P7101<1`@04PL0074700<01`L01`L404`7100B1`00L@L00`071`071`@0;`L402l7001a1`03
00L700L7100_1`@0;`L005h7100?1`0300L703X7100_1`00GPL400l70P0k1`@0;`L005h7100?1`03
00L706d7001N1`@03`L00`071`0L1`@0C@L0074700<01`L070L404d7001a1`0300L701`7100_1`@0
6PL007470P0M1`@0;`L401X7001a1`0300L000<0C0L401X7001a1`0300L000<0C0L401X7001a1`03
00L000<0;`L403L7001a1`0300L000<0;`L403L7001a1`0300L70387100g1`00L@L203<7100^1`@0
1@L0074700<01`L0I0L400D7001a1`0300L701@7101<1`@01@L006<710021`<01@L00`071`0D1`@0
C0L400D7001U1`0300L700@700<01`L00PL00`071`0D1`@0;`L40287001U1`0300L700@700<01`L0
0PL201D7100_1`@08PL006D700@01`L70`051`0300L704L7100R1`00I@L01@071`L000L700<01`L0
A`L40287001S1`<00`L00`071`051`0300L706d7001U1`0400L71`@010L00`071`0Z1`@0?`L00747
0P0[1`@0?`L0074700<01`L0:PL402h7100=1`00L@L00`071`0Z1`@0;PL400d7001a1`0300L705`7
100=1`00L@L00`071`1L1`@03@L007470P101`@0:PL0074700<01`L0?`L402X7001a1`0300L703l7
100Z1`00L@L00`071`0o1`@0:PL0074700<01`L0K@L0074700<01`L0K@L007470P1^1`00L@L00`07
1`1D1`@05@L0074700<01`L0E0L401D7001a1`0300L705@7100E1`00L@L00`071`1D1`@05@L00747
0P1^1`00L@L00`071`1]1`00L@L00`071`1]1`00H`L400<70P051`0300L706d7001S1`0300L700<7
00@01`L010L00`071`1]1`00I0L00`071`021`0400L700@70P1^1`00I@L01@071`L0008700<01`L0
LPL006H700@01`L00PL00`071`1b1`00H`L010071`021`0400L707@7001T1`8010L207D7003Q1`00
h@L00>470000\
\>"],
  ImageRangeCache->{{{0, 224.188}, {224.188, 0}} -> {-21.7212, -21.4343, \
0.191218, 0.191218}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[187]="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(basis53 = 
      FullSimplify[{A[5, 3, \[Alpha]] /. {m \[Rule] 1, n \[Rule] 0}, 
          A[5, 3, \[Alpha]] /. {m \[Rule] 0, 
              n \[Rule] 1}}]\), "\[IndentingNewLine]", 
    \(orig\  = \ 
      FullSimplify[
        A[5, 3, \[Alpha]] /. {m \[Rule] 0, n \[Rule] 0}]\)}], "Input",
  CellLabel->"In[188]:="],

Cell[BoxData[
    \({{\(-2.246977457514063`\), \(-3.257150914973`\)}, \
{\(-3.7920624293887997`\), \(-1.1305238940929`\)}}\)], "Output",
  CellLabel->"Out[188]="],

Cell[BoxData[
    \({0.25302254248593736`, 0.18380388620493415`}\)], "Output",
  CellLabel->"Out[189]="]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    \(\(rad53\  = \@\(\((basis53[\([1]\)]\  - \ orig)\) . \((basis53[\([1]\)]\
\  - \ orig)\)\);\)\)], "Input",
  CellLabel->"In[190]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AppendTo[basis53, orig], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-10\), 10}, {\(-10\), 10}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[191]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.38765 .33714 Mdot
.3104 .44347 Mdot
.51265 .50919 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[191]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L0088710031`80U@L008@700D01`L700021`0300L7098700241`0500L71`000PL00`07
1`031`80S@L007`710041`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`07
1`031`0300L708`700221`<00`L010071`051`0300L708`700241`0300L700870P061`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L007d700<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<7
00<01`L0S0L007h700<01`L02PL00`071`031`80S@L007H710041`0300L700L70`061`0300L708`7
001o1`0300L700H700<01`L01PL00`071`2<1`00O0L010071`081`0300L700H700<01`L0S0L007`7
10081`@01@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`700281`<01PL00`071`2<1`00R`L00`071`031`0300L708`7
002;1`0300L700<70P2=1`00PPL400870`061`0300L708`700281`0300L700H700<01`L0S0L008P7
00<01`L01PL00`071`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
001`1`H06`L00`071`2<1`00KPL:01T700<01`L0S0L006h72P0I1`80S@L006d7300H1`0300L708`7
001]1``060L00`071`2<1`00K@L<01P700<01`L0S0L006d7300H1`0300L708`7001]1``060L00`07
1`2<1`00K@L<01P700<01`L0S0L006h72P0I1`80S@L006h72P0I1`0300L708`7001`1`H06`L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00O0L400<700<01`L00PL300H700<01`L0S0L007`7
00<01`L030L00`071`031`0300L708`7001m1`0300L700/700<01`L00`L208d7001f1`@010L00`07
1`071`<01PL00`071`2<1`00O`L00`071`061`0300L700H700<01`L0S0L007`700@01`L020L00`07
1`061`0300L708`7001m1`802@L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00F`L6030700<01`L0S0L005T72P0^1`80S@L005T72P0^1`0300L708`7001H1``0;@L00`07
1`2<1`00F0L<02d700<01`L0S0L005P7300]1`0300L708`7001H1``0;@L00`071`2<1`00F0L<02d7
0P2=1`00F0L<02d700<01`L0S0L005T72P0^1`0300L708`7001I1`X0;PL00`071`2<1`001`L400<7
0P0G1`0300L700<700<01`L00PL301T70`0:1`H02@L400<700<01`L00PL301P700<01`L05`L400<7
00<01`L00PL301T70`0J1`0300L700<700<01`L00PL301H710031`800`L000T700D01`L700021`03
00L701@700<01`L02`L00`071`0I1`0300L701H700<01`L030L00`071`0E1`0300L701L700<01`L0
30L00`071`0I1`0300L701L700<01`L02`L00`071`0E1`0500L71`000PL100470@L000T700D01`L7
00021`0300L701D700<01`L02PL00`071`0I1`0300L701L700<01`L02`L00`071`0E1`0300L701P7
00<01`L02`L00`071`0I1`0300L701P700<01`L02PL00`071`0E1`0500L71`000PL100470@L00003
1`00008010L01@071`L0008700<01`L03@L400@700<01`L01`L301<710021`<04`L400@700<01`L0
1`L301P70P0J1`0300L700L70`0I1`<06`L00`071`071`<060L01@071`L000870@011`4700091`05
00L71`000PL00`071`0F1`0300L700H700<01`L06@L00`071`0L1`0300L700H700<01`L060L00`07
1`0J1`0300L700H700<01`L06@L00`071`0L1`0300L700H700<01`L060L01@071`L000870@011`47
00071`<00`L010071`0E1`0400L700P700<01`L06@L00`071`0I1`0400L700P700<01`L060L00`07
1`0G1`0400L700P700<01`L06@L00`071`0I1`0400L700P700<01`L05PL300<700@01`L00PL000T7
00<01`L00PL201H710081`@060L401T70P091`@05`L00`071`0H1`802@L401P7100H1`@020L401L7
00<01`L00PL200<7002A1`L0R0L009072P261`00T0L:08H700091ol04P061`002@L00`071`031`03
00L700@700<01`L010L00`071`041`0300L700@700<01`L00`L00`071`041`0300L700@700<01`L0
10L00`071`041`0300L700<700<01`L010L00`071`041`0300L700@700<01`L010L00`071`031`03
00L700@700<01`L010L00`071`041`0300L7008730031`0300L700@700<01`L010L00`071`041`03
00L700<700<01`L010L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@700<01`L0
10L00`071`041`0300L700@700<01`L00`L00`071`041`0300L700@700<01`L010L00`071`041`03
00L700@700091`0300L701l700<01`L07`L00`071`0O1`0300L701d7300H1`0300L701l700<01`L0
7`L00`071`0O1`0300L700@7002?1``0Q@L008l730251`00S`L<08D7002@1`X0QPL009072P261`00
T@L708P7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7001l1`@00`L00`071`021`<01PL00`071`2<1`00
O0L00`071`0<1`0300L700<700<01`L0S0L007d700<01`L02`L00`071`031`80S@L007h700<01`L0
1`L300H700<01`L0S0L007l700<01`L01PL00`071`061`0300L708`7001l1`0400L700P700<01`L0
1PL00`071`2<1`00O@L200T710051`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80
S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L008P70`061`0300L708`7002;1`03
00L700<700<01`L0S0L008/700<01`L00`L208d700281`<01PL00`071`2<1`00R0L00`071`061`03
00L708`700281`0300L700H700<01`L0S0L008P710051`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80
S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L007d700<01`L0
0`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<700<01`L0S0L007h700<01`L0
2PL00`071`031`80S@L007h700<01`L01`L300H700<01`L0S0L007l700<01`L01PL00`071`061`03
00L708`7001l1`0400L700P700<01`L01PL00`071`2<1`00O0L400P710051`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0088710031`801PL00`071`2<1`00Q0L01@071`L0008700<01`L00`L00`071`2<1`00Q0L01@07
1`L0008700<01`L00`L208d700241`0500L71`000PL00`071`2B1`00Q0L01@071`L0008700<01`L0
TPL008870`031`0400L709@700241`0300L700870P2E1`00o`LQ1`00o`LQ1`00o`LQ1`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.6619, -10.5516, 0.0735301, \
0.0735301}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[191]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice053\  = tiling2D[SphericalCut[N[AL053], 10], \ rad53]\)], "Input",\

  CellLabel->"In[192]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97711 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.487495 0.0494217 0.499543 0.0494217 [
[ 0 0 0 0 ]
[ 1 .97711 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .97711 L
0 .97711 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.67075 .95384 m
.47083 .88889 L
s
.67075 .95384 m
.54719 .78379 L
s
.47083 .88889 m
.27092 .82393 L
s
.47083 .88889 m
.34728 .71883 L
s
.27092 .82393 m
.071 .75897 L
s
.27092 .82393 m
.14736 .65387 L
s
.74711 .84874 m
.54719 .78379 L
s
.74711 .84874 m
.62355 .67868 L
s
.54719 .78379 m
.34728 .71883 L
s
.54719 .78379 m
.42364 .61373 L
s
.34728 .71883 m
.14736 .65387 L
s
.34728 .71883 m
.22372 .54877 L
s
.14736 .65387 m
.02381 .48382 L
s
.82347 .74364 m
.62355 .67868 L
s
.82347 .74364 m
.69991 .57358 L
s
.62355 .67868 m
.42364 .61373 L
s
.62355 .67868 m
.5 .50863 L
s
.42364 .61373 m
.22372 .54877 L
s
.42364 .61373 m
.30009 .44367 L
s
.22372 .54877 m
.02381 .48382 L
s
.22372 .54877 m
.10017 .37871 L
s
.89983 .63854 m
.69991 .57358 L
s
.89983 .63854 m
.77628 .46848 L
s
.69991 .57358 m
.5 .50863 L
s
.69991 .57358 m
.57636 .40353 L
s
.5 .50863 m
.30009 .44367 L
s
.5 .50863 m
.37645 .33857 L
s
.30009 .44367 m
.10017 .37871 L
s
.30009 .44367 m
.17653 .27361 L
s
.97619 .53344 m
.77628 .46848 L
s
.97619 .53344 m
.85264 .36338 L
s
.77628 .46848 m
.57636 .40353 L
s
.77628 .46848 m
.65272 .29842 L
s
.57636 .40353 m
.37645 .33857 L
s
.57636 .40353 m
.45281 .23347 L
s
.37645 .33857 m
.17653 .27361 L
s
.37645 .33857 m
.25289 .16851 L
s
.85264 .36338 m
.65272 .29842 L
s
.85264 .36338 m
.72908 .19332 L
s
.65272 .29842 m
.45281 .23347 L
s
.65272 .29842 m
.52917 .12837 L
s
.45281 .23347 m
.25289 .16851 L
s
.45281 .23347 m
.32925 .06341 L
s
.72908 .19332 m
.52917 .12837 L
s
.72908 .19332 m
.60553 .02326 L
s
.52917 .12837 m
.32925 .06341 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[192]:=",
  ImageSize->{288, 281.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00016@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00:d700<01`L0L0L00:h700<01`L0K`L00:h700<01`L0K`L00:l700<01`L0
KPL00;0700<01`L0K@L00;4700<01`L0K0L00;4700<01`L0K0L00;8700<01`L0J`L00;<700<01`L0
JPL00;@700<01`L0J@L00;@700<01`L0J@L005h70P1E1`0300L706P7001O1`@0D`L00`071`1W1`00
G`L010071`L3054700<01`L0IPL0060700<01`L00`L304h700<01`L0IPL0064700<01`L01@L304`7
00<01`L0I@L0068700<01`L01`L304X700<01`L0I0L0068700<01`L02PL304L700<01`L0I0L006<7
00<01`L030L304D700<01`L0H`L006@700<01`L03PL304<700<01`L0HPL006@700<01`L04@L30447
00<01`L0H@L006D700<01`L04`L303h700<01`L0H@L006H700<01`L05@L303`700<01`L0H0L006L7
00<01`L05`L303X700<01`L0G`L006L700<01`L06PL303P700<01`L0GPL006P700<01`L070L303D7
00<01`L0GPL006T700<01`L07PL303<700<01`L0G@L006T700<01`L08@L3034700<01`L0G0L006X7
00<01`L08`L302l700<01`L0F`L006/700<01`L09@L302`700<01`L0F`L006`700<01`L09`L302X7
00<01`L0FPL006`700<01`L0:@L402P700<01`L0F@L006d700<01`L0:0L010071`L302H700<01`L0
F0L006h700<01`L0:0L00`071`031`<08`L00`071`1H1`00KPL00`071`0Y1`0300L700D70`0Q1`03
00L705L7001_1`0300L702T700<01`L01`L301l700<01`L0EPL0070700<01`L0:0L00`071`0:1`<0
70L00`071`1F1`00L@L00`071`0X1`0300L700`70`0J1`0300L705D7001a1`0300L702T700<01`L0
3PL301P700<01`L0E0L0078700<01`L0:@L00`071`0@1`<05PL00`071`1C1`00L`L00`071`0X1`03
00L701<7100B1`0300L705<700181`80:@L00`071`0Y1`0300L701H70`0@1`0300L7058700191`@0
9`L00`071`0Y1`0300L701P70`0>1`0300L7054700191`0400L71`<09@L00`071`0Y1`0300L701X7
0`0<1`0300L70507001:1`0300L700<70`0S1`0300L702P700<01`L07@L300T700<01`L0D0L004/7
00<01`L01@L3020700<01`L0:@L00`071`0O1`<01`L00`071`1?1`00C0L00`071`071`<07PL00`07
1`0Y1`0300L702470`051`0300L704h7001<1`0300L700X70`0L1`0300L702P700<01`L090L300<7
00<01`L0C@L004d700<01`L030L301T700<01`L0:@L00`071`0V1`@0C`L004h700<01`L03PL301L7
00<01`L0:@L00`071`0X1`80CPL004l700<01`L040L301D700<01`L0:@L00`071`0Y1`0300L704/7
001?1`0300L701<70`0C1`0300L702P700<01`L0:@L00`071`1;1`00D0L00`071`0E1`<040L00`07
1`0Y1`0300L702T700<01`L0BPL0054700<01`L05`L300h700<01`L0:@L00`071`0Y1`0300L704T7
001B1`0300L701T70`0<1`0300L702T700<01`L0:@L00`071`181`00DPL00`071`0L1`<02@L00`07
1`0Y1`0300L702T700<01`L0B0L005<700<01`L07PL300L700<01`L0:@L00`071`0Y1`0300L704L7
001D1`0300L702070`051`0300L702T700<01`L0:@L00`071`161`00E0L00`071`0S1`<00`L00`07
1`0Y1`0300L702T700<01`L0A@L005D700<01`L09@L402/700<01`L0:@L00`071`151`00EPL00`07
1`0W1`<0:PL00`071`0Y1`0300L704@7001G1`0300L702P7100X1`0300L702T700<01`L0@`L005L7
00<01`L0:0L010071`L302H700<01`L0:0L00`071`131`00F0L00`071`0X1`0300L700<70`0S1`03
00L702T700<01`L0@PL005T700<01`L0:0L00`071`051`<08@L00`071`0Y1`0300L70447001J1`03
00L702P700<01`L01`L301l700<01`L0:@L00`071`101`00FPL00`071`0X1`0300L700X70`0L1`03
00L702T700<01`L0@0L005/700<01`L0:0L00`071`0<1`<06PL00`071`0Y1`0300L703l7001L1`03
00L702P700<01`L03PL301P700<01`L0:@L00`071`0n1`00G@L00`071`0X1`0300L701070`0F1`03
00L702T700<01`L0?@L005d700<01`L0:0L00`071`0C1`@04PL00`071`0Y1`0300L703d7001N1`03
00L702P700<01`L05PL3010700<01`L0:@L00`071`0l1`00<PL202/700<01`L0:0L00`071`0H1`<0
3PL00`071`0Y1`0300L703/7000c1`@0:@L00`071`0X1`0300L701X70`0<1`0300L702P700<01`L0
>`L003<700@01`L7100U1`0300L702P700<01`L07@L300T700<01`L0:@L00`071`0j1`00=0L00`07
1`041`<08`L00`071`0X1`0300L701l70`071`0300L702T700<01`L0>@L003D700<01`L01PL30247
00<01`L0:0L00`071`0Q1`<01@L00`071`0Y1`0300L703P7000f1`0300L700P70`0N1`0300L702P7
00<01`L090L300<700<01`L0:0L00`071`0h1`00=PL00`071`0;1`<070L00`071`0X1`0300L702H7
100[1`0300L703L7000g1`0300L700d7100I1`0300L702P700<01`L0:0L302X700<01`L0=PL003P7
00<01`L040L301L700<01`L0:0L00`071`0Y1`@0:0L00`071`0e1`00>@L00`071`0B1`<050L00`07
1`0X1`0300L702T700@01`L70`0U1`0300L703D7000i1`0300L701D70`0B1`0300L702P700<01`L0
:@L00`071`031`@08PL00`071`0d1`00>PL00`071`0G1`@03`L00`071`0X1`0300L702T700<01`L0
1PL3020700<01`L0<`L003/700<01`L06PL300d700<01`L0:0L00`071`0Y1`0300L700P70`0N1`03
00L70387000l1`0300L701`70`0:1`0300L702P700<01`L0:@L00`071`0;1`<06`L00`071`0b1`00
?0L00`071`0O1`<020L00`071`0X1`0300L702T700<01`L03@L301T700<01`L0<@L003d700<01`L0
8@L300H700<01`L0:0L00`071`0Y1`0300L700l70`0G1`0300L70307000n1`0300L702<710031`03
00L702P700<01`L0:0L00`071`0B1`@04`L00`071`0`1`00?`L00`071`0V1`@0:PL00`071`0Y1`03
00L701D70`0A1`0300L702l7000o1`0300L702T70`0Y1`0300L702T700<01`L05`L300l700<01`L0
;PL0040700<01`L0:PL402L700<01`L0:@L00`071`0I1`<03@L00`071`0]1`00@@L00`071`0Y1`04
00L71`<09@L00`071`0X1`0300L701`70`0:1`0300L702d700121`0300L702T700<01`L00`L30287
00<01`L0:@L00`071`0N1`<020L00`071`0/1`00@PL00`071`0Z1`0300L700D70`0P1`0300L702T7
00<01`L080L400D700<01`L0:`L004<700<01`L0:PL00`071`071`<07PL00`071`0X1`0300L702@7
0`031`0300L702X700141`0300L702T700<01`L02PL301/700<01`L0:@L00`071`0V1`@0;0L004D7
00<01`L0:@L00`071`0<1`<06@L00`071`0Y1`0300L702P70P0[1`00A@L00`071`0Z1`0300L700h7
0`0G1`0300L702T700<01`L0:@L00`071`0X1`00APL00`071`0Y1`0300L701470`0E1`0300L702P7
00<01`L0:@L00`071`0X1`00A`L00`071`0Y1`0300L701<70`0B1`0300L702T700<01`L0:@L00`07
1`0W1`00B0L00`071`0Y1`0300L701D70`0@1`0300L702T700<01`L0:@L00`071`0V1`0070L202X7
00<01`L0:PL00`071`0G1`<03PL00`071`0X1`0300L702X700<01`L09@L001d7100X1`0300L702T7
00<01`L06PL300`700<01`L0:0L00`071`0Y1`0300L702D7000M1`0400L71`@09@L00`071`0Y1`03
00L701`70`091`0300L702T700<01`L0:@L00`071`0T1`007PL00`071`041`<08`L00`071`0Y1`03
00L701h70`071`0300L702T700<01`L0:@L00`071`0S1`007`L00`071`061`<080L00`071`0Y1`03
00L702470`051`0300L702P700<01`L0:PL00`071`0R1`0080L00`071`081`<07PL00`071`0Y1`03
00L702<70`031`0300L702P700<01`L0:@L00`071`0R1`0080L00`071`0;1`<070L00`071`0Y1`03
00L702D7100[1`0300L702T700<01`L08@L0024700<01`L03@L401T700<01`L0:@L00`071`0W1`<0
:@L00`071`0Z1`0300L70207000R1`0300L701070`0F1`0300L702T700<01`L0:@L402L700<01`L0
:PL00`071`0O1`008`L00`071`0B1`<050L00`071`0Y1`0300L702P700@01`L70`0U1`0300L702T7
00<01`L07`L002<700<01`L05@L3018700<01`L0:@L00`071`0X1`0300L700<70`0S1`0300L702T7
00<01`L07PL002@700<01`L05`L400l700<01`L0:0L00`071`0Y1`0300L700D70`0P1`0300L702X7
00<01`L07@L002D700<01`L06PL300`700<01`L0:@L00`071`0Y1`0300L700L70`0N1`0300L702T7
00<01`L07@L002H700<01`L070L300X700<01`L0:@L00`071`0X1`0300L700X70`0L1`0300L702T7
00<01`L070L002H700<01`L07`L300P700<01`L0:@L00`071`0X1`0300L700`70`0I1`0300L702X7
00<01`L06`L002L700<01`L08@L300H700<01`L0:0L00`071`0Y1`0300L700h70`0G1`0300L702X7
00<01`L06PL002P700<01`L08`L4008700<01`L0:@L00`071`0X1`0300L701470`0E1`0300L702T7
00<01`L06PL002P700<01`L09`L402/700<01`L0:0L00`071`0C1`<04`L00`071`0Y1`0300L701T7
000Y1`0300L702T70`0Y1`0300L702T700<01`L05@L3010700<01`L0:PL00`071`0H1`00:PL00`07
1`0Z1`@09`L00`071`0Y1`0300L701L70`0>1`0300L702X700<01`L05`L002/700<01`L0:@L01007
1`L302D700<01`L0:0L00`071`0J1`<030L00`071`0Y1`0300L701L7000[1`0300L702X700<01`L0
0`L302<700<01`L0:0L00`071`0L1`<02@L00`071`0Z1`0300L701H7000/1`0300L702X700<01`L0
1@L3020700<01`L0:@L00`071`0N1`<01`L00`071`0Z1`0300L701D7000]1`0300L702X700<01`L0
1`L301h700<01`L0:0L00`071`0Q1`<01@L00`071`0Z1`0300L701@7000^1`0300L702T700<01`L0
2PL301`700<01`L0:0L00`071`0S1`<00`L00`071`0Y1`0300L701@7000^1`0300L702X700<01`L0
30L301T700<01`L0:@L00`071`0U1`@0;0L00`071`0C1`00;`L00`071`0Z1`0300L700h70`0G1`03
00L702T700<01`L09`L302/700<01`L04PL0030700<01`L0:@L00`071`0A1`<05@L00`071`0X1`03
00L702T7100Y1`0300L70147000a1`0300L702T700<01`L04`L301<700<01`L0:0L00`071`0X1`04
00L71`@09@L00`071`0A1`00<@L00`071`0Z1`0300L701D70`0@1`0300L702T700<01`L0:0L00`07
1`041`<08`L00`071`0@1`001PL202X700<01`L0:PL00`071`0G1`<03PL00`071`0X1`0300L702T7
00<01`L01PL3024700<01`L03`L000L7100X1`0300L702T700<01`L06PL300`700<01`L0:0L00`07
1`0Y1`0300L700P70`0N1`0300L700l700071`0400L71`<09PL00`071`0Y1`0300L701`70`091`03
00L702T700<01`L0:0L00`071`0;1`<070L00`071`0>1`0020L00`071`031`<08`L00`071`0Z1`03
00L701h70`071`0300L702T700<01`L0:0L00`071`0=1`@06@L00`071`0=1`002@L00`071`051`<0
8@L00`071`0Y1`0300L702470`051`0300L702P700<01`L0:@L00`071`0@1`<05`L00`071`0<1`00
2PL00`071`071`<07`L00`071`0Y1`0300L702<70`031`0300L702P700<01`L0:@L00`071`0B1`<0
50L00`071`0<1`002PL00`071`0:1`<070L00`071`0Z1`0300L702D7100[1`0300L702P700<01`L0
5@L3018700<01`L02`L000/700<01`L030L301X700<01`L0:PL00`071`0W1`<0:@L00`071`0Y1`03
00L701L7100?1`0300L700X7000<1`0300L700h70`0H1`0300L702T700<01`L0:@L402L700<01`L0
:@L00`071`0J1`<03@L00`071`091`003@L00`071`0@1`<05PL00`071`0Y1`0300L702P700@01`L7
0`0U1`0300L702T700<01`L070L300X700<01`L02@L000d700<01`L04`L4018700<01`L0:PL00`07
1`0X1`0300L700<70`0S1`0300L702P700<01`L07`L300P700<01`L020L000h700<01`L05PL30107
00<01`L0:@L00`071`0Y1`0300L700D70`0P1`0300L702T700<01`L08@L300H700<01`L01`L000l7
00<01`L060L300h700<01`L0:@L00`071`0Y1`0300L700L70`0N1`0300L702T700<01`L08`L400<7
00<01`L01PL0010700<01`L06PL300`700<01`L0:@L00`071`0X1`0300L700X70`0L1`0300L702T7
00<01`L09PL400P7000@1`0300L701d70`091`0300L702X700<01`L0:0L00`071`0<1`<06@L00`07
1`0Y1`0300L702T70P071`004@L00`071`0O1`<01`L00`071`0Y1`0300L702T700<01`L03PL301L7
00<01`L0:@L00`071`0a1`004PL00`071`0Q1`<01@L00`071`0Y1`0300L702P700<01`L04@L301D7
00<01`L0:@L00`071`0`1`004PL00`071`0T1`<00`L00`071`0Y1`0300L702P700<01`L04`L301<7
00<01`L0:@L00`071`0_1`004`L00`071`0V1`@0:`L00`071`0Y1`0300L701D70`0@1`0300L702T7
00<01`L0;`L001@700<01`L0:0L302X700<01`L0:@L00`071`0G1`<03PL00`071`0Y1`0300L702h7
000E1`0300L702T7100X1`0300L702P700<01`L06PL300`700<01`L0:@L00`071`0]1`005@L00`07
1`0Y1`0400L71`<09PL00`071`0X1`0300L701`70`091`0300L702X700<01`L0;0L001H700<01`L0
:@L00`071`031`@08PL00`071`0Y1`0300L701h70`071`0300L702T700<01`L0;0L001L700<01`L0
:@L00`071`061`<080L00`071`0X1`0300L702470`051`0300L702T700<01`L0:`L001P700<01`L0
:@L00`071`081`<07PL00`071`0X1`0300L702<70`031`0300L702T700<01`L0:PL001P700<01`L0
:@L00`071`0;1`<06`L00`071`0Y1`0300L702D7100/1`0300L702T7000I1`0300L702T700<01`L0
3@L301T700<01`L0:@L00`071`0W1`<0:PL00`071`0Y1`006PL00`071`0Y1`0300L700l70`0G1`03
00L702P700<01`L0:@L402P700<01`L0:0L001/700<01`L0:@L00`071`0A1`@050L00`071`0X1`03
00L702P700@01`L7100U1`0300L702L7000K1`0300L702T700<01`L05@L3014700<01`L0:@L00`07
1`0X1`0300L700@70`0S1`0300L702H7000L1`0300L702T700<01`L05`L300l700<01`L0:0L00`07
1`0Y1`0300L700H70`0P1`0300L702H7000M1`0300L702T700<01`L06@L300d700<01`L0:0L00`07
1`0Y1`0300L700P70`0N1`0300L702D7000N1`0300L702P700<01`L070L300X700<01`L0:@L00`07
1`0X1`0300L700/70`0L1`0300L702@7000N1`0300L702T700<01`L07PL300P700<01`L0:@L00`07
1`0X1`0300L700d7100I1`0300L702<7000O1`0300L702T700<01`L080L400D700<01`L0:0L00`07
1`0Y1`0300L701070`0F1`0300L702<7000P1`0300L702T700<01`L08`L300<700<01`L0:0L00`07
1`0Y1`0300L701870`0D1`0300L70287000P1`0300L702T700<01`L09PL402/700<01`L0:0L00`07
1`0E1`<04PL00`071`0Q1`008@L00`071`0Y1`0300L702P70`0Y1`0300L702T700<01`L05`L400l7
00<01`L080L0028700<01`L0:@L00`071`0Y1`@09`L00`071`0Y1`0300L701X70`0<1`0300L70207
000S1`0300L702T700<01`L0:0L010071`L302D700<01`L0:@L00`071`0L1`<02PL00`071`0O1`00
8`L00`071`0Y1`0300L702T700<01`L00`L302<700<01`L0:0L00`071`0O1`<020L00`071`0N1`00
90L00`071`0Y1`0300L702T700<01`L01@L3020700<01`L0:@L00`071`0Q1`<01PL00`071`0M1`00
9@L00`071`0Y1`0300L702T700<01`L01`L301h700<01`L0:@L00`071`0S1`@00PL00`071`0M1`00
9PL00`071`0X1`0300L702T700<01`L02PL301`700<01`L0:0L00`071`0W1`@07PL002H700<01`L0
:@L00`071`0Y1`0300L700`70`0I1`0300L702T700<01`L0:@L201d7000W1`0300L702T700<01`L0
:@L00`071`0>1`<05`L00`071`0Y1`0300L704L7000X1`0300L702T700<01`L0:@L00`071`0@1`<0
5@L00`071`0Y1`0300L704H7000Y1`0300L702P700<01`L0:@L00`071`0C1`<04`L00`071`0X1`03
00L704H7000Y1`0300L702T700<01`L0:@L00`071`0E1`<040L00`071`0Y1`0300L704D7000Z1`80
:PL00`071`0Y1`0300L701L70`0>1`0300L702T700<01`L0A0L002/7100X1`0300L702T700<01`L0
6@L300`700<01`L0:@L00`071`131`00:`L010071`L302D700<01`L0:@L00`071`0L1`<02@L00`07
1`0Y1`0300L704<7000/1`0300L700<7100R1`0300L702T700<01`L07PL300L700<01`L0:@L00`07
1`121`00;@L00`071`061`<080L00`071`0Y1`0300L702070`051`0300L702T700<01`L0@@L002h7
00<01`L020L301h700<01`L0:0L00`071`0S1`<00`L00`071`0Y1`0300L70407000^1`0300L700/7
0`0K1`0300L702T700<01`L09@L402/700<01`L0@0L002l700<01`L03@L301T700<01`L0:@L00`07
1`0W1`<0:PL00`071`0o1`00<0L00`071`0?1`<05`L00`071`0Y1`0300L702P7100X1`0300L703h7
000`1`0300L70187100C1`0300L702T700<01`L0:0L010071`L302H700<01`L0?@L0034700<01`L0
5@L3014700<01`L0:@L00`071`0X1`0300L700<70`0S1`0300L703d7000b1`0300L701L70`0?1`03
00L702T700<01`L0:0L00`071`051`<08@L00`071`0l1`00<`L00`071`0I1`<03@L00`071`0Y1`03
00L702P700<01`L01`L301l700<01`L0>`L003<700<01`L070L300X700<01`L0:@L00`071`0X1`03
00L700X70`0L1`0300L703/7000d1`0300L701h70`081`0300L702T700<01`L0:0L00`071`0<1`<0
6PL00`071`0j1`00=@L00`071`0P1`@01@L00`071`0Y1`0300L702P700<01`L03PL301P700<01`L0
>@L003D700<01`L090L300<700<01`L0:@L00`071`0X1`0300L701070`0F1`0300L703P7000f1`03
00L702H7100[1`0300L702P700<01`L04`L4018700<01`L0>0L003L700<01`L0:0L302X700<01`L0
:0L00`071`0F1`<040L00`071`0g1`00>0L00`071`0Y1`@0:0L00`071`0X1`0300L701P70`0>1`03
00L703H7000h1`0300L702T700@01`L70`0V1`0300L702P700<01`L06PL300`700<01`L0=@L003T7
00<01`L0:@L00`071`031`<08`L00`071`0X1`0300L701d70`091`0300L703D7000j1`0300L702T7
00<01`L01@L3024700<01`L0:0L00`071`0O1`<01`L00`071`0d1`00>PL00`071`0Z1`0300L700L7
0`0O1`0300L702P700<01`L08@L300D700<01`L0<`L003/700<01`L0:@L00`071`0:1`<070L00`07
1`0X1`0300L702@70`031`0300L70387000l1`0300L702T700<01`L030L301X700<01`L0:0L00`07
1`0V1`@0=0L003d700<01`L0:@L00`071`0>1`<060L00`071`0X1`0300L702P70P0c1`00?@L00`07
1`0Z1`0300L701070`0F1`0300L702P700<01`L0G0L003h700<01`L0:@L00`071`0C1`@04PL00`07
1`0X1`0300L705`7000o1`0300L702T700<01`L05PL3010700<01`L0:0L00`071`1K1`0050L202T7
00<01`L0:PL00`071`0H1`<03PL00`071`0X1`0300L705X7000F1`<09`L00`071`0Z1`0300L701X7
0`0<1`0300L702P700<01`L0F@L001T70`0U1`0300L702T700<01`L07@L300T700<01`L0:0L00`07
1`1I1`0070L302<700<01`L0:@L00`071`0O1`<01`L00`071`0X1`0300L705P7000O1`<080L00`07
1`0Z1`0300L702470`051`0300L702P700<01`L0E`L002870`0N1`0300L702T700<01`L090L300<7
00<01`L0:0L00`071`1F1`009@L301`700<01`L0:@L00`071`0V1`@0:PL00`071`1F1`00:0L301T7
00<01`L0:PL00`071`0X1`<0:@L00`071`1E1`00:`L301L700<01`L0:PL00`071`0Y1`@09`L00`07
1`1D1`00;PL301D700<01`L0:@L00`071`0Y1`0400L71`<09@L00`071`1C1`00<@L301<700<01`L0
:@L00`071`0Y1`0300L700<70`0R1`0300L705<7000d1`<040L00`071`0Z1`0300L702T700<01`L0
1@L3020700<01`L0DPL003L70`0>1`0300L702X700<01`L0:@L00`071`071`<07PL00`071`1A1`00
>PL300`700<01`L0:@L00`071`0Y1`0300L700X70`0K1`0300L70547000m1`<02@L00`071`0Z1`03
00L702T700<01`L030L301T700<01`L0D0L004070`071`0300L702X700<01`L0:@L00`071`0>1`<0
5`L00`071`1?1`00@`L300D700<01`L0:PL00`071`0X1`0300L701470`0E1`0300L704h700161`<0
0`L00`071`0Y1`0300L702T700<01`L04`L3018700<01`L0CPL004T7100/1`0300L702T700<01`L0
5@L3010700<01`L0C@L004`70`0[1`0300L702T700<01`L05`L300h700<01`L0C0L004l70`0Y1`03
00L702P700<01`L06PL300`700<01`L0B`L00587100U1`0300L702T700<01`L070L300T700<01`L0
B`L005H70`0S1`0300L702T700<01`L07PL300L700<01`L0BPL005T70`0Q1`0300L702P700<01`L0
8@L300D700<01`L0B@L005`70`0N1`0300L702T700<01`L08`L300<700<01`L0B0L005l70`0L1`03
00L702T700<01`L09@L404X7001R1`@06@L00`071`0Y1`0300L702L70P191`00IPL301L700<01`L0
:0L00`071`1b1`00J@L301@700<01`L0:@L00`071`1a1`00K0L3018700<01`L0:@L00`071`1`1`00
K`L400l700<01`L0:0L00`071`1`1`00L`L300d700<01`L0:0L00`071`1_1`00MPL300X700<01`L0
:@L00`071`1^1`00N@L300P700<01`L0:@L00`071`1]1`00O0L300H700<01`L0:0L00`071`1]1`00
O`L400<700<01`L0:0L00`071`1/1`00P`L402/700<01`L0J`L008H70`0Y1`0300L706/700291`<0
9`L00`071`1Z1`00S0L302D700<01`L0J@L008l70`0S1`0300L706P7002B1`<080L00`071`1X1`00
U@L301h700<01`L0I`L009P70`0L1`0300L706H7002K1`<06@L00`071`1V1`00WPL301L700<01`L0
I@L00:470`0E1`0300L706@7002T1`<04`L00`071`1S1`00Y`L3010700<01`L0H`L00:X70`0>1`03
00L70687002]1`<030L00`071`1Q1`00/0L300T700<01`L0H@L00;<70`071`0300L70607002f1`<0
1@L00`071`1O1`00^@L300<700<01`L0GPL00;`7101P1`00_`L205l7003o1b47003o1b47003o1b47
003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {280.375, 0}} -> {-9.86599, -10.1078, \
0.0705158, 0.0705158}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[192]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice53\  = 
      tiling2D[SphericalCut[N[Join[AL053, \ AL153, \ AL253, \ AL353]], 10], \ 
        rad53]\)], "Input",
  CellLabel->"In[193]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .97511 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499854 0.0481718 0.48745 0.0481718 [
[ 0 0 0 0 ]
[ 1 .97511 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .97511 L
0 .97511 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.67847 .93026 m
.48361 .86695 L
s
.67847 .93026 m
.55804 .7645 L
s
.67847 .93026 m
.78836 .75369 L
s
.48361 .86695 m
.28875 .80363 L
s
.48361 .86695 m
.36318 .70119 L
s
.48361 .86695 m
.5935 .69038 L
s
.28875 .80363 m
.0939 .74032 L
s
.28875 .80363 m
.16832 .63788 L
s
.28875 .80363 m
.39864 .62706 L
s
.0939 .74032 m
.20378 .56375 L
s
.7529 .82782 m
.55804 .7645 L
s
.7529 .82782 m
.63247 .66206 L
s
.7529 .82782 m
.86279 .65125 L
s
.55804 .7645 m
.36318 .70119 L
s
.55804 .7645 m
.43761 .59875 L
s
.55804 .7645 m
.42407 .92358 L
s
.55804 .7645 m
.66793 .58793 L
s
.36318 .70119 m
.16832 .63788 L
s
.36318 .70119 m
.24275 .53543 L
s
.36318 .70119 m
.22921 .86026 L
s
.36318 .70119 m
.47307 .52462 L
s
.16832 .63788 m
.0479 .47212 L
s
.16832 .63788 m
.27821 .46131 L
s
.82733 .72537 m
.63247 .66206 L
s
.82733 .72537 m
.7069 .55962 L
s
.82733 .72537 m
.69336 .88445 L
s
.82733 .72537 m
.93722 .5488 L
s
.63247 .66206 m
.43761 .59875 L
s
.63247 .66206 m
.51204 .4963 L
s
.63247 .66206 m
.4985 .82113 L
s
.63247 .66206 m
.74236 .48549 L
s
.43761 .59875 m
.24275 .53543 L
s
.43761 .59875 m
.31718 .43299 L
s
.43761 .59875 m
.30364 .75782 L
s
.43761 .59875 m
.5475 .42218 L
s
.24275 .53543 m
.0479 .47212 L
s
.24275 .53543 m
.12232 .36968 L
s
.24275 .53543 m
.10878 .69451 L
s
.24275 .53543 m
.35264 .35886 L
s
.0479 .47212 m
.15778 .29555 L
s
.90176 .62293 m
.7069 .55962 L
s
.90176 .62293 m
.78133 .45717 L
s
.90176 .62293 m
.76779 .782 L
s
.7069 .55962 m
.51204 .4963 L
s
.7069 .55962 m
.58647 .39386 L
s
.7069 .55962 m
.57293 .71869 L
s
.7069 .55962 m
.81679 .38305 L
s
.51204 .4963 m
.31718 .43299 L
s
.51204 .4963 m
.39161 .33055 L
s
.51204 .4963 m
.37807 .65538 L
s
.51204 .4963 m
.62193 .31973 L
s
.31718 .43299 m
.12232 .36968 L
s
.31718 .43299 m
.19675 .26723 L
s
.31718 .43299 m
.18321 .59206 L
s
.31718 .43299 m
.42707 .25642 L
s
.12232 .36968 m
.23221 .1931 L
s
.97619 .52049 m
.78133 .45717 L
s
.97619 .52049 m
.85576 .35473 L
s
.97619 .52049 m
.84222 .67956 L
s
.78133 .45717 m
.58647 .39386 L
s
.78133 .45717 m
.6609 .29142 L
s
.78133 .45717 m
.64736 .61625 L
s
.78133 .45717 m
.89122 .2806 L
s
.58647 .39386 m
.39161 .33055 L
s
.58647 .39386 m
.46604 .2281 L
s
.58647 .39386 m
.4525 .55293 L
s
.58647 .39386 m
.69636 .21729 L
s
.39161 .33055 m
.19675 .26723 L
s
.39161 .33055 m
.27118 .16479 L
s
.39161 .33055 m
.25764 .48962 L
s
.39161 .33055 m
.5015 .15397 L
s
.19675 .26723 m
.06278 .42631 L
s
.19675 .26723 m
.30664 .09066 L
s
.85576 .35473 m
.6609 .29142 L
s
.85576 .35473 m
.73533 .18897 L
s
.85576 .35473 m
.72179 .5138 L
s
.6609 .29142 m
.46604 .2281 L
s
.6609 .29142 m
.54047 .12566 L
s
.6609 .29142 m
.52693 .45049 L
s
.6609 .29142 m
.77079 .11485 L
s
.46604 .2281 m
.27118 .16479 L
s
.46604 .2281 m
.34561 .06235 L
s
.46604 .2281 m
.33207 .38718 L
s
.46604 .2281 m
.57593 .05153 L
s
.27118 .16479 m
.13721 .32386 L
s
.73533 .18897 m
.54047 .12566 L
s
.73533 .18897 m
.6149 .02322 L
s
.73533 .18897 m
.60136 .34805 L
s
.54047 .12566 m
.34561 .06235 L
s
.54047 .12566 m
.4065 .28473 L
s
.34561 .06235 m
.21164 .22142 L
s
.6149 .02322 m
.48093 .18229 L
s
.42407 .92358 m
.22921 .86026 L
s
.42407 .92358 m
.30364 .75782 L
s
.42407 .92358 m
.53396 .74701 L
s
.22921 .86026 m
.10878 .69451 L
s
.22921 .86026 m
.3391 .68369 L
s
.69336 .88445 m
.4985 .82113 L
s
.69336 .88445 m
.57293 .71869 L
s
.69336 .88445 m
.80325 .70788 L
s
.4985 .82113 m
.30364 .75782 L
s
.4985 .82113 m
.37807 .65538 L
s
.4985 .82113 m
.60839 .64456 L
s
.30364 .75782 m
.10878 .69451 L
s
.30364 .75782 m
.18321 .59206 L
s
.30364 .75782 m
.41353 .58125 L
s
.10878 .69451 m
.21867 .51793 L
s
.76779 .782 m
.57293 .71869 L
s
.76779 .782 m
.64736 .61625 L
s
.76779 .782 m
.87768 .60543 L
s
.57293 .71869 m
.37807 .65538 L
s
.57293 .71869 m
.4525 .55293 L
s
.57293 .71869 m
.68282 .54212 L
s
.37807 .65538 m
.18321 .59206 L
s
.37807 .65538 m
.25764 .48962 L
s
.37807 .65538 m
.48796 .4788 L
s
.18321 .59206 m
.06278 .42631 L
s
.18321 .59206 m
.2931 .41549 L
s
.84222 .67956 m
.64736 .61625 L
s
.84222 .67956 m
.72179 .5138 L
s
.84222 .67956 m
.9521 .50299 L
s
.64736 .61625 m
.4525 .55293 L
s
.64736 .61625 m
.52693 .45049 L
s
.64736 .61625 m
.75725 .43967 L
s
.4525 .55293 m
.25764 .48962 L
s
.4525 .55293 m
.33207 .38718 L
s
.4525 .55293 m
.56239 .37636 L
s
.25764 .48962 m
.06278 .42631 L
s
.25764 .48962 m
.13721 .32386 L
s
.25764 .48962 m
.36753 .31305 L
s
.06278 .42631 m
.17267 .24973 L
s
.91665 .57712 m
.72179 .5138 L
s
.91665 .57712 m
.79622 .41136 L
s
.72179 .5138 m
.52693 .45049 L
s
.72179 .5138 m
.60136 .34805 L
s
.72179 .5138 m
.83168 .33723 L
s
.52693 .45049 m
.33207 .38718 L
s
.52693 .45049 m
.4065 .28473 L
s
.52693 .45049 m
.63682 .27392 L
s
.33207 .38718 m
.13721 .32386 L
s
.33207 .38718 m
.21164 .22142 L
s
.33207 .38718 m
.44196 .2106 L
s
.13721 .32386 m
.2471 .14729 L
s
.79622 .41136 m
.60136 .34805 L
s
.79622 .41136 m
.67579 .2456 L
s
.79622 .41136 m
.9061 .23479 L
s
.60136 .34805 m
.4065 .28473 L
s
.60136 .34805 m
.48093 .18229 L
s
.60136 .34805 m
.71125 .17147 L
s
.4065 .28473 m
.21164 .22142 L
s
.4065 .28473 m
.28607 .11898 L
s
.4065 .28473 m
.51639 .10816 L
s
.21164 .22142 m
.32153 .04485 L
s
.87065 .30892 m
.67579 .2456 L
s
.87065 .30892 m
.75022 .14316 L
s
.67579 .2456 m
.48093 .18229 L
s
.67579 .2456 m
.55536 .07985 L
s
.48093 .18229 m
.28607 .11898 L
s
.75022 .14316 m
.55536 .07985 L
s
.44464 .89526 m
.24978 .83195 L
s
.44464 .89526 m
.32421 .72951 L
s
.24978 .83195 m
.12935 .66619 L
s
.71393 .85613 m
.51907 .79282 L
s
.71393 .85613 m
.5935 .69038 L
s
.51907 .79282 m
.32421 .72951 L
s
.51907 .79282 m
.39864 .62706 L
s
.51907 .79282 m
.3851 .95189 L
s
.32421 .72951 m
.12935 .66619 L
s
.32421 .72951 m
.20378 .56375 L
s
.78836 .75369 m
.5935 .69038 L
s
.78836 .75369 m
.66793 .58793 L
s
.78836 .75369 m
.65439 .91276 L
s
.5935 .69038 m
.39864 .62706 L
s
.5935 .69038 m
.47307 .52462 L
s
.5935 .69038 m
.45953 .84945 L
s
.39864 .62706 m
.20378 .56375 L
s
.39864 .62706 m
.27821 .46131 L
s
.39864 .62706 m
.26467 .78614 L
s
.20378 .56375 m
.08335 .39799 L
s
.86279 .65125 m
.66793 .58793 L
s
.86279 .65125 m
.74236 .48549 L
s
.86279 .65125 m
.72882 .81032 L
s
.66793 .58793 m
.47307 .52462 L
s
.66793 .58793 m
.5475 .42218 L
s
.66793 .58793 m
.53396 .74701 L
s
.47307 .52462 m
.27821 .46131 L
s
.47307 .52462 m
.35264 .35886 L
s
.47307 .52462 m
.3391 .68369 L
s
.27821 .46131 m
.08335 .39799 L
s
.27821 .46131 m
.15778 .29555 L
s
.27821 .46131 m
.14424 .62038 L
s
.93722 .5488 m
.74236 .48549 L
s
.93722 .5488 m
.81679 .38305 L
s
.93722 .5488 m
.80325 .70788 L
s
.74236 .48549 m
.5475 .42218 L
s
.74236 .48549 m
.62193 .31973 L
s
.74236 .48549 m
.60839 .64456 L
s
.5475 .42218 m
.35264 .35886 L
s
.5475 .42218 m
.42707 .25642 L
s
.5475 .42218 m
.41353 .58125 L
s
.35264 .35886 m
.15778 .29555 L
s
.35264 .35886 m
.23221 .1931 L
s
.35264 .35886 m
.21867 .51793 L
s
.15778 .29555 m
.02381 .45462 L
s
.81679 .38305 m
.62193 .31973 L
s
.81679 .38305 m
.69636 .21729 L
s
.81679 .38305 m
.68282 .54212 L
s
.62193 .31973 m
.42707 .25642 L
s
.62193 .31973 m
.5015 .15397 L
s
.62193 .31973 m
.48796 .4788 L
s
.42707 .25642 m
.23221 .1931 L
s
.42707 .25642 m
.30664 .09066 L
s
.42707 .25642 m
.2931 .41549 L
s
.23221 .1931 m
.09824 .35218 L
s
.89122 .2806 m
.69636 .21729 L
s
.89122 .2806 m
.77079 .11485 L
s
.89122 .2806 m
.75725 .43967 L
s
.69636 .21729 m
.5015 .15397 L
s
.69636 .21729 m
.57593 .05153 L
s
.69636 .21729 m
.56239 .37636 L
s
.5015 .15397 m
.30664 .09066 L
s
.5015 .15397 m
.36753 .31305 L
s
.30664 .09066 m
.17267 .24973 L
s
.77079 .11485 m
.57593 .05153 L
s
.77079 .11485 m
.63682 .27392 L
s
.57593 .05153 m
.44196 .2106 L
s
.3851 .95189 m
.26467 .78614 L
s
.65439 .91276 m
.45953 .84945 L
s
.65439 .91276 m
.53396 .74701 L
s
.45953 .84945 m
.26467 .78614 L
s
.45953 .84945 m
.3391 .68369 L
s
.26467 .78614 m
.14424 .62038 L
s
.72882 .81032 m
.53396 .74701 L
s
.72882 .81032 m
.60839 .64456 L
s
.53396 .74701 m
.3391 .68369 L
s
.53396 .74701 m
.41353 .58125 L
s
.3391 .68369 m
.14424 .62038 L
s
.3391 .68369 m
.21867 .51793 L
s
.14424 .62038 m
.02381 .45462 L
s
.80325 .70788 m
.60839 .64456 L
s
.80325 .70788 m
.68282 .54212 L
s
.60839 .64456 m
.41353 .58125 L
s
.60839 .64456 m
.48796 .4788 L
s
.41353 .58125 m
.21867 .51793 L
s
.41353 .58125 m
.2931 .41549 L
s
.21867 .51793 m
.02381 .45462 L
s
.21867 .51793 m
.09824 .35218 L
s
.87768 .60543 m
.68282 .54212 L
s
.87768 .60543 m
.75725 .43967 L
s
.68282 .54212 m
.48796 .4788 L
s
.68282 .54212 m
.56239 .37636 L
s
.48796 .4788 m
.2931 .41549 L
s
.48796 .4788 m
.36753 .31305 L
s
.2931 .41549 m
.09824 .35218 L
s
.2931 .41549 m
.17267 .24973 L
s
.9521 .50299 m
.75725 .43967 L
s
.9521 .50299 m
.83168 .33723 L
s
.75725 .43967 m
.56239 .37636 L
s
.75725 .43967 m
.63682 .27392 L
s
.56239 .37636 m
.36753 .31305 L
s
.56239 .37636 m
.44196 .2106 L
s
.36753 .31305 m
.17267 .24973 L
s
.36753 .31305 m
.2471 .14729 L
s
.83168 .33723 m
.63682 .27392 L
s
.83168 .33723 m
.71125 .17147 L
s
.63682 .27392 m
.44196 .2106 L
s
.63682 .27392 m
.51639 .10816 L
s
.44196 .2106 m
.2471 .14729 L
s
.44196 .2106 m
.32153 .04485 L
s
.9061 .23479 m
.71125 .17147 L
s
.71125 .17147 m
.51639 .10816 L
s
.51639 .10816 m
.32153 .04485 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[193]:=",
  ImageSize->{273.812, 266.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004A00012PP10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l74PL00?l74PL00?l74PL00?l74PL00?l7
4PL00?l74PL00:L700<01`L0I`L00:H700<01`00J0L00:D700@01`L0J0L00:@700<01`L00PL00`07
1`1U1`00Y0L00`071`031`0300L706@7002S1`0300L700D700<01`L0H`L005L70P191`0300L700H7
00<01`L0H`L005H700<01`000`151`0300L700P700<01`L0HPL005H700<01`000`L303h70P000`L0
1`0;1`0300L70647001E1`0500L71`001@L303X700<01`000`0<1`0300L70607001E1`0300L70087
00<01`L01@L403D70P000`L000021`<02@L00`071`1P1`00E0L00`071`041`0300L700801PL30347
0P021`801@L300L700<01`L0G`L005<700<01`L01@L0100700L400H70`0^1`8000D700L700071`@0
10L00`071`1N1`00D`L00`071`061`0400L700<70`061`<0:PL200031`0700<700<01`L020L30087
00<01`L0G@L0058700<01`L01PL00`0700021`0300L700<70`061`<09PL200031`0700@700<01`L0
2`L305l7001A1`0300L700L700@01`L00PL00`071`051`@01@L3028710071`0300L700d70`1L1`00
D@L00`071`061`0500L71`000`L00`071`081`<01@L301h700<01`000`071`0300L700d700<01`00
0P1I1`00D0L00`071`061`0300L700<700@01`L03@L300D70`0J1`0300L000800PL300@700<01`L0
3@L00`071`021`<0EPL0050700<01`L00P031`0300L700D700@01`L03`L300D70`0F1`0300L700<0
1@L3008700<01`L03@L00`071`041`<0D`L004l700D01`L01`0400T700@01`L04@L300D7100B1`04
00L0008700<01`L01@L400l700<01`L01PL30507001>1`0300L7008000D700L01`0300H700D01`L7
000C1`<01PL300h700@01`L010L00`071`071`<03PL00`071`081`<0C@L004h700@01`L00`L00`07
1`031`<010L010071`0F1`<01PL300X700@01`L01@L00`071`081`0300L000802`L00`071`0;1`@0
B@L004d700<01`L00P031`801`L3008700@01`L060L300H70`061`0300L700801PL00`071`081`04
00L71`<02@L00`071`0>1`<0APL004`700<01`L00P031`0400L700T70`031`0300L701P70`061`<0
0PL01@071`L000P700<01`L020L00`071`031`<01`L00`071`0@1`<0@`L004`700@01`000`L01@07
1`L000`70`000`L01`0K1`@00PL00`070003008700<01`L01`L00`071`081`0300L700H70P061`03
00L701870`101`00B`L01@0700L0008700<01`L00`L00`071`0:1`0300L000807`L300031`000087
0`0:1`0300L700P700<01`L01`L300<700<01`L05@L203h7001;1`8000D7000700071`0300L700X7
00<01`L0100M1`0300L000800PL200031`0000801`L00`071`081`0300L700T70`000`L01`0E1`03
00L003d7001:1`0500L000L010071`0300L700T700D01`L700021`806`L01@071`0700<01PL300D7
00<01`L020L00`071`0;1`<050L200031`0703`700191`0700L01`0700031`<010L00`071`0:1`04
00L700@70`0G1`0400L700<71@061`<00PL00`071`081`0300L700h70`0@1`800`L00`071`0j1`00
B@L200041`071`801@L3008700<01`L02PL010071`061`<04`L010071`031`8000<700L010061`@0
2PL00`071`0=1`0300L700<03@L200@700<01`L0>@L004P70P021`0300L0008700<01`L01@L400`7
00@01`L020L3010700<01`000`L200051`071`000`L300H70`091`0300L700d700<01`L00PL300T7
0P061`0300L703P700171`800PL00`0700041`0300L700P70`091`0500L71`002PL300`700<01`00
0`L01P070007008700<01`L00`L300@700<01`000P061`0300L700h700<01`L010L300D70P071`03
00L703P700171`8000@700L01@L00`071`081`0300L700<01`L010071`0=1`<020L00`0700031`05
00L01`000PL010071`071`@000<700L00PL400<700<01`L03@L00`071`071`<000@700L020L00`07
1`0g1`00APL200870P071`0300L700P700<01`L00PL300D700@01`L03`L300D70P031`0500L01`00
0`L01@071`L000X70`061`<000<700L03PL00`071`091`<02PL00`071`0f1`00@`L200041`071`80
2@L00`071`081`0300L700@70`031`0400L701470`0010L01`031`0400L000D700@01`L03@L300H7
0`0?1`0300L700L700@01`002`L00`071`0e1`00@PL00`07000500X700<01`L020L00`071`071`@0
0`L00`071`0A1`<00`L0100700071`0400L700`700<01`L00`051`@03@L00`071`051`0300L70080
2`L00`071`0e1`00@PL00`0700031`<02PL00`071`081`0300L700T70`000`L01`0B1`8000@70000
0PL00`071`071`0400L700`700<01`L00PL300<700<01`L00`0:1`0300L700D700<01`000PL00`07
1`091`0300L703@700111`0300L0008000<700000PL300P700<01`L020L00`071`0:1`@04@L20087
1P091`0500L71`0030L00`071`041`<000<700L00`L400L700<01`L00`L010071`031`0300L700T7
00<01`L0<`L0044700<01`000PL200H710051`0300L700P700<01`L02@L010071`L300h700<01`L0
0P000`L000021`<01`L010071`0<1`0300L700L70`071`<01@L01@071`L0008700<01`L00`L00`07
1`091`0300L7038700101`0300L000<70P021`801PL3008700<01`L020L00`071`0:1`0600L71`07
10091`0300L700800`L00`071`031`<01@L010071`0<1`0300L700P710071`<00`L00`0700021`03
00L700@700<01`L02@L00`071`0b1`00?`L0100700021`0600L01`0710061`@02PL00`071`0:1`04
00L700D70`051`0400L71`800PL00`0700071`@000<700L00PL00`071`0:1`0300L700P700<01`L0
0`071`D00`L00`071`051`0300L700T700<01`L0<@L003l70`021`800PL010071`031`<01PL300T7
00<01`L02PL010071`071`<00PL00`071`02008700D01`L7000:1`<00`L00`071`0:1`0300L700L7
00<01`L00`L400<700<01`000`000`L01`081`0300L700T700<01`L0<0L003h70P000`L01`020087
00<01`000PL00`071`031`<010L00`07000200L700<01`L02@L01@071`L000T70`000`L000021`80
0`L00`071`0;1`@030L00`071`081`0300L700H7100010L01`L400T700<01`L020L00`071`0`1`00
?@L01@07000700800`L010071`021`0300L700D710000`L01`021`<010L00`071`0:1`0400L700T7
0P001@L0000700801@L00`071`0;1`0300L000802`L00`071`081`0300L700L71@021`0300L700<0
1PL00`071`091`0300L702l7000m1`<00PL2008700D01`L700031`0300L700P70`051`<00PL00`07
1`0:1`0400L700L70P000`L01`0500H700<01`L02PL010071`L400T700<01`L020L00`071`061`04
00L01`@01@L300@700<01`L02@L00`071`0^1`00?0L200031`0700800PL00`071`031`0400L700d7
0`051`@030L010071`051`8000T700L01`0700L00`041`0300L700X700@01`L00`L300L700<01`L0
1`L00`071`051`0300L000<710071`<00PL00`071`091`0300L702d7000l1`0300L0008000@700L0
1`L010071`0<1`0300L700<01@L300X700D01`L700031`0800L01`0700L200D70`000`L01`0<1`04
00L700D70`041`0300L700P700<01`L00`L00`0700041`<000<700L020L400X700<01`L0;@L003/7
00<01`001P091`0400L700`700<01`L00PL300<700<01`000`071`0400L7008700X01`0700L01`07
0P071`<03@L010071`071`<00PL00`071`081`0300L700870P041`0600L000L030L300T700<01`L0
;0L003X700<01`L00P001@L01`0700<01PL010071`0=1`0300L700@70`000`L01`031`<01@L01@07
1`07008000@700L70P001@L01`L000T70`0:1`0500L71`002@L400T700@01`L70P051`800PL00`07
000<1`0300L000801`L00`071`0[1`00>PL0100700021`801@L300@700@01`L030L00`071`071`<0
1PL300<700D01`L01`0200870P000`L01`021`0300L700P700<01`000P081`0400L700`710071`04
00L000D700<01`000PL010071`0<1`0400L71`801PL00`071`0Z1`00>@L00`071`0200031`070080
1`L400051`071`0030L00`071`081`@01PL400031`0700800PL2008700<01`L00PL00`071`071`03
00L700870`061`0400L700`700<01`L00`051`801@L00`0700041`0400L700/700<01`L00`L300<7
00<01`L0:PL003P700<01`L00P0010L01`021`0300L700P70`021`0300L700X700<01`L020L00`07
1`0300H70`000`L01`021`0400L700H700<01`L01`L00`071`041`<010L010071`0<1`0300L70087
0`021`801@L200H700<01`0030L00`071`051`<000<700L0:PL003L70P000`L000021`800`L00`07
1`0:1`@030L00`071`091`0300L7008710021`0300L000<000<700L00PL00`071`051`0300L700L7
00<01`L01PL2008700D01`L7000<1`0300L700@710041`801`L010071`0<1`0300L700L70`0Z1`00
=PL200051`0000L00P051`0300L700X700<01`L00`0:1`0300L700T700<01`L01@L300031`000087
0`000`L01`071`0300L700L700<01`L020L4008700<01`L02PL00`071`051`0300L000800PL00`07
1`071`0400L700`700<01`L02@L302L7000f1`D00PL00`071`051`0300L700X700D01`L01`0300P7
00<01`L020L00`071`061`0300L000800PL200041`0000P700<01`L01`L00`071`0:1`<000<700L0
2`L00`071`031`0500L700L0100:1`0400L700/700<01`L02@L00`071`0302@7000e1`<000<70000
0`081`0300L700T700@01`L010L300H700<01`L020L00`071`051`0300L00087100010L01`L400D7
00<01`L01`L00`071`0:1`0300L0008030L010071`L200041`001`<000@700001`L010071`0<1`03
00L700T700<01`L00PL30247000d1`8000<700L00`021`<01@L00`071`0:1`0400L700H70`031`03
00L700T700<01`L00`L00`0700031`8000@700001PL300<700<01`L01`L00`071`0:1`0400L71`<0
2@L00`071`0200031`0000<700<01`L00`L400@700@01`L030L00`071`091`0300L700@70`0N1`00
<`L01P070007008700<01`L00`L300<700<01`L02PL010071`081`<000<700L02PL01P071`L01`80
0PL300031`0700@01PL400T700<01`L02`L010071`021`<01`L300870P021`0300L000P70`021`04
00L700`700<01`L020L00`071`071`<06`L0038700@01`000PL01@0700L000L71@0<1`0400L700X7
0`0:1`0700L71`0700021`800PL010071`031`<01PL300P700<01`L02`L010071`041`<01@L20003
1`00008700D01`L7000:1`@00PL00`071`091`0300L700T700<01`L02@L201T7000a1`0400L00087
00<01`000`L00`071`081`<02PL010071`0<1`D01`L0100700L200081`0700L01`021`0300L700<7
0`051`@01PL00`071`0:1`0500L71`001PL300031`0000<00PL200<700<01`L02`L400`700<01`L0
2@L00`071`081`0300L701P7000a1`0300L0008700@01`000`L00`071`091`0300L0008020L01007
1`0<1`0400L71`<01@L02007000700L00PL010071`021`0300L700D710000`L01`021`<010L00`07
1`0:1`0400L700T710000`L01`0200D700<01`L02`L00`07000200/700<01`L02@L00`071`071`03
00L701P7000`1`0300L000<70`051`0300L700T700@01`L70`061`0400L700`700<01`L00`L30087
0`021`800PL01@071`L000<700<01`L020L300D70`000`L01`0<1`0400L700L700<01`0010000`L0
00061`0300L700/700<01`L010091`0300L700P700<01`L01PL00`071`0I1`00;`L200041`071`80
00<700L01@L00`071`091`0300L700<70`041`0300L000d700<01`L01@L500061`0700L01@L01007
1`0=1`<01@L300d700@01`L01@L01`07000700L010071`0300L700X700@01`L00`L400D700<01`L0
2@L00`071`051`0300L701T7000^1`0300L000D000<700L01`L00`071`081`0300L700H70`001@L0
1`L000`700<01`L01PL00`07000200041`0700L700@01`L03@L00`07000200D70`0:1`0500L71`00
0`L00`071`0200031`0700800PL300@700<01`L02`L010071`061`<00`L00`071`091`0300L700<7
00<01`L06PL002h700<01`000`L300T700<01`L02@L00`071`081`<00PL00`071`0:1`0300L700@7
2@091`0400L700`700<01`L00PL300<700<01`000`071`0400L7008700<01`L00P001PL01`0700D7
0`021`0300L700/700@01`L020L300031`0700X700D01`L7000M1`00;@L00`07000200041`001`@0
1`L00`071`091`0300L700X70`0=1`0300L700870P0010L000L300041`0000H700@01`L03@L00`07
1`041`@01@L300D700L01`L01`0700800PL200041`0700L7100<1`0500L71`002PL300X700D01`L7
000M1`00;@L300870P000`L000031`@010L00`071`091`0300L700T700<01`L00`0:1`0300L70087
00@01`000PL200D70`041`0400L700d700<01`L01PL300H70`031`0400L7008700<01`L00P000`L0
1`021`0300L700P70`0:1`0400L700`710081`0300L001h7000/1`<00`L300031`00008010L30087
00<01`L020L00`071`0:1`0500L700L010071`0400L700870P021`<01`L3008700@01`L03@L00`07
1`071`@01PL400031`0700800PL01@0700L000<700<01`L020L00`071`0300P700@01`L030L00`07
1`0400D700<01`L07@L002/700@01`000PL00`0700021`0400L71`<010L300/700<01`L02PL01007
1`041`<01@L200870P021`800PL00`071`071`<00`L00`071`0:1`0300L700L700@01`L70`061`<0
00<700000PL200031`0700@700<01`L020L00`071`021`<01@L01@071`L000`700<01`L00`L30087
0P0N1`00:`L300870P000`L000021`0300L700<70`041`<02@L00`071`0:1`0300L000L70`021`80
00<700000PL200<700<01`L02PL400d700<01`L01`L00`071`031`@00PL00`07000300031`000087
00<01`L010L00`071`081`0300L700@70`031`0500L71`002`L00`071`061`@07PL002X70P000`L0
1`0200051`071`000PL00`071`051`<00PL00`07000200L700<01`L02@L010071`091`L00PL00`07
1`031`0300L700X700<01`000P0<1`0300L700L700<01`L01PL300031`0000870`000`L01`071`03
00L700L700<01`L01`L300051`071`0030L00`071`061`0400L001d7000Y1`8000<700L00P000`L0
1`021`0500L71`002@L300@70`041`0300L700X700@01`L02@L5008700<01`L01@L00`071`0:1`03
00L700@02PL00`071`071`0300L700H700<01`000P021`8000@700001`L00`071`081`0300L700T7
0`021`0300L700X700<01`L010L010071`0N1`00:@L00`0700021`<01@L010071`0<1`<010L30087
00<01`L02PL00`0700081`<000<700000`071`0300L700X700@01`L00`L200P700<01`L01`L00`07
1`061`0500L000L0100010L01`L300D700<01`L020L00`071`0:1`D030L00`071`021`0300L70080
7PL002P700D01`L01`0300L700@01`L030L00`07000200@7100<1`0300L000H70P000`L01`040004
1`0000D700<01`L02PL010071`041`<01PL00`071`071`0300L700@700@01`000`L00`07000200D7
0`031`0300L700P700<01`L02PL00`071`0300X700<01`L00PL01007000O1`009`L200061`0000L0
2@L010071`0<1`0400L71`<010L300X700@01`L010L01P070007008700<01`L00`L4008700<01`L0
2PL010071`061`<010L00`071`071`0300L7008700D01`0700021`8000<700L010051`<000<700L0
20L00`071`0;1`0500L700L010071`0400L700870P0O1`009`L00`07000600P700@01`L030L00`07
1`041`800`L00`07000300L700@01`L00PL0100700021`0300L0008020L400`700@01`L020L30003
1`0700T700H01`L700L2008700@01`L00PL010071`L300D70`091`0300L700X700D01`L700041`<0
1@L200870P0P1`009PL00`071`0200031`0000870`061`0400L700`700<01`L01@L300031`0700<7
0`051`0300L000870`021`0400L0008700<01`L020L300X700@01`L02`L300T700T01`L01`0700L0
0P0010L01`021`0300L700<70`041`@01`L00`071`0:1`0500L71`001PL300<700@01`008@L002D7
0P000`L000021`801@L300@700@01`L030L00`071`071`<01PL300<700H01`001`021`0400L000<7
00<01`L02@L00`07000200P700@01`L03@L300L70P001@L01`0700800PL010071`021`0300L700D7
100010L01`L200H700<01`L02PL010071`091`D000<700L080L002@70P021`8000D700L700071`D0
0`L00`071`0:1`0300L700P710061`@000@700000`L200031`0700<700<01`L02@L010071`L300H7
00@01`L03@L00`07000200D70P000`L01`02008700D01`L700031`0300L700P70`031`<00`L00`07
1`0:1`0500L71`002PL40287000S1`800PL200031`0700<700<01`L020L300031`0700/700<01`L0
2@L00`071`0300H71@021`8000<700L01@L00`071`081`0300L700@70`041`0300L000d700<01`L0
0PL300071`0000L01`0200031`0700@700@01`L030L400<70`000`L01`0;1`0500L71`0020L20003
1`070287000R1`0400L01`800PL00`071`021`0300L700X7100<1`0300L700T700<01`L00PL300<7
00<01`000`001@L01`L000L700<01`L020L00`071`061`D00PL00`071`0;1`0300L700@71@001@L0
00L000L700@01`L030L00`071`0300<70`0<1`0500L71`001PL2008700<01`L08@L002870P001PL0
000700H700<01`L02PL00`071`0300X700<01`L02@L00`071`041`@000@700L71@081`0300L700T7
00<01`L02@L300031`0700`700<01`L00`L200051`0000L00P091`0400L700`700<01`L00PL300<7
0`0:1`0400L700H70P000`L01`0S1`008@L00`07000300031`0000L700<01`L02@L010071`021`<0
20L00`071`081`0300L700H71@0010L000L400L700<01`L02@L00`071`0:1`@03@L010071`L20087
1P091`0500L71`002`L00`071`051`@00PL300L700D01`L700041`800PL00`071`0R1`0080L01@07
000700D01`L00`071`0:1`0400L700@70`051`0300L700T700<01`L01@L300031`00008000<700L0
0PL400@700<01`L020L00`071`0:1`0300L700@02PL01@071`L000870P000`L000021`<01`L01007
1`0<1`0300L700L70`031`<01@L01@071`L000870P021`0300L702<7000O1`0600L01`070`021`<0
1@L00`071`0:1`0400L700H70`031`0300L700T700<01`L00`L300<71@071`<00PL00`071`081`03
00L700X700@01`L00PL300P700<01`000PL200870P051`<01@L010071`0<1`0300L700P710031`<0
0`L01`071`L01`000PL00`071`0T1`007PL00`071`0200051`001`001@L300<700<01`L02@L01@07
1`L000P70`000`L01`0:1`0600L71`070P021`@000<700000P071`<02`L00`071`0:1`0400L700@7
10051`0400L71`8000D7000700071`@000<700L00PL00`071`0:1`0300L700L700@01`L70`031`@0
0`L200<700<01`L090L001d700<01`L00P021`<000<700L01PL500/700@01`L02`L300X700@01`L7
0`021`8000D7000700031`<01`L300P700<01`L02`L00`0700081`<000D700001`0200031`0000<7
00<01`L020L300<700<01`L02@L00`071`081`0300L700<710021`800PL2008700<01`L09@L001d7
00@01`000PL300<700<01`L020L300X700@01`L030L500L700L01`001`07008000L700L700L000D7
0`051`0300L000801PL00`071`0:1`0400L700X71P021`0300L7008700<01`L02`L400`700<01`L0
20L00`071`061`<000D700001`0202P7000L1`0400L700870P000`L01`021`0300L700T700<01`00
0P071`0500L71`0030L010071`L300D70P0020L01`0700L00`L00`0700071`@000<700L00`L300@7
00<01`L02PL010071`091`8000H700001`061`0300L700/700<01`000P0;1`0300L700P700<01`L0
1`L400<700<01`L09PL001/700@01`L00`L00`0700051`0300L700T700@01`L70`051`0400L700d7
00<01`L00`L300870`021`8000<700L00`L010071`0:1`<01PL3008700<01`L02PL00`0700081`80
00<700L01@061`0300L700X700@01`L710091`0300L700L700<01`L01PL00`071`0602P7000J1`80
0PL010071`021`0300L700@700<01`L020L00`071`041`<00`L010071`0<1`0300L700H71@001@L0
00L000H700<01`003@L300H70`0=1`0300L000H70P001@L01`0700800PL300@700<01`L02PL01007
1`031`<01PL00`071`081`0300L700D700L01`001`0700<09`L001/710001@L000L000P700<01`L0
20L00`071`061`<000D700L7000<1`0300L700D70P001@L00007008020L00`07000=1`0300L00080
1PL300X700@01`L010L0200700L01`070P051`<000<700L030L010071`051`<010L00`071`081`03
00L700<700@01`000`L01@0700L002H7000K1`800PL400T700<01`L02@L00`071`081`<00PL00`07
1`0:1`0300L700@700<01`001P091`0300L000`700<01`L00PL300@700<01`000`071`0400L70087
00P01`0700L01`8000<700L01PL300d700@01`L01`L3008700<01`L020L02@071`L01`0700021`<0
0PL00`071`0T1`006`L2008700<01`L00`081`0300L700T700<01`L02@L400d700<01`L00PL00`07
1`0200031`0000870`061`0400L700`700<01`L010L3008700<01`L00PL300D700<01`000PL20004
1`071`<00PL00`071`081`<02PL01@071`L000T70`0:1`0400L71`8000<700L00PL300<700<01`L0
8`L001X70P001@L0000700800PL400D700<01`L020L00`071`0:1`0300L700<02PL010071`L20003
1`0000870P051`<010L00`07000=1`0300L700H70`071`<00`L01@07000700800PL300@700<01`L0
20L00`07000200P700@01`L030L400L700@01`000PL020071`0700L00`L00`071`0R1`006@L20087
0P031`@00`L300<700<01`L020L00`071`091`0600L71`0710071`0400L000870P001@L000L000L7
0`021`0300L000d700<01`L020L300L710000`L0000200870P000`L01`041`0300L700L700<01`L0
0PL300H700@01`L030L00`071`0300D70P021`0600L700L00`L01@071`L002<7000I1`8000@70000
0`L010071`L300<7100;1`0300L700T700D01`L700041`<01@L200870P021`0500L71`002@L30087
00<01`L02PL00`071`091`0300L000801`L500<700<01`001`L00`071`071`0300L700@70`041`04
00L700`700<01`L00PL300870P000`L01`021`8010L01@071`L002<7000H1`800PL200031`070087
00<01`L00`L300<70`091`0300L700X700@01`L01`L300051`0700L00P021`0300L7008700<01`L0
2PL400`700<01`L020L00`071`021`@00`L00`07000300051`071`001`L00`071`081`0300L700H7
0P021`0500L71`002`L00`071`051`@000@700L70P061`0500L71`008PL001L700@01`070P031`05
00L71`001`L3008710071`0300L700X700@01`L02@L700031`0000D700<01`L02PL00`07000200/7
00<01`L020L00`071`051`@000@700071@091`0300L700L700<01`L020L4008700<01`L02PL00`07
1`051`0400L000<700<01`L01PL01@071`L00247000F1`0400L01`801@L01@071`L000T70`031`<0
1@L00`071`091`0500L71`0020L00`07000300031`0000L700<01`L02PL0100700L300T700<01`L0
20L00`071`061`D00PL00`07000300P700<01`L01`L00`071`0:1`<000<700L02`L00`071`031`08
00L700L01`0:1`0400L70247000E1`0700L01`0700051`0500L71`0030L300<70`021`0300L700X7
00@01`L01`L01@07000700D01`L00`071`0:1`0400L700<70P071`0300L700T700<01`L01@L01007
00L400031`07008710041`0300L700P700<01`L02PL00`07000200`700D01`L700021`8000@70000
2PL01@071`L00207000D1`0300L7008000<700L01PL01@071`L000`700<01`000P031`@030L01007
1`051`0600L01`07100010L000051`0300L700X700<01`001@L300D700<01`L020L00`071`041`03
00L000<71@071`<00PL00`071`081`0300L700X700@01`L70`091`0300L7008000<700000`L00`07
1`0:1`0500L71`007`L001<700<01`L00`000`L01`071`0500L71`0030L010071`L300<70`0:1`05
00L71`000`L00`071`0200031`0700801@L300<700<01`L02PL00`0700071`<00`L00`071`081`03
00L7008700@01`000PL400031`0000801`L400T700<01`L02`L010071`021`<01`L300870P021`03
00L000`700D01`L7000N1`004`L0100700L400T700@01`L030L00`071`041`800`L500L700L01`L7
00L000870P021`8000<700001`L500`700<01`002@L400/700L01`L700L000870P001@L000L000<7
0`071`<020L00`071`0;1`0400L700@70`051`0300L700800PL01@071`L000/700D01`L7000N1`00
4PL00`071`0400870`061`0500L71`0030L00`071`051`@010L300D700L01`L01`0700800PL20005
1`071`002PL300X700@01`L02`L300T700D01`L01`0200031`0700800PL00`0700051`@010L00`07
000200H700<01`L02PL01@071`L000H70`000`L0000300870P031`0300L700X700D01`L7000M1`00
4@L00`071`02008700<01`L00`L300@700D01`L7000<1`0300L700L70`051`<00`L010071`021`03
00L7008000<700L00PL00`071`091`0300L0008020L00`07000=1`@01`L200091`001`0700L000<7
00<01`0020L3008700@01`L70`041`0300L700X700@01`L02@L400031`0700801@L00`071`0:1`05
00L71`0070L0010700D01`L700021`0300L000L710000`L01`021`0300L700X700<01`L020L400D7
10000`L01`0200<70P000`L01`031`0300L700T700@01`L70`061`0300L000d700<01`L00`051`<0
0PL200031`0700<700@01`L02PL400D70`000`L01`0<1`0400L700L700<01`000`021`801PL00`07
1`0:1`0400L701`7000?1`0500L71`000PL01@071`L000X70`021`0300L700X700<01`L020L01007
1`L300D70`000`L000021`8000<700L01@L00`071`081`0300L700@70`041`0300L000`700<01`L0
0`L300031`00008000<700L00P061`0300L000d70`061`<03@L010071`051`0700L000L01`0300P7
00<01`L02@L01@071`L001/7000>1`0400L71`800PL01@071`L000`71@0<1`0300L700P700<01`L0
0`L3008700<01`000`021`0300L000P700<01`L020L00`071`061`<000D700L7000<1`0300L700D7
10000`L01`0200P700<01`003@L00`07000200H70`0:1`0500L71`000`L0200700L01`070P091`03
00L700X700D01`L7000J1`003PL01@071`L0008700<01`L00`L00`071`0:1`0300L700<02`L00`07
1`081`0300L700D70`000`L000021`<000<700L01`L00`071`091`0300L700P70`000`L01`0<1`03
00L700@71P000`L01`091`0300L000d700@01`L70`041`0300L000<01`L010071`021`0300L70080
00H700L01`0:1`0300L700X700D01`L7000I1`003@L010071`L2008700<01`L010L00`071`0:1`05
00L700L00`091`0300L700P700<01`L01@L00`07000200870P000`L0000200L700<01`L02@L00`07
1`0:1`<03@L00`071`021`8000@7000710091`0400L700`700<01`L010L500D70`051`0700L700L0
1`0200870P0010L01`0:1`0300L700X700@01`L06@L000`700<01`L00`L400L700<01`L02@L01@07
1`L000<70`061`0300L700P700<01`L01@L01@07000700@000<700L00PL300D700<01`L020L00`07
1`0:1`0300L700<02PL00`071`021`0300L0008000<700000PL300L700<01`003@L00`071`071`<0
1PL300<700D01`L01`0200870P000`L01`021`0300L700P700<01`L02@L01@071`L001P7000;1`03
00L700@70P021`<010L00`071`0:1`0500L71`001@L300@700<01`L020L00`071`031`0400L000<7
00<01`000P061`<00`L00`071`081`0300L700X700D01`L01`0400L700@01`L00PL200870P051`<0
1@L00`07000=1`0300L700P710061`@000<700L00P021`0500L01`000`L00`071`081`0300L700X7
00D01`L7000G1`002PL00`071`061`0300L700<70`021`0300L700X700D01`L700071`<00PL00`07
1`081`0500L71`000PL200870P000`L01`0400H7100;1`0300L700X700<01`001@L300D70P021`<0
00D700L700071`@000D700L7000<1`0300L700P700@01`L70`061`<000<700L00PL200031`0700@7
00<01`L020L00`071`0:1`0400L701L700091`0300L700H700<01`001`L400`700@01`L02PL300X7
00H01`L700L200870P001@L01`L000<70`061`<02@L00`071`0;1`0300L000L70`021`8000H70000
1`041`0300L700P70`021`0300L700X700<01`L020L00`071`031`<00`L00`07000300031`000087
00<01`L010L00`071`081`0300L700X700@01`L05PL000T700<01`L01@L01@071`L000X70`091`05
00L71`0030L400L700P01`0700L01`8000@700L00PL00`071`031`<01@L400L700<01`L02PL01007
1`091`@000@700070P041`0300L700/70`0=1`0300L700P700<01`L01@L400031`0000870`000`L0
1`071`0300L700L700<01`L02PL01@071`L001D700081`0300L700H700D01`L7000:1`0300L700<0
1`L01@071`L000`700<01`L00`051`<000P700L01`07008700@01`L01`L400031`07008710041`03
00L700X700<01`002PL800H700<01`L02`L00`07000200X700<01`L02@L00`071`061`0300L00080
0PL200041`0000L700<01`L020L00`071`0:1`0500L71`0050L000L700<01`L01PL00`071`031`03
00L700P700<01`L00PL300D700@01`L03@L00`071`021`<00PL200081`0700L01`031`0500L71`00
2PL300H70`021`0300L700X700<01`0020L200031`0700@01`L00`071`0:1`0500L700L00`081`03
00L700P700<01`L01PL01@07000700@000@700L70`051`0300L700P700<01`L02PL010071`0D1`00
1PL200P700<01`L010L00`071`081`0300L700@70`031`0400L700`700<01`L01@L400031`070080
00<700L010L010071`0=1`<01PL300d700<01`001PL200031`0700@000@700001@L00`071`0:1`03
00L000@70`061`0300L700P700<01`L010L0100700021`8000@700001@L300<700<01`L020L00`07
1`091`0500L71`004`L000L710041`0300L700H700<01`L01`L00`071`071`@00`L00`071`0:1`03
00L700D700<01`000`000`L000071`0400L700d700<01`000P061`<02PL010071`041`0400L00087
0`051`<00PL00`071`0;1`0300L000H70`041`0300L700P700<01`L00PL0100700031`8000<700L0
10051`<000<700L020L00`071`0:1`0500L71`004PL000L700@01`L710091`0300L700P700<01`L0
2@L3008700<01`L02PL00`071`031`8000<700L010091`0400L700`700<01`L00PL300@700<01`00
0P081`0300L000<700H01`0700L200031`0000L7100=1`0300L000P70`000`L01`0:1`0600L71`07
0P021`0400L7008700@01`L70`051`<02@L00`071`0:1`0500L71`004@L000P700<01`L00`L300P7
00<01`L020L00`071`0:1`@03@L00`071`021`0300L000<000<700L00`061`0500L71`0030L00`07
1`041`<00PL010071`L400D700<01`000PL200071`071`0700021`0300L700L70`0;1`0400L700X7
0`0:1`0500L700L00P021`8000@700L00PL00`071`031`<010L400L700<01`L02PL010071`0A1`00
2@L010071`L2008710051`0300L700P700<01`L02@L010071`L300X700D01`L700021`800PL200@7
0`041`0400L700d700<01`L01PL300L70`031`0500L000L00P021`0300L000<700<01`L02@L400T7
00<01`003@L400L70P001@L01`0700800PL00`0700031`0300L700D70`021`0300L700801PL00`07
1`091`0500L71`0040L000X700@01`L710031`<00`L00`071`071`0300L700X700H01`L700L400L7
00<01`000PL200870`071`<00PL010071`0=1`0300L700P70`071`@000<700000P021`8000<700L0
0`L00`071`081`0400L71`<01`L00`07000<1`0400L71`<01@L200031`0700800PL01@071`L000<7
00<01`L01`L300@70`031`0300L700X700D01`L7000?1`002PL01@071`L000<70`031`@02PL00`07
1`0:1`0500L71`0010L300D70P0010L000021`0400L700T70`031`0300L700X700<01`L02@L00`07
000200L71@031`0300L000H700<01`L020L00`071`031`<01@L00`07000<1`0300L700<70`000`L0
000200061`0700L01@L010071`0<1`<010L300031`0700/700@01`L03`L000/700D01`L700051`<0
0`L300T700<01`L02PL010071`071`<000<7000010021`0500L71`0030L300031`0700/700<01`L0
20L00`071`021`@00`L00`07000300051`071`001PL00`071`091`0300L700D70P031`0400L700`7
00<01`L01@L500051`001`001`L010071`0<1`0300L0008010L300`700@01`L03PL000`700D01`L7
00071`<00PL400L700<01`L02@L01@071`L000T7100010L01`L200@700<01`L02PL00`07000200`7
00<01`L020L00`071`051`@000@700L71@081`0300L700P700<01`L01`L300041`0700`700<01`L0
1@L200051`0000L00P081`0500L71`0030L010071`L300@70`091`0500L71`003@L000d700@01`L0
2PL300<70`041`0300L700X700D01`L700081`H000<700001PL00`071`0:1`0300L700@02PL00`07
1`081`0300L700H71@0010L000L400L700<01`L020L00`071`091`<000<700L02`L00`071`031`80
00<700001@091`0400L700`700<01`L010L2008700<01`L00`071`0500L71`0030L000d700D01`L7
000<1`<00`L3008700<01`L02PL010071`071`8000@7000710061`0300L700X700D01`L700021`<0
1`L00`071`091`0300L700D700@01`0710000`L01`021`@010L00`071`081`0300L700X7100<1`03
00L7008700<01`L00P001@L01`0700<01`L010071`0<1`0300L700D710041`<01@L010071`0<1`00
3PL01@071`L000`700<01`000P031`@030L010071`051`0700L000L01`0300041`0000@700<01`L0
2PL010071`051`<01@L00`071`081`0300L700@700<01`000`L500L70`000`L01`0:1`0300L700X7
00<01`L00`0:1`0400L700870P021`801@L300@700D01`L7000<1`0300L700L70`051`<00`L01007
1`0;1`003`L01@071`L000`700@01`L70`031`<02PL01@071`L000<700H01`001`021`801@L30087
00<01`L02PL010071`071`<00`L00`071`081`0300L7008700@01`000PL400031`0000801`L300X7
00<01`L02`L00`0700021`<01`L0100700021`8000D7000700071`@000<700L00PL00`071`0:1`03
00L700L700<01`000P051`@00`L00`071`081`0040L010071`0<1`0300L700@70P021`0300L000<0
1`L01`071`L01`000PL01`071`0700L00P071`@030L010071`091`@02`L010071`L300870P001@L0
00L000<70`071`<020L00`071`0;1`0300L000@70`051`800PL200031`0000<700<01`L020L30087
00<01`L02PL00`071`081`0400L71`<01@L2008700<01`L020L0010700D01`L7000<1`0300L700D7
10041`<01@L020071`0700L00PL01@0700L0008700<01`L01`L400T700D01`L7000;1`<02@L00`07
1`0200051`0700L00P021`0300L000D70`041`0300L700<01PL00`071`0:1`0400L700H70`021`80
00<700000PL00`071`021`0300L700/7100<1`0300L700P700<01`L00`L3008700<01`L00PL00`07
1`071`004@L01@071`L000`700<01`L01`L300D70`031`0500L700L00P001PL01`0700<700<01`L0
20L00`071`0300L700@01`L03@L400L70`0020L01`0700L00PL010071`071`@000<700L00`L300@7
00<01`L02PL00`0700091`L000<700L01@L00`071`0:1`0300L700<02`L00`071`081`0300L700D7
0`051`0300L700H7000B1`0400L700d700<01`L01`L00`07000200D710000`L01`02008700D01`07
00041`0300L700P700<01`L00PL300D700@01`L03@L00`071`0300D700T01`0700L01`0010L01007
1`0:1`<01PL300031`0700`700<01`0020L200041`00008700<01`L01@L00`071`0:1`0500L700L0
0`091`0300L700L700<01`L01PL00`07000200<700<01`L01@L0018700D01`L7000<1`0300L700P7
00@01`L70`051`<000T700L700L01`001PL00`071`071`0300L700D70`031`0400L700`700<01`L0
0`L300031`00008000<700L00P061`0300L000d70`061`<03@L00`0700061`0500L000L01@081`03
00L700X700@01`L00`L300H700<01`L020L00`071`051`0300L7008710071`004`L01@071`L000`7
00<01`L020L00`071`031`<00PL00`07000300051`001`0020L00`071`071`0300L700L710031`03
00L700X700<01`L01@L400031`07008020L00`07000<1`0300L700<01PL300X700@01`L010L01007
00021`<00PL300D700<01`L02PL01@071`L000D70`041`0300L700P700<01`L00`L00`071`061`80
1PL001@700@01`L03@L00`071`081`0300L700D70`000`L000021`<000<700L01`L00`071`081`03
00L700T70`000`L01`0<1`0300L700@700<01`000`000`L01`081`0400L700`700<01`L00PL300@7
00<01`000`071`0300L000<700P01`0700L01`801@L4008700<01`L02PL01@071`L000L70`021`03
00L700P700D01`L700091`0300L700D7000E1`0400L700d700<01`L01`L00`071`061`0300L00080
00D700001`0300P700<01`L020L00`071`0:1`@03@L00`071`021`0300L7008000<700000P091`04
00L700`700<01`L010L300031`0700@70`051`0300L0008700@01`000PL300031`0700L7100<1`04
00L700X70`0:1`0500L71`0020L00`071`061`005@L01@071`L000`700<01`L020L00`071`051`05
00L000L0100010L01`L400D700<01`L01`L00`071`0:1`0400L71`<02PL010071`L200051`0000L0
0P021`<01`L00`07000<1`0300L700L70`071`<00`L01@07000700800PL300<700<01`L020L300/7
00@01`L030L400L700<01`0020L00`071`071`005PL01@071`L000`700<01`L020L00`071`031`04
00L000870P0010L000061`<00`L00`071`071`0300L700X700H01`L700L400L700@01`000PL20087
0P051`<010L010071`0<1`0300L700T70`071`@000<700000P021`0400L000<700<01`L02@L00`07
000200P700D01`L7000<1`0300L700<01@L00`071`071`0300L700L7000G1`0400L700d700<01`L0
20L01P071`L01`800`L200031`0700@01PL400X700<01`L02PL010071`051`<01@L200870`001@L0
1`L000L710001@L01`L000`700<01`L020L00`071`0300L71@031`<01@L00`071`091`0400L71`<0
1PL010071`0=1`0300L700870`021`801`L00`071`081`0060L010071`0<1`0300L700P700@01`L7
0P001@L01`L0008700@01`L00`L300H70`081`0300L700/700@01`L01`L300870P001PL0000700@7
00<01`L020L3008700<01`L02PL00`071`081`0300L7008710031`0300L000<000D7000700061`03
00L700T700<01`L00`L300@700@01`L030L00`071`051`@01PL00`071`091`0060L01@071`L000`7
00<01`L020L01P070007008700H01`L01`021`0300L700<70`051`@01PL00`071`0:1`0500L71`00
2@L400041`001`8010L00`071`0;1`<030L00`071`091`0300L700D7100010L000L500P700<01`L0
20L00`071`061`@000D700L7000<1`0300L700D700@01`0010L00`071`0:1`006@L010071`0=1`03
00L700P700H01`0700L2008700@01`L00PL00`071`051`@000<700L00PL300@700<01`L02PL01007
1`091`0300L000H01PL00`071`0:1`0300L700<02PL00`071`091`0300L700H71@021`0300L000<0
1PL00`071`091`0300L700T70`000`L01`0<1`0300L700<700@01`L010L00`071`0;1`006PL01007
1`0=1`0300L700L70P000`L01`02008700D01`L700031`0300L700P70`051`<00PL00`071`0:1`04
00L700L700H01`0700L400L700<01`L02PL01@071`0700<020L00`071`081`0300L700H700@01`07
10000`L01`021`<010L00`071`091`0300L700X7100=1`0500L71`000PL200<700<01`L030L001/7
00@01`L030L00`071`061`@00PL010071`051`0400L700d70`051`<03@L010071`051`0600L01`07
100010L000041`0300L700/700<01`0010L300H700<01`L020L00`071`041`0400L000871@061`<0
0PL00`071`091`0300L700X700<01`L00`0:1`0500L71`000PL01@071`L000l7000K1`0400L700d7
00<01`L01@L00`071`0400031`0700H700@01`L03@L00`07000200D70`0:1`0500L71`000`L00`07
1`0200870`051`<00PL00`071`0:1`0400L700H70`031`0300L700T700<01`L00PL0100700031`<0
00<700000P061`@02PL00`071`0:1`0600L71`070`081`0300L000870P031`0300L700d7000L1`04
00L700d700<01`L00`L01@071`0700@02@L010071`0<1`0300L700870`031`0300L000<01`L01007
1`021`0700L700L01`0200031`0000L7100<1`0400L700P70`000`L01`0:1`0400L71`8000H700L7
00L200031`0700870`061`<02@L00`071`0:1`0400L700@710051`0300L700800`L00`071`0>1`00
7@L010071`0=1`0500L71`000`L500041`0000H700D01`L7000<1`0300L700@70`000`L01`031`<0
1@L02P071`0700L01`021`0300L0008700<01`L01`L300/700@01`L02PL300X700<01`L00P0010L0
1`L200061`0700L01@L300@700<01`000P071`0300L700X700@01`L01`L3008710031`0300L700l7
000M1`0400L700d700D01`L700021`8000<700001@L300@700@01`L03@L00`071`061`<01PL300<7
00@01`L00PL2008700<01`000`L00`071`081`0300L0008020L010071`0<1`D01`L300041`071`80
00D700L700021`0300L700D710000`L01`021`801PL00`071`0:1`0400L700T710001@L01`L00187
000N1`0400L700d700<01`000PL200031`0700801`L3008700@01`L03@L00`071`071`@01PL40003
1`0700<00PL200031`0700<700<01`L020L010071`L300H700@01`L030L010071`L300D700D01`L0
1`0200031`0700<700@01`L02PL300@70`031`0300L700X700@01`L02PL4008700<01`L04@L001l7
00@01`L03@L010071`L200031`00008700<01`L01`L300<700<01`L02PL00`071`081`0300L700<0
1PL300031`0000<700<01`001PL00`071`081`0300L700<70`041`0400L700`700<01`L00`L30003
1`00008000<700L00P061`0300L000`710041`<000<700L02`L010071`081`0400L0008700<01`L0
4PL0020700@01`L02`L300041`001`800`L00`071`0:1`<000<700L02`L00`071`071`0300L700<7
10021`0300L000<00PL010071`061`0300L700P700<01`L01PL200<700@01`L030L00`071`051`D0
00@7000020L00`07000<1`0300L700<010L300`700@01`L01PL01`0700L01`005@L0020700@01`L0
2PL200041`07008700<01`L00`L00`071`0:1`0300L0008030L00`071`071`0300L700H70`000`L0
00021`<000<700L01`L00`071`081`0300L700L710021`0300L700X700<01`L01@L00`071`030003
1`0700P700@01`L030L00`071`021`<010L300T700D01`L700051`8000D700L7000E1`008@L01007
1`091`800PL200031`0700H700<01`L02PL00`071`0400X700<01`L01`L00`071`061`0300L00080
0PL200041`0000P700<01`L020L00`071`091`<000<700L02`L00`071`031`0300L700L02@L01007
1`0;1`0300L700D70`0010L01`L300L700@01`L010L2008700<01`005PL0028700@01`L01`L20087
00<01`000`061`0300L700X700D01`L700021`8020L00`071`081`0300L700D700D01`L01`040004
1`071`@01@L00`071`081`0300L700X7100<1`0400L71`800PL200031`0000870`071`0300L000`7
00<01`L01`L300@70`051`0400L700870P021`0300L001L7000S1`0300L000H70P031`0400L00087
0`041`0300L700X700@01`L010L300H700<01`L01`L00`071`041`0400L700<71@061`<00PL00`07
1`081`0300L700X700@01`L70`091`0300L700800PL200870P051`<010L010071`0<1`0300L700T7
0`041`<00`L01@071`07008000@700L060L002<700@01`L010L00`0700021`0300L700801@L30087
00<01`L02PL010071`061`<010L00`071`071`0300L7008700<01`L00P021`8000<700L010061`@0
2PL00`071`0:1`0400L700870`071`8000<700L00`001@L01`L000L710001@L01`L000`700<01`L0
20L00`071`0300@710021`<00PL201T7000T1`0400L7008700<01`000`L01P07000700L7100<1`04
00L700P70`000`L01`091`0600L71`070P021`8000D700L700031`<01PL300T700<01`L02PL01007
1`041`<01@L200870P000`L01`031`0300L700P70`021`0300L700T700<01`L02@L00`071`021`@0
0`L2008700<01`L00P0J1`009@L01`0700L01`000`L0100700031`0300L700L710091`0500L71`00
2PL300T700/01`L01`0700L01`0200051`071`001@L300@700<01`000P061`0300L700/700@01`L0
1PL300051`0000L00P021`0300L7008700<01`L02`L300`700<01`L02@L00`071`051`@00PL00`07
000201/7000V1`0600L000L00PL0100700041`0300L700P700<01`L00`071`0400L700d70`071`80
00X700L01`0700L00PL010071`071`@000<700L00PL300@700<01`L02PL010071`091`L000<700L0
1@L00`071`0:1`0300L700<02PL00`071`091`0300L700L70`031`0300L701X7000V1`0300L00080
0`L200031`0700@700<01`L020L00`071`021`<01@L010071`0=1`0300L000801@L200081`0700L0
1`031`0500L71`002PL300D70`021`0300L700X700@01`L01`L0100700L300031`0000L700<01`L0
2PL01@071`0700<020L00`071`081`0300L700H700<01`001@0L1`009`L200041`071`8000<700L0
1PL00`071`071`0300L700D70`031`0400L700`700<01`L00PL300091`0700L01`0700801@L01007
1`0=1`<01@L300d700@01`L01@L00`071`0200031`0000<020L00`071`0:1`0300L000@70`051`03
00L700T700<01`L01@L00`0700031`<06`L002P71P000`L01`071`0300L700P700<01`L01`L400<7
00<01`L02PL00`071`041`D000<700L00P071`0400L700`700<01`L00`051`<02PL01@071`L000<7
00<01`L00P021`<00PL300D700<01`L02PL010071`061`<00`L00`071`091`0300L700<700<01`00
0`L00`07000L1`00:0L00`071`0500T700<01`L020L00`071`091`<000<700L030L00`071`031`80
00@700000PL00`071`071`0400L700`700<01`L00PL300<700<01`000`071`0400L7008700L01`L0
1`07008000<700L010L300<700<01`L02PL010071`081`<000<700L02PL01P071`L01`800PL00`07
000M1`00:0L200041`001`@020L00`071`081`0300L700X7100=1`0400L71`800PL600T700D01`L7
000<1`0300L700@70`000`L01`031`<01@L01P071`0700870P021`<000<700L01PL500`700@01`L0
2PL300X700@01`L70`021`8000<700L070L002L700<01`L00`000`L01`021`@01@L00`071`071`03
00L700X700@01`L70`0:1`0500L71`000PL200031`0000870`071`0400L700`700<01`L01`L300H7
0`031`0400L700870P021`<00`L00`071`081`<02`L00`07000<1`D01`L01`07000700L00P000`L0
1`0M1`009PL010071`L200031`0000L70`021`0300L700P700<01`L02PL01P071`L01`@01`L00`07
00021`800`L00`071`031`<01@L010071`0<1`0300L700P710061`@000<700L00`021`8000<700L0
0PL00`071`091`0300L0008020L010071`0<1`0400L71`<01@L01@070007008000<700L07PL002H7
00H01`L01`021`@01`L400X700<01`L02PL010071`051`<01@L010071`L2008700<01`001`L40003
1`07008700<01`L02PL00`071`081`0300L700<01PL300031`0000<700<01`001@L00`071`091`04
00L71`<01PL010071`0<1`0300L700<70`021`<00PL30207000U1`0300L700800PL00`0700031`<0
1`L300P700<01`L02`L010071`071`<00PL200031`00008700D01`L7000:1`<00`L00`071`0:1`03
00L700L700<01`L00`L4008700<01`000`021`0400L700H700<01`L02@L00`071`031`<010L01007
1`0;1`0300L700H71@0010L0000Q1`009@L0100700041`0300L000D710041`0300L000801PL00`07
1`0:1`0500L71`002@L600870P031`0300L700/7100<1`0300L700P700<01`L01PL300051`0000L0
0`000`L01`071`0300L700P700<01`L01PL3008700<01`0030L00`071`061`0300L0008000<700L0
8@L002@700@01`001PL00`0700081`<00PL010071`L300@700<01`L02PL010071`091`8000D70000
1`0200D700<01`L02`L00`07000200/700<01`L020L00`071`061`0300L000800`L00`07000200L7
00<01`L02@L00`071`081`<00PL00`071`0:1`0300L700@700<01`000P000`L0000R1`008`L00`07
1`0200H700@01`L02PL400D70`021`0300L700X700@01`L01`L200031`0700D01PL00`071`0:1`04
00L71`@02@L00`071`081`0300L700D700D01`L01`0400041`071`<01@L00`071`091`0300L700X7
100<1`0300L7008700<01`L00P000`L0000S1`008`L0100700081`0300L000d70`061`<03@L01007
1`051`8000T700L01`0700L00`041`0300L700X700@01`L00`L300L700<01`L01`L00`071`041`03
00L700800PL500D70`031`0300L700T700<01`L02PL00`07000200X700<01`L00PL0100700021`03
00L70287000R1`<000<700L020L00`07000=1`0300L000801PL300X700D01`L700031`0800L01`07
00L200D70`000`L01`0<1`0400L700D70`041`0300L700P700<01`L00PL00`071`0200870P000`L0
1`0400D70`000`L01`091`0300L700X700D01`L01`0400L700@01`L00PL200031`0702@7000Q1`03
00L000@02@L00`07000=1`0400L71`<010L00`07000300L700@01`L00PL02P0700L01`0700L200L7
0`0=1`0400L700L70`021`0300L700P700X01`L700L01`070P001@L01`L000<70`051`<02PL00`07
1`0:1`0400L700@70`051`800PL200031`0702D7000Q1`8000<700L00PL300H700@01`L03@L00`07
1`031`@000<700L00`L300D700D01`L01`0200041`071`8000@700L02PL300X700D01`L700091`@0
2@L020071`0700L00PL300051`071`001@L300@710081`0300L700X700@01`L01PL300870P000`L0
00021`0300L702@7000P1`800PL200D70`041`0300L000d700<01`L01`L300H70`031`0500L700L0
0P021`8000<700L00PL00`071`081`0300L0008020L010071`0<1`@01`L200041`0700870P0010L0
1`031`0300L700D7100010L01`L300H700<01`L02PL00`0700091`L000<700L09PL0020700@01`L0
0PL00`071`051`<00PL00`07000=1`0300L700P710061`@000<700L00P021`800PL00`071`021`03
00L700L700<01`L00PL300H700@01`L030L00`071`0300D70P021`0600L000L00`L01@071`L000X7
0`041`<00`L00`071`0:1`0400L700T71@000`L0000W1`007`L200031`0700<700<01`L01`L30087
00<01`L02`L00`071`081`0300L700<01PL300031`07008700@01`L01PL00`071`071`0300L700@7
0`041`0400L700`700<01`L00PL300091`0700L01`0700801@L010071`0<1`@010L300031`0700/7
00@01`L01`L300031`070080:0L001h70P021`0300L7008700<01`L02PL400`700<01`L020L00`07
1`031`<00`L00`07000300031`07008700<01`L010L00`071`081`0300L700H70P021`0500L71`00
30L00`071`041`@000@700070P071`0400L700`700<01`L00`041`<030L010071`051`8000<700L0
0`0Y1`007PL010071`061`0300L700X700<01`000P0;1`0300L700P700<01`L01@L400031`000087
0`000`L01`071`0300L700L700<01`L020L4008700<01`L02PL00`071`041`8000<700000P000`L0
1`071`0500L71`0030L00`071`021`<010L300T700@01`L010L01@070007008000<700L0:0L001d7
0P021`0300L700D700<01`L02PL0100700L300T700<01`L020L00`071`061`0300L000800PL20004
1`0000P700<01`L01`L00`071`0:1`<000<700L02`L00`071`021`800PL00`07000300T700D01`L7
000;1`0300L700D70`0010L01`L300L700@01`L00PL0100700021`<0:PL001h710081`0300L700T7
00@01`L00`L200P700<01`L020L00`071`051`0300L00087100010L01`L400@700<01`L020L00`07
1`0:1`0300L0008030L01@071`L000871P0010L000071`0400L700`700<01`L01`L300@70`051`03
00L7008000<700000PL302/7000N1`800PL300D700<01`L02PL00`0700051`<01@L00`071`081`03
00L700@700<01`000`L200041`0000H70`021`0300L700P700<01`L02PL010071`L300T700@01`L0
0PL3008700<01`L00`L400<700D01`L7000<1`0300L700T70`041`<00`L01P071`0700870P000`L0
1`0Z1`007`L00`071`031`<00`L00`071`0:1`0300L000L70`031`0300L700P700<01`L00PL01007
00021`<000<700L010061`@02@L00`071`0;1`0400L700870`071`<00PL2008700<01`0020L30003
1`07008700<01`L02PL00`071`081`0300L700<010L400041`0000<700<01`00;0L001h700<01`00
1`L500`700<01`002@L300031`0700T700L01`L700L000870P021`0400L700<70`061`<020L00`07
1`0;1`0400L700@70`051`0300L700800PL01@071`L000X70`031`0300L700T700<01`L02@L00`07
1`021`@00`L2008700@01`L00PL00`071`0Z1`007@L01@071`L000X70`0:1`0400L700/70`091`05
00L700L00P0020L01`0700L00PL00`071`031`<010L00`07000200H700<01`L02PL01@071`L000H7
0`000`L01`0400031`0000<700<01`L02`L400`700<01`L02@L00`071`051`@00PL00`0700020003
1`0702`7000M1`0500L71`002`L00`07000200P700<01`003@L400L70P001`L000L01`000PL01007
1`021`0300L700D710000`L01`021`<010L00`071`0:1`0400L700T710000`L01`0200D700<01`L0
2PL00`071`0300/700<01`L02@L00`071`071`<00`L00`07000^1`0070L00`071`031`0300L700T7
00@01`L70`061`0300L000d700<01`L00`051`<00PL2008700D01`L700031`0300L700P70`051`<0
00<700L030L010071`071`8000<700000P000`L000061`0300L700X700@01`L710091`0300L700P7
00<01`L01PL00`07000500031`0702d7000L1`0300L700@700<01`L02@L00`071`031`<010L00`07
000=1`0300L700870`000`L0000200061`0700L01@L010071`0<1`@01@L300d700@01`L01@L01`07
000700L010071`0300L700X700@01`L00`L400D700<01`L02@L00`071`051`<00PL402l7000K1`03
00L700H700<01`L020L00`071`061`<000D700L7000<1`0300L700D710001PL01`0700L700@01`L0
30L00`071`0300D70`0:1`0500L71`000`L0200700L01`070P021`<010L00`071`0:1`0500L71`00
1PL300<700<01`L02@L00`071`031`<00PL200031`0702l7000J1`0300L700L700<01`L02@L00`07
1`081`<000<700L030L00`071`041`H000<700002@L010071`0<1`0300L700870`031`0300L000<0
1`L010071`021`0;00L01`0700L01`001@L3008700<01`L02PL01@071`L000P70`000`L01`0:1`06
00L71`070P001@L000L00347000J1`0300L700P700<01`L02@L00`071`0:1`<03@L00`071`021`80
00@7000710091`0400L700`700<01`L01@L400D70`051`0700L700L01`0200870P0010L01`071`@0
30L01@071`L000X70`0:1`0400L71`<00PL200031`070307000I1`802`L00`071`091`0300L700T7
00<01`L00`0:1`0300L7008700@01`000PL200870`071`0400L700`700<01`L01`L300H70`031`05
00L700L00P021`8000<700L00PL00`071`081`<02PL010071`0<1`@020L01`07000700L00P000`L0
1`0a1`006`L300T700<01`L020L00`071`0:1`0500L700L010071`0400L7008700@01`L70P051`<0
1@L010071`0<1`0300L700P710061`@000<700L00P021`0500L01`000`L00`071`081`0300L700<0
1`L01@071`L000`700<01`L010051`8000<700L00P000`L01`0b1`007PL300H700<01`L02@L00`07
1`0:1`0300L000D70`051`800PL200870P000`L01`061`@000<700L00PL00`071`091`0300L700P7
00@01`L70`061`<000<700L00PL200031`0700@700<01`L020L00`071`021`<01@L01@071`L000`7
00<01`L00`L300870`000`L01`0203@7000Q1`<010L00`071`091`0300L700X700<01`001`L30087
0P000`L000021`800`L00`071`081`<00PL00`071`0:1`0300L700P700<01`L00`L4008700<01`00
0`000`L000021`0300L700@700<01`L020L00`071`041`<00`L01@071`L000/700<01`L01PL60003
1`0003D7000T1`<00PL00`071`091`0300L700T700@01`L02@L400031`07008700<01`L00PL00`07
1`0;1`@030L00`071`081`0300L700H70`000`L000021`<000<700L01`L00`071`071`0300L700L7
0`001@L01`L000`700<01`L01@L200061`0000L0=PL002L70`0;1`0300L700X700<01`002PL50087
00<01`L010L00`071`0;1`0300L000802PL00`071`091`0300L700H700<01`000P021`8000@70000
1`L00`071`081`0300L700T70`021`0300L700X700<01`L010L00`07000200031`0003H7000Z1`<0
2@L00`071`0:1`0300L000P70P031`@01`L00`071`0:1`0500L700L00`081`0300L700P700<01`L0
1PL00`0700021`@000@700L70`051`0300L700P700<01`L02PL500`700<01`L00PL00`071`020003
1`0003L7000[1`0300L000801`L00`071`0:1`0300L000H70P041`<000@700001@L00`071`0:1`04
00L700<70`061`0300L700P700<01`L010L0100700021`8000@700001@L300<700<01`L020L00`07
1`0:1`0300L700<02PL010071`L200031`00008700<01`L0=PL002`700@01`L70`051`0300L700T7
00@01`L010L00`0700051`0300L700<70`021`0300L700/700@01`L01@L300@700<01`L020L00`07
1`021`0400L000<70P000`L01`0400D70`000`L01`081`0300L700X700H01`L700L400L700@01`00
0PL200031`0703P7000/1`0300L700@70P031`0300L700X700<01`000`L00`0700051`<01`L400d7
00@01`L01`L300031`0700X700H01`L700L2008700@01`L00PL010071`L300D70`091`0300L700X7
00D01`L700041`<01@L200870P000`L01`0i1`00;@L00`071`051`<000<700L02`L00`0700021`80
1@L2008700<01`L01`L300/700@01`L02PL300X700D01`L01`0200870P0010L01`021`0300L700<7
0`041`@01`L00`071`0:1`0500L71`001PL300051`0700L00P021`0300L703P7000^1`0300L700L7
0`0<1`0600L000L010L200<700<01`L02@L400T700@01`L030L400L70P000`L000021`800PL01007
1`021`0300L700D7100010L01`L200H700<01`L02PL010071`091`L000<700L0>PL002l700<01`L0
20L400T700<01`000P041`0300L000@700<01`L020L010071`L300L700@01`L02`L010071`L300D7
0P000`L01`02008700D01`L700031`0300L700P70`031`<00`L00`071`0:1`0500L71`0020L00`07
000300031`0003/7000_1`0300L700T700<01`L00`071`@00`L00`0700061`0300L700P700<01`L0
0`L300D700<01`0030L00`071`031`<000<700000P001PL01`0700D700@01`L030L400<70`000`L0
1`0;1`0500L71`001PL01`07000700L00P0l1`00<0L00`071`091`0300L700870`051`@000D700L7
00071`0300L700P700<01`L01@L200<700@01`L030L00`071`051`D000D7000700071`0400L700`7
00<01`L00`031`<030L01@071`L000@700@01`000PL303d7000a1`0300L700T700<01`L010L30087
00<01`L01@081`0300L700P700<01`L01`L300051`071`002`L00`071`051`8000D700001`0200T7
00@01`L030L00`071`021`<00`L300T700D01`L700031`0300L7008000D70007000m1`00<PL00`07
1`081`0300L700L710021`0300L000<01`L00`071`081`0300L700T70`000`L01`0;1`0300L700<7
0P001@L0000700<02@L01@071`L000/700<01`L01@L400870`071`0700L71`0700021`800PL303h7
000b1`0300L700T700<01`L01`L00`07000300031`07008710041`0300L700P700<01`L02PL400`7
00<01`L00PL00`071`0200031`0000870`071`0400L700`700<01`L01`L300<70`051`0400L71`80
00<700000PL303l7000c1`0300L700T700<01`L01@L010071`L500L70`021`0300L700P700<01`L0
2PL00`071`0300X700@01`L00PL200870P051`<01@L010071`0<1`0300L700P710031`<00`L00`07
1`0200041`071`8000<700L0?PL003@700<01`L02@L00`071`041`0600L700L00`L300L70`0:1`03
00L700/700D01`L01`0300L700<01`000PL200870P091`@000<700L00PL00`071`0:1`0300L700L7
00@01`L70`031`@000<700L00P031`0300L00407000d1`0300L700T700<01`L00`L010071`031`03
00L700<70`071`<020L00`071`0;1`0300L000@70`051`800PL200031`0000h70`031`0300L700T7
00<01`L020L00`071`031`@00PL200870P021`0400L70407000e1`0300L700T700<01`L00PL00`07
00051`0300L700D70`051`0300L000801PL00`071`0:1`0400L700H70`021`8000<700000PL00`07
1`0@1`@030L00`071`081`0300L700H70`021`8000H700001`111`00=PL00`071`091`0600L700L0
1`L00`071`071`@000<700L00`L300@700<01`L02PL010071`081`H00PL00`071`0B1`0300L00080
2`L00`071`081`0300L700P70`031`0300L00487000g1`0300L700T70P021`0300L700D700<01`L0
2`L300H70`000`L01`0<1`0300L000P70P001@L00007008050L010071`L400T700<01`L01`L00`07
1`091`H000<700L0@@L003L700<01`L02@L200031`0700P700<01`L03@L300H70`0=1`0300L000H7
0P000`L01`021`<05@L010071`031`<01PL00`071`081`0300L700L70P021`@0@`L003P700<01`L0
20L300/700<01`L03@L00`07000200H70`0:1`0400L700@700D01`0700031`0300L700<04`L01007
1`051`<010L00`071`081`0300L700D70P021`80APL003T700<01`L01PL0100700L300T700<01`L0
30L00`071`021`<010L00`07000300L700@01`L00PL01@0700L000<70P051`@040L010071`071`<0
0PL00`071`081`0300L700<700@01`070P171`00>PL00`071`051`801@L300H700<01`L03@L00`07
1`041`<000<700L010L300D700<01`000PL200031`0700870P0:1`<03@L01@071`L000T70`0:1`03
00L7008700<01`000PL204L7000j1`0300L700@70P091`<010L00`071`0=1`0300L700H70`071`<0
0`L01@07000700800`L200h70`0;1`0400L700`710071`0400L7008700@01`00B0L003/700<01`L0
0`L00`071`0;1`<00PL00`071`0=1`0300L700P70`071`@000<700000P031`0300L001470`091`04
00L700`700<01`L00`051`800PL0100700191`00?0L010071`L201070`0?1`0300L700P700<01`L0
0`071`D00`L00`07000E1`<01`L010071`0<1`0300L700870`031`0700L01`0700191`00?@L01007
000D1`<03@L00`071`081`0300L7008710061`<000D700L7000H1`<010L01@071`L000/700<01`L0
1@L400051`001`00BPL003d700<01`005PL00`07000200/700<01`L020L00`071`051`<00PL20003
1`0000<070L400051`071`0030L00`071`051`0800L000L01`1:1`00?PL201L700@01`L70`091`03
00L700P700<01`L01`L300<700<01`000`0N1`<00PL00`071`0:1`0300L700<700P01`L01`0704/7
00101`<050L00`071`041`801`L00`071`081`0300L700P700<01`000`000`L01`021`@070L500`7
00D01`L700031`8000<700L0B`L004<70`0B1`0300L700D70`051`0300L700P700<01`L01PL01P07
1`L01`<01`L301X700<01`L00`0:1`0400L700<70P021`0300L704X700161`<040L00`071`071`<0
0`L00`071`081`0300L700@70P021`0300L700<70`071`<060L01@071`0700<020L200@700@01`L0
C@L004T7100=1`0300L700T7100;1`0300L700<700@01`L02@L300L70`0F1`0400L700<710051`05
00L71`000PL00`071`1<1`00C@L300X700<01`L030L300T700<01`L00PL200031`0700`710061`<0
4`L01@071`L000H70`001@L01`0700800PL00`071`1<1`00D0L300P700<01`L03@L400L700<01`L0
0P000`L01`0A1`<01PL3014700@01`L02@L400051`071`00C`L005<70`061`0300L700d700<01`L0
0`051`<00PL00`071`0C1`<01PL300l700@01`L01`L010071`L200<700<01`L0C@L005H70`041`03
00L700`700<01`L00`L300870`000`L01`0H1`<01PL300d700@01`L01@L00`071`061`0300L704h7
001I1`<000<700L03PL00`071`051`@000<700L070L300H70`0:1`0500L71`000`L00`071`061`03
00L704l7001L1`<03`L00`071`051`@08@L300H710071`0400L7008700<01`L01`L00`071`1?1`00
G`L300d700<01`L00`L01007000U1`@01PL300D700H01`L01`081`0300L70507001O1`0300L700<0
2PL00`071`021`0400L002X70`061`<00`L010071`081`0300L70547001P1`0300L7008710071`04
00L7008700<01`L0;0L300H7100010L01`071`0300L70547001Q1`0300L700D70`051`800PL20347
0`061`800PL00`071`041`0300L70587001R1`0300L700L70`021`8000<70000=@L300P700<01`L0
0`L00`071`1B1`00HPL00`071`0:1`@000<700L0>0L400D700D01`L7001E1`00H`L00`071`0:1`04
00L003h70`031`0300L005H7001T1`0300L700P700<01`L0@`L400031`0705D7001U1`0300L700H7
00<01`L0A`L205L7001U1`0300L700D700<01`L0X@L006H700<01`L00`L00`071`2R1`00I`L00`07
1`021`0300L70:87001X1`0400L70:D7001X1`0300L00:H7001Y1`0300L70:D7003o1a87003o1a87
003o1a87003o1a87003o1a87003o1a870000\
\>"],
  ImageRangeCache->{{{0, 272.812}, {265.938, 0}} -> {-10.3799, -10.1191, \
0.0761177, 0.0761177}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[193]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["j = 5, k =4", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AL054, Axes \[Rule] True, Prolog \[Rule] PointSize[0.025], 
      PlotRange \[Rule] \ {{\(-20\), 20}, {\(-20\), 20}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[194]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.025 0.5 0.025 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -9 -9 ]
[.125 .4875 9 0 ]
[.25 .4875 -9 -9 ]
[.25 .4875 9 0 ]
[.375 .4875 -6 -9 ]
[.375 .4875 6 0 ]
[.625 .4875 -3 -9 ]
[.625 .4875 3 0 ]
[.75 .4875 -6 -9 ]
[.75 .4875 6 0 ]
[.875 .4875 -6 -9 ]
[.875 .4875 6 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -18 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -12 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -6 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -12 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -12 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-20)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-15)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-10)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(10)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(15)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(20)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-20)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-15)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-10)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(10)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(15)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(20)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.025 w
.62556 .88661 Mdot
.56306 .86631 Mdot
.50056 .846 Mdot
.43806 .82569 Mdot
.37556 .80538 Mdot
.31306 .78508 Mdot
.25056 .76477 Mdot
.18806 .74446 Mdot
.12556 .72415 Mdot
.06306 .70385 Mdot
.00056 .68354 Mdot
.66419 .83345 Mdot
.60169 .81314 Mdot
.53919 .79283 Mdot
.47669 .77253 Mdot
.41419 .75222 Mdot
.35169 .73191 Mdot
.28919 .7116 Mdot
.22669 .6913 Mdot
.16419 .67099 Mdot
.10169 .65068 Mdot
.03919 .63037 Mdot
.70282 .78028 Mdot
.64032 .75997 Mdot
.57782 .73967 Mdot
.51532 .71936 Mdot
.45282 .69905 Mdot
.39032 .67874 Mdot
.32782 .65844 Mdot
.26532 .63813 Mdot
.20282 .61782 Mdot
.14032 .59752 Mdot
.07782 .57721 Mdot
.74144 .72712 Mdot
.67894 .70681 Mdot
.61644 .6865 Mdot
.55394 .66619 Mdot
.49144 .64589 Mdot
.42894 .62558 Mdot
.36644 .60527 Mdot
.30394 .58496 Mdot
.24144 .56466 Mdot
.17894 .54435 Mdot
.11644 .52404 Mdot
.78007 .67395 Mdot
.71757 .65364 Mdot
.65507 .63334 Mdot
.59257 .61303 Mdot
.53007 .59272 Mdot
.46757 .57241 Mdot
.40507 .55211 Mdot
.34257 .5318 Mdot
.28007 .51149 Mdot
.21757 .49118 Mdot
.15507 .47088 Mdot
.8187 .62079 Mdot
.7562 .60048 Mdot
.6937 .58017 Mdot
.6312 .55986 Mdot
.5687 .53956 Mdot
.5062 .51925 Mdot
.4437 .49894 Mdot
.3812 .47863 Mdot
.3187 .45833 Mdot
.2562 .43802 Mdot
.1937 .41771 Mdot
.85732 .56762 Mdot
.79482 .54731 Mdot
.73232 .527 Mdot
.66982 .5067 Mdot
.60732 .48639 Mdot
.54482 .46608 Mdot
.48232 .44577 Mdot
.41982 .42547 Mdot
.35732 .40516 Mdot
.29482 .38485 Mdot
.23232 .36454 Mdot
.89595 .51445 Mdot
.83345 .49415 Mdot
.77095 .47384 Mdot
.70845 .45353 Mdot
.64595 .43322 Mdot
.58345 .41292 Mdot
.52095 .39261 Mdot
.45845 .3723 Mdot
.39595 .35199 Mdot
.33345 .33169 Mdot
.27095 .31138 Mdot
.93458 .46129 Mdot
.87208 .44098 Mdot
.80958 .42067 Mdot
.74708 .40037 Mdot
.68458 .38006 Mdot
.62208 .35975 Mdot
.55958 .33944 Mdot
.49708 .31914 Mdot
.43458 .29883 Mdot
.37208 .27852 Mdot
.30958 .25821 Mdot
.97321 .40812 Mdot
.91071 .38782 Mdot
.84821 .36751 Mdot
.78571 .3472 Mdot
.72321 .32689 Mdot
.66071 .30659 Mdot
.59821 .28628 Mdot
.53571 .26597 Mdot
.47321 .24566 Mdot
.41071 .22536 Mdot
.34821 .20505 Mdot
.94933 .33465 Mdot
.88683 .31434 Mdot
.82433 .29403 Mdot
.76183 .27373 Mdot
.69933 .25342 Mdot
.63683 .23311 Mdot
.57433 .2128 Mdot
.51183 .1925 Mdot
.44933 .17219 Mdot
.38683 .15188 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[194]:=",
  ImageSize->{225.188, 225.188},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Q0000h@P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc>47003Q1`00h@L00>47003Q1`00h@L006<7
10031`80M@L006<700<01`L00`L010071`1d1`00I0L00`071`021`0400L700@70P1^1`00G@L400@7
00D01`L700021`0300L7008700<01`L0K@L006H700@01`L00PL00`071`021`0300L706d7001S1`04
00L7008700@01`L010L00`071`1]1`00I0L200@70P051`0300L706d7001a1`80KPL0074700<01`L0
K@L0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L007470P1^1`00L@L00`071`1]1`00
L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L206h7001a1`03
00L706d7001a1`0300L706d7001a1`0300L706d7001a1`0300L706d7001a1`80KPL0074700<01`L0
K@L0074700<01`L0K@L006<710021`<01@L00`071`1]1`00I@L00`071`041`0300L7008700<01`L0
K@L006D700<01`L010L00`071`021`80KPL005d710041`0400L71`<01@L00`071`1]1`00I@L01@07
1`L000L700<01`L0K@L006<70`031`0300L700D700<01`L0K@L005P710091`0400L71`@010L00`07
1`1]1`00F0L401D70P1^1`00F0L401D700<01`L0K@L005P7100E1`0300L706d7001U1`@020L00`07
1`1]1`00I@L400P700<01`L0K@L006D710081`80KPL006D710081`0300L706d7001a1`0300L000<0
JPL0074700<01`000`1Z1`00L@L00`07000306X7001@1`@07@L00`07000306X7001@1`@07@L200d7
101M1`00D0L401d700<01`L030L405d7001@1`@07@L00`071`0<1`@0G@L005d7100@1`0300L700`7
101M1`00G@L4010700<01`L0K@L005d7100@1`806PL40507001M1`@040L00`071`0I1`@0D0L006X7
10031`0300L701T7101@1`00H`L400<710031`0300L701T7101@1`00I@L010071`L500<700<01`L0
9PL404<700181`@06@L010071`L500<70P0W1`@0@`L004P7100A1`@010L01@071`L0008700<01`L0
0PL00`071`0V1`@0@`L004P7100I1`0500L71`000PL00`071`021`0300L700@7100N1`@0@`L004P7
100G1`<00`L010071`041`0300L700@7100[1`@0=PL005D7100<1`0300L700870P051`0300L700@7
100[1`@0=PL005D7100H1`801@L402/7100f1`00E@L401P700<01`L04@L401h7100f1`00E@L401P7
00<01`L04@L402/7100Y1`00HPL400/700<01`L04@L402/7100Y1`00HPL400/700<01`L04@L402/7
100Y1`00HPL400/700<01`L07PL401h7100Y1`00@0L401h7100;1`807`L404/700101`@0;@L00`07
1`0N1`@0:`L401`700101`@0:`L401l7100[1`@070L00407100[1`@0;0L401h7100L1`00C@L401h7
100/1`@07PL401`7001=1`@07PL402`7100[1`@03`L004d7100P1`0300L700P7100O1`@0:`L400l7
001=1`@080L00`071`081`@0CPL400l7001a1`0300L700P7100/1`@07PL400l7001J1`@04`L00`07
1`081`@0;0L40347001J1`@04`L201L7100N1`@0<@L003P7100N1`@04`L00`071`0F1`@07PL40347
000h1`@07PL401<700<01`L05PL402/7100T1`00>0L402/71@051`0300L701H7100[1`@090L003P7
100[1`@000<700L00`L00`071`0S1`@07PL402@700151`@07PL400031`0700<70P0T1`@07PL402@7
00151`@06PL900D700<01`L08`L402/7100G1`00A@L4020700<01`L01@L00`071`0401l7100[1`@0
5`L004D7100P1`0300L700D700<01`L0101>1`@05`L006T710041`0300L700@0;0L401h7100G1`00
DPL401/70P000`L0000202`7100[1`@02PL00587100K1`0300L700d7100O1`@0:`L400X7000`1`@0
7PL401/700<01`L03@L401l7100[1`@02PL00307100N1`@06`L00`071`0=1`@0;0L401h7100:1`00
<0L402/7100>1`0300L700d7100/1`@0;0L00307100[1`@03PL00`071`0K1`@07PL402`7001O1`@0
3PL201`7100N1`@0;0L003d7100N1`@03PL00`071`0K1`@0:`L401l7000m1`@0:`L400031`0701`7
100[1`@07`L003d7100[1`@000<700L0B`L401l7000m1`@0:`L400031`0702T7100N1`@07`L004X7
100N1`@000<70000:@L402/7100B1`001`L400<70P0A1`@00PL3014710031`801PL400X70`0F1`03
00L700D7100<1`<040L800<70P0B1`@00PL300L710061`@00`L200<700071`0300L700<700@01`L0
4PL00`071`021`@04@L01@071`L0008700<01`L00`L400d700<01`L04`L00`071`051`@03`L00`07
1`0=1`@00PL01@071`L0008700<01`L04@L00`071`041`0300L700@710061`0300L700<700@01`L0
0PL000P700<01`L00PL010071`0B1`0300L70087100A1`0500L71`000PL00`071`031`@03@L00`07
1`0C1`0300L700D7100?1`0300L701<700D01`L700021`@040L00`071`041`0300L700@710071`03
00L7008700@01`L00PL000031`00008010L01@071`L0008700<01`L020L400@700@01`L71@091`@0
10L01@071`L0008700<01`L02`L400031`0000805PL00`071`051`@030L301H700D01`L700021`@0
40L010071`L301<700D01`L700021`400@L11`002PL010071`021`0300L7010700@01`L71@0A1`05
00L71`000PL00`071`0@1`@05PL201H700<01`L05PL01@071`L00087100@1`0500L71`005PL01007
1`021`400@L11`001`L010071`021`0400L701070`031`0300L701470`031`0400L70187100F1`03
00L70187100F1`<00`L00`071`0400h70`031`0300L7014700@01`L00PL010071`021`0020L200@7
0P0C1`0400L71`@02PL400@700<01`L00PL201<71@0E1`0300L701871`0E1`0300L700870P0=1`@0
0`L010071`L401470P041`800`L003D7100[1`@02@L00`071`0B1`@0;0L402L7000e1`@0:`L400T7
00<01`L04PL402`7100W1`002@OB00H700091`0300L7008700<01`L00PL00`071`021`0300L70087
00<01`L00`L00`071`021`0300L7008700<01`L00PL00`071`031`0300L7008700<01`L00PL40003
1`0700<700<01`L00`L00`071`021`0300L7008700<01`L00PL00`071`0400@700<01`L00PL00`07
1`021`0300L700<700<01`L00PL00`071`021`0300L7008700<01`L00PL010071`L400<700<01`L0
0PL00`071`021`0300L700<700<01`L00PL00`071`021`0300L7008700<01`L00`L00`071`0400<7
00<01`L00PL00`071`021`0300L700<700<01`L010L000T700<01`L05`L00`071`0G1`0300L70087
100A1`0300L701L7100F1`0300L700H7100=1`0300L701P700<01`L0100C1`0300L700@7000P1`@0
7PL402/7100O1`@0:`L401X7000P1`@07PL402/7100/1`@07PL401X7000P1`@0:`L401h7100/1`@0
?0L00207100[1`@07PL202h7100l1`00C`L401h700<01`L02PL401l7100l1`00;@L401h7100N1`03
00L700X7100/1`@0;`L002d7100[1`@04@L00`071`0:1`@0;0L402l7000]1`@0:`L4014700<01`L0
2PL402`7100_1`00;@L402/7100A1`8060L401l7100_1`00>PL401h7100A1`0300L701L7101B1`00
>PL403<700<01`L05`L402`7100R1`00>PL402/710041`0300L701L7100/1`@08PL001P7100N1`@0
:`L400@700<01`L09@L401h7100R1`0060L402/7100N1`@010L202H7100N1`@08PL001P7100[1`@0
7PL400@700<01`L09@L404@7000H1`@0:`L402H700<01`L00PL401l710141`009@L401h7100V1`03
00L70087100/1`@0=`L002D7100[1`@06@L00`071`021`@0;0L403L7000U1`@0:`L401T70P031`@0
;0L403L7000U1`@0:`L401T700<01`L03`L401l7100g1`00<PL401h7100I1`0300L700l7101J1`00
<PL403/700<01`L03`L402`7100Z1`00<PL402/710041`<01@L00`071`0?1`@0;0L402X7000@1`@0
7PL402/710071`0300L7008700<01`L070L401l7100Z1`0040L402/7100N1`@01`L00`071`021`80
7@L401l7100Z1`0040L402/7100N1`@010L300D700<01`L070L404d7000@1`@0:`L402H700<01`L0
0PL401h7101=1`007@L401h7100V1`0300L70087101_1`007@L404P710000`L0000202`7100o1`00
7@L402/7100N1`D0:`L403l7000M1`@0:`L4024700<01`L01`L401l7100o1`00:PL401h7100Q1`03
00L700L7100O1`@0?`L002X7100N1`@08@L00`071`071`@0;0L40387000Z1`@0:`L401@700<01`L0
1`L402`7100b1`0020L401h7100[1`@050L201D7100O1`@0<PL000P7100[1`@07PL401@700<01`L0
50L401l7100b1`0020L402/7100N1`@050L00`071`0D1`@0E@L000P7100[1`@0:`L400L700<01`L0
50L405D7000E1`@07PL402/710071`0300L706d7000E1`@0C@L400L70P0R1`@0B0L001D7100[1`@0
7PL400L700<01`L08@L404P7000E1`@0:`L402T700<01`000`0N1`@0B0L00287100N1`@0:@L00`07
000301h710181`008PL401h7100Y1`0300L000<0;0L403X7000R1`@0:`L401`71P0/1`@0>PL00287
100[1`@070L00`071`0_1`@0>PL00547100L1`0300L700`7100O1`@0>PL002l7100N1`@070L00`07
1`0<1`@0G@L002l7100[1`@000<700000P031`801@L00`071`0<1`@0G@L002l7100[1`@00`L01@07
1`L0008700<01`L00PL00`071`0<1`@0G@L002l7100[1`@00`L01@071`L0008700<01`L00PL201X7
101@1`00?0L401h710031`0500L71`000PL00`071`021`0300L701T7101@1`00?0L402D700H01`L7
00L4008700<01`L06@L40507000l1`@08`L300<700<01`000`021`0300L701T7101@1`00?0L402D7
00<01`L00PL5008700<01`L09PL404<700191`@07PL400870P0W1`@0@`L004T7100T1`0300L702H7
10131`00B@L402@700<01`L010L401h710131`00B@L402@700<01`L010L406D7001F1`@05`L00`07
1`041`@0I@L005H7100G1`801@L406D7001F1`@05`L00`071`0A1`@0F0L005H7100G1`0300L70147
101H1`00L@L00`071`0A1`@0F0L006<7100:1`0300L70147101H1`00H`L400X70P0O1`@0B`L006<7
100:1`0300L701h7101;1`00H`L400X700<01`L07PL404/7001`1`@07PL404/7001`1`@0K@L00707
101]1`00L0L406d7001a1`0300L700T7101P1`00L@L00`071`091`@0H0L006<710021`<01@L00`07
1`091`@0H0L006D700<01`L010L00`071`021`0300L700T7101P1`00I@L00`071`041`0300L70087
0P0G1`@0D`L006D700@01`L70`051`0300L701H7101C1`00I@L01@071`L000L700<01`L05PL405<7
001S1`<00`L00`071`051`0300L701H7101C1`00I@L010071`L400@700<01`L0K@L007470P1^1`00
L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L00`071`1]1`00L@L206h7001a1`03
00L706d7001a1`0300L706d7001a1`0300L706d7001a1`0300L706d7001a1`0300L706d7001a1`80
KPL0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L0074700<01`L0K@L007470P1^1`00
L@L00`071`1]1`00L@L00`071`1]1`00H`L400<70P051`0300L706d7001S1`0300L700<700@01`L0
10L00`071`1]1`00I0L00`071`021`0400L700@70P1^1`00I@L01@071`L0008700<01`L0LPL006H7
00@01`L00PL00`071`1b1`00H`L010071`021`0400L707@7001T1`8010L207D7003Q1`00h@L00>47
0000\
\>"],
  ImageRangeCache->{{{0, 224.188}, {224.188, 0}} -> {-21.7212, -21.4343, \
0.191218, 0.191218}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[194]="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(basis54 = 
      FullSimplify[{A[5, 4, \[Alpha]] /. {m \[Rule] 1, n \[Rule] 0}, 
          A[5, 4, \[Alpha]] /. {m \[Rule] 0, 
              n \[Rule] 1}}]\), "\[IndentingNewLine]", 
    \(orig\  = \ 
      FullSimplify[
        A[5, 4, \[Alpha]] /. {m \[Rule] 0, n \[Rule] 0}]\)}], "Input",
  CellLabel->"In[195]:="],

Cell[BoxData[
    \({{1.7929669378859874`, \(-1.3567081569293098`\)}, {\(-2.25211803398875`\
\), \(-0.04238037663147598`\)}}\)], "Output",
  CellLabel->"Out[195]="],

Cell[BoxData[
    \({0.24788196601125012`, 0.7699188639507899`}\)], "Output",
  CellLabel->"Out[196]="]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
    \(\(rad54\  = \@\(\((basis54[\([1]\)]\  - \ orig)\) . \((basis54[\([1]\)]\
\  - \ orig)\)\);\)\)], "Input",
  CellLabel->"In[197]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[AppendTo[basis54, orig], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-10\), 10}, {\(-10\), 10}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[198]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.05 0.5 0.05 [
[0 .4875 -9 -9 ]
[0 .4875 9 0 ]
[.125 .4875 -12 -9 ]
[.125 .4875 12 0 ]
[.25 .4875 -6 -9 ]
[.25 .4875 6 0 ]
[.375 .4875 -12 -9 ]
[.375 .4875 12 0 ]
[.625 .4875 -9 -9 ]
[.625 .4875 9 0 ]
[.75 .4875 -3 -9 ]
[.75 .4875 3 0 ]
[.875 .4875 -9 -9 ]
[.875 .4875 9 0 ]
[1 .4875 -6 -9 ]
[1 .4875 6 0 ]
[.4875 0 -18 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .125 -24 -4.5 ]
[.4875 .125 0 4.5 ]
[.4875 .25 -12 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .375 -24 -4.5 ]
[.4875 .375 0 4.5 ]
[.4875 .625 -18 -4.5 ]
[.4875 .625 0 4.5 ]
[.4875 .75 -6 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 .875 -18 -4.5 ]
[.4875 .875 0 4.5 ]
[.4875 1 -12 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-10)] 0 .4875 0 1 Mshowa
.125 .5 m
.125 .50625 L
s
[(-7.5)] .125 .4875 0 1 Mshowa
.25 .5 m
.25 .50625 L
s
[(-5)] .25 .4875 0 1 Mshowa
.375 .5 m
.375 .50625 L
s
[(-2.5)] .375 .4875 0 1 Mshowa
.625 .5 m
.625 .50625 L
s
[(2.5)] .625 .4875 0 1 Mshowa
.75 .5 m
.75 .50625 L
s
[(5)] .75 .4875 0 1 Mshowa
.875 .5 m
.875 .50625 L
s
[(7.5)] .875 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(10)] 1 .4875 0 1 Mshowa
.125 Mabswid
.025 .5 m
.025 .50375 L
s
.05 .5 m
.05 .50375 L
s
.075 .5 m
.075 .50375 L
s
.1 .5 m
.1 .50375 L
s
.15 .5 m
.15 .50375 L
s
.175 .5 m
.175 .50375 L
s
.2 .5 m
.2 .50375 L
s
.225 .5 m
.225 .50375 L
s
.275 .5 m
.275 .50375 L
s
.3 .5 m
.3 .50375 L
s
.325 .5 m
.325 .50375 L
s
.35 .5 m
.35 .50375 L
s
.4 .5 m
.4 .50375 L
s
.425 .5 m
.425 .50375 L
s
.45 .5 m
.45 .50375 L
s
.475 .5 m
.475 .50375 L
s
.525 .5 m
.525 .50375 L
s
.55 .5 m
.55 .50375 L
s
.575 .5 m
.575 .50375 L
s
.6 .5 m
.6 .50375 L
s
.65 .5 m
.65 .50375 L
s
.675 .5 m
.675 .50375 L
s
.7 .5 m
.7 .50375 L
s
.725 .5 m
.725 .50375 L
s
.775 .5 m
.775 .50375 L
s
.8 .5 m
.8 .50375 L
s
.825 .5 m
.825 .50375 L
s
.85 .5 m
.85 .50375 L
s
.9 .5 m
.9 .50375 L
s
.925 .5 m
.925 .50375 L
s
.95 .5 m
.95 .50375 L
s
.975 .5 m
.975 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-10)] .4875 0 1 0 Mshowa
.5 .125 m
.50625 .125 L
s
[(-7.5)] .4875 .125 1 0 Mshowa
.5 .25 m
.50625 .25 L
s
[(-5)] .4875 .25 1 0 Mshowa
.5 .375 m
.50625 .375 L
s
[(-2.5)] .4875 .375 1 0 Mshowa
.5 .625 m
.50625 .625 L
s
[(2.5)] .4875 .625 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(5)] .4875 .75 1 0 Mshowa
.5 .875 m
.50625 .875 L
s
[(7.5)] .4875 .875 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(10)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .025 m
.50375 .025 L
s
.5 .05 m
.50375 .05 L
s
.5 .075 m
.50375 .075 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .175 m
.50375 .175 L
s
.5 .2 m
.50375 .2 L
s
.5 .225 m
.50375 .225 L
s
.5 .275 m
.50375 .275 L
s
.5 .3 m
.50375 .3 L
s
.5 .325 m
.50375 .325 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .425 m
.50375 .425 L
s
.5 .45 m
.50375 .45 L
s
.5 .475 m
.50375 .475 L
s
.5 .525 m
.50375 .525 L
s
.5 .55 m
.50375 .55 L
s
.5 .575 m
.50375 .575 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .675 m
.50375 .675 L
s
.5 .7 m
.50375 .7 L
s
.5 .725 m
.50375 .725 L
s
.5 .775 m
.50375 .775 L
s
.5 .8 m
.50375 .8 L
s
.5 .825 m
.50375 .825 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .925 m
.50375 .925 L
s
.5 .95 m
.50375 .95 L
s
.5 .975 m
.50375 .975 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.58965 .43216 Mdot
.38739 .49788 Mdot
.51239 .5385 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[198]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L0088710031`80U@L008@700D01`L700021`0300L7098700241`0500L71`000PL00`07
1`031`80S@L007`710041`0500L71`000PL00`071`031`0300L708`700241`0500L71`000PL00`07
1`031`0300L708`700221`<00`L010071`051`0300L708`700241`0300L700870P061`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L007d700<01`L00`L00`071`021`<01PL00`071`2<1`00O@L00`071`0;1`0300L700<7
00<01`L0S0L007h700<01`L02PL00`071`031`80S@L007H710041`0300L700L70`061`0300L708`7
001o1`0300L700H700<01`L01PL00`071`2<1`00O0L010071`081`0300L700H700<01`L0S0L007`7
10081`@01@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`700281`<01PL00`071`2<1`00R`L00`071`031`0300L708`7
002;1`0300L700<70P2=1`00PPL400870`061`0300L708`700281`0300L700H700<01`L0S0L008P7
00<01`L01PL00`071`2<1`00R0L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L00947
0P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7
002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`07
1`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00O0L400<700<01`L00PL300H7
00<01`L0S0L007`700<01`L030L00`071`031`0300L708`7001m1`0300L700/700<01`L00`L208d7
001f1`@010L00`071`071`<01PL00`071`2<1`00O`L00`071`061`0300L700H700<01`L0S0L007`7
00@01`L020L00`071`061`0300L708`7001m1`802@L400D700<01`L0S0L0094700<01`L0S0L00947
00<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`0C1`H0L`L00947
00<01`L04@L:0747002A1`0300L701472P1a1`00T@L00`071`0@1``0L0L009470P0A1``0L0L00947
00<01`L040L<0707002A1`0300L70107301`1`00T@L00`071`0@1``0L0L0094700<01`L040L<0707
002A1`0300L701472P1a1`00T@L201872P1a1`00T@L00`071`0C1`H0L`L0094700<01`L0S0L00947
00<01`L0S0L000L710031`805`L00`071`031`0300L700870`0I1`<06@L400<700<01`L00PL301P7
00<01`L05`L400<700<01`L00PL301T70`0J1`0300L700<700<01`L00PL301H710031`800`L000T7
00D01`L700021`0300L701@700<01`L02`L00`071`0I1`0300L701H700<01`L030L00`071`0E1`03
00L701L700<01`L030L00`071`0I1`0300L701L700<01`L02`L00`071`0E1`0500L71`000PL10047
0@L000T700D01`L700021`0300L701D700<01`L02PL00`071`0I1`0300L701L700<01`L02`L00`07
1`0E1`0300L701P700<01`L02`L00`071`0I1`0300L701P700<01`L02PL00`071`0E1`0500L71`00
0PL100470@L000031`00008010L01@071`L0008700<01`L03@L400@700<01`L01`L301<710021`<0
4`L400@700<01`L01`L301P70P0J1`0300L700L70`0I1`<06`L00`071`071`<060L01@071`L00087
0@011`4700091`0500L71`000PL00`071`0F1`0300L700H700<01`L06@L00`071`0L1`0300L700L0
6PL00`071`0J1`0300L700H700<01`L06@L00`071`0L1`0300L700H700<01`L060L01@071`L00087
0@011`4700071`<00`L010071`0E1`0400L700P700<01`L06@L00`071`0I1`0300L700/06@L00`07
1`0G1`0400L700P700<01`L06@L00`071`0I1`0400L700P700<01`L05PL300<700@01`L00PL000T7
00<01`L00PL201H710081`@060L401T70P000`L0000:01L700<01`L060L200T7100H1`@060L400P7
100G1`0300L700870P031`00K@L<01P700<01`L0S0L006d7300H1`0300L708`7001]1``060L00`07
1`2<1`002@Oo01801PL000T700<01`L00`L00`071`041`0300L700@700<01`L010L00`071`041`03
00L700<700<01`L010L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@700<01`L0
10L00`071`041`0300L7008730031`0300L700@700<01`L010L00`071`041`0300L700<700<01`L0
10L00`071`041`0300L700@700<01`L010L00`071`031`0300L700@700<01`L010L00`071`041`03
00L700@700<01`L00`L00`071`041`0300L700@700<01`L010L00`071`041`0300L700<700<01`L0
10L00`071`041`0300L700@700<01`L010L00`071`041`002@L00`071`0O1`0300L701l700<01`L0
7@L<01P700<01`L07`L00`071`0O1`0300L701l700<01`L07`L00`071`041`00KPL:01T700<01`L0
S0L006h72P0I1`0300L708`7001`1`H06`L708P7002@1`X0QPL009072P261`00S`L<08D7002?1``0
Q@L008l730251`00S`L<08D7002?1``0Q@L008l730251`00T0L:08H7002@1`X0QPL009471`281`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80
S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L007`710031`03
00L700870`061`0300L708`7001l1`0300L700`700<01`L00`L00`071`2<1`00O@L00`071`0;1`03
00L700<70P2=1`00OPL00`071`071`<01PL00`071`2<1`00O`L00`071`061`0300L700H700<01`L0
S0L007`700@01`L020L00`071`061`0300L708`7001m1`802@L400D700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`0300L708`7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80S@L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
R0L300H700<01`L0S0L008/700<01`L00`L00`071`2<1`00R`L00`071`031`80S@L008P70`061`03
00L708`700281`0300L700H700<01`L0S0L008P700<01`L01PL00`071`2<1`00R0L400D700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L208d7002A1`03
00L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`80
S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00O@L00`071`031`0300L700870`061`0300L708`7001m1`0300L700/700<01`L0
0`L00`071`2<1`00OPL00`071`0:1`0300L700<70P2=1`00OPL00`071`071`<01PL00`071`2<1`00
O`L00`071`061`0300L700H700<01`L0S0L007`700@01`L020L00`071`061`0300L708`7001l1`@0
20L400D700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L208d7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`0300L708`7002A1`03
00L708`7002A1`80S@L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0S0L0094700<01`L0
S0L0094700<01`L0S0L0094700<01`L0S0L009470P2=1`00T@L00`071`2<1`00T@L00`071`2<1`00
T@L00`071`2<1`00T@L00`071`2<1`00PPL400<70P061`0300L708`700241`0500L71`000PL00`07
1`031`0300L708`700241`0500L71`000PL00`071`031`80S@L008@700D01`L700021`0300L70987
00241`0500L71`000PL00`071`2B1`00PPL300<700@01`L0U0L008@700<01`L00PL209D7003o1b47
003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.6619, -10.5516, 0.0735301, \
0.0735301}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[198]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice054\  = tiling2D[SphericalCut[N[AL054], 10], \ rad54]\)], "Input",\

  CellLabel->"In[199]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00251 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.48695 0.0526463 0.516701 0.0526463 [
[ 0 0 0 0 ]
[ 1 1.00251 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.00251 L
0 1.00251 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.5192 .97864 m
.38759 .93588 L
s
.5192 .97864 m
.60055 .86668 L
s
.38759 .93588 m
.25597 .89311 L
s
.38759 .93588 m
.46893 .82392 L
s
.25597 .89311 m
.12436 .85035 L
s
.25597 .89311 m
.33731 .78115 L
s
.12436 .85035 m
.2057 .73839 L
s
.73216 .90945 m
.60055 .86668 L
s
.73216 .90945 m
.8135 .79749 L
s
.60055 .86668 m
.46893 .82392 L
s
.60055 .86668 m
.68189 .75472 L
s
.46893 .82392 m
.33731 .78115 L
s
.46893 .82392 m
.55027 .71196 L
s
.33731 .78115 m
.2057 .73839 L
s
.33731 .78115 m
.41866 .66919 L
s
.2057 .73839 m
.07408 .69562 L
s
.2057 .73839 m
.28704 .62643 L
s
.07408 .69562 m
.15543 .58366 L
s
.8135 .79749 m
.68189 .75472 L
s
.8135 .79749 m
.89485 .68553 L
s
.68189 .75472 m
.55027 .71196 L
s
.68189 .75472 m
.76323 .64276 L
s
.55027 .71196 m
.41866 .66919 L
s
.55027 .71196 m
.63162 .6 L
s
.41866 .66919 m
.28704 .62643 L
s
.41866 .66919 m
.5 .55723 L
s
.28704 .62643 m
.15543 .58366 L
s
.28704 .62643 m
.36838 .51447 L
s
.15543 .58366 m
.02381 .5409 L
s
.15543 .58366 m
.23677 .47171 L
s
.02381 .5409 m
.10515 .42894 L
s
.89485 .68553 m
.76323 .64276 L
s
.89485 .68553 m
.97619 .57357 L
s
.76323 .64276 m
.63162 .6 L
s
.76323 .64276 m
.84457 .5308 L
s
.63162 .6 m
.5 .55723 L
s
.63162 .6 m
.71296 .48804 L
s
.5 .55723 m
.36838 .51447 L
s
.5 .55723 m
.58134 .44528 L
s
.36838 .51447 m
.23677 .47171 L
s
.36838 .51447 m
.44973 .40251 L
s
.23677 .47171 m
.10515 .42894 L
s
.23677 .47171 m
.31811 .35975 L
s
.10515 .42894 m
.1865 .31698 L
s
.97619 .57357 m
.84457 .5308 L
s
.84457 .5308 m
.71296 .48804 L
s
.84457 .5308 m
.92592 .41885 L
s
.71296 .48804 m
.58134 .44528 L
s
.71296 .48804 m
.7943 .37608 L
s
.58134 .44528 m
.44973 .40251 L
s
.58134 .44528 m
.66269 .33332 L
s
.44973 .40251 m
.31811 .35975 L
s
.44973 .40251 m
.53107 .29055 L
s
.31811 .35975 m
.1865 .31698 L
s
.31811 .35975 m
.39945 .24779 L
s
.1865 .31698 m
.05488 .27422 L
s
.1865 .31698 m
.26784 .20502 L
s
.05488 .27422 m
.13622 .16226 L
s
.92592 .41885 m
.7943 .37608 L
s
.7943 .37608 m
.66269 .33332 L
s
.7943 .37608 m
.87564 .26412 L
s
.66269 .33332 m
.53107 .29055 L
s
.66269 .33332 m
.74403 .22136 L
s
.53107 .29055 m
.39945 .24779 L
s
.53107 .29055 m
.61241 .17859 L
s
.39945 .24779 m
.26784 .20502 L
s
.39945 .24779 m
.4808 .13583 L
s
.26784 .20502 m
.13622 .16226 L
s
.26784 .20502 m
.34918 .09306 L
s
.87564 .26412 m
.74403 .22136 L
s
.74403 .22136 m
.61241 .17859 L
s
.61241 .17859 m
.4808 .13583 L
s
.61241 .17859 m
.69376 .06663 L
s
.4808 .13583 m
.34918 .09306 L
s
.4808 .13583 m
.56214 .02387 L
s
.69376 .06663 m
.56214 .02387 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[199]:=",
  ImageSize->{288, 288.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00:470P1m1`00X0L00`071`0307X7002P1`0300L700<70`1g1`00W`L00`07
1`071`@0L`L009h700<01`L030L30707002M1`0300L701070`1]1`00W@L00`071`0C1`<0JPL009`7
00<01`L05`L306L7002K1`0300L701/70`1T1`00VPL00`071`0O1`@0H0L009X700<01`L08`L305d7
002I1`0300L702L70`1J1`00V0L00`071`0[1`80F0L009L700<01`L0;0L00`071`1G1`00U`L00`07
1`0/1`0300L705L7002F1`0300L702`700<01`L0F0L009D700<01`L0;0L00`071`1I1`00U0L00`07
1`0/1`0300L705X7002D1`0300L702`700<01`L0FPL009<700<01`L0;0L00`071`1K1`00I0L202`7
00<01`L0;0L00`071`1L1`00H`L00`071`0302P700<01`L0;0L00`071`1M1`00H`L00`071`031`<0
9@L00`071`0/1`0300L705d7001R1`0300L700L70`0Q1`0300L702`700<01`L0GPL0064700<01`L0
2`L301d700<01`L0;0L00`071`1O1`00H0L00`071`0?1`<06@L00`071`0/1`0300L70607001P1`03
00L70187100E1`0300L702`700<01`L0H0L005l700<01`L05`L3014700<01`L0;0L00`071`1Q1`00
GPL00`071`0K1`<03@L00`071`0/1`0300L70687001M1`0300L701l70`091`0300L702`700<01`L0
H`L005d700<01`L08PL300H700<01`L0;0L00`071`1S1`00G0L00`071`0V1`<00PL00`071`0/1`03
00L706@7001K1`0300L702X70`0]1`0300L706D7001J1`0300L702/700<01`L00`0Y1`0300L706H7
001J1`0300L702/700<01`L00`L302H700<01`L0IPL005T700<01`L0:`L00`071`071`@08@L00`07
1`1W1`00F0L00`071`0[1`0300L700`70`0M1`0300L706P7001G1`0300L702/700<01`L040L301T7
00<01`L0J@L005L700<01`L0:`L00`071`0C1`<05PL00`071`1Y1`009`L202d700<01`L0:`L00`07
1`0G1`<04PL00`071`1Z1`009PL00`071`0302T700<01`L0:`L00`071`0K1`<03PL00`071`1[1`00
9PL00`071`031`<09@L00`071`0/1`0300L701h710091`0300L706`7000U1`0300L700L70P0S1`03
00L702/700<01`L08`L300H700<01`L0K0L002@700<01`L02PL301l700<01`L0:`L00`071`0W1`<0
0PL00`071`1]1`008`L00`071`0>1`<06`L00`071`0[1`0300L702/70`1_1`008`L00`071`0A1`<0
5`L00`071`0/1`0300L702/700<01`L00`1/1`008PL00`071`0E1`<050L00`071`0[1`0300L702`7
00<01`L00`L306T7000Q1`0300L701T70`0@1`0300L702/700<01`L0;0L00`071`071`@0I@L00207
00<01`L07@L300`700<01`L0;0L00`071`0[1`0300L700`70`1R1`0080L00`071`0P1`802@L00`07
1`0/1`0300L702/700<01`L040L305l7000O1`0300L702<70`061`0300L702/700<01`L0;0L00`07
1`0C1`<0G0L001h700<01`L09`L3008700<01`L0:`L00`071`0/1`0300L701L70`1I1`007PL00`07
1`0Z1`<0;@L00`071`0[1`0300L701/70`1F1`007@L00`071`0[1`0300L700<0:@L00`071`0/1`03
00L701h7101B1`0070L00`071`0/1`0300L700<70`0U1`0300L702`700<01`L08`L304l7000K1`03
00L702`700<01`L01`L4020700<01`L0;0L00`071`0W1`<0C0L001/700<01`L0:`L00`071`0<1`<0
7@L00`071`0[1`0300L702/70`191`006PL00`071`0[1`0300L701070`0I1`0300L702`700<01`L0
:`L00`071`0304H7000I1`0300L702`700<01`L04`L301D700<01`L0;0L00`071`0/1`0300L700<7
0`131`0060L00`071`0/1`0300L701L70`0B1`0300L702/700<01`L0;0L00`071`071`<0@0L001P7
00<01`L0:`L00`071`0K1`<03PL00`071`0/1`0300L702/700<01`L02`L303d7000G1`0300L702`7
00<01`L07PL400T700<01`L0;0L00`071`0[1`0300L700l70`0j1`005PL00`071`0/1`0300L702<7
0`051`0300L702`700<01`L0;0L00`071`0B1`80>0L001H700<01`L0:`L00`071`0W1`<00PL00`07
1`0[1`0300L702`700<01`L05@L303D7000E1`0300L702/700<01`L0:`L302d700<01`L0:`L00`07
1`0I1`<0<PL001@700<01`L0;0L00`071`0[1`0300L700<0:@L00`071`0/1`0300L701`70`0_1`00
4`L00`071`0/1`0300L702`700<01`L00`L302D700<01`L0;0L00`071`0P1`<0;0L001<700<01`L0
:`L00`071`0/1`0300L700L7100P1`0300L702`700<01`L090L302T7000B1`0300L702`700<01`L0
:`L00`071`0<1`<07@L00`071`0[1`0300L702P70`0V1`004@L00`071`0/1`0300L702/700<01`L0
40L301T700<01`L0;0L00`071`0[1`8090L0010700<01`L0;0L00`071`0/1`0300L701<70`0E1`03
00L702`700<01`L0;0L00`071`0S1`0040L00`071`0[1`0300L702`700<01`L05`L3018700<01`L0
:`L00`071`0]1`0300L702<7000?1`80;@L00`071`0[1`0300L701/70`0>1`0300L702`700<01`L0
;0L00`071`0T1`004@L302T700<01`L0;0L00`071`0N1`@02@L00`071`0/1`0300L702`700<01`L0
9@L001@70`0U1`0300L702`700<01`L08`L300D700<01`L0;0L00`071`0/1`0300L702H7000G1`@0
80L00`071`0/1`0300L702L70`021`0300L702/700<01`L0;@L00`071`0V1`006`L301d700<01`L0
:`L00`071`0[1`<0;@L00`071`0/1`0300L702L7000N1`<06@L00`071`0/1`0300L702/700<01`L0
0`0Y1`0300L702`700<01`L0:0L002470`0E1`0300L702`700<01`L0;0L00`071`031`<09@L00`07
1`0/1`0300L702T7000T1`<04PL00`071`0[1`0300L702`700<01`L01`L4020700<01`L0;@L00`07
1`0Y1`009`L300h700<01`L0;0L00`071`0[1`0300L700`70`0M1`0300L702`700<01`L0:PL002X7
10091`0300L702`700<01`L0:`L00`071`0@1`<06@L00`071`0/1`0300L702/7000^1`<01@L00`07
1`0/1`0300L702`700<01`L04`L301D700<01`L0;0L00`071`0/1`00<@L3008700<01`L0:`L00`07
1`0/1`0300L701L70`0B1`0300L702`700<01`L0;0L003@70`0]1`0300L702/700<01`L06`L300h7
00<01`L0;0L00`071`0]1`00=0L00`071`0302T700<01`L0;0L00`071`0N1`@02@L00`071`0/1`03
00L702h7000d1`0300L700<70`0U1`0300L702`700<01`L08`L300D700<01`L0;0L00`071`0_1`00
<`L00`071`071`@080L00`071`0/1`0300L702L70`021`0300L702`700<01`L0;`L0038700<01`L0
30L301d700<01`L0:`L00`071`0[1`<0;@L00`071`0`1`00<@L00`071`0@1`<06@L00`071`0/1`03
00L702/700<01`L00`0Y1`0300L70347000a1`0300L701<70`0E1`0300L702`700<01`L0;0L00`07
1`031`<09@L00`071`0b1`00<0L00`071`0G1`<04PL00`071`0[1`0300L702`700<01`L01`L202<7
00<01`L0<PL002l700<01`L06`L300h700<01`L0;0L00`071`0[1`0300L700X70`0O1`0300L703<7
000_1`0300L701h710091`0300L702`700<01`L0:`L00`071`0>1`<06`L00`071`0d1`00;PL00`07
1`0S1`<01@L00`071`0/1`0300L702`700<01`L04@L301L700<01`L0=@L002d700<01`L09`L30087
00<01`L0:`L00`071`0/1`0300L701D70`0D1`0300L703D7000/1`0300L702/70`0]1`0300L702/7
00<01`L06@L3010700<01`L0=PL002`700<01`L0:`L00`071`0302T700<01`L0:`L00`071`0M1`<0
30L00`071`0g1`00:`L00`071`0/1`0300L700<70`0U1`0300L702`700<01`L080L200T700<01`L0
>0L002X700<01`L0;0L00`071`071`@080L00`071`0/1`0300L702<70`061`0300L703P7000Z1`03
00L702/700<01`L030L301d700<01`L0:`L00`071`0W1`<00PL00`071`0i1`00:@L00`071`0[1`03
00L701070`0I1`0300L702`700<01`L0:PL303/7000X1`0300L702`700<01`L04`L301D700<01`L0
;0L00`071`0[1`0300L700<0>0L002L700<01`L0;0L00`071`0G1`<04PL00`071`0[1`0300L702`7
00<01`L00`L303D7000W1`0300L702/700<01`L06`L300h700<01`L0:`L00`071`0/1`0300L700L7
100a1`009PL00`071`0[1`0300L701l710091`0300L702`700<01`L0:`L00`071`0<1`<0;PL002D7
00<01`L0;0L00`071`0S1`<01@L00`071`0/1`0300L702/700<01`L040L302/7000T1`0300L702`7
00<01`L09`L3008700<01`L0:`L00`071`0/1`0300L701<70`0X1`0090L00`071`0[1`0300L702/7
0`0/1`0300L702`700<01`L05`L302D7000S1`0300L702/700<01`L0;0L00`071`0302T700<01`L0
:`L00`071`0K1`<08PL0028700<01`L0;0L00`071`0/1`0300L700<70`0U1`0300L702`700<01`L0
7PL401h7000R1`0300L702/700<01`L0;0L00`071`071`808PL00`071`0/1`0300L702<70`0K1`00
8@L00`071`0[1`0300L702`700<01`L02PL301l700<01`L0:`L00`071`0W1`<060L0020700<01`L0
:`L00`071`0/1`0300L700h70`0K1`0300L702/700<01`L0:`L201H7000O1`0300L702`700<01`L0
;0L00`071`0A1`<05`L00`071`0/1`0300L702/700<01`L05@L001l700<01`L0:`L00`071`0/1`03
00L701D70`0C1`0300L702`700<01`L0;0L00`071`0E1`007PL202`700<01`L0;0L00`071`0I1`<0
40L00`071`0[1`0300L702`700<01`L05PL001d700<01`L00`0X1`0300L702`700<01`L07@L300`7
00<01`L0;0L00`071`0[1`0300L701L7000M1`0300L700<70`0U1`0300L702`700<01`L080L200T7
00<01`L0;0L00`071`0[1`0300L701P7000L1`0300L700L70`0Q1`0300L702`700<01`L08`L300D7
00<01`L0;0L00`071`0/1`0300L701P7000K1`0300L700/70`0M1`0300L702`700<01`L09`L30087
00<01`L0:`L00`071`0/1`0300L701T7000J1`0300L700l70`0I1`0300L702`700<01`L0:`L302d7
00<01`L0:`L00`071`0J1`006PL00`071`0B1`@05@L00`071`0/1`0300L702/700<01`L00`0Y1`03
00L702`700<01`L06PL001T700<01`L05`L3014700<01`L0;0L00`071`0/1`0300L700<70`0U1`03
00L702`700<01`L06`L001P700<01`L06`L300d700<01`L0;0L00`071`0/1`0300L700L7100P1`03
00L702`700<01`L070L001L700<01`L07`L300T700<01`L0;0L00`071`0/1`0300L700`70`0M1`03
00L702/700<01`L07@L001L700<01`L08PL300H700<01`L0;0L00`071`0[1`0300L701070`0I1`03
00L702`700<01`L07@L001H700<01`L09PL3008700<01`L0;0L00`071`0/1`0300L701<70`0E1`03
00L702`700<01`L07PL001D700<01`L0:PL302d700<01`L0;0L00`071`0G1`<04PL00`071`0[1`03
00L701l7000D1`0300L702/700<01`L00`0Y1`0300L702`700<01`L06`L300h700<01`L0;0L00`07
1`0O1`0050L00`071`0[1`0300L700<70`0V1`0300L702`700<01`L07PL400T700<01`L0;0L00`07
1`0P1`004`L00`071`0[1`0300L700L7100Q1`0300L702`700<01`L08`L300D700<01`L0;0L00`07
1`0Q1`004PL00`071`0[1`0300L700`70`0M1`0300L702`700<01`L09`L3008700<01`L0:`L00`07
1`0R1`004@L00`071`0[1`0300L701070`0I1`0300L702`700<01`L0:`L302d700<01`L08PL00147
00<01`L0:`L00`071`0C1`<05PL00`071`0/1`0300L702/700<01`L00`0Y1`0300L702<7000@1`03
00L702/700<01`L05`L3018700<01`L0;0L00`071`0/1`0300L700<70`0U1`0300L702@7000?1`03
00L702/700<01`L06`L300h700<01`L0;0L00`071`0/1`0300L700L7100P1`0300L702D7000>1`03
00L702`700<01`L07PL400T700<01`L0;@L00`071`0[1`0300L700`70`0M1`0300L702D7000>1`03
00L702/700<01`L08`L300H700<01`L0;0L00`071`0[1`0300L701070`0I1`0300L702H7000=1`03
00L702/700<01`L09`L3008700<01`L0;0L00`071`0/1`0300L701<70`0E1`0300L702L7000<1`03
00L702/700<01`L0:`L302d700<01`L0;0L00`071`0G1`<04PL00`071`0W1`002`L00`071`0/1`03
00L702/700<01`L00`0Z1`0300L702/700<01`L06`L300h700<01`L0:0L000/700<01`L0:`L00`07
1`0/1`0300L700<70`0V1`0300L702`700<01`L07PL400T700<01`L0:@L000X700<01`L0:`L00`07
1`0/1`0300L700L70`0R1`0300L702`700<01`L08`L300D700<01`L0:PL000T700<01`L0;0L00`07
1`0[1`0300L700/70`0N1`0300L702`700<01`L09`L3008700<01`L0:PL000P700<01`L0;0L00`07
1`0/1`0300L700h70`0K1`0300L702/700<01`L0:`L302`700081`0300L702/700<01`L0;0L00`07
1`0B1`8060L00`071`0/1`0300L702/700<01`L00`0Y1`001`L00`071`0[1`0300L702`700<01`L0
5@L301@700<01`L0;0L00`071`0/1`0300L700<70`0V1`001PL202d700<01`L0:`L00`071`0I1`<0
4@L00`071`0[1`0300L702`700<01`L01`L4028700081`<0:@L00`071`0/1`0300L701`70`0=1`03
00L702`700<01`L0:`L00`071`0<1`<07`L000/70`0U1`0300L702`700<01`L080L300T700<01`L0
;0L00`071`0[1`0300L701070`0L1`003PL4020700<01`L0;0L00`071`0T1`<01@L00`071`0/1`03
00L702`700<01`L04`L301T7000B1`<07@L00`071`0/1`0300L702L70`021`0300L702/700<01`L0
;0L00`071`0G1`<05PL001D70`0I1`0300L702`700<01`L0:`L302d700<01`L0:`L00`071`0K1`<0
4`L001P70`0E1`0300L702`700<01`L0;0L00`071`0302T700<01`L0;0L00`071`0N1`@03`L001/7
0`0B1`0300L702`700<01`L0;0L00`071`031`<09@L00`071`0/1`0300L702<70`0<1`007PL300h7
00<01`L0;0L00`071`0/1`0300L700L7100P1`0300L702`700<01`L09`L300T7000Q1`@02@L00`07
1`0/1`0300L702`700<01`L030L301d700<01`L0:`L00`071`0[1`801`L002D70`051`0300L702`7
00<01`L0;0L00`071`0@1`<06@L00`071`0/1`0300L702/700<01`L01PL002P70`021`0300L702`7
00<01`L0;0L00`071`0C1`<05@L00`071`0/1`0300L702`700<01`L01PL002/70`0]1`0300L702`7
00<01`L05`L3018700<01`L0:`L00`071`0/1`0300L700L7000[1`0300L700<0:@L00`071`0/1`03
00L701/70`0>1`0300L702`700<01`L0:`L00`071`081`00:`L00`071`031`<09PL00`071`0/1`03
00L701h710091`0300L702`700<01`L0:`L00`071`091`00:PL00`071`071`<08PL00`071`0/1`03
00L702<70`051`0300L702`700<01`L0;0L00`071`091`00:@L00`071`0;1`<07PL00`071`0/1`03
00L702L70`021`0300L702/700<01`L0;0L00`071`0:1`00:0L00`071`0?1`<06`L00`071`0[1`03
00L702/70`0]1`0300L702/700<01`L02`L002P700<01`L04PL201P700<01`L0;0L00`071`0[1`03
00L700<0:@L00`071`0[1`0300L700`7000W1`0300L701D70`0D1`0300L702`700<01`L0;0L00`07
1`031`<09@L00`071`0/1`0300L700`7000V1`0300L701T70`0@1`0300L702`700<01`L0;0L00`07
1`071`@080L00`071`0/1`0300L700d7000V1`0300L701`70`0=1`0300L702`700<01`L0:`L00`07
1`0<1`<07@L00`071`0[1`0300L700h7000U1`0300L702070`091`0300L702`700<01`L0:`L00`07
1`0@1`<06@L00`071`0/1`0300L700h7000T1`0300L702@70`051`0300L702`700<01`L0;0L00`07
1`0C1`<05@L00`071`0/1`0300L700l7000S1`0300L702P70`021`0300L702/700<01`L0;0L00`07
1`0G1`<04PL00`071`0[1`0300L70107000S1`0300L702/70`0]1`0300L702/700<01`L06`L300h7
00<01`L0:`L00`071`0A1`008PL00`071`0/1`0300L700<0:@L00`071`0[1`0300L701l710091`03
00L702`700<01`L04@L0024700<01`L0;@L00`071`031`<09@L00`071`0/1`0300L702<70`051`03
00L702`700<01`L04PL0024700<01`L0;0L00`071`071`@080L00`071`0/1`0300L702L70`021`03
00L702/700<01`L04`L0020700<01`L0;0L00`071`0<1`<07@L00`071`0[1`0300L702/70`0/1`03
00L701@7000O1`0300L702`700<01`L040L301T700<01`L0:`L00`071`0/1`0300L700<0:@L00`07
1`0D1`007PL00`071`0]1`0300L701<70`0E1`0300L702`700<01`L0;0L00`071`031`<09@L00`07
1`0E1`007PL00`071`0/1`0300L701L70`0B1`0300L702/700<01`L0;0L00`071`071`808PL00`07
1`0F1`007@L00`071`0/1`0300L701/70`0>1`0300L702/700<01`L0;0L00`071`0:1`<07`L00`07
1`0F1`0070L00`071`0]1`0300L701h710091`0300L702/700<01`L0;0L00`071`0>1`<06`L00`07
1`0G1`006`L00`071`0]1`0300L702<70`051`0300L702`700<01`L0;0L00`071`0A1`<05`L00`07
1`0H1`006`L00`071`0/1`0300L702L70`021`0300L702/700<01`L0;0L00`071`0E1`<04`L00`07
1`0I1`006PL00`071`0/1`0300L702/70`0/1`0300L702`700<01`L06@L3010700<01`L06@L001T7
00<01`L0;@L00`071`0[1`0300L700<0:0L00`071`0/1`0300L701d70`0<1`0300L701X7000I1`03
00L702`700<01`L0;0L00`071`031`<09@L00`071`0/1`0300L702070P091`0300L701/7000H1`03
00L702`700<01`L0;0L00`071`071`<08@L00`071`0/1`0300L702<70`051`0300L701`7000G1`03
00L702d700<01`L0:`L00`071`0;1`<07@L00`071`0/1`0300L702L70`021`0300L701`7000F1`03
00L702d700<01`L0:`L00`071`0?1`<06@L00`071`0/1`0300L702/70P0O1`005PL00`071`0/1`03
00L702`700<01`L04PL401D700<01`L0;0L00`071`0[1`0300L701h7000E1`80;@L00`071`0/1`03
00L701L70`0A1`0300L702`700<01`L0;0L00`071`0N1`005`L302X700<01`L0:`L00`071`0K1`<0
3@L00`071`0/1`0300L702`700<01`L07`L001X70`0V1`0300L702/700<01`L07`L300T700<01`L0
;0L00`071`0/1`0300L70207000M1`<08PL00`071`0/1`0300L702870`061`0300L702`700<01`L0
:`L00`071`0Q1`0080L301h700<01`L0;0L00`071`0V1`<00PL00`071`0/1`0300L702`700<01`L0
8@L002<70`0K1`0300L702/700<01`L0:PL302d700<01`L0;0L00`071`0R1`009PL201P700<01`L0
:`L00`071`0[1`0300L700<0:@L00`071`0/1`0300L702<7000X1`<050L00`071`0/1`0300L702/7
00<01`L00`L302H700<01`L0;0L00`071`0S1`00:`L3014700<01`L0:`L00`071`0[1`0300L700L7
100Q1`0300L702`700<01`L090L002h70`0=1`0300L702/700<01`L0:`L00`071`0<1`<07@L00`07
1`0/1`0300L702D7000a1`<02@L00`071`0[1`0300L702/700<01`L040L301T700<01`L0;0L00`07
1`0V1`00=0L300D700<01`L0;0L00`071`0[1`0300L701<70`0F1`0300L702`700<01`L09PL003L7
0`021`0300L702/700<01`L0:`L00`071`0G1`<04PL00`071`0/1`0300L702L7000j1`<0;0L00`07
1`0[1`0300L701/70`0>1`0300L702`700<01`L0:0L003X700<01`L00`0X1`0300L702`700<01`L0
7PL400T700<01`L0;@L00`071`0X1`00>PL00`071`031`<09@L00`071`0[1`0300L702<70`061`03
00L702`700<01`L0:@L003T700<01`L01`L3024700<01`L0:`L00`071`0W1`<00PL00`071`0/1`03
00L702X7000h1`0300L700/70`0M1`0300L702/700<01`L0:`L302d700<01`L0:`L003L700<01`L0
3`L301T700<01`L0;0L00`071`0[1`0300L700<0:PL00`071`0[1`00=`L00`071`0B1`@05@L00`07
1`0[1`0300L702`700<01`L00`L302H700<01`L0;0L003H700<01`L05`L3014700<01`L0:`L00`07
1`0/1`0300L700L70`0R1`0300L702d7000e1`0300L701/70`0=1`0300L702`700<01`L0:`L00`07
1`0;1`<07PL00`071`0^1`00=0L00`071`0O1`<02@L00`071`0/1`0300L702`700<01`L03PL301/7
00<01`L0;PL003@700<01`L08PL300H700<01`L0:`L00`071`0/1`0300L701870P0H1`0300L702l7
000c1`0300L702H70`021`0300L702/700<01`L0;0L00`071`0E1`<050L00`071`0`1`00<PL00`07
1`0Z1`<0;@L00`071`0[1`0300L701T70`0A1`0300L70307000a1`0300L702/700<01`L00`0Y1`03
00L702`700<01`L070L300d700<01`L0<@L0034700<01`L0:`L00`071`031`<09@L00`071`0/1`03
00L702070`091`0300L70387000`1`0300L702/700<01`L01`L4020700<01`L0;0L00`071`0T1`<0
1@L00`071`0c1`00;`L00`071`0[1`0300L700`70`0M1`0300L702`700<01`L09`L3008700<01`L0
<`L002h700<01`L0:`L00`071`0@1`<06@L00`071`0/1`0300L702/70P0f1`00;PL00`071`0[1`03
00L701<70`0E1`0300L702`700<01`L0;0L00`071`0e1`00;@L00`071`0[1`0300L701L70`0B1`03
00L702`700<01`L0;0L00`071`0e1`00;0L00`071`0[1`0300L701/70`0>1`0300L702`700<01`L0
;0L00`071`0f1`00:`L00`071`0/1`0300L701h710091`0300L702`700<01`L0;0L00`071`0g1`00
:`L00`071`0[1`0300L702<70`051`0300L702`700<01`L0;0L00`071`0h1`00:PL00`071`0[1`03
00L702L70`021`0300L702`700<01`L0;0L00`071`0h1`00:@L00`071`0[1`0300L702/70`0]1`03
00L702`700<01`L0>@L002P700<01`L0;0L00`071`0[1`0300L700<0:@L00`071`0/1`0300L703X7
000X1`0300L702/700<01`L0;0L00`071`031`<09PL00`071`0/1`0300L703X7000W1`0300L702/7
00<01`L0;0L00`071`071`<08PL00`071`0/1`0300L703/7000V1`0300L702`700<01`L0:`L00`07
1`0;1`<07PL00`071`0/1`0300L703`7000U1`0300L702`700<01`L0:`L00`071`0?1`<06`L00`07
1`0[1`0300L703d7000U1`0300L702/700<01`L0;0L00`071`0B1`8060L00`071`0/1`0300L703d7
000T1`0300L702/700<01`L0;0L00`071`0E1`<050L00`071`0/1`0300L703h7000S1`80;@L00`07
1`0[1`0300L701T70`0@1`0300L702`700<01`L0?`L002D70`0Y1`0300L702`700<01`L070L300d7
00<01`L0;0L00`071`0o1`00:0L302D700<01`L0;0L00`071`0P1`<02@L00`071`0/1`0300L70407
000[1`@080L00`071`0/1`0300L702@70`051`0300L702`700<01`L0@@L002l70`0M1`0300L702/7
00<01`L0:0L3008700<01`L0:`L00`071`121`00<PL301T700<01`L0;0L00`071`0[1`<0;@L00`07
1`121`00=@L301D700<01`L0;0L00`071`0/1`0300L700<0:@L00`071`131`00>0L3018700<01`L0
:`L00`071`0]1`0300L700<70`0U1`0300L704@7000k1`<03PL00`071`0/1`0300L702`700<01`L0
1`L4020700<01`L0A@L003h710091`0300L702`700<01`L0;0L00`071`0<1`<07@L00`071`151`00
@PL300D700<01`L0;0L00`071`0/1`0300L701070`0I1`0300L704H700151`<00PL00`071`0[1`03
00L702d700<01`L04`L301D700<01`L0A`L004P70`0]1`0300L702`700<01`L05`L3018700<01`L0
A`L004/70`0Y1`0300L702`700<01`L06`L300h700<01`L0B0L004h70`0U1`0300L702d700<01`L0
7PL400T700<01`L0B@L00547100P1`0300L702d700<01`L08`L300D700<01`L0BPL005D70`0M1`03
00L702`700<01`L09`L3008700<01`L0BPL005P70`0I1`0300L702`700<01`L0:`L204d7001K1`<0
5@L00`071`0]1`0300L707X7001N1`<04PL00`071`0/1`0300L707/7001Q1`<03PL00`071`0/1`03
00L707`7001T1`@02@L00`071`0]1`0300L707`7001X1`<01@L00`071`0]1`0300L707d7001[1`<0
0PL00`071`0/1`0300L707h7001^1`<0;@L00`071`1o1`00L@L302X700<01`L0O`L007@70`0V1`03
00L70807001g1`<08PL00`071`211`00NPL301h700<01`L0PPL007d70`0K1`0300L7088700201`80
60L00`071`231`00PPL301@700<01`L0Q0L008D70`0A1`0300L708@700281`<03@L00`071`251`00
R`L300T700<01`L0QPL008h70`051`0300L708L7002A1`<00PL00`071`271`00U0L208X7003o1b47
003o1b47003o1b47003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {287.688, 0}} -> {-9.25064, -9.81467, \
0.0661918, 0.0661918}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[199]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(lattice54\  = 
      tiling2D[SphericalCut[N[Join[AL054, \ AL154, \ AL254, \ AL354]], 10], \ 
        rad54]\)], "Input",
  CellLabel->"In[200]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.03596 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.500105 0.049582 0.517956 0.049582 [
[ 0 0 0 0 ]
[ 1 1.03596 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.03596 L
0 1.03596 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.53048 .95301 m
.40653 .91273 L
s
.53048 .95301 m
.60709 .84757 L
s
.40653 .91273 m
.28257 .87246 L
s
.40653 .91273 m
.48313 .80729 L
s
.28257 .87246 m
.15862 .83218 L
s
.28257 .87246 m
.35918 .76701 L
s
.15862 .83218 m
.23522 .72674 L
s
.73104 .88784 m
.60709 .84757 L
s
.73104 .88784 m
.80765 .7824 L
s
.60709 .84757 m
.48313 .80729 L
s
.60709 .84757 m
.6837 .74212 L
s
.48313 .80729 m
.35918 .76701 L
s
.48313 .80729 m
.55974 .70185 L
s
.35918 .76701 m
.23522 .72674 L
s
.35918 .76701 m
.43579 .66157 L
s
.23522 .72674 m
.11127 .68646 L
s
.23522 .72674 m
.31183 .6213 L
s
.11127 .68646 m
.18788 .58102 L
s
.80765 .7824 m
.6837 .74212 L
s
.80765 .7824 m
.88426 .67696 L
s
.6837 .74212 m
.55974 .70185 L
s
.6837 .74212 m
.76031 .63668 L
s
.55974 .70185 m
.43579 .66157 L
s
.55974 .70185 m
.63635 .59641 L
s
.43579 .66157 m
.31183 .6213 L
s
.43579 .66157 m
.5124 .55613 L
s
.31183 .6213 m
.18788 .58102 L
s
.31183 .6213 m
.38844 .51585 L
s
.18788 .58102 m
.06392 .54075 L
s
.18788 .58102 m
.26449 .47558 L
s
.06392 .54075 m
.14053 .4353 L
s
.88426 .67696 m
.76031 .63668 L
s
.88426 .67696 m
.96087 .57151 L
s
.76031 .63668 m
.63635 .59641 L
s
.76031 .63668 m
.83691 .53124 L
s
.63635 .59641 m
.5124 .55613 L
s
.63635 .59641 m
.71296 .49096 L
s
.5124 .55613 m
.38844 .51585 L
s
.5124 .55613 m
.589 .45069 L
s
.38844 .51585 m
.26449 .47558 L
s
.38844 .51585 m
.46505 .41041 L
s
.26449 .47558 m
.14053 .4353 L
s
.26449 .47558 m
.34109 .37014 L
s
.14053 .4353 m
.21714 .32986 L
s
.96087 .57151 m
.83691 .53124 L
s
.83691 .53124 m
.71296 .49096 L
s
.83691 .53124 m
.91352 .4258 L
s
.71296 .49096 m
.589 .45069 L
s
.71296 .49096 m
.78957 .38552 L
s
.589 .45069 m
.46505 .41041 L
s
.589 .45069 m
.66561 .34524 L
s
.46505 .41041 m
.34109 .37014 L
s
.46505 .41041 m
.54166 .30497 L
s
.34109 .37014 m
.21714 .32986 L
s
.34109 .37014 m
.4177 .26469 L
s
.21714 .32986 m
.09318 .28959 L
s
.21714 .32986 m
.29375 .22442 L
s
.09318 .28959 m
.16979 .18414 L
s
.91352 .4258 m
.78957 .38552 L
s
.78957 .38552 m
.66561 .34524 L
s
.78957 .38552 m
.86618 .28008 L
s
.66561 .34524 m
.54166 .30497 L
s
.66561 .34524 m
.74222 .2398 L
s
.54166 .30497 m
.4177 .26469 L
s
.54166 .30497 m
.61827 .19953 L
s
.4177 .26469 m
.29375 .22442 L
s
.4177 .26469 m
.49431 .15925 L
s
.29375 .22442 m
.16979 .18414 L
s
.29375 .22442 m
.37036 .11898 L
s
.86618 .28008 m
.74222 .2398 L
s
.74222 .2398 m
.61827 .19953 L
s
.61827 .19953 m
.49431 .15925 L
s
.61827 .19953 m
.69487 .09408 L
s
.49431 .15925 m
.37036 .11898 L
s
.49431 .15925 m
.57092 .05381 L
s
.69487 .09408 m
.57092 .05381 L
s
.46919 1.01129 m
.34524 .97102 L
s
.46919 1.01129 m
.5458 .90585 L
s
.34524 .97102 m
.42185 .86558 L
s
.66976 .94613 m
.5458 .90585 L
s
.66976 .94613 m
.74637 .84069 L
s
.5458 .90585 m
.42185 .86558 L
s
.5458 .90585 m
.62241 .80041 L
s
.42185 .86558 m
.29789 .8253 L
s
.42185 .86558 m
.49846 .76013 L
s
.29789 .8253 m
.17394 .78503 L
s
.29789 .8253 m
.3745 .71986 L
s
.17394 .78503 m
.25055 .67958 L
s
.74637 .84069 m
.62241 .80041 L
s
.74637 .84069 m
.82297 .73524 L
s
.62241 .80041 m
.49846 .76013 L
s
.62241 .80041 m
.69902 .69497 L
s
.49846 .76013 m
.3745 .71986 L
s
.49846 .76013 m
.57506 .65469 L
s
.3745 .71986 m
.25055 .67958 L
s
.3745 .71986 m
.45111 .61442 L
s
.25055 .67958 m
.12659 .63931 L
s
.25055 .67958 m
.32715 .57414 L
s
.12659 .63931 m
.2032 .53387 L
s
.82297 .73524 m
.69902 .69497 L
s
.82297 .73524 m
.89958 .6298 L
s
.69902 .69497 m
.57506 .65469 L
s
.69902 .69497 m
.77563 .58953 L
s
.57506 .65469 m
.45111 .61442 L
s
.57506 .65469 m
.65167 .54925 L
s
.45111 .61442 m
.32715 .57414 L
s
.45111 .61442 m
.52772 .50897 L
s
.32715 .57414 m
.2032 .53387 L
s
.32715 .57414 m
.40376 .4687 L
s
.2032 .53387 m
.07924 .49359 L
s
.2032 .53387 m
.27981 .42842 L
s
.07924 .49359 m
.15585 .38815 L
s
.89958 .6298 m
.77563 .58953 L
s
.89958 .6298 m
.97619 .52436 L
s
.77563 .58953 m
.65167 .54925 L
s
.77563 .58953 m
.85224 .48408 L
s
.65167 .54925 m
.52772 .50897 L
s
.65167 .54925 m
.72828 .44381 L
s
.52772 .50897 m
.40376 .4687 L
s
.52772 .50897 m
.60433 .40353 L
s
.40376 .4687 m
.27981 .42842 L
s
.40376 .4687 m
.48037 .36326 L
s
.27981 .42842 m
.15585 .38815 L
s
.27981 .42842 m
.35642 .32298 L
s
.15585 .38815 m
.23246 .28271 L
s
.97619 .52436 m
.85224 .48408 L
s
.85224 .48408 m
.72828 .44381 L
s
.85224 .48408 m
.92884 .37864 L
s
.72828 .44381 m
.60433 .40353 L
s
.72828 .44381 m
.80489 .33837 L
s
.60433 .40353 m
.48037 .36326 L
s
.60433 .40353 m
.68093 .29809 L
s
.48037 .36326 m
.35642 .32298 L
s
.48037 .36326 m
.55698 .25781 L
s
.35642 .32298 m
.23246 .28271 L
s
.35642 .32298 m
.43302 .21754 L
s
.23246 .28271 m
.10851 .24243 L
s
.23246 .28271 m
.30907 .17726 L
s
.10851 .24243 m
.18511 .13699 L
s
.92884 .37864 m
.80489 .33837 L
s
.80489 .33837 m
.68093 .29809 L
s
.80489 .33837 m
.8815 .23292 L
s
.68093 .29809 m
.55698 .25781 L
s
.68093 .29809 m
.75754 .19265 L
s
.55698 .25781 m
.43302 .21754 L
s
.55698 .25781 m
.63359 .15237 L
s
.43302 .21754 m
.30907 .17726 L
s
.43302 .21754 m
.50963 .1121 L
s
.30907 .17726 m
.18511 .13699 L
s
.30907 .17726 m
.38568 .07182 L
s
.8815 .23292 m
.75754 .19265 L
s
.75754 .19265 m
.63359 .15237 L
s
.63359 .15237 m
.50963 .1121 L
s
.50963 .1121 m
.38568 .07182 L
s
.61432 .96414 m
.49037 .92386 L
s
.61432 .96414 m
.69093 .8587 L
s
.49037 .92386 m
.36641 .88359 L
s
.49037 .92386 m
.56698 .81842 L
s
.36641 .88359 m
.24246 .84331 L
s
.36641 .88359 m
.44302 .77815 L
s
.24246 .84331 m
.1185 .80304 L
s
.24246 .84331 m
.31907 .73787 L
s
.1185 .80304 m
.19511 .6976 L
s
.81489 .89897 m
.69093 .8587 L
s
.81489 .89897 m
.89149 .79353 L
s
.69093 .8587 m
.56698 .81842 L
s
.69093 .8587 m
.76754 .75325 L
s
.56698 .81842 m
.44302 .77815 L
s
.56698 .81842 m
.64358 .71298 L
s
.44302 .77815 m
.31907 .73787 L
s
.44302 .77815 m
.51963 .6727 L
s
.31907 .73787 m
.19511 .6976 L
s
.31907 .73787 m
.39567 .63243 L
s
.19511 .6976 m
.07116 .65732 L
s
.19511 .6976 m
.27172 .59215 L
s
.07116 .65732 m
.14776 .55188 L
s
.89149 .79353 m
.76754 .75325 L
s
.76754 .75325 m
.64358 .71298 L
s
.76754 .75325 m
.84415 .64781 L
s
.64358 .71298 m
.51963 .6727 L
s
.64358 .71298 m
.72019 .60754 L
s
.51963 .6727 m
.39567 .63243 L
s
.51963 .6727 m
.59624 .56726 L
s
.39567 .63243 m
.27172 .59215 L
s
.39567 .63243 m
.47228 .52699 L
s
.27172 .59215 m
.14776 .55188 L
s
.27172 .59215 m
.34833 .48671 L
s
.14776 .55188 m
.02381 .5116 L
s
.14776 .55188 m
.22437 .44644 L
s
.02381 .5116 m
.10042 .40616 L
s
.84415 .64781 m
.72019 .60754 L
s
.84415 .64781 m
.92076 .54237 L
s
.72019 .60754 m
.59624 .56726 L
s
.72019 .60754 m
.7968 .50209 L
s
.59624 .56726 m
.47228 .52699 L
s
.59624 .56726 m
.67285 .46182 L
s
.47228 .52699 m
.34833 .48671 L
s
.47228 .52699 m
.54889 .42154 L
s
.34833 .48671 m
.22437 .44644 L
s
.34833 .48671 m
.42494 .38127 L
s
.22437 .44644 m
.10042 .40616 L
s
.22437 .44644 m
.30098 .34099 L
s
.10042 .40616 m
.17703 .30072 L
s
.92076 .54237 m
.7968 .50209 L
s
.7968 .50209 m
.67285 .46182 L
s
.7968 .50209 m
.87341 .39665 L
s
.67285 .46182 m
.54889 .42154 L
s
.67285 .46182 m
.74945 .35638 L
s
.54889 .42154 m
.42494 .38127 L
s
.54889 .42154 m
.6255 .3161 L
s
.42494 .38127 m
.30098 .34099 L
s
.42494 .38127 m
.50154 .27583 L
s
.30098 .34099 m
.17703 .30072 L
s
.30098 .34099 m
.37759 .23555 L
s
.17703 .30072 m
.25363 .19528 L
s
.87341 .39665 m
.74945 .35638 L
s
.74945 .35638 m
.6255 .3161 L
s
.74945 .35638 m
.82606 .25093 L
s
.6255 .3161 m
.50154 .27583 L
s
.6255 .3161 m
.70211 .21066 L
s
.50154 .27583 m
.37759 .23555 L
s
.50154 .27583 m
.57815 .17038 L
s
.37759 .23555 m
.25363 .19528 L
s
.37759 .23555 m
.4542 .13011 L
s
.25363 .19528 m
.33024 .08983 L
s
.82606 .25093 m
.70211 .21066 L
s
.70211 .21066 m
.57815 .17038 L
s
.57815 .17038 m
.4542 .13011 L
s
.57815 .17038 m
.65476 .06494 L
s
.4542 .13011 m
.33024 .08983 L
s
.4542 .13011 m
.53081 .02467 L
s
.65476 .06494 m
.53081 .02467 L
s
.42908 .98215 m
.30513 .94188 L
s
.42908 .98215 m
.50569 .87671 L
s
.30513 .94188 m
.38173 .83643 L
s
.62964 .91698 m
.50569 .87671 L
s
.62964 .91698 m
.70625 .81154 L
s
.50569 .87671 m
.38173 .83643 L
s
.50569 .87671 m
.5823 .77127 L
s
.38173 .83643 m
.25778 .79616 L
s
.38173 .83643 m
.45834 .73099 L
s
.25778 .79616 m
.13382 .75588 L
s
.25778 .79616 m
.33439 .69072 L
s
.13382 .75588 m
.21043 .65044 L
s
.83021 .85182 m
.70625 .81154 L
s
.83021 .85182 m
.90682 .74637 L
s
.70625 .81154 m
.5823 .77127 L
s
.70625 .81154 m
.78286 .7061 L
s
.5823 .77127 m
.45834 .73099 L
s
.5823 .77127 m
.65891 .66582 L
s
.45834 .73099 m
.33439 .69072 L
s
.45834 .73099 m
.53495 .62555 L
s
.33439 .69072 m
.21043 .65044 L
s
.33439 .69072 m
.411 .58527 L
s
.21043 .65044 m
.08648 .61016 L
s
.21043 .65044 m
.28704 .545 L
s
.08648 .61016 m
.16309 .50472 L
s
.90682 .74637 m
.78286 .7061 L
s
.78286 .7061 m
.65891 .66582 L
s
.78286 .7061 m
.85947 .60066 L
s
.65891 .66582 m
.53495 .62555 L
s
.65891 .66582 m
.73551 .56038 L
s
.53495 .62555 m
.411 .58527 L
s
.53495 .62555 m
.61156 .52011 L
s
.411 .58527 m
.28704 .545 L
s
.411 .58527 m
.4876 .47983 L
s
.28704 .545 m
.16309 .50472 L
s
.28704 .545 m
.36365 .43956 L
s
.16309 .50472 m
.03913 .46445 L
s
.16309 .50472 m
.23969 .39928 L
s
.03913 .46445 m
.11574 .359 L
s
.85947 .60066 m
.73551 .56038 L
s
.85947 .60066 m
.93608 .49521 L
s
.73551 .56038 m
.61156 .52011 L
s
.73551 .56038 m
.81212 .45494 L
s
.61156 .52011 m
.4876 .47983 L
s
.61156 .52011 m
.68817 .41466 L
s
.4876 .47983 m
.36365 .43956 L
s
.4876 .47983 m
.56421 .37439 L
s
.36365 .43956 m
.23969 .39928 L
s
.36365 .43956 m
.44026 .33411 L
s
.23969 .39928 m
.11574 .359 L
s
.23969 .39928 m
.3163 .29384 L
s
.11574 .359 m
.19235 .25356 L
s
.93608 .49521 m
.81212 .45494 L
s
.81212 .45494 m
.68817 .41466 L
s
.81212 .45494 m
.88873 .3495 L
s
.68817 .41466 m
.56421 .37439 L
s
.68817 .41466 m
.76478 .30922 L
s
.56421 .37439 m
.44026 .33411 L
s
.56421 .37439 m
.64082 .26895 L
s
.44026 .33411 m
.3163 .29384 L
s
.44026 .33411 m
.51687 .22867 L
s
.3163 .29384 m
.19235 .25356 L
s
.3163 .29384 m
.39291 .1884 L
s
.19235 .25356 m
.26896 .14812 L
s
.88873 .3495 m
.76478 .30922 L
s
.76478 .30922 m
.64082 .26895 L
s
.76478 .30922 m
.84138 .20378 L
s
.64082 .26895 m
.51687 .22867 L
s
.64082 .26895 m
.71743 .1635 L
s
.51687 .22867 m
.39291 .1884 L
s
.51687 .22867 m
.59347 .12323 L
s
.39291 .1884 m
.26896 .14812 L
s
.39291 .1884 m
.46952 .08295 L
s
.84138 .20378 m
.71743 .1635 L
s
.71743 .1635 m
.59347 .12323 L
s
.59347 .12323 m
.46952 .08295 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[200]:=",
  ImageSize->{273.812, 283.625},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004A00016`P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;XNZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmoOda<C9B;WMKBg2XX;H=kRbLW9`00
?g=cLh20P240<?oo_hjYUM3KddiMD^GQY9no_m[ViUY]KLC4a000O`00_`0o000o?`0oO`0o_`0oo`1o
001o?`1oO`1o_`1oo`2o002o?`2oOfF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oOggN?Sl?Ei02o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOoGN/lBbShMj
HWAdM<;2`^SXj79bLZFUYJNWYg<7i/30`9T0I_ooc020P800082006IVc3<cIP2009VIod:JYb8R8_mV
<`00P00g??mVc9W<VIW<c9W<oiWo09Wo<iWoIYWoVIWoc?l74PL00?l74PL00?l74PL00?l74PL00?l7
4PL00?l74PL00?l74PL009070P1o1`00S`L00`071`0307`7002?1`0300L700<70`1i1`00SPL00`07
1`071`<0MPL008d700<01`L02`L307<7002<1`0300L700l70`1`1`00S0L00`071`0B1`@0K0L008/7
00<01`L05`L306T7002:1`0300L700h70P0;1`<0IPL008T700<01`L03PL00`071`0300/70`1S1`00
R@L00`071`0>1`0300L700<70`0;1`<0H0L008P700<01`L03PL00`071`071`<02`L205h7001Y1`80
70L00`071`0>1`0300L700/70`081`0300L705d7001X1`0300L700<060L00`071`0>1`0300L700l7
0`051`0300L705d7001X1`0300L700<70`0E1`0300L700h700<01`L04PL50607001W1`0300L700L7
0`0A1`0300L700h700<01`L05PL405h7001V1`0300L700/70`091`800PL00`071`0>1`0300L701H7
00<01`L00PL305/7001J1`802@L00`071`0?1`<01@L00`071`0300l700<01`L05`L00`071`051`<0
F0L005T700<01`L00`061`0300L7018710000`L01`021`0300L000<02`L00`071`0F1`0300L700T7
0`1E1`00F@L00`071`031`<00PL00`071`0G1`<000<700L01@L300L700<01`L05PL00`071`0=1`80
D`L005P700<01`L01`L301P700@01`L70`081`<00`L00`071`0F1`0300L700h700<01`L0DPL005L7
00<01`L020L00`071`0301@700D01`L700031`<020L401P700<01`L03PL00`071`1B1`00EPL00`07
1`091`0300L700<70`0A1`0500L71`001PL300L700<01`000P0D1`0300L700h700<01`L0D`L005H7
00<01`L020L00`071`071`<03@L01@071`L000X70`031`0300L700<70`0@1`0300L700h700<01`L0
E0L005D700<01`L020L00`071`0;1`<02@L01@071`L000/700<01`L00`091`@02`L00`071`0>1`03
00L705D7001D1`0300L700T700<01`L00PL200X70`051`0500L71`0030L01P071`L01`<02PL300P7
00<01`L03PL00`071`1E1`00D`L00`071`091`0300L7008700<01`L00`0:1`<00PL01@071`L000/7
00<01`L00PL00`071`021`<02PL300@700<01`L03PL00`071`1F1`00D`L00`071`081`0300L700<7
00<01`L00`L300X70`021`0300L700T700<01`L00PL00`071`061`<01`L00`071`04010700<01`L0
E`L0058700<01`L020L00`071`031`0300L700L70`071`0300L700<02PL00`071`021`0300L700X7
0`041`0300L70087100=1`0300L705P7001A1`0300L700T700<01`L00PL00`071`0;1`<00`L01@07
1`L000870`071`0500L71`0040L400D700@01`L70`0:1`0300L705P7000b1`807@L00`071`081`03
00L7008700<01`L03`L400<700<01`L00`L300<700<01`L00PL00`071`0@1`@00PL00`071`051`<0
1PL00`071`1I1`00<@L00`071`0301T700<01`L020L00`071`031`0300L701471@091`<010L00`07
1`0A1`0400L71`<02PL3008700<01`L0FPL0034700<01`L00`L301D700<01`L02@L00`071`021`03
00L7014700@01`L710081`0300L000<04`L00`071`021`0300L700<02PL405/7000`1`0300L700L7
0`0<1`800`L00`071`091`0300L7008700<01`L04@L00`071`021`0400L71`<01@L010071`L40107
00<01`L00`L00`071`031`<020L00`071`0305P7000_1`0300L700/70`081`0300L700@02PL00`07
1`021`0300L7018700D01`L700071`<000<700L00`L010071`L400/700<01`L00`L00`071`071`<0
10L00`071`041`<0E@L002h700<01`L03`L300D700<01`L00PL400L700<01`L00`L00`071`0A1`05
00L71`002`L3008700<01`L01PL300P700<01`L00PL00`071`081`0300L700@02PL30587000^1`03
00L701871@041`0300L700870`041`0300L7008700<01`L04@L01@071`L000`700<01`L00`0;1`<0
10L00`071`021`0300L700T700<01`L00PL400/70`1?1`00;@L00`071`0F1`@00PL00`071`051`@0
10L00`071`0A1`0300L7008700<01`L02@L01@071`L000870`0;1`@01@L00`071`081`0300L700<7
00@01`L70`0;1`<0C0L002`700<01`L05PL00`071`021`<02@L4008700<01`L04@L01@071`L000/7
00<01`L00PL00`071`031`<02`L3008700<01`L020L00`071`031`0300L700D70`081`0300L700<0
B@L002/700<01`L05`L00`071`021`0300L700<01@L00`071`021`@04@L01@071`L000/700<01`L0
0PL00`071`071`<01`L010071`L300T700<01`L00`L00`071`091`<01@L00`071`031`<0APL002/7
00<01`L05PL00`071`021`0300L700@70`021`0300L7008700@01`L70`0=1`0300L7008700<01`L0
2@L01@071`L000d70`031`0300L7008700<01`L00`061`0300L7008700<01`L03@L500T70`131`00
:PL00`071`0F1`0300L700<700<01`L01`L300<700<01`L01@L300T700<01`L00PL00`071`091`05
00L71`004@L400@700<01`L00`L3008700<01`L00`L00`071`0@1`@02PL30407000Y1`0300L701H7
00<01`L00`L00`071`081`0300L700@02PL300H700D01`L7000;1`0300L7008700<01`L04@L600T7
0`041`0300L7010700<01`L00PL300X70`0m1`00:@L00`071`021`804PL00`071`021`0300L700T7
00<01`L00PL400/70`021`0300L7008700<01`L02@L01@071`L001<700<01`L00PL400L700<01`L0
100C1`0300L700D70`0:1`@0>@L002P700<01`L00PL00`071`0300h700<01`L00PL00`071`091`03
00L7008700<01`L00PL300/70`031`0300L700T700D01`L7000D1`0500L71`0010L300@700<01`L0
0PL4010700<01`L02@L300/70`0f1`009`L00`071`031`0300L700<70`0:1`0300L700<700<01`L0
20L00`071`031`0300L700D70`081`0300L700<02`L01@071`L001@700<01`L00PL00`071`051`@0
1@L010071`L400/700<01`L03@L300/70`0c1`009PL00`071`031`0300L700L70`071`0300L70087
0P091`0300L700<700<01`L02@L300D700<01`L00PL400L700<01`L00PL00`071`0A1`0300L70087
00<01`L020L4008700<01`L01PL300L700<01`L03PL00`071`0300/70`0`1`009PL00`071`021`03
00L700/70`031`0300L7008700<01`L00`061`0300L7008700<01`L03@L500@700<01`L00PL300@7
00D01`L7000D1`0500L71`002`L010071`L300/70`041`0300L700h700<01`L00`L300/70`0]1`00
9@L00`071`021`0300L700l70`051`0300L700<70`021`0300L7008700<01`L04@L400031`0700L7
10031`0300L7018700D01`L7000;1`0300L7008700<01`L00`0;1`@040L00`071`071`<02`L202/7
000T1`0300L700<700<01`L040L00`07000400T70`041`0300L7010700<01`L00PL300T710000`L0
1`0B1`0300L7008700<01`L020L00`071`031`0300L700<70`0:1`@03@L00`071`0;1`<020L00`07
1`0Z1`0090L00`071`021`0300L7014700<01`L00PL400L700<01`L0100C1`0300L7008700<01`L0
0`051`0300L70087100@1`0300L7008700<01`L020L00`071`031`0300L700L70`071`0400L71`<0
2@L00`071`0?1`<01@L00`071`0Z1`008`L00`071`021`0300L7014700<01`L00PL00`071`021`<0
10L00`071`021`@040L00`071`021`0300L700@70`021`0500L71`0010L300d700D01`L7000;1`03
00L7008700<01`L02`L300<700<01`L00PL00`071`0300H700<01`L04PL502d7000R1`0300L70087
00<01`L04@L00`071`031`0300L700D710041`0300L70087100;1`0300L7008700<01`L020L30087
00<01`L01PL300T700<01`L00PL00`071`081`0300L7008700<01`L03`L300D700<01`L00`L30087
00<01`L05PL402/7000Q1`0300L700<700<01`L04@L00`071`021`0300L700P710021`0300L700H7
0`071`0300L700<700<01`L020L00`071`0300/70`051`0300L7008700<01`L020L00`071`031`03
00L7010700<01`0010091`<05`L00`071`021`<0:0L0024700<01`L00PL00`071`0A1`0300L70087
00<01`L02@L010071`L300/70`041`0300L7008700<01`L02@L01P071`L01`<02`L3008700D01`L7
000;1`0300L7008700<01`L04@L00`071`021`@01`L00`071`0301@700<01`L01@L302D7000P1`03
00L7008700<01`L04@L00`071`021`0300L700T700<01`L00PL00`071`0300/710041`0300L700T7
00D01`L700051`<02`L3008700<01`L02@L00`071`021`0300L7014700<01`L00PL00`071`021`<0
10L00`071`031`<040L00`071`091`<08PL001l700<01`L00`L00`071`0@1`0300L700<700<01`L0
20L00`071`031`0300L700<70`0:1`@00PL00`071`081`0300L7008700<01`L01PL300P700<01`L0
0`0:1`0300L7008700<01`L04@L00`071`031`0300L700D710091`@02`L00`071`0=1`8080L001h7
00<01`L00`L00`071`0A1`0300L7008700<01`L020L00`071`031`0300L700L70`071`0400L71`<0
2@L00`071`021`0300L700X70`051`0600L71`070`061`0300L700<700<01`L04@L00`071`021`03
00L700P7100;1`<01`L00`071`0>1`0300L701l7000N1`0300L7008700<01`L04@L00`071`021`03
00L700T700<01`L00PL00`071`0;1`<00`L00`071`021`0300L700<01PL01@071`L001070`000`L0
1`021`0300L700<70`031`0300L7008700<01`L04@L00`071`021`0300L700T700@01`L70`0;1`<0
10L00`071`0>1`0300L701l7000M1`800`L00`071`0A1`0300L700<700<01`L020L00`071`021`03
00L700l70`051`0300L700<70`021`0500L71`0050L3008700<01`L01PL300@700<01`L04@L00`07
1`021`0300L700T700<01`L00PL00`071`0300/7100@1`0300L70207000O1`@04PL00`071`031`03
00L700P700<01`L00`L00`071`0@1`0300L0008000<700L020L300<700<01`L04@L010071`L300T7
00<01`000P000`L01`0A1`0300L700<700<01`L020L00`071`031`0300L700<70`0:1`@03@L00`07
1`0Q1`008@L4010700<01`L00PL00`071`091`0300L7008700<01`L04@L00`071`021`<020L00`07
1`0301@700D01`L700021`<01@L00`071`031`<04@L00`071`021`0300L700P700<01`L00`L00`07
1`071`<01`L010071`L200X700<01`L08PL0020700<01`L00PL300`70P031`0300L700T700<01`L0
0PL00`071`0A1`0300L7008700@01`L70`051`0600L71`070`0@1`0500L71`001PL3008700<01`L0
0PL010071`L300d700<01`L00PL00`071`091`0300L7008700<01`L02`L300<700<01`L00PL00`07
1`091`0300L70287000P1`0300L700D70`081`0300L700@02PL00`071`021`0300L7014700<01`L0
0`L00`071`041`<000<700L00PL00`071`031`<030L00`071`021`0300L700L70`031`0300L700D7
0`091`0300L700<700<01`L020L00`071`021`0300L700l70`051`0300L700P700<01`L08`L001l7
00<01`L02@L300D700<01`L00PL400L700<01`L00`L00`071`0A1`0300L7008700<01`L020L30087
00<01`L01PL300P700<01`L00PL00`071`081`0300L700@02PL300D700<01`L00`L00`071`081`03
00L700<700<01`L040L00`07000400X700<01`L090L001h700<01`L03@L500@700<01`L00PL300@7
00<01`L00PL00`071`0A1`0300L7008700<01`L02@L00`071`0300/70`051`0500L71`002`L00`07
1`021`@02`L3008700<01`L00PL00`071`091`0300L7008700<01`L04@L00`071`021`@01`L00`07
1`0U1`007@L00`071`0A1`@00PL00`071`051`@010L00`071`0A1`0300L7008700<01`L02@L01@07
1`L000870`0;1`<000<700L00PL00`071`091`0300L7008700<01`L00PL300/70`031`0300L700T7
00<01`L00PL00`071`0A1`0300L7008700<01`L00PL300@700<01`L09@L001d700<01`L040L00`07
1`021`<02@L4008700<01`L040L00`071`031`0300L700P700<01`L00PL00`071`031`<02`L30087
00<01`L020L00`071`031`0300L700D70`081`0300L700@02PL00`071`021`0300L7014700<01`L0
0`L00`071`051`@0:0L001`700<01`L04@L00`071`021`0300L700<01@L00`071`021`@04@L00`07
1`021`0300L700P700<01`L00PL00`071`071`<020L00`071`0300X700<01`L00PL00`071`091`<0
1@L00`071`021`@01`L00`071`031`0300L7014700<01`L00PL00`071`081`@09PL001/700<01`L0
4@L00`071`021`0300L700@70`021`0300L7008700@01`L70`0=1`0300L7008700<01`L02@L01@07
1`L000d70`041`0500L71`000PL300H700<01`L00PL00`071`0=1`D010L00`071`021`<010L00`07
1`021`0300L7014700<01`L00PL00`071`091`0400L71`8090L001X700<01`L04@L00`071`031`03
00L700L70`031`0300L700D70`091`0300L700<700<01`L020L00`071`021`0300L700h710041`03
00L700<70`021`0300L7008700<01`L04@L4008700<01`L01@L400@700<01`L04@L00`071`021`03
00L700T700<01`L00PL00`071`0S1`006PL00`071`0@1`0300L700<700<01`L020L00`071`0400X7
0`051`0300L700<700<01`L020L00`071`021`0300L701471P091`<010L00`071`0@1`0300L70087
0`091`@00PL00`071`0@1`0300L700<700<01`L020L00`071`031`0300L702<7000I1`804PL00`07
1`021`0300L700T700<01`L00PL400/70`021`0300L7008700<01`L02@L01@071`L001@700@01`L7
10081`0300L000<04`L00`071`021`0300L700<01@L00`071`021`@04@L00`071`021`0300L700P7
00<01`L00`L00`071`0T1`006`L300h700<01`L00PL00`071`091`0300L7008700<01`L00PL300/7
0`031`0300L700T700D01`L7000D1`0500L71`0010L300@700<01`L00PL4010700<01`L00PL00`07
1`041`<00PL00`071`021`0400L71`<03@L00`071`021`0300L700T700<01`L00PL00`071`0U1`00
7PL300X700<01`L00`L00`071`081`0300L700<700<01`L01@L300P700<01`L0100:1`0300L70087
00<01`L04@L00`071`021`0300L700D710041`0300L70087100;1`0300L700<700<01`L01`L300<7
00<01`L01@L300T700<01`L00`L00`071`081`0300L7008700<01`L09PL002470`071`0300L70087
0P091`0300L700<700<01`L02@L300D700<01`L00PL400L700<01`L00PL00`071`0B1`0500L71`00
2`L3008700<01`L01PL300L700<01`L00`L00`071`081`0300L700@02PL300D700<01`L00`L00`07
1`081`0300L700<700<01`L09PL002@70`031`0300L7008700<01`L00`061`0300L7008700<01`L0
3@L500@700<01`L00PL300@700D01`L7000D1`0500L71`002`L010071`L300/70`041`0300L70087
00<01`L02@L00`071`021`@02`L3008700<01`L00PL00`071`091`0300L7008700<01`L09`L002L7
0`051`0300L700<70`021`0300L7008700<01`L04@L4008700<01`L01@L400@700<01`L04@L01@07
1`L000/700<01`L00PL00`071`0300/710041`0300L700T700<01`L00PL00`071`021`<02`L300<7
00<01`L02@L00`071`021`0300L702P7000X1`0300L000@02@L300@700<01`L040L00`071`021`<0
2@L400031`07018700<01`L00PL00`071`091`0300L7008700<01`L00`L300X710021`0300L700P7
00<01`L00`L00`071`051`<020L00`071`0400X700<01`L00PL00`071`0Y1`00:0L00`071`021`@0
1`L00`071`0401<700<01`L00PL00`071`0300D700<01`L00PL4014700D01`L7000;1`0300L70087
00<01`L01`L300L700@01`L70`091`0300L700<700<01`L02@L300D700<01`L00PL400L700<01`L0
0`L00`071`0Y1`009`L00`071`021`0300L700870`041`0300L70087100@1`0300L7008700<01`L0
10L3008700<01`L00PL010071`L300d700D01`L7000;1`0300L7008700<01`L02`L300<700<01`L0
0PL00`071`0300H700<01`L00PL00`071`0=1`D010L00`071`021`<010L00`071`021`0300L702X7
000V1`0300L700<700<01`L01@L400@700<01`L00PL400/700<01`L00`L00`071`071`<00`L00`07
1`051`<02@L00`071`021`0300L700T700D01`L7000A1`<01@L00`071`031`<00PL00`071`021`03
00L7014710021`0300L700D710041`0300L702/7000V1`0300L7008700<01`L020L4008700<01`L0
1PL300L700<01`L00`L00`071`081`0300L700<02`L300D700<01`L00PL00`071`091`0300L70087
00<01`L040L00`07000400T70`041`0300L7010700<01`L00PL300T710021`0300L702/7000U1`03
00L7008700<01`L02@L010071`L300/70`041`0300L7008700<01`L02@L00`071`021`@02`L30087
00D01`L7000;1`0300L7008700<01`L04@L00`071`021`@01`L00`071`0401<700<01`L00PL00`07
1`0300D700<01`L00PL402`7000T1`0300L7008700<01`L02@L00`071`021`0300L700<02`L400@7
00<01`L02@L00`071`021`0300L700870`0;1`<00PL00`071`0:1`0500L71`004`L00`071`021`03
00L700870`041`0300L70087100@1`0300L7008700<01`L010L3008700<01`L00PL010071`L302T7
000S1`0300L700<700<01`L020L00`071`031`0300L700<70`0:1`@00PL00`071`081`0300L70087
00<01`L01PL300P700<01`L00`0;1`0500L71`004`L00`071`031`0300L700D710041`0300L70087
100;1`0300L700<700<01`L01`L300<700<01`L01@L302H7000S1`0300L7008700<01`L020L00`07
1`031`0300L700L70`071`0400L71`<02@L00`071`031`0300L700T70`051`0600L71`070`071`03
00L7008700<01`L04@L00`071`021`0300L700P710021`0300L700H70`071`0300L700<700<01`L0
20L00`071`0400X70`0S1`008PL00`071`021`0300L700T700<01`L00PL00`071`0;1`<00`L00`07
1`021`0300L700<01PL00`071`021`0300L700d71@031`0300L700<70`031`0300L7008700<01`L0
4@L00`071`021`0300L700T700@01`L70`0;1`<010L00`071`021`0300L700T700<01`L00PL400/7
0`0P1`008@L00`071`031`0300L700P700<01`L00PL00`071`0?1`<01@L00`071`031`<00PL00`07
1`021`0300L7014710000`L01`071`@00`L00`071`0A1`0300L7008700<01`L02@L00`071`021`03
00L700<02`L400@700<01`L02@L00`071`021`0300L700870`0;1`807PL0020700<01`L00`L00`07
1`081`0300L700<700<01`L040L00`07000400T70`031`0300L7014700<01`L00PL300T710000`L0
1`0A1`0300L700<700<01`L020L00`071`031`0300L700<70`0:1`@00PL00`071`081`0300L700<7
00<01`L01@L300P700<01`L07@L0020700<01`L00PL00`071`091`0300L7008700<01`L04@L00`07
1`021`@01`L00`071`0401<700D01`L700031`<01@L00`071`021`<04@L00`071`021`0300L700P7
00<01`L00`L00`071`071`<01`L010071`L300T700<01`L00`L00`071`091`<01@L00`071`0M1`00
7`L200<700<01`L02@L00`071`021`0300L7014700<01`L00PL00`071`021`<010L00`071`021`@0
40L01@071`L000L70`021`0500L71`000`L300d700<01`L00PL00`071`091`0300L7008700<01`L0
2`L300<700<01`L00PL00`071`0300H700<01`L00PL00`071`0=1`D080L001h700<01`L0100:1`03
00L7008700<01`L04@L00`071`031`0300L700D710041`0300L700870`0<1`0300L7008700<01`L0
20L3008700<01`L01@L300T700<01`L00`L00`071`081`0300L7008700<01`L03`L300D700<01`L0
0`L3008700<01`L00PL00`071`0A1`@07PL001h700<01`L00PL400L700<01`L00`L00`071`0A1`03
00L7008700<01`L020L4008700<01`L01@L300P700<01`L00PL00`071`091`0300L700<02PL300D7
00<01`L00`L00`071`081`0300L700<700<01`L040L00`07000400T70`041`0300L7010700<01`L0
0PL301/7000M1`0300L7008700<01`L00PL300@700<01`L00PL00`071`0A1`0300L7008700<01`L0
2@L010071`L300X70`051`0500L71`0030L01P071`L01`<02PL3008700<01`L00PL00`071`091`03
00L7008700<01`L04@L00`071`021`@01`L00`071`0401<700<01`L01@L301P7000L1`0300L700<7
00<01`L01@L400@700<01`L04@L00`071`021`0300L700T700<01`L00PL00`071`0300X70`000`L0
1`021`0300L700X700D01`L700051`<02PL300<700<01`L02@L00`071`021`0300L7014700<01`L0
0PL00`071`021`<010L00`071`021`@040L00`071`091`<05@L001/700<01`L00`L00`071`081`@0
0PL00`071`0@1`0300L700<700<01`L020L00`071`031`0300L700<70`0:1`<00PL00`071`091`03
00L7008700<01`L01PL300L700<01`L0100:1`0300L7008700<01`L04@L00`071`031`0300L700D7
10041`0300L70087100;1`0300L700d70P0C1`006`L00`071`021`0300L700P700<01`L00PL40147
00<01`L00PL00`071`081`0300L700<700<01`L01`L300L700<01`L00`0:1`0300L7008700<01`L0
2PL300@700<01`L00PL400L700<01`L00`L00`071`0A1`0300L7008700<01`L020L4008700<01`L0
1PL300L700<01`L03PL00`071`0B1`006PL00`071`021`0300L700T700<01`L00PL010071`L300d7
00<01`L00PL00`071`091`0300L7008700<01`L02`L300<700D01`L700021`<01`L01@071`L00107
10041`0300L700870`041`0300L7008700<01`L04@L00`071`021`0300L700T700@01`L70`0;1`<0
10L00`071`0>1`0300L70187000I1`0300L700<700<01`L020L200<700<01`L01@L300T700<01`L0
0`L00`071`081`0300L7008700<01`L03`L300@700<01`L00`L300<700D01`L7000C1`@00PL00`07
1`051`@010L00`071`0A1`0300L7008700<01`L02@L00`071`021`0300L700<02`L4010700<01`L0
4`L001P700<01`L00`L00`071`081`0300L700@02PL300D700<01`L00`L00`071`081`0300L700<7
00<01`L040L00`07000300T70`041`0300L7014700@01`L70`091`@00PL00`071`0@1`0300L700<7
00<01`L020L00`071`031`0300L700<70`0:1`@03@L00`071`0D1`0060L00`071`021`0300L700T7
00<01`L00PL400/70`021`0300L7008700<01`L02@L00`071`021`0300L7014700@01`L710081`03
00L000<04`L00`071`021`0300L700<01@L00`071`021`@04@L00`071`021`0300L700P700<01`L0
0`L00`071`071`<01`L010071`L200X700<01`L05@L001L700<01`L00PL00`071`091`0300L70087
00<01`L00PL300/70`031`0300L700T700<01`L00PL00`071`0A1`0300L7008700@01`L70`051`04
00L71`@040L00`071`021`0300L700@70`021`0300L7008700@01`L70`0=1`0300L7008700<01`L0
2@L00`071`021`0300L700/70`031`0300L7008700<01`L02@L00`071`0E1`005PL00`071`031`03
00L700P700<01`L00`L00`071`051`<020L00`071`0400X700<01`L00PL00`071`0A1`0300L70087
00<01`L01@L300031`07008700<01`L00PL400/700<01`L00`L00`071`071`<00`L00`071`051`<0
2@L00`071`031`0300L700P700<01`L00PL00`071`0?1`<01@L00`071`081`0300L701H7000F1`03
00L700870P091`0300L700<700<01`L02@L300D700<01`L00PL400L700<01`L00`L00`071`0A1`05
00L71`002`L3008700<01`L01PL300P700<01`L00PL00`071`081`0300L700@02PL300D700<01`L0
0`L00`071`081`0300L700<700<01`L040L00`07000400X700<01`L05`L001D700<01`L00PL00`07
1`0300H700<01`L00PL00`071`0=1`D010L00`071`021`<010L00`071`021`0300L7014700D01`L7
000<1`0300L700<02`L300@700<01`L00PL00`071`091`0300L70087100;1`<00PL00`071`021`03
00L700T700<01`L00PL00`071`0A1`0300L7008710071`0300L701P7000D1`0300L700<700<01`L0
0`L3008700<01`L00PL00`071`0A1`@00PL00`071`051`@010L00`071`0A1`0300L7008700<01`L0
2@L01@071`L000870`0;1`@010L00`071`091`0300L7008700<01`L00PL300/70`031`0300L700T7
00<01`L00PL00`071`0A1`0300L7008700<01`L00PL300@700<01`L060L001<700<01`L00`L00`07
1`071`<010L00`071`0@1`0300L700870`091`@00PL00`071`0@1`0300L7008700<01`L02@L00`07
1`021`0300L700<70`0;1`<00PL00`071`081`0300L700<700<01`L01@L300P700<01`L0100:1`03
00L7008700<01`L04@L00`071`031`0300L700D7100K1`004`L00`071`021`0300L700P700<01`L0
100C1`0300L7008700<01`L00`051`0300L70087100A1`0500L71`002`L00`071`021`0300L700L7
0`071`0400L71`<02@L00`071`031`0300L700T70`051`0300L7008710071`0300L700<700<01`L0
4@L00`071`021`0300L700P7100I1`004PL00`071`021`0300L700T700<01`L00PL4010700<01`L0
0PL00`071`041`<00PL00`071`021`0400L71`<03@L00`071`021`0300L700T700D01`L7000=1`<0
0`L00`071`021`0300L700<01PL00`071`021`0300L700d71@041`0300L700870`041`0300L70087
00<01`L04@L00`071`021`0300L700T700@01`L70P0G1`004@L00`071`031`0300L700P700<01`L0
0PL00`071`021`@02`L00`071`031`0300L700L70`031`0300L700D70`091`0300L7008700<01`L0
2@L01@071`L0014710041`0300L700<70`021`0300L7008700<01`L04@L4008700<01`L01@L400@7
00<01`L04@L00`071`021`0300L700T700<01`L00PL00`071`0F1`004@L00`071`021`0300L700P7
00<01`L00`L00`071`061`<01`L00`071`031`0300L700P700<01`L0100:1`<01@L00`071`021`03
00L700T700<01`L00PL00`071`0A1`H02@L300@700<01`L040L00`071`021`<02@L4008700<01`L0
40L00`071`031`0300L700P700<01`L00`L00`071`0F1`0040L00`071`021`0300L700T700<01`L0
0PL200/70`041`0300L7008700<01`L02@L00`071`021`@02`L3008700<01`L00PL00`071`091`05
00L71`004`L00`071`021`@01`L00`071`0401<700<01`L00PL00`071`0300D700<01`L00PL40147
00<01`L00PL00`071`081`0300L700<700<01`L05`L000l700<01`L00PL00`071`091`0300L70087
00<01`L00`0;1`@010L00`071`091`0300L7008700<01`L00PL300/70`031`0300L700T700D01`L7
000D1`0500L71`0010L300@700<01`L00PL4010700<01`L00PL00`071`041`<00PL00`071`021`04
00L71`<03@L00`071`021`0300L700T700<01`L00PL00`071`0H1`003PL00`071`031`0300L700P7
00<01`L00`L00`071`031`<02PL4008700<01`L020L00`071`031`0300L700D70`081`0300L700<0
2`L01@071`L001@700<01`L00PL00`071`051`@010L00`071`021`@02`L00`071`031`0300L700L7
0`031`0300L700D70`091`0300L700<700<01`L020L00`071`021`0300L701T7000>1`0300L70087
00<01`L020L00`071`031`0300L700L70`071`0400L71`<02@L00`071`031`0300L700T70`051`03
00L7008710071`0300L7008700<01`L04@L00`071`021`0300L700P710021`0300L700H70`071`03
00L700<700<01`L020L00`071`0400X70`051`0300L700<700<01`L020L00`071`031`0300L701T7
000=1`0300L7008700<01`L02@L00`071`021`0300L700/70`031`0300L7008700<01`L00`061`03
00L7008700<01`L03@L500@700<01`L00PL300@700D01`L7000D1`0500L71`002`L010071`L300/7
0`041`0300L7008700<01`L02@L00`071`021`@02`L3008700<01`L00PL00`071`091`0300L70087
00<01`L06PL000`700<01`L00PL00`071`091`0300L7008700<01`L03`L300D700<01`L00`L30087
00<01`L00PL00`071`0A1`@000<700L01`L400<700<01`L04PL01@071`L000/700<01`L00PL00`07
1`0300/710041`0300L700T700<01`L00PL00`071`021`<02`L300<700<01`L02@L00`071`021`03
00L701/7000;1`0300L700<700<01`L020L00`071`031`0300L7010700<01`0010091`<010L00`07
1`0@1`0300L700870`091`@000<700L04PL00`071`021`0300L700P700<01`L00`L00`071`031`<0
2PL4008700<01`L020L00`071`031`0300L700D70`081`0300L700@02PL00`071`021`0300L701`7
000;1`0300L7008700<01`L02@L00`071`021`0300L7014700<01`L00PL400L700<01`L0100C1`03
00L7008700<01`L00`051`0300L70087100@1`0300L7008700<01`L020L00`071`031`0300L700L7
0`071`0400L71`<02@L00`071`031`0300L700T70`051`0300L7008710071`0300L700<700<01`L0
70L000X70P031`0300L700T700<01`L00PL00`071`0A1`0300L7008700<01`L00PL300@700<01`L0
0PL4010700<01`L00PL00`071`041`<00PL01@071`L000@70`0=1`0500L71`002`L00`071`021`03
00L700/70`031`0300L7008700<01`L00`061`0300L7008700<01`L03@L500@700<01`L00PL300@7
00<01`L00PL00`071`0M1`0030L300/700<01`L00PL00`071`0A1`0300L700<700<01`L01@L400@7
00<01`L00PL400/700<01`L00PL00`071`081`<00PL00`071`061`<02@L00`071`021`0300L700P7
00<01`L00PL00`071`0?1`<01@L00`071`031`<00PL00`071`021`0300L7014710021`0300L700D7
10041`0300L701h7000>1`@01`L00`071`031`0300L7014700<01`L00PL00`071`081`@00PL00`07
1`061`<01`L00`071`031`0300L700P700<01`L00`0;1`<01@L00`071`021`0300L700P700<01`L0
0`L00`071`0@1`0300L000@02@L300@700<01`L040L00`071`021`<02@L4008700<01`L07PL000d7
00<01`L00PL300@700<01`L00PL00`071`0A1`0300L7008700<01`L02@L010071`L300/70`041`03
00L7008700<01`L02@L01P071`L01`<02`L3008700D01`L7000;1`0300L7008700<01`L04@L00`07
1`021`@01`L00`071`0401<700<01`L00PL00`071`0300D700<01`L00PL401l7000<1`0300L700H7
10041`0300L7014700<01`L00PL00`071`091`0300L7008700<01`L00`0;1`@010L00`071`091`05
00L71`001@L300/70`021`0300L700T700<01`L00PL00`071`0A1`0300L7008700<01`L00PL300@7
00<01`L00PL4010700<01`L00PL00`071`041`<00PL00`071`021`0400L71`<070L000/700<01`L0
2@L400031`07018700<01`L00`L00`071`081`0300L700<700<01`L00`L300X710021`0300L700P7
00<01`L00PL00`071`061`<020L00`071`0300X700<01`L00PL00`071`0A1`0300L700<700<01`L0
1@L400@700<01`L00PL400/700<01`L00`L00`071`071`<00`L00`071`051`<06@L000/700<01`L0
20L00`071`021`@04@L00`071`021`0300L700P700<01`L00`L00`071`071`<01`L010071`L300T7
00<01`L00PL00`071`0:1`<01@L01P071`L01`<01PL00`071`031`0300L7014700<01`L00PL00`07
1`081`@00PL00`071`061`<01`L00`071`031`0300L700P700<01`L0100:1`<05PL000X700<01`L0
2@L00`071`021`0400L71`<03@L00`071`021`0300L700T700<01`L00PL00`071`0;1`<00`L00`07
1`021`0300L700<01PL01@071`L001070`000`L01`021`0300L700<70`031`0300L7008700<01`L0
4@L00`071`021`0300L700T700@01`L70`0;1`<010L00`071`021`0300L700T700<01`L00PL400/7
0`0C1`002@L00`071`091`800`L00`071`051`<02@L00`071`021`0300L700T700<01`L00PL00`07
1`0?1`<01@L00`071`031`<00PL01@071`L001@70`021`0300L700H70`041`0300L7014700<01`L0
0PL00`071`091`0300L7008700<01`L00`0;1`@010L00`071`091`0300L7008700<01`L00PL300/7
0P0A1`0020L00`071`0<1`<02`L300D700<01`L00`L00`071`081`0300L700<700<01`L040L00`07
000200031`0700P70`031`0300L7014700@01`L70`091`0300L0008000<700L04@L00`071`031`03
00L700P700<01`L00`L00`071`031`<02PL4008700<01`L020L00`071`031`0300L700D70`081`03
00L7010700081`0300L700h7100;1`<00PL00`071`021`0300L700T700<01`L00PL00`071`0A1`03
00L700870`081`0300L700<050L01@071`L000870`051`0300L700<70`0A1`0300L7008700<01`L0
20L00`071`031`0300L700L70`071`0400L71`<02@L00`071`031`0300L700T70`051`0300L70107
00071`0300L700h700<01`L00PL300/70`031`0300L700T700<01`L00PL00`071`0A1`0300L70087
00@01`L70`051`0600L71`070`0@1`0500L71`001PL3008700<01`L00PL010071`L300d700<01`L0
0PL00`071`091`0300L7008700<01`L02`L300<700<01`L00PL00`071`0300H700<01`L00PL00`07
1`0=1`D04`L000H70P0?1`0300L700H70`081`0300L700<02`L00`071`021`0300L7014700<01`L0
0`L00`071`041`<000<700L00PL00`071`031`<030L00`071`021`0300L700L70`031`0300L700D7
0`091`0300L700<700<01`L020L00`071`021`0300L700l70`051`0300L700<70`021`0300L70087
00<01`L04@L4014700081`<02`L00`071`0:1`<01@L00`071`021`@01`L00`071`031`0300L70147
00<01`L00PL00`071`081`<00PL00`071`061`<020L00`071`021`0300L700P700<01`L0100:1`<0
1@L00`071`031`0300L700P700<01`L00`L00`071`0@1`0300L000@02@L300@700<01`L040L00`07
1`021`<03PL000/70`081`0300L700d71@041`0300L700870`041`0300L7008700<01`L04@L00`07
1`021`0300L700T700<01`L00`0;1`<01@L01@071`L000/700<01`L00PL400/70`021`0300L70087
00<01`L02@L00`071`021`0300L7014700<01`L00PL400L700<01`L0100C1`0300L700D70`0;1`00
3PL300@700<01`L04@L400031`0700L710041`0300L7014700<01`L00PL00`071`091`0500L71`00
0PL300/70`000`L01`021`0300L700T700<01`L00PL00`071`021`<02`L300<700<01`L02@L00`07
1`021`0300L7014700<01`L00PL00`071`021`<010L00`071`021`@040L00`071`091`<020L00147
100C1`0300L700870`091`@000<700L04PL00`071`031`0300L700P700<01`L00PL00`071`031`<0
2`L3008700<01`L020L00`071`031`0300L700D70`081`0300L700@02PL00`071`021`0300L70147
00<01`L00`L00`071`051`@010L00`071`021`@02`L00`071`0=1`801PL001<7100A1`0300L70087
00<01`L00`051`0300L70087100A1`0300L7008700<01`L020L00`071`021`0300L700L70`081`03
00L700<02@L00`071`031`0300L700T70`051`0300L7008710071`0300L700<700<01`L04@L00`07
1`021`0300L700P710021`0300L700H70`071`0300L700h700<01`L01@L001<700@01`L7100<1`03
00L7008700<01`L010L3008700<01`L00PL010071`L300d700<01`L00PL00`071`091`0500L71`00
3@L300@700D01`L700021`<01PL00`071`021`0300L700d71@041`0300L700870`041`0300L70087
00<01`L04@L00`071`021`0300L700T700@01`L70`0;1`<010L00`071`0>1`0300L700D7000B1`03
00L700H70`081`0300L7008700<01`L020L300<700<01`L01@L300T700<01`L00PL00`071`091`05
00L71`004@L400@700<01`L00`L3008700<01`L00PL00`071`0A1`@00PL00`071`051`@010L00`07
1`0A1`0300L7008700<01`L02@L00`071`021`0300L700<02`L4010700<01`L01PL001470P0;1`<0
10L00`071`021`0300L700T700<01`L00`0;1`<01@L00`071`031`0300L700P700<01`L00PL00`07
1`0A1`H02@L300@700<01`L040L00`071`021`<02@L4008700<01`L040L00`071`031`0300L700P7
00<01`L00`L00`071`031`<02PL400d700<01`L01`L001<70`0;1`<000<700L00`L00`071`091`03
00L70087100;1`<00PL00`071`021`0300L700T700D01`L7000D1`0400L71`@020L00`07000301<7
00<01`L00PL00`071`0300D700<01`L00PL4014700<01`L00PL00`071`081`0300L700<700<01`L0
1`L300L700@01`L70P0:1`0300L700P7000F1`<02`L3008700<01`L02@L00`071`021`0300L70087
0`0;1`<00`L00`071`091`0500L71`0050L01@071`L000@70`041`0300L70087100@1`0300L70087
00<01`L010L3008700<01`L00PL010071`L300d700<01`L00PL00`071`091`0300L7008700<01`L0
2`L300<700<01`L00PL00`071`091`0300L700P7000I1`<01`L010071`L300X700<01`L00PL00`07
1`061`<020L00`071`0300/700<01`L00PL00`071`0A1`0300L7008700<01`L01@L400@700<01`L0
0PL400/700<01`L00`L00`071`071`<00`L00`071`051`<02@L00`071`031`0300L700P700<01`L0
0PL00`071`0?1`<01@L00`071`081`0300L700T7000L1`<00`L00`071`021`0300L700<01PL00`07
1`021`0300L700X70`051`0300L7008710071`0300L7008700<01`L04PL01@071`L000X710021`03
00L700H70`071`0300L700<700<01`L020L00`071`0400X70`051`0300L700<700<01`L020L00`07
1`031`0300L7010700<01`00100:1`0300L700X7000O1`@010L00`071`031`<00`L00`071`021`03
00L700d71@041`0300L700870`041`0500L71`0050L01@071`L000/700@01`L70`0;1`<010L00`07
1`021`0300L700T700<01`L00PL400/70`021`0300L7008700<01`L02@L00`071`021`0300L70147
00<01`L00PL400L700<01`L02`L002471P091`<010L00`071`0A1`@000<700L01`L400<700<01`L0
4PL01@071`L000/700<01`L00PL00`071`0300/710041`0300L700T700<01`L00PL00`071`021`<0
2`L300<700<01`L02@L00`071`021`0300L7014700<01`L00PL00`071`021`<010L00`071`0;1`00
80L00`071`021`@020L00`07000301<700<01`L00PL300T710000`L01`0B1`0300L7008700<01`L0
20L00`071`031`0300L700<70`0:1`@00PL00`071`081`0300L700<700<01`L01@L300P700<01`L0
100:1`0300L7008700<01`L04@L00`071`031`0300L700D7100>1`007`L00`071`021`0300L70087
0`041`0300L70087100A1`0300L7008700<01`L00`051`0300L70087100A1`0500L71`002`L00`07
1`021`0300L700L70`071`0400L71`<02@L00`071`031`0300L700T70`051`0300L7008710071`03
00L700<700<01`L04@L00`071`021`0300L700P7100<1`007`L00`071`021`0300L700D70`000`L0
1`031`0400L71`@030L00`071`021`0300L700@70`021`0500L71`0010L300d700D01`L7000;1`03
00L7008700<01`L02`L300<700<01`L00PL00`071`0300H700<01`L00PL00`071`0=1`D010L00`07
1`021`<010L00`071`021`0300L7014700<01`L00PL00`071`091`0400L71`802PL001h700<01`L0
0PL00`071`091`<00PL00`071`061`<020L00`071`021`0300L700P70`031`0300L700D70`091`05
00L71`002`L00`071`021`0300L700l70`051`0300L700<70`021`0300L7008700<01`L04@L40087
00<01`L01@L400@700<01`L04@L00`071`021`0300L700T700<01`L00PL00`071`091`007@L00`07
1`021`0300L700T700@01`L70`0;1`<010L00`071`021`0300L700T700<01`L0100:1`<01@L00`07
1`021`0300L700P700<01`L00`L00`071`0@1`0300L000@02@L300@700<01`L040L00`071`021`<0
2@L4008700<01`L040L00`071`031`0300L700P700<01`L00`L00`071`091`0070L00`071`021`03
00L700T700<01`L00PL00`071`0300/70`000`L01`031`0300L700T700D01`L700021`<02PL30087
00D01`L7000;1`0300L7008700<01`L04@L00`071`021`@01`L00`071`0401<700<01`L00PL00`07
1`0300D700<01`L00PL4014700<01`L00PL00`071`081`0300L700<700<01`L02PL001`700<01`L0
0PL00`071`091`0300L7008700<01`L00`L300/70`021`0300L700T700D01`L700061`<02PL30087
00<01`L02@L00`071`021`0300L7014700<01`L00PL00`071`021`<010L00`071`021`@040L00`07
1`021`0300L700@70`021`0300L7008700@01`L70`0=1`0300L7008700<01`L02@L00`071`021`03
00L700/7000K1`0300L7008700<01`L02@L00`071`021`0300L700L70`071`0400L71`<02PL00`07
1`021`0300L700L710061`0300L700<02PL00`071`021`0300L7014700<01`L00`L00`071`051`@0
10L00`071`021`@02`L00`071`031`0300L700L70`031`0300L700D70`091`0300L700<700<01`L0
20L00`071`021`0300L700`7000J1`0300L7008700<01`L02@L00`071`021`0300L700/70`031`03
00L7008700<01`L00`061`0300L7008700<01`L030L300<700H01`L700L300L700<01`L00PL00`07
1`0A1`0300L7008700<01`L020L4008700<01`L01PL300L700<01`L00`L00`071`081`0300L700@0
2PL300D700<01`L00`L00`071`081`0300L700<700<01`L030L001T700<01`L00`L00`071`081`03
00L7008700<01`L03`L400@700<01`L00`L300<700D01`L7000B1`@00PL00`071`031`<00`L00`07
1`021`0300L7014700<01`L00PL00`071`081`0300L700870`0;1`<010L00`071`021`0300L700T7
00<01`L00PL400/70`021`0300L7008700<01`L02@L00`071`021`0300L700d7000I1`0300L70087
00<01`L02@L00`071`021`0300L701471P091`<010L00`071`0A1`0300L700<020L300@700<01`L0
4@L00`071`021`0300L700T700<01`L00PL00`071`0300/710041`0300L700T700<01`L00PL00`07
1`021`<02`L200@700<01`L02@L00`071`021`0300L700h7000H1`0300L7008700<01`L02@L00`07
1`021`0300L7014700<01`L00PL400P700<01`000`0C1`0500L71`000PL300H700<01`000`0C1`03
00L700<700<01`L020L00`071`031`0300L700<70`0:1`@00PL00`071`081`0300L700<700<01`L0
1@L300P700<01`L00`L00`071`081`0300L7008700<01`L03`L001L70P031`0300L700T700<01`L0
0PL00`071`0A1`0300L7008700<01`L00PL300@700<01`L00PL4014700D01`L700051`@00PL00`07
1`021`<04@L00`071`021`0300L700P700<01`L00`L00`071`071`<01`L010071`L300T700<01`L0
0`L00`071`091`<01@L00`071`021`0300L700P700<01`L00`L00`071`0?1`006@L400X700<01`L0
0PL00`071`0B1`0300L7008700<01`L01@L300031`07008700<01`L00PL300d700D01`L7000:1`<0
0`L010071`L300d700<01`L00PL00`071`081`0300L700<700<01`L02`L300<700<01`L00PL00`07
1`0300H700<01`L00PL00`071`0=1`D010L00`071`091`0300L7008700<01`L040L001/710081`03
00L7008700<01`L04@L00`071`021`0300L700T70`021`0300L700D70`091`0500L71`002`L00`07
1`0300L70`091`0300L7008700<01`L02@L00`071`021`0300L700l70`051`0300L700<70`021`03
00L7008700<01`L04@L4008700<01`L020L00`071`021`0300L70147000J1`0300L700870`041`03
00L7008700<01`L04@L00`071`021`0300L700T700@01`L70`0:1`<01@L01@071`L000`700H01`L7
00L300L70`051`0300L700<700<01`L020L00`071`031`0300L7010700<01`0010091`<010L00`07
1`0@1`0300L700870`091`0300L700<700<01`L04@L001X700<01`L01@L400@700<01`L04@L00`07
1`021`0300L700T700<01`L00PL00`071`0300X70`021`0500L71`002`L00`071`021`0300L70087
0`071`<00PL00`071`021`0300L700P700<01`L00`L00`071`0A1`0300L7008710071`0300L700@0
4`L00`071`021`0300L700<01@L00`071`031`0300L70187000I1`0300L700P710021`0300L70147
00<01`L00PL00`071`091`0300L7008700<01`L00`L300X70`021`0300L700T700<01`L00PL00`07
1`061`<01`L300<700<01`L020L00`071`031`0300L7014700<01`L00PL00`071`021`<010L00`07
1`021`@040L00`071`021`0300L700@70`021`0300L7008700<01`L04`L001P700<01`L02@L01007
1`L4014700<01`L00PL00`071`091`0300L7008700<01`L01`L300L700<01`L00`0:1`0300L70087
00<01`L02PL300@700<01`L00`0;1`0300L7008700<01`L04@L00`071`031`0300L700D710041`03
00L70087100;1`0300L700<700<01`L01`L200@700<01`L050L001L700<01`L02@L00`071`021`04
00L71`<03@L00`071`021`0300L700T700<01`L00PL00`071`0;1`<00`L01@071`L000870`071`05
00L71`0040L300031`0700<710071`0300L700<700<01`L04@L00`071`021`0300L700P710021`03
00L700H70`071`0300L700<700<01`L020L00`071`031`0300L701@7000G1`0300L700P70P031`03
00L700D70`091`0300L700<700<01`L020L00`071`021`0300L700l710031`0300L700<70`031`03
00L7008700<01`L04@L3008700<01`L00PL300<700<01`L00`L00`071`0A1`0300L7008700<01`L0
20L00`071`021`<02`L300@700<01`L00PL00`071`091`0300L7008700<01`L05@L001H700<01`L0
2`L400X70`061`0300L7008700<01`L02@L00`071`021`0300L701471@091`<010L00`071`0A1`04
00L71`<01`L300D700<01`L04@L00`071`021`0300L700T700<01`L00PL00`071`0300/710041`03
00L700T700<01`L00PL00`071`0F1`005@L00`071`0>1`@02`L3008700<01`L00PL00`071`091`03
00L7008700<01`L04@L010071`L400P700<01`000`0C1`0300L7008700<01`L00`061`@000<700L0
4PL00`071`031`0300L700P700<01`L00`L00`071`031`<02PL4008700<01`L020L00`071`031`03
00L701H7000D1`0300L700h700<01`L00PL300/70`031`0300L700T700<01`L00PL00`071`0A1`03
00L7008700@01`L70`051`0400L71`@04@L00`071`021`0300L700<70`021`0300L70087100A1`03
00L7008700<01`L020L00`071`031`0300L700L70`071`0400L71`802PL00`071`031`0300L701L7
000D1`0300L700h700<01`L01@L300P700<01`L0100:1`0300L7008700<01`L04PL01@071`L000L7
0`000`L01`031`0400L71`@030L00`071`021`0300L700L70`041`0400L71`<03@L00`071`021`03
00L700P700<01`L00`L00`071`0;1`<00`L00`071`021`0300L700T700<01`L00PL00`071`0H1`00
4`L200l700<01`L02@L300D700<01`L00PL400P700<01`L00PL00`071`0A1`0500L71`002`L30087
00<01`L01PL300P700<01`L00PL00`071`081`0300L700@01`L300T700<01`L00PL00`071`091`03
00L7008700<01`L03`L300D700<01`L020L00`071`021`0300L701T7000E1`<02`L00`071`0=1`D0
10L00`071`021`<010L00`071`021`0300L7014700D01`L7000<1`0300L700<02`L300D700D01`L7
000;1`0300L7008710081`<01@L00`071`031`0300L700P700<01`L00`L00`071`0@1`0300L000@0
2PL00`071`031`0300L701T7000H1`<01`L00`071`0A1`@00PL00`071`051`@010L00`071`0A1`03
00L7008700<01`L02@L01@071`L000870`0;1`<000<700L00`L00`071`081`0300L700<700@01`L7
0`081`<00PL00`071`021`0300L700P700<01`L00`L00`071`0A1`0300L7008710071`0300L700<7
00<01`L06PL001/70`041`0300L7010700<01`L00PL300T710021`0300L7014700D01`L7000;1`03
00L7008700<01`L00`L300/70`021`0300L700P700<01`L00`L00`071`051`<020L300<700<01`L0
20L00`071`031`0300L7014700<01`L00PL00`071`021`<010L00`071`021`0300L701/7000N1`@0
4`L00`071`021`0300L700<01PL010071`L4014700D01`L7000;1`0300L7008700<01`L01`L300L7
00@01`L70`091`0300L700<700<01`L02@L300D700<01`L00`0;1`0300L7008700<01`L04@L00`07
1`031`0300L700D710041`0300L701`7000P1`@040L00`071`021`0300L700@70`021`0300L70087
00@01`L70`0=1`0300L7008700<01`L02@L01@071`L000d70`041`0500L71`000PL300H700<01`L0
0PL00`071`0=1`@000<700L00`L400L700<01`L00`L00`071`0A1`0300L7008700<01`L020L40087
00<01`L070L001l700<01`L00PL400/700<01`L00`L00`071`071`<00`L00`071`051`<02@L00`07
1`021`0300L700T700D01`L7000A1`@010L00`071`031`<00PL00`071`031`0300L701470`021`03
00L700870`031`0300L700<700<01`L04@L00`071`021`0300L700P700<01`L00PL201l7000O1`03
00L700H70`071`0300L700<700<01`L020L00`071`0400X70`061`0500L71`002`L00`071`021`03
00L701471P091`<010L00`071`0A1`0400L71`<01`L300D700<01`L04@L00`071`021`0300L700T7
00<01`L00PL00`071`0N1`007PL200/70`041`0300L7008700<01`L02@L00`071`021`@02`L30087
00<01`L00PL00`071`091`0500L71`0050L010071`L400L700<01`L0100C1`0300L7008700<01`L0
0`061`@000<700L04PL00`071`031`0300L700P700<01`L00`L00`071`0N1`0080L300/710041`03
00L700T700<01`L00PL00`071`021`<02`L300<700<01`L02@L01@071`L001@700D01`L700041`<0
10L00`071`021`@04@L00`071`021`0300L700<70`021`0300L70087100A1`0300L7008700<01`L0
20L00`071`031`0300L701l7000S1`<02PL4008700<01`L020L00`071`031`0300L700D70`081`03
00L700<02`L01@071`L001@700<01`L00PL00`071`051`@01@L010071`L400`700<01`L00PL00`07
1`071`<010L010071`L300d700<01`L00PL00`071`081`0300L700<700<01`L080L002H70`071`04
00L71`<02@L00`071`031`0300L700T70`051`0300L7008710071`0300L7008700<01`L04@L00`07
1`021`0300L700P710021`0300L700H70`081`0300L7008700<01`L020L00`071`0400L70`091`03
00L7008700<01`L02@L00`071`021`0300L70247000Y1`<00`L00`071`021`0300L700<01PL00`07
1`021`0300L700d71@041`0300L700870`041`0500L71`0050L01@071`L000/700@01`L70`0;1`<0
10L00`071`021`0300L700T700<01`L00PL400P70`051`0300L700<700<01`L020L00`071`031`03
00L70247000/1`<01@L00`071`031`<00PL00`071`021`0300L7014710000`L01`071`@00`L00`07
1`0B1`0500L71`002`L00`071`021`0300L700<02`L300031`0700<700<01`L020L00`071`031`04
00L71`<020L3008700<01`L00PL00`071`081`0300L700<700<01`L08PL002d700<01`0010091`<0
10L00`071`0@1`0300L700870`091`@000<700L04PL00`071`021`0300L700P700<01`L00`L00`07
1`031`<02`L3008700<01`L020L00`071`031`0300L700D70`081`<00`L00`071`081`0300L700<7
00<01`L08`L002d700<01`L00PL400L700<01`L0100C1`0300L7008700<01`L00`051`0300L70087
100A1`0500L71`002PL00`071`031`0300L700L70`071`0400L71`<02@L00`071`031`0300L700T7
0`051`0300L700@02PL00`071`021`0300L702@7000/1`0300L7008700<01`L00PL300@700<01`L0
0PL4010700<01`L00PL00`071`041`<00PL01@071`L000@70`0=1`0500L71`002`L00`071`021`03
00L700/70`031`0300L7008700<01`L00`061`0300L7008700<01`L03@L400031`0700<700<01`00
0P061`0300L700<700<01`L090L002/700<01`L00`L00`071`051`@010L00`071`021`@02`L00`07
1`021`0300L700P70`021`0300L700H70`091`0300L7008700<01`L020L00`071`021`0300L700l7
10041`0300L700<70`021`0300L700<700<01`L04@L3008700<01`L00`L3008700<01`L00`L00`07
1`0U1`00:`L00`071`021`0300L700P710021`0300L700H70`071`0300L700<700<01`L020L00`07
1`0300/70`051`0300L7008700<01`L020L00`071`031`0300L701471P091`<010L00`071`0A1`04
00L71`<020L400<700<01`L09PL002X700<01`L00PL00`071`091`0400L71`<02`L300@700<01`L0
0PL00`071`091`0600L71`070`0;1`<00PL01@071`L000/700<01`L00PL00`071`0A1`0300L70087
10071`0300L700@04`L00`071`021`0300L700<01PL00`071`0302T7000Y1`0300L7008700<01`L0
2@L00`071`021`0300L700<02`L400@700<01`L02@L01@071`L000D70`0;1`<00PL00`071`091`03
00L7008700<01`L04@L00`071`021`0300L700870`041`0300L70087100A1`0300L7008700<01`L0
0`L3008700<01`L00`L502D7000X1`0300L700<700<01`L020L00`071`031`0300L700<70`0:1`@0
0PL00`071`081`0300L7008700<01`L01PL300P700<01`L00`0:1`0300L7008700<01`L04PL00`07
1`021`0300L700D710051`0400L71`@030L00`071`021`0300L700L70P051`0300L700<70`0R1`00
:0L00`071`021`0300L700P700<01`L00`L00`071`071`<01`L010071`L300T700<01`L00PL00`07
1`0:1`<01@L01P071`L01`<01PL00`071`031`0300L7014700<01`L00PL00`071`081`@00PL00`07
1`061`<020L00`071`021`0300L700P700<01`L00`L00`071`071`<07`L002L700<01`L00PL00`07
1`091`0300L7008700<01`L02`L300<700<01`L00PL00`071`0300H700D01`L7000@1`<000<700L0
0PL00`071`031`<00`L00`071`021`0300L7014700<01`L00PL00`071`091`0400L71`<02`L300@7
00<01`L00PL00`071`091`0300L7008700<01`L02`L401/7000V1`0300L700<700<01`L020L00`07
1`021`0300L700l70`051`0300L700<70`021`0500L71`0050L3008700<01`L01PL300@700<01`L0
4@L00`071`021`0300L700T700<01`L00PL00`071`0300/70`000`L01`031`0300L700P700<01`L0
0`L00`071`0?1`806@L002D700<01`L00`L00`071`081`0300L700<700<01`L040L00`0700020003
1`0700P70`031`0300L7014700@01`L70`091`0300L0008000<700L04PL00`071`021`0300L700P7
00<01`L00`L00`071`031`<02`L3008700<01`L020L00`071`031`0300L7010700<01`L060L002D7
00<01`L00PL00`071`091`0300L7008700<01`L04@L00`071`021`<020L00`071`0301@700D01`L7
00021`<01@L00`071`031`<04@L00`071`021`0300L700P700<01`L00`L00`071`071`<01`L01007
1`L300T700<01`L00`L00`071`0A1`0300L701P7000T1`800`L00`071`091`0300L7008700<01`L0
4@L00`071`021`0400L71`<01@L01P071`L01`<040L01@071`L000H70`021`0300L7008700@01`L7
0`0=1`0300L7008700<01`L02@L00`071`021`0300L700/70`031`0300L7008700<01`L00`061`03
00L7008700<01`L04@L00`071`0I1`009PL400X700<01`L00PL00`071`0A1`0300L700<700<01`L0
10L300031`07008700<01`L00`L300`700<01`L00PL00`071`071`<00`L00`071`051`<02@L00`07
1`031`0300L700P700<01`L00PL00`071`0?1`@010L00`071`031`<00PL00`071`031`0300L70107
00<01`L06PL002P710071`0300L700<700<01`L04@L00`071`021`0300L700P70`021`0300L700H7
0`081`0300L7008700<01`L020L00`071`0400X70`061`0300L7008700<01`L020L00`071`031`03
00L701471P091`<010L00`071`0@1`0300L701/7000W1`0300L700870`041`0300L7008700<01`L0
4@L00`071`021`0300L700T700<01`L00`0;1`<01@L01@071`L000/700<01`L00PL400/70`021`03
00L7008700<01`L02@L00`071`021`0300L7014700<01`L00PL400L700<01`L0100C1`0300L701/7
000W1`0300L700D710041`0300L7014700<01`L00PL00`071`091`0500L71`000PL300/70`000`L0
1`021`0300L700T700<01`L00PL00`071`021`<02`L300<700<01`L02@L00`071`021`0300L70147
00<01`L00PL00`071`021`<010L00`071`021`@040L00`071`0L1`009PL00`071`081`@00PL00`07
1`0@1`0300L700<700<01`L020L00`071`021`0300L700<70`0;1`<00PL00`071`081`0300L700<7
00<01`L01@L300P700<01`L0100:1`0300L7008700<01`L04PL00`071`021`0300L700D710051`04
00L71`@02`L00`071`0M1`009@L00`071`081`0300L70087100A1`0300L7008700<01`L020L00`07
1`021`0300L700L70`081`0300L700<02PL00`071`021`0300L700T70`051`0300L7008710071`03
00L700<700<01`L04@L00`071`021`0300L700P710021`0300L700H70`071`0300L701h7000T1`03
00L700T700<01`L00PL010071`L300d700<01`L00PL00`071`091`0500L71`003@L300@700D01`L7
00021`<01PL00`071`021`0300L700d71@041`0300L700870`041`0300L7008700<01`L04@L00`07
1`021`0300L700T700@01`L70P0<1`<010L00`071`0N1`0090L00`071`081`800`L00`071`051`<0
2@L00`071`031`0300L700P700<01`L00PL00`071`0>1`@010L00`071`031`<00PL00`071`021`03
00L7014710021`0300L700D710041`0300L7014700<01`L00PL00`071`091`0300L7008700<01`L0
3PL40247000S1`0300L700/7100:1`<01@L00`071`031`0300L700P700<01`L00PL00`071`0A1`H0
2@L300@700<01`L040L00`071`021`<02@L4008700<01`L04@L00`071`021`0300L700P700<01`L0
0`L00`071`0@1`@07`L0028700<01`L03PL400/70`021`0300L7008700<01`L02@L01@071`L001@7
00@01`L710081`0300L000<04`L00`071`021`0300L700<01@L00`071`021`@04@L00`071`021`03
00L700P700<01`L00`L00`071`0A1`0400L71`807@L0024700<01`L03PL00`071`021`<02`L300<7
00<01`L02@L01@071`L001@700D01`L700041`<010L00`071`021`@040L00`071`021`0300L700@7
0`021`0300L7008700@01`L70`0=1`0300L7008700<01`L02@L00`071`021`0300L7014700<01`L0
0PL00`071`0L1`008@L00`071`0>1`0300L700D70`0;1`@02PL00`071`021`0300L7014700<01`L0
0PL00`071`051`@010L00`071`021`@02`L00`071`031`0300L700L70`031`0300L700D70`091`03
00L700<700<01`L020L00`071`021`0300L7014700<01`L00`L00`071`0L1`0080L200l700<01`L0
2@L300X710071`0300L7008700<01`L04PL01@071`L000/70`021`0300L700H70`071`0300L700<7
00<01`L020L00`071`0400X70`061`0300L7008700<01`L020L00`071`031`0300L7010700<01`L0
0`L00`071`0M1`008PL300/700<01`L03@L400D700<01`L00PL300@700D01`L7000D1`0500L71`00
2`L010071`L300/70`041`0300L7008700<01`L02@L00`071`021`@02`L3008700<01`L00PL00`07
1`091`0300L7008700<01`L04@L00`071`021`0300L701h7000U1`<01`L00`071`0B1`<00PL00`07
1`051`@010L00`071`0A1`0500L71`002`L00`071`021`0300L700<02`L400@700<01`L02@L00`07
1`021`0300L700870`0;1`<00`L00`071`091`0300L7008700<01`L04@L00`071`021`0300L701l7
000X1`<010L00`071`0E1`<02@L400031`07018700<01`L00PL00`071`091`0300L7008700<01`L0
0`L300X710021`0300L700P700<01`L00`L00`071`051`<020L00`071`0400X700<01`L00PL00`07
1`0A1`0300L700<700<01`L07`L002/7100H1`0300L700<01@L00`071`021`@04@L01@071`L000/7
00<01`L00PL00`071`071`<01`L010071`L300T700<01`L00`L00`071`091`<01@L00`071`021`@0
1`L00`071`031`0300L7014700<01`L00PL00`071`0P1`00;@L401D700<01`L010L3008700<01`L0
0PL010071`L300d700D01`L7000;1`0300L7008700<01`L02`L300<700<01`L00PL00`071`0300H7
00<01`L00PL00`071`0=1`D010L00`071`021`<010L00`071`021`0300L7014700<01`L00PL00`07
1`0Q1`00;0L00`071`021`@04@L00`071`071`<00`L00`071`051`<02@L00`071`021`0300L700T7
00D01`L7000A1`<01@L00`071`031`<00PL00`071`021`0300L7014710021`0300L700D710041`03
00L7014700<01`L00PL00`071`0R1`00;0L00`071`061`<03@L00`071`0;1`<02`L300D700<01`L0
0PL00`071`091`0300L7008700<01`L040L00`07000400T70`041`0300L7010700<01`L00PL300T7
10021`0300L7010700<01`L00`L00`071`0R1`00:`L200/70`091`0300L700h7100;1`<00PL01@07
1`L000/700<01`L00PL00`071`0A1`0300L7008710071`0300L700@04`L00`071`021`0300L700<0
1@L00`071`021`@04@L00`071`021`0300L702<7000]1`<02`L300D700<01`L03PL00`071`021`<0
2`L3008700<01`L02PL01@071`L001<700<01`L00PL00`071`021`<010L00`071`021`@040L00`07
1`021`0300L700@70`021`0300L7008700@01`L70`0=1`0300L7008700<01`L090L003070`0;1`<0
0PL00`071`0=1`0300L700H70`081`0300L700<02`L01@071`L001<700<01`L00`L00`071`051`@0
10L00`071`021`@02`L00`071`031`0300L700L70P041`0300L700D70`091`0300L700<700<01`L0
90L003<70`0;1`<03`L00`071`091`<01@L01P071`L01`<01`L00`071`021`0300L7014700<01`L0
0PL00`071`081`@00PL00`071`061`<01`L00`071`031`0300L700P700<01`L00`L00`071`081`<0
1@L00`071`031`0300L702D7000f1`<02`L300/700<01`L03@L500<700<01`L00`L300<700<01`L0
0PL00`071`0A1`0300L7008700<01`L02@L010071`L300/70`041`0300L7008700<01`L02@L00`07
1`021`0300L700`70`021`0300L7008700<01`L09PL003T70`0;1`<01`L00`071`0A1`@000<700L0
1`L400<700<01`L04@L00`071`021`0300L700T700<01`L00PL00`071`0300/710041`0300L700T7
00<01`L00PL00`071`0@1`8010L00`071`0W1`00?0L400X70`031`0300L7014700<01`L00PL300T7
10000`L01`0A1`0300L700<700<01`L020L00`071`031`0300L700<70`0:1`@00PL00`071`081`03
00L700<700<01`L05PL00`071`0W1`00@0L300X7100C1`0500L71`000`L300D700<01`L00PL30147
00<01`L00PL00`071`081`0300L700<700<01`L01`L300L700@01`L70`091`0300L700<700<01`L0
5PL00`071`0X1`00@`L300T7100@1`0500L71`001`L3008700D01`L700031`<03@L00`071`021`03
00L700T700<01`L00PL00`071`0;1`<00`L00`071`021`0300L700<01PL00`071`021`0300L701H7
00<01`L0:@L004H70`051`0300L700870`0<1`0300L7008700<01`L020L3008700<01`L01@L300T7
00<01`L00`L00`071`081`0300L7008700<01`L03`L300D700<01`L00`L3008700<01`L00PL00`07
1`0G1`0300L702T700191`<00PL00`071`051`<020L00`071`021`0300L700T700<01`L00`0:1`<0
1@L00`071`031`0300L700P700<01`L00`L00`071`0@1`0300L000@02@L300@700<01`L05PL00`07
1`0Z1`00C0L300X70`051`0500L71`0030L01P071`L01`<02PL3008700<01`L00PL00`071`091`03
00L7008700<01`L04@L00`071`021`@01`L00`071`0401P700<01`L0:`L004l70`0:1`<000<700L0
0PL00`071`0:1`0500L71`001@L300X70`031`0300L700T700<01`L00PL00`071`0A1`0300L70087
00<01`L00PL300@700<01`L00PL401D700<01`L0;0L005870`0:1`<00PL00`071`091`0300L70087
00<01`L01PL300L700<01`L0100:1`0300L7008700<01`L04@L00`071`031`0300L700D710041`03
00L70087100A1`0300L702`7001E1`<01`L00`071`0300X700<01`L00PL00`071`0:1`<010L00`07
1`021`@01`L00`071`031`0300L7014700<01`L00PL00`071`081`@00PL00`071`061`<03@L00`07
1`0]1`00F0L300<700<01`L010L300L700D01`L7000@1`@010L00`071`021`<010L00`071`021`03
00L7014700<01`L00PL00`071`091`0400L71`8030L300T700<01`L0;PL005/70`0:1`<00`L01@07
1`L001<710021`0300L700D710041`0300L7014700<01`L00PL00`071`091`0300L701<70`051`03
00L702l7001L1`0300L000802PL300@700<01`L04@L010071`L300T710021`0300L7010700<01`L0
0`L00`071`081`0300L701L70`021`0300L702l7001L1`0300L700870`081`0300L000<04`L00`07
1`021`0300L700<01@L00`071`021`@04@L00`071`021`0300L700P700<01`L06`L20387001K1`03
00L700H70`051`0400L71`@040L00`071`021`0300L700@70`021`0300L7008700@01`L70`0=1`03
00L7008700<01`L02@L00`071`1?1`00FPL00`071`0:1`<000<700L00PL00`071`021`@02`L00`07
1`031`0300L700L70`031`0300L700D70`091`0300L700<700<01`L020L00`071`1@1`00FPL00`07
1`0=1`<00PL00`071`061`<020L00`071`021`0300L700P700<01`L0100:1`<01@L00`071`031`03
00L700P700<01`L0D@L005T700<01`L03PL00`071`0300/70`041`0300L7008700<01`L02@L00`07
1`021`@02`L3008700<01`L00PL00`071`091`0300L70547001H1`0300L700h700<01`L010L300/7
10041`0300L700T700<01`L00PL00`071`021`<02`L200@700<01`L02@L00`071`1B1`00E`L00`07
1`0>1`0300L700P70`0;1`<00PL00`071`081`0300L700<700<01`L01@L300h700<01`L020L00`07
1`1C1`00E`L00`071`0=1`0300L700`70`071`0400L71`<02PL00`071`021`0300L700T70`0:1`03
00L700P700<01`L0E0L005H700<01`L03PL00`071`0?1`<00`L00`071`051`<01PL00`071`021`03
00L700d710051`0300L700T700<01`L0E0L005D700<01`L03PL00`071`0C1`@02PL3008700<01`L0
0PL00`071`0B1`<00PL00`071`081`0300L705D7001D1`0300L700h700<01`L05PL500X70`041`03
00L701D70`091`0300L705H7001D1`0300L700h700<01`L05@L00`071`031`<020L00`07000301P7
00<01`L00`051`0300L705L7001C1`803`L00`071`0F1`0300L700H70`041`0300L70087100E1`03
00L700@70`021`0300L705L7001E1`<02`L00`071`0F1`0300L700X710041`0300L70087100A1`03
00L700L70P1J1`00F0L300L700<01`L05PL00`071`0>1`<00PL00`071`061`<03@L00`071`1T1`00
F`L300@700<01`L05PL00`071`0=1`0400L71`8030L300T700<01`L0I@L005h7100H1`0300L700d7
00<01`L04`L300D700<01`L0IPL00607100E1`0300L700h700<01`L05PL3008700<01`L0IPL005l7
00<01`L00PL4010700<01`L03PL00`071`0J1`80J@L005l700<01`L01PL300d700<01`L03@L00`07
1`261`00GPL200/70`091`0300L700h700<01`L0QPL006070`0;1`<01@L00`071`0>1`0300L708L7
001S1`<02`L3008700<01`L03@L00`071`281`00IPL300/70P0@1`0300L708P7001Y1`<06@L00`07
1`291`00K0L301D700<01`L0RPL006l7100@1`0300L708/7001c1`<03@L00`071`2;1`00MPL300T7
00<01`L0S0L007T70`051`0300L708d7001l1`<00PL00`071`2=1`00O`L20907003o1a87003o1a87
003o1a87003o1a87003o1a87003o1a870000\
\>"],
  ImageRangeCache->{{{0, 272.812}, {282.625, 0}} -> {-10.0865, -10.4466, \
0.0739292, 0.0739292}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[200]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Shifts:", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FullSimplify[RR[2, 1, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR[3, 1, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR[3, 2, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR[4, 1, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR[4, 2, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR[4, 3, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR[5, 1, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR[5, 2, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR[5, 3, \[Alpha]]]\), "\[IndentingNewLine]", 
    \(FullSimplify[RR[5, 4, \[Alpha]]]\)}], "Input",
  CellLabel->"In[201]:="],

Cell[BoxData[
    \({\(-0.6541039886902862`\), \(-0.47516171126863`\)}\)], "Output",
  CellLabel->"Out[201]="],

Cell[BoxData[
    \({\(-0.09508699431533882`\), \(-0.29532778659193704`\)}\)], "Output",
  CellLabel->"Out[202]="],

Cell[BoxData[
    \({0.2514635254915625`, \(-0.7693984328949843`\)}\)], "Output",
  CellLabel->"Out[203]="],

Cell[BoxData[
    \({\(-0.09508699431533879`\), 0.2909186239319485`}\)], "Output",
  CellLabel->"Out[204]="],

Cell[BoxData[
    \({0.24722745751406264`, \(-0.18023679868204007`\)}\)], "Output",
  CellLabel->"Out[205]="],

Cell[BoxData[
    \({0.80886248587776`, \(-0.002204581329994182`\)}\)], "Output",
  CellLabel->"Out[206]="],

Cell[BoxData[
    \({\(-0.6541039886902862`\), 0.47684586154281877`}\)], "Output",
  CellLabel->"Out[207]="],

Cell[BoxData[
    \({\(-0.31007601136932234`\), 0.0008420751370943891`}\)], "Output",
  CellLabel->"Out[208]="],

Cell[BoxData[
    \({0.25302254248593736`, 0.18380388620493415`}\)], "Output",
  CellLabel->"Out[209]="],

Cell[BoxData[
    \({0.24788196601125012`, 0.7699188639507899`}\)], "Output",
  CellLabel->"Out[210]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Families", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[lattice21, \ lattice32, \ lattice43, \ lattice41]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0483268 0.5 0.0483268 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.12046 .2061 m
.21712 .10945 L
s
.12046 .2061 m
.12046 .34279 L
s
.21712 .10945 m
.21712 .24614 L
s
.02381 .43944 m
.12046 .34279 L
s
.02381 .43944 m
.02381 .57613 L
s
.12046 .34279 m
.21712 .24614 L
s
.12046 .34279 m
.12046 .47948 L
s
.21712 .24614 m
.31377 .14948 L
s
.21712 .24614 m
.21712 .38283 L
s
.31377 .14948 m
.41042 .05283 L
s
.31377 .14948 m
.31377 .28617 L
s
.41042 .05283 m
.41042 .18952 L
s
.02381 .57613 m
.12046 .47948 L
s
.12046 .47948 m
.21712 .38283 L
s
.12046 .47948 m
.12046 .61617 L
s
.21712 .38283 m
.31377 .28617 L
s
.21712 .38283 m
.21712 .51951 L
s
.31377 .28617 m
.41042 .18952 L
s
.31377 .28617 m
.31377 .42286 L
s
.41042 .18952 m
.50708 .09287 L
s
.41042 .18952 m
.41042 .32621 L
s
.50708 .09287 m
.50708 .22955 L
s
.12046 .61617 m
.21712 .51951 L
s
.12046 .61617 m
.12046 .75286 L
s
.21712 .51951 m
.31377 .42286 L
s
.21712 .51951 m
.21712 .6562 L
s
.31377 .42286 m
.41042 .32621 L
s
.31377 .42286 m
.31377 .55955 L
s
.41042 .32621 m
.50708 .22955 L
s
.41042 .32621 m
.41042 .4629 L
s
.50708 .22955 m
.60373 .1329 L
s
.50708 .22955 m
.50708 .36624 L
s
.60373 .1329 m
.60373 .26959 L
s
.12046 .75286 m
.21712 .6562 L
s
.21712 .6562 m
.31377 .55955 L
s
.21712 .6562 m
.21712 .79289 L
s
.31377 .55955 m
.41042 .4629 L
s
.31377 .55955 m
.31377 .69624 L
s
.41042 .4629 m
.50708 .36624 L
s
.41042 .4629 m
.41042 .59959 L
s
.50708 .36624 m
.60373 .26959 L
s
.50708 .36624 m
.50708 .50293 L
s
.60373 .26959 m
.70038 .17294 L
s
.60373 .26959 m
.60373 .40628 L
s
.70038 .17294 m
.70038 .30962 L
s
.21712 .79289 m
.31377 .69624 L
s
.31377 .69624 m
.41042 .59959 L
s
.31377 .69624 m
.31377 .83293 L
s
.41042 .59959 m
.50708 .50293 L
s
.41042 .59959 m
.41042 .73627 L
s
.50708 .50293 m
.60373 .40628 L
s
.50708 .50293 m
.50708 .63962 L
s
.60373 .40628 m
.70038 .30962 L
s
.60373 .40628 m
.60373 .54297 L
s
.70038 .30962 m
.79704 .21297 L
s
.70038 .30962 m
.70038 .44631 L
s
.79704 .21297 m
.79704 .34966 L
s
.31377 .83293 m
.41042 .73627 L
s
.41042 .73627 m
.50708 .63962 L
s
.41042 .73627 m
.41042 .87296 L
s
.50708 .63962 m
.60373 .54297 L
s
.50708 .63962 m
.50708 .77631 L
s
.60373 .54297 m
.70038 .44631 L
s
.60373 .54297 m
.60373 .67966 L
s
.70038 .44631 m
.79704 .34966 L
s
.70038 .44631 m
.70038 .583 L
s
.79704 .34966 m
.89369 .25301 L
s
.79704 .34966 m
.79704 .48635 L
s
.89369 .25301 m
.89369 .38969 L
s
.41042 .87296 m
.50708 .77631 L
s
.50708 .77631 m
.60373 .67966 L
s
.50708 .77631 m
.50708 .913 L
s
.60373 .67966 m
.70038 .583 L
s
.60373 .67966 m
.60373 .81634 L
s
.70038 .583 m
.79704 .48635 L
s
.70038 .583 m
.70038 .71969 L
s
.79704 .48635 m
.89369 .38969 L
s
.79704 .48635 m
.79704 .62304 L
s
.89369 .38969 m
.89369 .52638 L
s
.50708 .913 m
.60373 .81634 L
s
.60373 .81634 m
.70038 .71969 L
s
.60373 .81634 m
.60373 .95303 L
s
.70038 .71969 m
.79704 .62304 L
s
.70038 .71969 m
.70038 .85638 L
s
.79704 .62304 m
.89369 .52638 L
s
.79704 .62304 m
.79704 .75973 L
s
.89369 .52638 m
.89369 .66307 L
s
.60373 .95303 m
.70038 .85638 L
s
.70038 .85638 m
.79704 .75973 L
s
.79704 .75973 m
.89369 .66307 L
s
.05798 .33693 m
.15464 .24027 L
s
.05798 .33693 m
.05798 .47362 L
s
.15464 .24027 m
.25129 .14362 L
s
.15464 .24027 m
.15464 .37696 L
s
.25129 .14362 m
.34794 .04697 L
s
.25129 .14362 m
.25129 .28031 L
s
.34794 .04697 m
.34794 .18366 L
s
.05798 .47362 m
.15464 .37696 L
s
.05798 .47362 m
.05798 .61031 L
s
.15464 .37696 m
.25129 .28031 L
s
.15464 .37696 m
.15464 .51365 L
s
.25129 .28031 m
.34794 .18366 L
s
.25129 .28031 m
.25129 .417 L
s
.34794 .18366 m
.4446 .087 L
s
.34794 .18366 m
.34794 .32034 L
s
.4446 .087 m
.4446 .22369 L
s
.05798 .61031 m
.15464 .51365 L
s
.15464 .51365 m
.25129 .417 L
s
.15464 .51365 m
.15464 .65034 L
s
.25129 .417 m
.34794 .32034 L
s
.25129 .417 m
.25129 .55369 L
s
.34794 .32034 m
.4446 .22369 L
s
.34794 .32034 m
.34794 .45703 L
s
.4446 .22369 m
.54125 .12704 L
s
.4446 .22369 m
.4446 .36038 L
s
.54125 .12704 m
.54125 .26373 L
s
.15464 .65034 m
.25129 .55369 L
s
.15464 .65034 m
.15464 .78703 L
s
.25129 .55369 m
.34794 .45703 L
s
.25129 .55369 m
.25129 .69038 L
s
.34794 .45703 m
.4446 .36038 L
s
.34794 .45703 m
.34794 .59372 L
s
.4446 .36038 m
.54125 .26373 L
s
.4446 .36038 m
.4446 .49707 L
s
.54125 .26373 m
.6379 .16707 L
s
.54125 .26373 m
.54125 .40041 L
s
.6379 .16707 m
.6379 .30376 L
s
.15464 .78703 m
.25129 .69038 L
s
.25129 .69038 m
.34794 .59372 L
s
.25129 .69038 m
.25129 .82706 L
s
.34794 .59372 m
.4446 .49707 L
s
.34794 .59372 m
.34794 .73041 L
s
.4446 .49707 m
.54125 .40041 L
s
.4446 .49707 m
.4446 .63376 L
s
.54125 .40041 m
.6379 .30376 L
s
.54125 .40041 m
.54125 .5371 L
s
.6379 .30376 m
.73456 .20711 L
s
.6379 .30376 m
.6379 .44045 L
s
.73456 .20711 m
.73456 .3438 L
s
.25129 .82706 m
.34794 .73041 L
s
.34794 .73041 m
.4446 .63376 L
s
.34794 .73041 m
.34794 .8671 L
s
.4446 .63376 m
.54125 .5371 L
s
.4446 .63376 m
.4446 .77045 L
s
.54125 .5371 m
.6379 .44045 L
s
.54125 .5371 m
.54125 .67379 L
s
.6379 .44045 m
.73456 .3438 L
s
.6379 .44045 m
.6379 .57714 L
s
.73456 .3438 m
.83121 .24714 L
s
.73456 .3438 m
.73456 .48049 L
s
.83121 .24714 m
.83121 .38383 L
s
.34794 .8671 m
.4446 .77045 L
s
.4446 .77045 m
.54125 .67379 L
s
.4446 .77045 m
.4446 .90713 L
s
.54125 .67379 m
.6379 .57714 L
s
.54125 .67379 m
.54125 .81048 L
s
.6379 .57714 m
.73456 .48049 L
s
.6379 .57714 m
.6379 .71383 L
s
.73456 .48049 m
.83121 .38383 L
s
.73456 .48049 m
.73456 .61717 L
s
.83121 .38383 m
.92786 .28718 L
s
.83121 .38383 m
.83121 .52052 L
s
.92786 .28718 m
.92786 .42387 L
s
.4446 .90713 m
.54125 .81048 L
s
.54125 .81048 m
.6379 .71383 L
s
.54125 .81048 m
.54125 .94717 L
s
.6379 .71383 m
.73456 .61717 L
s
.6379 .71383 m
.6379 .85052 L
s
.73456 .61717 m
.83121 .52052 L
s
.73456 .61717 m
.73456 .75386 L
s
.83121 .52052 m
.92786 .42387 L
s
.83121 .52052 m
.83121 .65721 L
s
.92786 .42387 m
.92786 .56056 L
s
.54125 .94717 m
.6379 .85052 L
s
.6379 .85052 m
.73456 .75386 L
s
.73456 .75386 m
.83121 .65721 L
s
.73456 .75386 m
.73456 .89055 L
s
.83121 .65721 m
.92786 .56056 L
s
.83121 .65721 m
.83121 .7939 L
s
.92786 .56056 m
.92786 .69724 L
s
.73456 .89055 m
.83121 .7939 L
s
.83121 .7939 m
.92786 .69724 L
s
.07214 .30276 m
.16879 .2061 L
s
.07214 .30276 m
.07214 .43944 L
s
.16879 .2061 m
.26544 .10945 L
s
.16879 .2061 m
.16879 .34279 L
s
.26544 .10945 m
.26544 .24614 L
s
.07214 .43944 m
.16879 .34279 L
s
.07214 .43944 m
.07214 .57613 L
s
.16879 .34279 m
.26544 .24614 L
s
.16879 .34279 m
.16879 .47948 L
s
.26544 .24614 m
.3621 .14948 L
s
.26544 .24614 m
.26544 .38283 L
s
.3621 .14948 m
.45875 .05283 L
s
.3621 .14948 m
.3621 .28617 L
s
.45875 .05283 m
.45875 .18952 L
s
.07214 .57613 m
.16879 .47948 L
s
.07214 .57613 m
.07214 .71282 L
s
.16879 .47948 m
.26544 .38283 L
s
.16879 .47948 m
.16879 .61617 L
s
.26544 .38283 m
.3621 .28617 L
s
.26544 .38283 m
.26544 .51951 L
s
.3621 .28617 m
.45875 .18952 L
s
.3621 .28617 m
.3621 .42286 L
s
.45875 .18952 m
.5554 .09287 L
s
.45875 .18952 m
.45875 .32621 L
s
.5554 .09287 m
.5554 .22955 L
s
.07214 .71282 m
.16879 .61617 L
s
.16879 .61617 m
.26544 .51951 L
s
.16879 .61617 m
.16879 .75286 L
s
.26544 .51951 m
.3621 .42286 L
s
.26544 .51951 m
.26544 .6562 L
s
.3621 .42286 m
.45875 .32621 L
s
.3621 .42286 m
.3621 .55955 L
s
.45875 .32621 m
.5554 .22955 L
s
.45875 .32621 m
.45875 .4629 L
s
.5554 .22955 m
.65206 .1329 L
s
.5554 .22955 m
.5554 .36624 L
s
.65206 .1329 m
.65206 .26959 L
s
.16879 .75286 m
.26544 .6562 L
s
.26544 .6562 m
.3621 .55955 L
s
.26544 .6562 m
.26544 .79289 L
s
.3621 .55955 m
.45875 .4629 L
s
.3621 .55955 m
.3621 .69624 L
s
.45875 .4629 m
.5554 .36624 L
s
.45875 .4629 m
.45875 .59959 L
s
.5554 .36624 m
.65206 .26959 L
s
.5554 .36624 m
.5554 .50293 L
s
.65206 .26959 m
.74871 .17294 L
s
.65206 .26959 m
.65206 .40628 L
s
.74871 .17294 m
.74871 .30962 L
s
.26544 .79289 m
.3621 .69624 L
s
.3621 .69624 m
.45875 .59959 L
s
.3621 .69624 m
.3621 .83293 L
s
.45875 .59959 m
.5554 .50293 L
s
.45875 .59959 m
.45875 .73627 L
s
.5554 .50293 m
.65206 .40628 L
s
.5554 .50293 m
.5554 .63962 L
s
.65206 .40628 m
.74871 .30962 L
s
.65206 .40628 m
.65206 .54297 L
s
.74871 .30962 m
.84536 .21297 L
s
.74871 .30962 m
.74871 .44631 L
s
.84536 .21297 m
.84536 .34966 L
s
.3621 .83293 m
.45875 .73627 L
s
.45875 .73627 m
.5554 .63962 L
s
.45875 .73627 m
.45875 .87296 L
s
.5554 .63962 m
.65206 .54297 L
s
.5554 .63962 m
.5554 .77631 L
s
.65206 .54297 m
.74871 .44631 L
s
.65206 .54297 m
.65206 .67966 L
s
.74871 .44631 m
.84536 .34966 L
s
.74871 .44631 m
.74871 .583 L
s
.84536 .34966 m
.84536 .48635 L
s
.45875 .87296 m
.5554 .77631 L
s
.5554 .77631 m
.65206 .67966 L
s
.5554 .77631 m
.5554 .913 L
s
.65206 .67966 m
.74871 .583 L
s
.65206 .67966 m
.65206 .81634 L
s
.74871 .583 m
.84536 .48635 L
s
.74871 .583 m
.74871 .71969 L
s
.84536 .48635 m
.94202 .38969 L
s
.84536 .48635 m
.84536 .62304 L
s
.94202 .38969 m
.94202 .52638 L
s
.5554 .913 m
.65206 .81634 L
s
.65206 .81634 m
.74871 .71969 L
s
.65206 .81634 m
.65206 .95303 L
s
.74871 .71969 m
.84536 .62304 L
s
.74871 .71969 m
.74871 .85638 L
s
.84536 .62304 m
.94202 .52638 L
s
.84536 .62304 m
.84536 .75973 L
s
.94202 .52638 m
.94202 .66307 L
s
.65206 .95303 m
.74871 .85638 L
s
.74871 .85638 m
.84536 .75973 L
s
.84536 .75973 m
.94202 .66307 L
s
.10631 .33693 m
.20296 .24027 L
s
.10631 .33693 m
.10631 .47362 L
s
.20296 .24027 m
.29962 .14362 L
s
.20296 .24027 m
.20296 .37696 L
s
.29962 .14362 m
.39627 .04697 L
s
.29962 .14362 m
.29962 .28031 L
s
.39627 .04697 m
.39627 .18366 L
s
.10631 .47362 m
.20296 .37696 L
s
.10631 .47362 m
.10631 .61031 L
s
.20296 .37696 m
.29962 .28031 L
s
.20296 .37696 m
.20296 .51365 L
s
.29962 .28031 m
.39627 .18366 L
s
.29962 .28031 m
.29962 .417 L
s
.39627 .18366 m
.49292 .087 L
s
.39627 .18366 m
.39627 .32034 L
s
.49292 .087 m
.49292 .22369 L
s
.10631 .61031 m
.20296 .51365 L
s
.10631 .61031 m
.10631 .74699 L
s
.20296 .51365 m
.29962 .417 L
s
.20296 .51365 m
.20296 .65034 L
s
.29962 .417 m
.39627 .32034 L
s
.29962 .417 m
.29962 .55369 L
s
.39627 .32034 m
.49292 .22369 L
s
.39627 .32034 m
.39627 .45703 L
s
.49292 .22369 m
.58958 .12704 L
s
.49292 .22369 m
.49292 .36038 L
s
.58958 .12704 m
.58958 .26373 L
s
.10631 .74699 m
.20296 .65034 L
s
.20296 .65034 m
.29962 .55369 L
s
.20296 .65034 m
.20296 .78703 L
s
.29962 .55369 m
.39627 .45703 L
s
.29962 .55369 m
.29962 .69038 L
s
.39627 .45703 m
.49292 .36038 L
s
.39627 .45703 m
.39627 .59372 L
s
.49292 .36038 m
.58958 .26373 L
s
.49292 .36038 m
.49292 .49707 L
s
.58958 .26373 m
.68623 .16707 L
s
.58958 .26373 m
.58958 .40041 L
s
.68623 .16707 m
.68623 .30376 L
s
.20296 .78703 m
.29962 .69038 L
s
.29962 .69038 m
.39627 .59372 L
s
.29962 .69038 m
.29962 .82706 L
s
.39627 .59372 m
.49292 .49707 L
s
.39627 .59372 m
.39627 .73041 L
s
.49292 .49707 m
.58958 .40041 L
s
.49292 .49707 m
.49292 .63376 L
s
.58958 .40041 m
.68623 .30376 L
s
.58958 .40041 m
.58958 .5371 L
s
.68623 .30376 m
.78288 .20711 L
s
.68623 .30376 m
.68623 .44045 L
s
.78288 .20711 m
.78288 .3438 L
s
.29962 .82706 m
.39627 .73041 L
s
.39627 .73041 m
.49292 .63376 L
s
.39627 .73041 m
.39627 .8671 L
s
.49292 .63376 m
.58958 .5371 L
s
.49292 .63376 m
.49292 .77045 L
s
.58958 .5371 m
.68623 .44045 L
s
.58958 .5371 m
.58958 .67379 L
s
.68623 .44045 m
.78288 .3438 L
s
.68623 .44045 m
.68623 .57714 L
s
.78288 .3438 m
.87954 .24714 L
s
.78288 .3438 m
.78288 .48049 L
s
.87954 .24714 m
.87954 .38383 L
s
.39627 .8671 m
.49292 .77045 L
s
.49292 .77045 m
.58958 .67379 L
s
.49292 .77045 m
.49292 .90713 L
s
.58958 .67379 m
.68623 .57714 L
s
.58958 .67379 m
.58958 .81048 L
s
.68623 .57714 m
.78288 .48049 L
s
.68623 .57714 m
.68623 .71383 L
s
.78288 .48049 m
.87954 .38383 L
s
.78288 .48049 m
.78288 .61717 L
s
.87954 .38383 m
.87954 .52052 L
s
.49292 .90713 m
.58958 .81048 L
s
.58958 .81048 m
.68623 .71383 L
s
.58958 .81048 m
.58958 .94717 L
s
.68623 .71383 m
.78288 .61717 L
s
.68623 .71383 m
.68623 .85052 L
s
.78288 .61717 m
.87954 .52052 L
s
.78288 .61717 m
.78288 .75386 L
s
.87954 .52052 m
.97619 .42387 L
s
.87954 .52052 m
.87954 .65721 L
s
.97619 .42387 m
.97619 .56056 L
s
.58958 .94717 m
.68623 .85052 L
s
.68623 .85052 m
.78288 .75386 L
s
.78288 .75386 m
.87954 .65721 L
s
.78288 .75386 m
.78288 .89055 L
s
.87954 .65721 m
.97619 .56056 L
s
.87954 .65721 m
.87954 .7939 L
s
.78288 .89055 m
.87954 .7939 L
s
.43944 .02381 m
.57613 .02381 L
s
.43944 .02381 m
.34279 .12046 L
s
.57613 .02381 m
.47948 .12046 L
s
.2061 .12046 m
.34279 .12046 L
s
.2061 .12046 m
.10945 .21712 L
s
.34279 .12046 m
.47948 .12046 L
s
.34279 .12046 m
.24614 .21712 L
s
.47948 .12046 m
.61617 .12046 L
s
.47948 .12046 m
.38283 .21712 L
s
.61617 .12046 m
.75286 .12046 L
s
.61617 .12046 m
.51951 .21712 L
s
.75286 .12046 m
.6562 .21712 L
s
.10945 .21712 m
.24614 .21712 L
s
.24614 .21712 m
.38283 .21712 L
s
.24614 .21712 m
.14948 .31377 L
s
.38283 .21712 m
.51951 .21712 L
s
.38283 .21712 m
.28617 .31377 L
s
.51951 .21712 m
.6562 .21712 L
s
.51951 .21712 m
.42286 .31377 L
s
.6562 .21712 m
.79289 .21712 L
s
.6562 .21712 m
.55955 .31377 L
s
.79289 .21712 m
.69624 .31377 L
s
.14948 .31377 m
.28617 .31377 L
s
.14948 .31377 m
.05283 .41042 L
s
.28617 .31377 m
.42286 .31377 L
s
.28617 .31377 m
.18952 .41042 L
s
.42286 .31377 m
.55955 .31377 L
s
.42286 .31377 m
.32621 .41042 L
s
.55955 .31377 m
.69624 .31377 L
s
.55955 .31377 m
.4629 .41042 L
s
.69624 .31377 m
.83293 .31377 L
s
.69624 .31377 m
.59959 .41042 L
s
.83293 .31377 m
.73627 .41042 L
s
.05283 .41042 m
.18952 .41042 L
s
.18952 .41042 m
.32621 .41042 L
s
.18952 .41042 m
.09287 .50708 L
s
.32621 .41042 m
.4629 .41042 L
s
.32621 .41042 m
.22955 .50708 L
s
.4629 .41042 m
.59959 .41042 L
s
.4629 .41042 m
.36624 .50708 L
s
.59959 .41042 m
.73627 .41042 L
s
.59959 .41042 m
.50293 .50708 L
s
.73627 .41042 m
.87296 .41042 L
s
.73627 .41042 m
.63962 .50708 L
s
.87296 .41042 m
.77631 .50708 L
s
.09287 .50708 m
.22955 .50708 L
s
.22955 .50708 m
.36624 .50708 L
s
.22955 .50708 m
.1329 .60373 L
s
.36624 .50708 m
.50293 .50708 L
s
.36624 .50708 m
.26959 .60373 L
s
.50293 .50708 m
.63962 .50708 L
s
.50293 .50708 m
.40628 .60373 L
s
.63962 .50708 m
.77631 .50708 L
s
.63962 .50708 m
.54297 .60373 L
s
.77631 .50708 m
.913 .50708 L
s
.77631 .50708 m
.67966 .60373 L
s
.913 .50708 m
.81634 .60373 L
s
.1329 .60373 m
.26959 .60373 L
s
.26959 .60373 m
.40628 .60373 L
s
.26959 .60373 m
.17294 .70038 L
s
.40628 .60373 m
.54297 .60373 L
s
.40628 .60373 m
.30962 .70038 L
s
.54297 .60373 m
.67966 .60373 L
s
.54297 .60373 m
.44631 .70038 L
s
.67966 .60373 m
.81634 .60373 L
s
.67966 .60373 m
.583 .70038 L
s
.81634 .60373 m
.95303 .60373 L
s
.81634 .60373 m
.71969 .70038 L
s
.95303 .60373 m
.85638 .70038 L
s
.17294 .70038 m
.30962 .70038 L
s
.30962 .70038 m
.44631 .70038 L
s
.30962 .70038 m
.21297 .79704 L
s
.44631 .70038 m
.583 .70038 L
s
.44631 .70038 m
.34966 .79704 L
s
.583 .70038 m
.71969 .70038 L
s
.583 .70038 m
.48635 .79704 L
s
.71969 .70038 m
.85638 .70038 L
s
.71969 .70038 m
.62304 .79704 L
s
.85638 .70038 m
.75973 .79704 L
s
.21297 .79704 m
.34966 .79704 L
s
.34966 .79704 m
.48635 .79704 L
s
.34966 .79704 m
.25301 .89369 L
s
.48635 .79704 m
.62304 .79704 L
s
.48635 .79704 m
.38969 .89369 L
s
.62304 .79704 m
.75973 .79704 L
s
.62304 .79704 m
.52638 .89369 L
s
.75973 .79704 m
.66307 .89369 L
s
.25301 .89369 m
.38969 .89369 L
s
.38969 .89369 m
.52638 .89369 L
s
.52638 .89369 m
.66307 .89369 L
s
.30276 .07214 m
.43944 .07214 L
s
.30276 .07214 m
.2061 .16879 L
s
.43944 .07214 m
.57613 .07214 L
s
.43944 .07214 m
.34279 .16879 L
s
.57613 .07214 m
.71282 .07214 L
s
.57613 .07214 m
.47948 .16879 L
s
.71282 .07214 m
.61617 .16879 L
s
.2061 .16879 m
.34279 .16879 L
s
.2061 .16879 m
.10945 .26544 L
s
.34279 .16879 m
.47948 .16879 L
s
.34279 .16879 m
.24614 .26544 L
s
.47948 .16879 m
.61617 .16879 L
s
.47948 .16879 m
.38283 .26544 L
s
.61617 .16879 m
.75286 .16879 L
s
.61617 .16879 m
.51951 .26544 L
s
.75286 .16879 m
.6562 .26544 L
s
.10945 .26544 m
.24614 .26544 L
s
.24614 .26544 m
.38283 .26544 L
s
.24614 .26544 m
.14948 .3621 L
s
.38283 .26544 m
.51951 .26544 L
s
.38283 .26544 m
.28617 .3621 L
s
.51951 .26544 m
.6562 .26544 L
s
.51951 .26544 m
.42286 .3621 L
s
.6562 .26544 m
.79289 .26544 L
s
.6562 .26544 m
.55955 .3621 L
s
.79289 .26544 m
.69624 .3621 L
s
.14948 .3621 m
.28617 .3621 L
s
.14948 .3621 m
.05283 .45875 L
s
.28617 .3621 m
.42286 .3621 L
s
.28617 .3621 m
.18952 .45875 L
s
.42286 .3621 m
.55955 .3621 L
s
.42286 .3621 m
.32621 .45875 L
s
.55955 .3621 m
.69624 .3621 L
s
.55955 .3621 m
.4629 .45875 L
s
.69624 .3621 m
.83293 .3621 L
s
.69624 .3621 m
.59959 .45875 L
s
.83293 .3621 m
.73627 .45875 L
s
.05283 .45875 m
.18952 .45875 L
s
.18952 .45875 m
.32621 .45875 L
s
.18952 .45875 m
.09287 .5554 L
s
.32621 .45875 m
.4629 .45875 L
s
.32621 .45875 m
.22955 .5554 L
s
.4629 .45875 m
.59959 .45875 L
s
.4629 .45875 m
.36624 .5554 L
s
.59959 .45875 m
.73627 .45875 L
s
.59959 .45875 m
.50293 .5554 L
s
.73627 .45875 m
.87296 .45875 L
s
.73627 .45875 m
.63962 .5554 L
s
.87296 .45875 m
.77631 .5554 L
s
.09287 .5554 m
.22955 .5554 L
s
.22955 .5554 m
.36624 .5554 L
s
.22955 .5554 m
.1329 .65206 L
s
.36624 .5554 m
.50293 .5554 L
s
.36624 .5554 m
.26959 .65206 L
s
.50293 .5554 m
.63962 .5554 L
s
.50293 .5554 m
.40628 .65206 L
s
.63962 .5554 m
.77631 .5554 L
s
.63962 .5554 m
.54297 .65206 L
s
.77631 .5554 m
.913 .5554 L
s
.77631 .5554 m
.67966 .65206 L
s
.913 .5554 m
.81634 .65206 L
s
.1329 .65206 m
.26959 .65206 L
s
.26959 .65206 m
.40628 .65206 L
s
.26959 .65206 m
.17294 .74871 L
s
.40628 .65206 m
.54297 .65206 L
s
.40628 .65206 m
.30962 .74871 L
s
.54297 .65206 m
.67966 .65206 L
s
.54297 .65206 m
.44631 .74871 L
s
.67966 .65206 m
.81634 .65206 L
s
.67966 .65206 m
.583 .74871 L
s
.81634 .65206 m
.95303 .65206 L
s
.81634 .65206 m
.71969 .74871 L
s
.95303 .65206 m
.85638 .74871 L
s
.17294 .74871 m
.30962 .74871 L
s
.30962 .74871 m
.44631 .74871 L
s
.30962 .74871 m
.21297 .84536 L
s
.44631 .74871 m
.583 .74871 L
s
.44631 .74871 m
.34966 .84536 L
s
.583 .74871 m
.71969 .74871 L
s
.583 .74871 m
.48635 .84536 L
s
.71969 .74871 m
.85638 .74871 L
s
.71969 .74871 m
.62304 .84536 L
s
.85638 .74871 m
.75973 .84536 L
s
.21297 .84536 m
.34966 .84536 L
s
.34966 .84536 m
.48635 .84536 L
s
.48635 .84536 m
.62304 .84536 L
s
.48635 .84536 m
.38969 .94202 L
s
.62304 .84536 m
.75973 .84536 L
s
.62304 .84536 m
.52638 .94202 L
s
.75973 .84536 m
.66307 .94202 L
s
.38969 .94202 m
.52638 .94202 L
s
.52638 .94202 m
.66307 .94202 L
s
.33693 .05798 m
.47362 .05798 L
s
.33693 .05798 m
.24027 .15464 L
s
.47362 .05798 m
.61031 .05798 L
s
.47362 .05798 m
.37696 .15464 L
s
.61031 .05798 m
.51365 .15464 L
s
.24027 .15464 m
.37696 .15464 L
s
.24027 .15464 m
.14362 .25129 L
s
.37696 .15464 m
.51365 .15464 L
s
.37696 .15464 m
.28031 .25129 L
s
.51365 .15464 m
.65034 .15464 L
s
.51365 .15464 m
.417 .25129 L
s
.65034 .15464 m
.78703 .15464 L
s
.65034 .15464 m
.55369 .25129 L
s
.78703 .15464 m
.69038 .25129 L
s
.14362 .25129 m
.28031 .25129 L
s
.14362 .25129 m
.04697 .34794 L
s
.28031 .25129 m
.417 .25129 L
s
.28031 .25129 m
.18366 .34794 L
s
.417 .25129 m
.55369 .25129 L
s
.417 .25129 m
.32034 .34794 L
s
.55369 .25129 m
.69038 .25129 L
s
.55369 .25129 m
.45703 .34794 L
s
.69038 .25129 m
.82706 .25129 L
s
.69038 .25129 m
.59372 .34794 L
s
.82706 .25129 m
.73041 .34794 L
s
.04697 .34794 m
.18366 .34794 L
s
.18366 .34794 m
.32034 .34794 L
s
.18366 .34794 m
.087 .4446 L
s
.32034 .34794 m
.45703 .34794 L
s
.32034 .34794 m
.22369 .4446 L
s
.45703 .34794 m
.59372 .34794 L
s
.45703 .34794 m
.36038 .4446 L
s
.59372 .34794 m
.73041 .34794 L
s
.59372 .34794 m
.49707 .4446 L
s
.73041 .34794 m
.8671 .34794 L
s
.73041 .34794 m
.63376 .4446 L
s
.8671 .34794 m
.77045 .4446 L
s
.087 .4446 m
.22369 .4446 L
s
.22369 .4446 m
.36038 .4446 L
s
.22369 .4446 m
.12704 .54125 L
s
.36038 .4446 m
.49707 .4446 L
s
.36038 .4446 m
.26373 .54125 L
s
.49707 .4446 m
.63376 .4446 L
s
.49707 .4446 m
.40041 .54125 L
s
.63376 .4446 m
.77045 .4446 L
s
.63376 .4446 m
.5371 .54125 L
s
.77045 .4446 m
.90713 .4446 L
s
.77045 .4446 m
.67379 .54125 L
s
.90713 .4446 m
.81048 .54125 L
s
.12704 .54125 m
.26373 .54125 L
s
.26373 .54125 m
.40041 .54125 L
s
.26373 .54125 m
.16707 .6379 L
s
.40041 .54125 m
.5371 .54125 L
s
.40041 .54125 m
.30376 .6379 L
s
.5371 .54125 m
.67379 .54125 L
s
.5371 .54125 m
.44045 .6379 L
s
.67379 .54125 m
.81048 .54125 L
s
.67379 .54125 m
.57714 .6379 L
s
.81048 .54125 m
.94717 .54125 L
s
.81048 .54125 m
.71383 .6379 L
s
.94717 .54125 m
.85052 .6379 L
s
.16707 .6379 m
.30376 .6379 L
s
.30376 .6379 m
.44045 .6379 L
s
.30376 .6379 m
.20711 .73456 L
s
.44045 .6379 m
.57714 .6379 L
s
.44045 .6379 m
.3438 .73456 L
s
.57714 .6379 m
.71383 .6379 L
s
.57714 .6379 m
.48049 .73456 L
s
.71383 .6379 m
.85052 .6379 L
s
.71383 .6379 m
.61717 .73456 L
s
.85052 .6379 m
.75386 .73456 L
s
.20711 .73456 m
.3438 .73456 L
s
.3438 .73456 m
.48049 .73456 L
s
.3438 .73456 m
.24714 .83121 L
s
.48049 .73456 m
.61717 .73456 L
s
.48049 .73456 m
.38383 .83121 L
s
.61717 .73456 m
.75386 .73456 L
s
.61717 .73456 m
.52052 .83121 L
s
.75386 .73456 m
.89055 .73456 L
s
.75386 .73456 m
.65721 .83121 L
s
.89055 .73456 m
.7939 .83121 L
s
.24714 .83121 m
.38383 .83121 L
s
.38383 .83121 m
.52052 .83121 L
s
.38383 .83121 m
.28718 .92786 L
s
.52052 .83121 m
.65721 .83121 L
s
.52052 .83121 m
.42387 .92786 L
s
.65721 .83121 m
.7939 .83121 L
s
.65721 .83121 m
.56056 .92786 L
s
.7939 .83121 m
.69724 .92786 L
s
.28718 .92786 m
.42387 .92786 L
s
.42387 .92786 m
.56056 .92786 L
s
.56056 .92786 m
.69724 .92786 L
s
.33693 .10631 m
.47362 .10631 L
s
.33693 .10631 m
.24027 .20296 L
s
.47362 .10631 m
.61031 .10631 L
s
.47362 .10631 m
.37696 .20296 L
s
.61031 .10631 m
.74699 .10631 L
s
.61031 .10631 m
.51365 .20296 L
s
.74699 .10631 m
.65034 .20296 L
s
.24027 .20296 m
.37696 .20296 L
s
.24027 .20296 m
.14362 .29962 L
s
.37696 .20296 m
.51365 .20296 L
s
.37696 .20296 m
.28031 .29962 L
s
.51365 .20296 m
.65034 .20296 L
s
.51365 .20296 m
.417 .29962 L
s
.65034 .20296 m
.78703 .20296 L
s
.65034 .20296 m
.55369 .29962 L
s
.78703 .20296 m
.69038 .29962 L
s
.14362 .29962 m
.28031 .29962 L
s
.14362 .29962 m
.04697 .39627 L
s
.28031 .29962 m
.417 .29962 L
s
.28031 .29962 m
.18366 .39627 L
s
.417 .29962 m
.55369 .29962 L
s
.417 .29962 m
.32034 .39627 L
s
.55369 .29962 m
.69038 .29962 L
s
.55369 .29962 m
.45703 .39627 L
s
.69038 .29962 m
.82706 .29962 L
s
.69038 .29962 m
.59372 .39627 L
s
.82706 .29962 m
.73041 .39627 L
s
.04697 .39627 m
.18366 .39627 L
s
.18366 .39627 m
.32034 .39627 L
s
.18366 .39627 m
.087 .49292 L
s
.32034 .39627 m
.45703 .39627 L
s
.32034 .39627 m
.22369 .49292 L
s
.45703 .39627 m
.59372 .39627 L
s
.45703 .39627 m
.36038 .49292 L
s
.59372 .39627 m
.73041 .39627 L
s
.59372 .39627 m
.49707 .49292 L
s
.73041 .39627 m
.8671 .39627 L
s
.73041 .39627 m
.63376 .49292 L
s
.8671 .39627 m
.77045 .49292 L
s
.087 .49292 m
.22369 .49292 L
s
.22369 .49292 m
.36038 .49292 L
s
.22369 .49292 m
.12704 .58958 L
s
.36038 .49292 m
.49707 .49292 L
s
.36038 .49292 m
.26373 .58958 L
s
.49707 .49292 m
.63376 .49292 L
s
.49707 .49292 m
.40041 .58958 L
s
.63376 .49292 m
.77045 .49292 L
s
.63376 .49292 m
.5371 .58958 L
s
.77045 .49292 m
.90713 .49292 L
s
.77045 .49292 m
.67379 .58958 L
s
.90713 .49292 m
.81048 .58958 L
s
.12704 .58958 m
.26373 .58958 L
s
.26373 .58958 m
.40041 .58958 L
s
.26373 .58958 m
.16707 .68623 L
s
.40041 .58958 m
.5371 .58958 L
s
.40041 .58958 m
.30376 .68623 L
s
.5371 .58958 m
.67379 .58958 L
s
.5371 .58958 m
.44045 .68623 L
s
.67379 .58958 m
.81048 .58958 L
s
.67379 .58958 m
.57714 .68623 L
s
.81048 .58958 m
.94717 .58958 L
s
.81048 .58958 m
.71383 .68623 L
s
.94717 .58958 m
.85052 .68623 L
s
.16707 .68623 m
.30376 .68623 L
s
.30376 .68623 m
.44045 .68623 L
s
.30376 .68623 m
.20711 .78288 L
s
.44045 .68623 m
.57714 .68623 L
s
.44045 .68623 m
.3438 .78288 L
s
.57714 .68623 m
.71383 .68623 L
s
.57714 .68623 m
.48049 .78288 L
s
.71383 .68623 m
.85052 .68623 L
s
.71383 .68623 m
.61717 .78288 L
s
.85052 .68623 m
.75386 .78288 L
s
.20711 .78288 m
.3438 .78288 L
s
.3438 .78288 m
.48049 .78288 L
s
.3438 .78288 m
.24714 .87954 L
s
.48049 .78288 m
.61717 .78288 L
s
.48049 .78288 m
.38383 .87954 L
s
.61717 .78288 m
.75386 .78288 L
s
.61717 .78288 m
.52052 .87954 L
s
.75386 .78288 m
.89055 .78288 L
s
.75386 .78288 m
.65721 .87954 L
s
.89055 .78288 m
.7939 .87954 L
s
.24714 .87954 m
.38383 .87954 L
s
.38383 .87954 m
.52052 .87954 L
s
.52052 .87954 m
.65721 .87954 L
s
.52052 .87954 m
.42387 .97619 L
s
.65721 .87954 m
.7939 .87954 L
s
.65721 .87954 m
.56056 .97619 L
s
.42387 .97619 m
.56056 .97619 L
s
.7939 .12046 m
.89055 .21712 L
s
.7939 .12046 m
.65721 .12046 L
s
.89055 .21712 m
.75386 .21712 L
s
.56056 .02381 m
.65721 .12046 L
s
.56056 .02381 m
.42387 .02381 L
s
.65721 .12046 m
.75386 .21712 L
s
.65721 .12046 m
.52052 .12046 L
s
.75386 .21712 m
.85052 .31377 L
s
.75386 .21712 m
.61717 .21712 L
s
.85052 .31377 m
.94717 .41042 L
s
.85052 .31377 m
.71383 .31377 L
s
.94717 .41042 m
.81048 .41042 L
s
.42387 .02381 m
.52052 .12046 L
s
.52052 .12046 m
.61717 .21712 L
s
.52052 .12046 m
.38383 .12046 L
s
.61717 .21712 m
.71383 .31377 L
s
.61717 .21712 m
.48049 .21712 L
s
.71383 .31377 m
.81048 .41042 L
s
.71383 .31377 m
.57714 .31377 L
s
.81048 .41042 m
.90713 .50708 L
s
.81048 .41042 m
.67379 .41042 L
s
.90713 .50708 m
.77045 .50708 L
s
.38383 .12046 m
.48049 .21712 L
s
.38383 .12046 m
.24714 .12046 L
s
.48049 .21712 m
.57714 .31377 L
s
.48049 .21712 m
.3438 .21712 L
s
.57714 .31377 m
.67379 .41042 L
s
.57714 .31377 m
.44045 .31377 L
s
.67379 .41042 m
.77045 .50708 L
s
.67379 .41042 m
.5371 .41042 L
s
.77045 .50708 m
.8671 .60373 L
s
.77045 .50708 m
.63376 .50708 L
s
.8671 .60373 m
.73041 .60373 L
s
.24714 .12046 m
.3438 .21712 L
s
.3438 .21712 m
.44045 .31377 L
s
.3438 .21712 m
.20711 .21712 L
s
.44045 .31377 m
.5371 .41042 L
s
.44045 .31377 m
.30376 .31377 L
s
.5371 .41042 m
.63376 .50708 L
s
.5371 .41042 m
.40041 .41042 L
s
.63376 .50708 m
.73041 .60373 L
s
.63376 .50708 m
.49707 .50708 L
s
.73041 .60373 m
.82706 .70038 L
s
.73041 .60373 m
.59372 .60373 L
s
.82706 .70038 m
.69038 .70038 L
s
.20711 .21712 m
.30376 .31377 L
s
.30376 .31377 m
.40041 .41042 L
s
.30376 .31377 m
.16707 .31377 L
s
.40041 .41042 m
.49707 .50708 L
s
.40041 .41042 m
.26373 .41042 L
s
.49707 .50708 m
.59372 .60373 L
s
.49707 .50708 m
.36038 .50708 L
s
.59372 .60373 m
.69038 .70038 L
s
.59372 .60373 m
.45703 .60373 L
s
.69038 .70038 m
.78703 .79704 L
s
.69038 .70038 m
.55369 .70038 L
s
.78703 .79704 m
.65034 .79704 L
s
.16707 .31377 m
.26373 .41042 L
s
.26373 .41042 m
.36038 .50708 L
s
.26373 .41042 m
.12704 .41042 L
s
.36038 .50708 m
.45703 .60373 L
s
.36038 .50708 m
.22369 .50708 L
s
.45703 .60373 m
.55369 .70038 L
s
.45703 .60373 m
.32034 .60373 L
s
.55369 .70038 m
.65034 .79704 L
s
.55369 .70038 m
.417 .70038 L
s
.65034 .79704 m
.74699 .89369 L
s
.65034 .79704 m
.51365 .79704 L
s
.74699 .89369 m
.61031 .89369 L
s
.12704 .41042 m
.22369 .50708 L
s
.22369 .50708 m
.32034 .60373 L
s
.22369 .50708 m
.087 .50708 L
s
.32034 .60373 m
.417 .70038 L
s
.32034 .60373 m
.18366 .60373 L
s
.417 .70038 m
.51365 .79704 L
s
.417 .70038 m
.28031 .70038 L
s
.51365 .79704 m
.61031 .89369 L
s
.51365 .79704 m
.37696 .79704 L
s
.61031 .89369 m
.47362 .89369 L
s
.087 .50708 m
.18366 .60373 L
s
.18366 .60373 m
.28031 .70038 L
s
.18366 .60373 m
.04697 .60373 L
s
.28031 .70038 m
.37696 .79704 L
s
.28031 .70038 m
.14362 .70038 L
s
.37696 .79704 m
.47362 .89369 L
s
.37696 .79704 m
.24027 .79704 L
s
.47362 .89369 m
.33693 .89369 L
s
.04697 .60373 m
.14362 .70038 L
s
.14362 .70038 m
.24027 .79704 L
s
.24027 .79704 m
.33693 .89369 L
s
.66307 .05798 m
.75973 .15464 L
s
.66307 .05798 m
.52638 .05798 L
s
.75973 .15464 m
.85638 .25129 L
s
.75973 .15464 m
.62304 .15464 L
s
.85638 .25129 m
.95303 .34794 L
s
.85638 .25129 m
.71969 .25129 L
s
.95303 .34794 m
.81634 .34794 L
s
.52638 .05798 m
.62304 .15464 L
s
.52638 .05798 m
.38969 .05798 L
s
.62304 .15464 m
.71969 .25129 L
s
.62304 .15464 m
.48635 .15464 L
s
.71969 .25129 m
.81634 .34794 L
s
.71969 .25129 m
.583 .25129 L
s
.81634 .34794 m
.913 .4446 L
s
.81634 .34794 m
.67966 .34794 L
s
.913 .4446 m
.77631 .4446 L
s
.38969 .05798 m
.48635 .15464 L
s
.48635 .15464 m
.583 .25129 L
s
.48635 .15464 m
.34966 .15464 L
s
.583 .25129 m
.67966 .34794 L
s
.583 .25129 m
.44631 .25129 L
s
.67966 .34794 m
.77631 .4446 L
s
.67966 .34794 m
.54297 .34794 L
s
.77631 .4446 m
.87296 .54125 L
s
.77631 .4446 m
.63962 .4446 L
s
.87296 .54125 m
.73627 .54125 L
s
.34966 .15464 m
.44631 .25129 L
s
.34966 .15464 m
.21297 .15464 L
s
.44631 .25129 m
.54297 .34794 L
s
.44631 .25129 m
.30962 .25129 L
s
.54297 .34794 m
.63962 .4446 L
s
.54297 .34794 m
.40628 .34794 L
s
.63962 .4446 m
.73627 .54125 L
s
.63962 .4446 m
.50293 .4446 L
s
.73627 .54125 m
.83293 .6379 L
s
.73627 .54125 m
.59959 .54125 L
s
.83293 .6379 m
.69624 .6379 L
s
.21297 .15464 m
.30962 .25129 L
s
.30962 .25129 m
.40628 .34794 L
s
.30962 .25129 m
.17294 .25129 L
s
.40628 .34794 m
.50293 .4446 L
s
.40628 .34794 m
.26959 .34794 L
s
.50293 .4446 m
.59959 .54125 L
s
.50293 .4446 m
.36624 .4446 L
s
.59959 .54125 m
.69624 .6379 L
s
.59959 .54125 m
.4629 .54125 L
s
.69624 .6379 m
.79289 .73456 L
s
.69624 .6379 m
.55955 .6379 L
s
.79289 .73456 m
.6562 .73456 L
s
.17294 .25129 m
.26959 .34794 L
s
.26959 .34794 m
.36624 .4446 L
s
.26959 .34794 m
.1329 .34794 L
s
.36624 .4446 m
.4629 .54125 L
s
.36624 .4446 m
.22955 .4446 L
s
.4629 .54125 m
.55955 .6379 L
s
.4629 .54125 m
.32621 .54125 L
s
.55955 .6379 m
.6562 .73456 L
s
.55955 .6379 m
.42286 .6379 L
s
.6562 .73456 m
.75286 .83121 L
s
.6562 .73456 m
.51951 .73456 L
s
.75286 .83121 m
.61617 .83121 L
s
.1329 .34794 m
.22955 .4446 L
s
.22955 .4446 m
.32621 .54125 L
s
.22955 .4446 m
.09287 .4446 L
s
.32621 .54125 m
.42286 .6379 L
s
.32621 .54125 m
.18952 .54125 L
s
.42286 .6379 m
.51951 .73456 L
s
.42286 .6379 m
.28617 .6379 L
s
.51951 .73456 m
.61617 .83121 L
s
.51951 .73456 m
.38283 .73456 L
s
.61617 .83121 m
.71282 .92786 L
s
.61617 .83121 m
.47948 .83121 L
s
.71282 .92786 m
.57613 .92786 L
s
.09287 .4446 m
.18952 .54125 L
s
.18952 .54125 m
.28617 .6379 L
s
.18952 .54125 m
.05283 .54125 L
s
.28617 .6379 m
.38283 .73456 L
s
.28617 .6379 m
.14948 .6379 L
s
.38283 .73456 m
.47948 .83121 L
s
.38283 .73456 m
.24614 .73456 L
s
.47948 .83121 m
.57613 .92786 L
s
.47948 .83121 m
.34279 .83121 L
s
.57613 .92786 m
.43944 .92786 L
s
.05283 .54125 m
.14948 .6379 L
s
.14948 .6379 m
.24614 .73456 L
s
.24614 .73456 m
.34279 .83121 L
s
.24614 .73456 m
.10945 .73456 L
s
.34279 .83121 m
.43944 .92786 L
s
.34279 .83121 m
.2061 .83121 L
s
.43944 .92786 m
.30276 .92786 L
s
.10945 .73456 m
.2061 .83121 L
s
.2061 .83121 m
.30276 .92786 L
s
.69724 .07214 m
.7939 .16879 L
s
.69724 .07214 m
.56056 .07214 L
s
.7939 .16879 m
.89055 .26544 L
s
.7939 .16879 m
.65721 .16879 L
s
.89055 .26544 m
.75386 .26544 L
s
.56056 .07214 m
.65721 .16879 L
s
.56056 .07214 m
.42387 .07214 L
s
.65721 .16879 m
.75386 .26544 L
s
.65721 .16879 m
.52052 .16879 L
s
.75386 .26544 m
.85052 .3621 L
s
.75386 .26544 m
.61717 .26544 L
s
.85052 .3621 m
.94717 .45875 L
s
.85052 .3621 m
.71383 .3621 L
s
.94717 .45875 m
.81048 .45875 L
s
.42387 .07214 m
.52052 .16879 L
s
.42387 .07214 m
.28718 .07214 L
s
.52052 .16879 m
.61717 .26544 L
s
.52052 .16879 m
.38383 .16879 L
s
.61717 .26544 m
.71383 .3621 L
s
.61717 .26544 m
.48049 .26544 L
s
.71383 .3621 m
.81048 .45875 L
s
.71383 .3621 m
.57714 .3621 L
s
.81048 .45875 m
.90713 .5554 L
s
.81048 .45875 m
.67379 .45875 L
s
.90713 .5554 m
.77045 .5554 L
s
.28718 .07214 m
.38383 .16879 L
s
.38383 .16879 m
.48049 .26544 L
s
.38383 .16879 m
.24714 .16879 L
s
.48049 .26544 m
.57714 .3621 L
s
.48049 .26544 m
.3438 .26544 L
s
.57714 .3621 m
.67379 .45875 L
s
.57714 .3621 m
.44045 .3621 L
s
.67379 .45875 m
.77045 .5554 L
s
.67379 .45875 m
.5371 .45875 L
s
.77045 .5554 m
.8671 .65206 L
s
.77045 .5554 m
.63376 .5554 L
s
.8671 .65206 m
.73041 .65206 L
s
.24714 .16879 m
.3438 .26544 L
s
.3438 .26544 m
.44045 .3621 L
s
.3438 .26544 m
.20711 .26544 L
s
.44045 .3621 m
.5371 .45875 L
s
.44045 .3621 m
.30376 .3621 L
s
.5371 .45875 m
.63376 .5554 L
s
.5371 .45875 m
.40041 .45875 L
s
.63376 .5554 m
.73041 .65206 L
s
.63376 .5554 m
.49707 .5554 L
s
.73041 .65206 m
.82706 .74871 L
s
.73041 .65206 m
.59372 .65206 L
s
.82706 .74871 m
.69038 .74871 L
s
.20711 .26544 m
.30376 .3621 L
s
.30376 .3621 m
.40041 .45875 L
s
.30376 .3621 m
.16707 .3621 L
s
.40041 .45875 m
.49707 .5554 L
s
.40041 .45875 m
.26373 .45875 L
s
.49707 .5554 m
.59372 .65206 L
s
.49707 .5554 m
.36038 .5554 L
s
.59372 .65206 m
.69038 .74871 L
s
.59372 .65206 m
.45703 .65206 L
s
.69038 .74871 m
.78703 .84536 L
s
.69038 .74871 m
.55369 .74871 L
s
.78703 .84536 m
.65034 .84536 L
s
.16707 .3621 m
.26373 .45875 L
s
.26373 .45875 m
.36038 .5554 L
s
.26373 .45875 m
.12704 .45875 L
s
.36038 .5554 m
.45703 .65206 L
s
.36038 .5554 m
.22369 .5554 L
s
.45703 .65206 m
.55369 .74871 L
s
.45703 .65206 m
.32034 .65206 L
s
.55369 .74871 m
.65034 .84536 L
s
.55369 .74871 m
.417 .74871 L
s
.65034 .84536 m
.51365 .84536 L
s
.12704 .45875 m
.22369 .5554 L
s
.22369 .5554 m
.32034 .65206 L
s
.22369 .5554 m
.087 .5554 L
s
.32034 .65206 m
.417 .74871 L
s
.32034 .65206 m
.18366 .65206 L
s
.417 .74871 m
.51365 .84536 L
s
.417 .74871 m
.28031 .74871 L
s
.51365 .84536 m
.61031 .94202 L
s
.51365 .84536 m
.37696 .84536 L
s
.61031 .94202 m
.47362 .94202 L
s
.087 .5554 m
.18366 .65206 L
s
.18366 .65206 m
.28031 .74871 L
s
.18366 .65206 m
.04697 .65206 L
s
.28031 .74871 m
.37696 .84536 L
s
.28031 .74871 m
.14362 .74871 L
s
.37696 .84536 m
.47362 .94202 L
s
.37696 .84536 m
.24027 .84536 L
s
.47362 .94202 m
.33693 .94202 L
s
.04697 .65206 m
.14362 .74871 L
s
.14362 .74871 m
.24027 .84536 L
s
.24027 .84536 m
.33693 .94202 L
s
.66307 .10631 m
.75973 .20296 L
s
.66307 .10631 m
.52638 .10631 L
s
.75973 .20296 m
.85638 .29962 L
s
.75973 .20296 m
.62304 .20296 L
s
.85638 .29962 m
.95303 .39627 L
s
.85638 .29962 m
.71969 .29962 L
s
.95303 .39627 m
.81634 .39627 L
s
.52638 .10631 m
.62304 .20296 L
s
.52638 .10631 m
.38969 .10631 L
s
.62304 .20296 m
.71969 .29962 L
s
.62304 .20296 m
.48635 .20296 L
s
.71969 .29962 m
.81634 .39627 L
s
.71969 .29962 m
.583 .29962 L
s
.81634 .39627 m
.913 .49292 L
s
.81634 .39627 m
.67966 .39627 L
s
.913 .49292 m
.77631 .49292 L
s
.38969 .10631 m
.48635 .20296 L
s
.38969 .10631 m
.25301 .10631 L
s
.48635 .20296 m
.583 .29962 L
s
.48635 .20296 m
.34966 .20296 L
s
.583 .29962 m
.67966 .39627 L
s
.583 .29962 m
.44631 .29962 L
s
.67966 .39627 m
.77631 .49292 L
s
.67966 .39627 m
.54297 .39627 L
s
.77631 .49292 m
.87296 .58958 L
s
.77631 .49292 m
.63962 .49292 L
s
.87296 .58958 m
.73627 .58958 L
s
.25301 .10631 m
.34966 .20296 L
s
.34966 .20296 m
.44631 .29962 L
s
.34966 .20296 m
.21297 .20296 L
s
.44631 .29962 m
.54297 .39627 L
s
.44631 .29962 m
.30962 .29962 L
s
.54297 .39627 m
.63962 .49292 L
s
.54297 .39627 m
.40628 .39627 L
s
.63962 .49292 m
.73627 .58958 L
s
.63962 .49292 m
.50293 .49292 L
s
.73627 .58958 m
.83293 .68623 L
s
.73627 .58958 m
.59959 .58958 L
s
.83293 .68623 m
.69624 .68623 L
s
.21297 .20296 m
.30962 .29962 L
s
.30962 .29962 m
.40628 .39627 L
s
.30962 .29962 m
.17294 .29962 L
s
.40628 .39627 m
.50293 .49292 L
s
.40628 .39627 m
.26959 .39627 L
s
.50293 .49292 m
.59959 .58958 L
s
.50293 .49292 m
.36624 .49292 L
s
.59959 .58958 m
.69624 .68623 L
s
.59959 .58958 m
.4629 .58958 L
s
.69624 .68623 m
.79289 .78288 L
s
.69624 .68623 m
.55955 .68623 L
s
.79289 .78288 m
.6562 .78288 L
s
.17294 .29962 m
.26959 .39627 L
s
.26959 .39627 m
.36624 .49292 L
s
.26959 .39627 m
.1329 .39627 L
s
.36624 .49292 m
.4629 .58958 L
s
.36624 .49292 m
.22955 .49292 L
s
.4629 .58958 m
.55955 .68623 L
s
.4629 .58958 m
.32621 .58958 L
s
.55955 .68623 m
.6562 .78288 L
s
.55955 .68623 m
.42286 .68623 L
s
.6562 .78288 m
.75286 .87954 L
s
.6562 .78288 m
.51951 .78288 L
s
.75286 .87954 m
.61617 .87954 L
s
.1329 .39627 m
.22955 .49292 L
s
.22955 .49292 m
.32621 .58958 L
s
.22955 .49292 m
.09287 .49292 L
s
.32621 .58958 m
.42286 .68623 L
s
.32621 .58958 m
.18952 .58958 L
s
.42286 .68623 m
.51951 .78288 L
s
.42286 .68623 m
.28617 .68623 L
s
.51951 .78288 m
.61617 .87954 L
s
.51951 .78288 m
.38283 .78288 L
s
.61617 .87954 m
.47948 .87954 L
s
.09287 .49292 m
.18952 .58958 L
s
.18952 .58958 m
.28617 .68623 L
s
.18952 .58958 m
.05283 .58958 L
s
.28617 .68623 m
.38283 .78288 L
s
.28617 .68623 m
.14948 .68623 L
s
.38283 .78288 m
.47948 .87954 L
s
.38283 .78288 m
.24614 .78288 L
s
.47948 .87954 m
.57613 .97619 L
s
.47948 .87954 m
.34279 .87954 L
s
.57613 .97619 m
.43944 .97619 L
s
.05283 .58958 m
.14948 .68623 L
s
.14948 .68623 m
.24614 .78288 L
s
.24614 .78288 m
.34279 .87954 L
s
.24614 .78288 m
.10945 .78288 L
s
.34279 .87954 m
.43944 .97619 L
s
.34279 .87954 m
.2061 .87954 L
s
.10945 .78288 m
.2061 .87954 L
s
.73456 .10945 m
.83121 .2061 L
s
.73456 .10945 m
.73456 .24614 L
s
.83121 .2061 m
.92786 .30276 L
s
.83121 .2061 m
.83121 .34279 L
s
.92786 .30276 m
.92786 .43944 L
s
.54125 .05283 m
.6379 .14948 L
s
.54125 .05283 m
.54125 .18952 L
s
.6379 .14948 m
.73456 .24614 L
s
.6379 .14948 m
.6379 .28617 L
s
.73456 .24614 m
.83121 .34279 L
s
.73456 .24614 m
.73456 .38283 L
s
.83121 .34279 m
.92786 .43944 L
s
.83121 .34279 m
.83121 .47948 L
s
.92786 .43944 m
.92786 .57613 L
s
.4446 .09287 m
.54125 .18952 L
s
.4446 .09287 m
.4446 .22955 L
s
.54125 .18952 m
.6379 .28617 L
s
.54125 .18952 m
.54125 .32621 L
s
.6379 .28617 m
.73456 .38283 L
s
.6379 .28617 m
.6379 .42286 L
s
.73456 .38283 m
.83121 .47948 L
s
.73456 .38283 m
.73456 .51951 L
s
.83121 .47948 m
.92786 .57613 L
s
.83121 .47948 m
.83121 .61617 L
s
.92786 .57613 m
.92786 .71282 L
s
.34794 .1329 m
.4446 .22955 L
s
.34794 .1329 m
.34794 .26959 L
s
.4446 .22955 m
.54125 .32621 L
s
.4446 .22955 m
.4446 .36624 L
s
.54125 .32621 m
.6379 .42286 L
s
.54125 .32621 m
.54125 .4629 L
s
.6379 .42286 m
.73456 .51951 L
s
.6379 .42286 m
.6379 .55955 L
s
.73456 .51951 m
.83121 .61617 L
s
.73456 .51951 m
.73456 .6562 L
s
.83121 .61617 m
.92786 .71282 L
s
.83121 .61617 m
.83121 .75286 L
s
.25129 .17294 m
.34794 .26959 L
s
.25129 .17294 m
.25129 .30962 L
s
.34794 .26959 m
.4446 .36624 L
s
.34794 .26959 m
.34794 .40628 L
s
.4446 .36624 m
.54125 .4629 L
s
.4446 .36624 m
.4446 .50293 L
s
.54125 .4629 m
.6379 .55955 L
s
.54125 .4629 m
.54125 .59959 L
s
.6379 .55955 m
.73456 .6562 L
s
.6379 .55955 m
.6379 .69624 L
s
.73456 .6562 m
.83121 .75286 L
s
.73456 .6562 m
.73456 .79289 L
s
.15464 .21297 m
.25129 .30962 L
s
.15464 .21297 m
.15464 .34966 L
s
.25129 .30962 m
.34794 .40628 L
s
.25129 .30962 m
.25129 .44631 L
s
.34794 .40628 m
.4446 .50293 L
s
.34794 .40628 m
.34794 .54297 L
s
.4446 .50293 m
.54125 .59959 L
s
.4446 .50293 m
.4446 .63962 L
s
.54125 .59959 m
.6379 .69624 L
s
.54125 .59959 m
.54125 .73627 L
s
.6379 .69624 m
.73456 .79289 L
s
.6379 .69624 m
.6379 .83293 L
s
.15464 .34966 m
.25129 .44631 L
s
.15464 .34966 m
.15464 .48635 L
s
.25129 .44631 m
.34794 .54297 L
s
.25129 .44631 m
.25129 .583 L
s
.34794 .54297 m
.4446 .63962 L
s
.34794 .54297 m
.34794 .67966 L
s
.4446 .63962 m
.54125 .73627 L
s
.4446 .63962 m
.4446 .77631 L
s
.54125 .73627 m
.6379 .83293 L
s
.54125 .73627 m
.54125 .87296 L
s
.05798 .38969 m
.15464 .48635 L
s
.05798 .38969 m
.05798 .52638 L
s
.15464 .48635 m
.25129 .583 L
s
.15464 .48635 m
.15464 .62304 L
s
.25129 .583 m
.34794 .67966 L
s
.25129 .583 m
.25129 .71969 L
s
.34794 .67966 m
.4446 .77631 L
s
.34794 .67966 m
.34794 .81634 L
s
.4446 .77631 m
.54125 .87296 L
s
.4446 .77631 m
.4446 .913 L
s
.05798 .52638 m
.15464 .62304 L
s
.05798 .52638 m
.05798 .66307 L
s
.15464 .62304 m
.25129 .71969 L
s
.15464 .62304 m
.15464 .75973 L
s
.25129 .71969 m
.34794 .81634 L
s
.25129 .71969 m
.25129 .85638 L
s
.34794 .81634 m
.4446 .913 L
s
.34794 .81634 m
.34794 .95303 L
s
.05798 .66307 m
.15464 .75973 L
s
.15464 .75973 m
.25129 .85638 L
s
.25129 .85638 m
.34794 .95303 L
s
.60373 .04697 m
.70038 .14362 L
s
.60373 .04697 m
.60373 .18366 L
s
.70038 .14362 m
.79704 .24027 L
s
.70038 .14362 m
.70038 .28031 L
s
.79704 .24027 m
.89369 .33693 L
s
.79704 .24027 m
.79704 .37696 L
s
.89369 .33693 m
.89369 .47362 L
s
.50708 .087 m
.60373 .18366 L
s
.50708 .087 m
.50708 .22369 L
s
.60373 .18366 m
.70038 .28031 L
s
.60373 .18366 m
.60373 .32034 L
s
.70038 .28031 m
.79704 .37696 L
s
.70038 .28031 m
.70038 .417 L
s
.79704 .37696 m
.89369 .47362 L
s
.79704 .37696 m
.79704 .51365 L
s
.89369 .47362 m
.89369 .61031 L
s
.41042 .12704 m
.50708 .22369 L
s
.41042 .12704 m
.41042 .26373 L
s
.50708 .22369 m
.60373 .32034 L
s
.50708 .22369 m
.50708 .36038 L
s
.60373 .32034 m
.70038 .417 L
s
.60373 .32034 m
.60373 .45703 L
s
.70038 .417 m
.79704 .51365 L
s
.70038 .417 m
.70038 .55369 L
s
.79704 .51365 m
.89369 .61031 L
s
.79704 .51365 m
.79704 .65034 L
s
.89369 .61031 m
.89369 .74699 L
s
.31377 .16707 m
.41042 .26373 L
s
.31377 .16707 m
.31377 .30376 L
s
.41042 .26373 m
.50708 .36038 L
s
.41042 .26373 m
.41042 .40041 L
s
.50708 .36038 m
.60373 .45703 L
s
.50708 .36038 m
.50708 .49707 L
s
.60373 .45703 m
.70038 .55369 L
s
.60373 .45703 m
.60373 .59372 L
s
.70038 .55369 m
.79704 .65034 L
s
.70038 .55369 m
.70038 .69038 L
s
.79704 .65034 m
.89369 .74699 L
s
.79704 .65034 m
.79704 .78703 L
s
.21712 .20711 m
.31377 .30376 L
s
.21712 .20711 m
.21712 .3438 L
s
.31377 .30376 m
.41042 .40041 L
s
.31377 .30376 m
.31377 .44045 L
s
.41042 .40041 m
.50708 .49707 L
s
.41042 .40041 m
.41042 .5371 L
s
.50708 .49707 m
.60373 .59372 L
s
.50708 .49707 m
.50708 .63376 L
s
.60373 .59372 m
.70038 .69038 L
s
.60373 .59372 m
.60373 .73041 L
s
.70038 .69038 m
.79704 .78703 L
s
.70038 .69038 m
.70038 .82706 L
s
.12046 .24714 m
.21712 .3438 L
s
.12046 .24714 m
.12046 .38383 L
s
.21712 .3438 m
.31377 .44045 L
s
.21712 .3438 m
.21712 .48049 L
s
.31377 .44045 m
.41042 .5371 L
s
.31377 .44045 m
.31377 .57714 L
s
.41042 .5371 m
.50708 .63376 L
s
.41042 .5371 m
.41042 .67379 L
s
.50708 .63376 m
.60373 .73041 L
s
.50708 .63376 m
.50708 .77045 L
s
.60373 .73041 m
.70038 .82706 L
s
.60373 .73041 m
.60373 .8671 L
s
.12046 .38383 m
.21712 .48049 L
s
.12046 .38383 m
.12046 .52052 L
s
.21712 .48049 m
.31377 .57714 L
s
.21712 .48049 m
.21712 .61717 L
s
.31377 .57714 m
.41042 .67379 L
s
.31377 .57714 m
.31377 .71383 L
s
.41042 .67379 m
.50708 .77045 L
s
.41042 .67379 m
.41042 .81048 L
s
.50708 .77045 m
.60373 .8671 L
s
.50708 .77045 m
.50708 .90713 L
s
.02381 .42387 m
.12046 .52052 L
s
.02381 .42387 m
.02381 .56056 L
s
.12046 .52052 m
.21712 .61717 L
s
.12046 .52052 m
.12046 .65721 L
s
.21712 .61717 m
.31377 .71383 L
s
.21712 .61717 m
.21712 .75386 L
s
.31377 .71383 m
.41042 .81048 L
s
.31377 .71383 m
.31377 .85052 L
s
.41042 .81048 m
.50708 .90713 L
s
.41042 .81048 m
.41042 .94717 L
s
.02381 .56056 m
.12046 .65721 L
s
.12046 .65721 m
.21712 .75386 L
s
.12046 .65721 m
.12046 .7939 L
s
.21712 .75386 m
.31377 .85052 L
s
.21712 .75386 m
.21712 .89055 L
s
.31377 .85052 m
.41042 .94717 L
s
.12046 .7939 m
.21712 .89055 L
s
.78288 .10945 m
.87954 .2061 L
s
.78288 .10945 m
.78288 .24614 L
s
.87954 .2061 m
.87954 .34279 L
s
.58958 .05283 m
.68623 .14948 L
s
.58958 .05283 m
.58958 .18952 L
s
.68623 .14948 m
.78288 .24614 L
s
.68623 .14948 m
.68623 .28617 L
s
.78288 .24614 m
.87954 .34279 L
s
.78288 .24614 m
.78288 .38283 L
s
.87954 .34279 m
.97619 .43944 L
s
.87954 .34279 m
.87954 .47948 L
s
.97619 .43944 m
.97619 .57613 L
s
.49292 .09287 m
.58958 .18952 L
s
.49292 .09287 m
.49292 .22955 L
s
.58958 .18952 m
.68623 .28617 L
s
.58958 .18952 m
.58958 .32621 L
s
.68623 .28617 m
.78288 .38283 L
s
.68623 .28617 m
.68623 .42286 L
s
.78288 .38283 m
.87954 .47948 L
s
.78288 .38283 m
.78288 .51951 L
s
.87954 .47948 m
.97619 .57613 L
s
.87954 .47948 m
.87954 .61617 L
s
.39627 .1329 m
.49292 .22955 L
s
.39627 .1329 m
.39627 .26959 L
s
.49292 .22955 m
.58958 .32621 L
s
.49292 .22955 m
.49292 .36624 L
s
.58958 .32621 m
.68623 .42286 L
s
.58958 .32621 m
.58958 .4629 L
s
.68623 .42286 m
.78288 .51951 L
s
.68623 .42286 m
.68623 .55955 L
s
.78288 .51951 m
.87954 .61617 L
s
.78288 .51951 m
.78288 .6562 L
s
.87954 .61617 m
.87954 .75286 L
s
.29962 .17294 m
.39627 .26959 L
s
.29962 .17294 m
.29962 .30962 L
s
.39627 .26959 m
.49292 .36624 L
s
.39627 .26959 m
.39627 .40628 L
s
.49292 .36624 m
.58958 .4629 L
s
.49292 .36624 m
.49292 .50293 L
s
.58958 .4629 m
.68623 .55955 L
s
.58958 .4629 m
.58958 .59959 L
s
.68623 .55955 m
.78288 .6562 L
s
.68623 .55955 m
.68623 .69624 L
s
.78288 .6562 m
.87954 .75286 L
s
.78288 .6562 m
.78288 .79289 L
s
.20296 .21297 m
.29962 .30962 L
s
.20296 .21297 m
.20296 .34966 L
s
.29962 .30962 m
.39627 .40628 L
s
.29962 .30962 m
.29962 .44631 L
s
.39627 .40628 m
.49292 .50293 L
s
.39627 .40628 m
.39627 .54297 L
s
.49292 .50293 m
.58958 .59959 L
s
.49292 .50293 m
.49292 .63962 L
s
.58958 .59959 m
.68623 .69624 L
s
.58958 .59959 m
.58958 .73627 L
s
.68623 .69624 m
.78288 .79289 L
s
.68623 .69624 m
.68623 .83293 L
s
.10631 .25301 m
.20296 .34966 L
s
.10631 .25301 m
.10631 .38969 L
s
.20296 .34966 m
.29962 .44631 L
s
.20296 .34966 m
.20296 .48635 L
s
.29962 .44631 m
.39627 .54297 L
s
.29962 .44631 m
.29962 .583 L
s
.39627 .54297 m
.49292 .63962 L
s
.39627 .54297 m
.39627 .67966 L
s
.49292 .63962 m
.58958 .73627 L
s
.49292 .63962 m
.49292 .77631 L
s
.58958 .73627 m
.68623 .83293 L
s
.58958 .73627 m
.58958 .87296 L
s
.10631 .38969 m
.20296 .48635 L
s
.10631 .38969 m
.10631 .52638 L
s
.20296 .48635 m
.29962 .583 L
s
.20296 .48635 m
.20296 .62304 L
s
.29962 .583 m
.39627 .67966 L
s
.29962 .583 m
.29962 .71969 L
s
.39627 .67966 m
.49292 .77631 L
s
.39627 .67966 m
.39627 .81634 L
s
.49292 .77631 m
.58958 .87296 L
s
.49292 .77631 m
.49292 .913 L
s
.10631 .52638 m
.20296 .62304 L
s
.10631 .52638 m
.10631 .66307 L
s
.20296 .62304 m
.29962 .71969 L
s
.20296 .62304 m
.20296 .75973 L
s
.29962 .71969 m
.39627 .81634 L
s
.29962 .71969 m
.29962 .85638 L
s
.39627 .81634 m
.49292 .913 L
s
.39627 .81634 m
.39627 .95303 L
s
.10631 .66307 m
.20296 .75973 L
s
.20296 .75973 m
.29962 .85638 L
s
.29962 .85638 m
.39627 .95303 L
s
.65206 .04697 m
.74871 .14362 L
s
.65206 .04697 m
.65206 .18366 L
s
.74871 .14362 m
.84536 .24027 L
s
.74871 .14362 m
.74871 .28031 L
s
.84536 .24027 m
.94202 .33693 L
s
.84536 .24027 m
.84536 .37696 L
s
.94202 .33693 m
.94202 .47362 L
s
.5554 .087 m
.65206 .18366 L
s
.5554 .087 m
.5554 .22369 L
s
.65206 .18366 m
.74871 .28031 L
s
.65206 .18366 m
.65206 .32034 L
s
.74871 .28031 m
.84536 .37696 L
s
.74871 .28031 m
.74871 .417 L
s
.84536 .37696 m
.94202 .47362 L
s
.84536 .37696 m
.84536 .51365 L
s
.94202 .47362 m
.94202 .61031 L
s
.45875 .12704 m
.5554 .22369 L
s
.45875 .12704 m
.45875 .26373 L
s
.5554 .22369 m
.65206 .32034 L
s
.5554 .22369 m
.5554 .36038 L
s
.65206 .32034 m
.74871 .417 L
s
.65206 .32034 m
.65206 .45703 L
s
.74871 .417 m
.84536 .51365 L
s
.74871 .417 m
.74871 .55369 L
s
.84536 .51365 m
.94202 .61031 L
s
.84536 .51365 m
.84536 .65034 L
s
.3621 .16707 m
.45875 .26373 L
s
.3621 .16707 m
.3621 .30376 L
s
.45875 .26373 m
.5554 .36038 L
s
.45875 .26373 m
.45875 .40041 L
s
.5554 .36038 m
.65206 .45703 L
s
.5554 .36038 m
.5554 .49707 L
s
.65206 .45703 m
.74871 .55369 L
s
.65206 .45703 m
.65206 .59372 L
s
.74871 .55369 m
.84536 .65034 L
s
.74871 .55369 m
.74871 .69038 L
s
.84536 .65034 m
.84536 .78703 L
s
.26544 .20711 m
.3621 .30376 L
s
.26544 .20711 m
.26544 .3438 L
s
.3621 .30376 m
.45875 .40041 L
s
.3621 .30376 m
.3621 .44045 L
s
.45875 .40041 m
.5554 .49707 L
s
.45875 .40041 m
.45875 .5371 L
s
.5554 .49707 m
.65206 .59372 L
s
.5554 .49707 m
.5554 .63376 L
s
.65206 .59372 m
.74871 .69038 L
s
.65206 .59372 m
.65206 .73041 L
s
.74871 .69038 m
.84536 .78703 L
s
.74871 .69038 m
.74871 .82706 L
s
.16879 .24714 m
.26544 .3438 L
s
.16879 .24714 m
.16879 .38383 L
s
.26544 .3438 m
.3621 .44045 L
s
.26544 .3438 m
.26544 .48049 L
s
.3621 .44045 m
.45875 .5371 L
s
.3621 .44045 m
.3621 .57714 L
s
.45875 .5371 m
.5554 .63376 L
s
.45875 .5371 m
.45875 .67379 L
s
.5554 .63376 m
.65206 .73041 L
s
.5554 .63376 m
.5554 .77045 L
s
.65206 .73041 m
.74871 .82706 L
s
.65206 .73041 m
.65206 .8671 L
s
.07214 .28718 m
.16879 .38383 L
s
.07214 .28718 m
.07214 .42387 L
s
.16879 .38383 m
.26544 .48049 L
s
.16879 .38383 m
.16879 .52052 L
s
.26544 .48049 m
.3621 .57714 L
s
.26544 .48049 m
.26544 .61717 L
s
.3621 .57714 m
.45875 .67379 L
s
.3621 .57714 m
.3621 .71383 L
s
.45875 .67379 m
.5554 .77045 L
s
.45875 .67379 m
.45875 .81048 L
s
.5554 .77045 m
.65206 .8671 L
s
.5554 .77045 m
.5554 .90713 L
s
.07214 .42387 m
.16879 .52052 L
s
.07214 .42387 m
.07214 .56056 L
s
.16879 .52052 m
.26544 .61717 L
s
.16879 .52052 m
.16879 .65721 L
s
.26544 .61717 m
.3621 .71383 L
s
.26544 .61717 m
.26544 .75386 L
s
.3621 .71383 m
.45875 .81048 L
s
.3621 .71383 m
.3621 .85052 L
s
.45875 .81048 m
.5554 .90713 L
s
.45875 .81048 m
.45875 .94717 L
s
.07214 .56056 m
.16879 .65721 L
s
.07214 .56056 m
.07214 .69724 L
s
.16879 .65721 m
.26544 .75386 L
s
.16879 .65721 m
.16879 .7939 L
s
.26544 .75386 m
.3621 .85052 L
s
.26544 .75386 m
.26544 .89055 L
s
.3621 .85052 m
.45875 .94717 L
s
.07214 .69724 m
.16879 .7939 L
s
.16879 .7939 m
.26544 .89055 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;RLW9b40<?oo_`00?g=cLda<C820P8NZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmo
OiB;WMKBg2XX;H=kRhjYUM3KddiMD^GQY9no_m[ViUY]KD=EIB4Z<M_Vkl?Ei6F0V;2^]4U5CX61PFYo
L4mOGbL_;n;/k<oOggN?ShRZVHEhU000O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o
002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmo
Ocmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?glo
Oglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0
_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo
_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo
?oooOlS3cdDnCFmlS[g3bcU0B]C>N7j0VLG6dD52Cf]]PW5VO]_Ggd8lBVIbVOoo0_oo1mWIhEiPLko0
c3m0C1lO9FAJKk>ic=;EhC<iC1TL9DaELeioI[C3]c11=?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L007T7;@1j1`00NPL010071`0S1`0400L707/7001k1`809@L207`7001k1`80
9@L207`7001j1`0400L702<700@01`L0N`L007T700<01`L00PL00`071`0O1`0300L7008700<01`L0
N0L007P700<01`L010L00`071`0M1`0300L700@700<01`L0M`L006<700<01`L02`L00`071`031`03
00L700H700<01`L06`L00`071`061`0300L700<700<01`L02`L00`071`1R1`00HPL200`70P041`03
00L700P700<01`L06@L00`071`081`0300L700870P0<1`80H`L0064700<01`002`L00`0700031`03
00L700X70P0G1`8030L01`071`L01`002`L00`07001R1`00H0MO0647001O1`0500L71`002@L00`07
1`0200041`0700/700H01`001`0A1`0600L000L02`L0100700L2008700<01`L01`L01@071`L00607
001N1`0300L7008700<01`L01PL00`071`021`800PL00`071`081`0600L700L04`L00`0700021`03
00L700P700<01`L00P041`0300L700H700<01`L00PL00`071`1M1`00G@L00`071`031`0300L700D7
00<01`L00`L2008700<01`L01`L010071`L200031`07010700@01`000`L00`071`071`0300L70080
1@L00`071`051`0300L700<700<01`L0G0L00587N`1C1`00D`L00`0700051`0300L700D700<01`L0
0`L00`071`031`0300L000870P041`0400L700@70P041`0300L700/700<01`L00PL200@700@01`L0
10L2008700<01`001@L00`071`031`0300L700D700<01`L00`L00`07001D1`00E0L00`071`031`03
00L700H700<01`L00PL00`071`031`0400L700<700<01`L00`L200@700<01`001@L00`071`091`03
00L700<700<01`0010L200D700D01`L700021`0300L700<700<01`L00PL00`071`061`0300L700<7
00<01`L0D`L005<700<01`000`L00`071`071`0500L71`001@L01@071`L000<70P041`800`L01007
1`061`0300L700L700<01`L010L010071`031`8010L200<700D01`L700051`0500L71`002@L01`07
1`L01`00E0L0058700L01`L700L000X700@01`L01@L00`071`021`0700L71`0700021`0600L700L0
0`L00`071`051`0300L000<700<01`001`L01`071`L01`000PL01P071`0700<700<01`L00PL00`07
1`031`0400L700X700<01`000`L00`071`1A1`00D@L00`071`031`0300L700T700<01`001@L00`07
1`031`0500L71`000PL200@70P031`0300L700H70P031`8020L010071`L200@70P021`0500L71`00
1@L00`071`031`0300L000/700<01`L00`L00`071`1@1`00D0L00`071`031`0300L000X70P051`03
00L700@700D01`L700021`800`L00`0700031`0300L700D700<01`000`L00`0700071`0700L71`07
00031`800PL01@071`L000H700<01`L00`L200X700<01`001@L00`071`1?1`00C`L00`071`031`80
0PL00`071`071`0300L700<700<01`L01@L01`071`L01`000PL00`0700021`800PL00`071`041`03
00L7008000<700000PL00`071`041`0300L700800PL00`0700021`0300L000<700<01`L01@L00`07
1`031`0300L700L700<01`L00P051`0300L704h7001>1`0300L700<70P041`0300L700D70P041`03
00L700H700@01`L70P041`0900L71`0700L000D700T01`L700L01`000`L00`071`031`0500L01`00
0`L00`071`021`800`L00`071`061`0300L700870P071`0300L700870P051`0300L704d7001=1`03
00L700<70P061`0300L700<700<01`000`L00`071`071`0300L7008010L00`0700021`0300L70080
10L00`071`021`8000<7000010L00`071`021`800PL01P071`0700@70P021`0300L700L700L01`L7
00L000D700<01`L010L200D700<01`L0C0L004P7S`191`00?PL00`071`081`0400L000@70P0:1`03
00L000<700<01`002PL400041`071`8010L200<70P000`L01`041`800`L200D700@01`000`L200@7
0P021`0300L000<02PL00`0700031`0300L000X70P041`8000<700L02@L00`071`0m1`00?@L200/7
0`031`8030L00`071`021`8030L2008700@01`001PL01`071`L01`001@L00`0700031`0300L000D7
00<01`000`L00`071`041`8000@700L70P0<1`8010L00`071`0:1`800`L300/70P0n1`00?0L00`07
000:1`@00PL200`700<01`000`L00`071`0:1`<00PL300L70P021`8000<700L00PL010071`031`04
00L700<700@01`000PL200L70`021`<030L01`071`L01`0030L20087100:1`0300L003d7000k1jT0
?0L003X700D01`L700081`800`L300`700<01`L00`L00`07000:1`8000@700L70P091`0300L70080
10L00`071`021`0500L71`0010L00`071`021`800PL00`071`071`800PL01007000:1`0300L000D7
00<01`L02PL300<70P081`0500L71`00>`L003T700<01`L00PL00`071`061`800`L300/700<01`L0
0`L0100700091`8000@700070`091`0500L01`000`L00`0700031`0500L71`000`L00`0700031`05
00L01`002@L300041`001`802@L200031`0700@700<01`L02@L300<70P081`0300L7008700<01`L0
>0L003P700<01`L00`L00`071`051`0500L700L00P021`0300L700L700<01`L00`L01@071`L000P7
0P031`<000<7000020L200870P000`L01`021`0400L700<700@01`L00`L0100700021`8020L20004
1`0000<70P081`0500L71`001@L00`071`071`0300L7008000D700L700071`0300L700<700<01`L0
=`L003L700<01`L010L00`071`041`0300L700870`031`0300L700D700<01`L00`L00`071`021`80
1PL200@70P021`0300L000L700L01`L700L000D700<01`000`L00`0700051`0300L000<700<01`L0
1@L00`0700021`8010L200H70P041`0300L700<700<01`L01@L010071`L300@700<01`L010L00`07
1`041`0300L703H7000f1`0300L700D700<01`L00`L00`071`021`@010L00`071`031`0300L700<7
00<01`L00`L300@70P041`@000D700L700051`800`L200031`0700@70P031`801@L0100700031`80
1@L01@071`0700@010L200@70`051`0300L700<700<01`L00`L00`071`021`@010L00`071`031`03
00L700D700<01`L0=@L003D700<01`L01PL00`071`021`0300L700870P021`0300L700<700D01`L7
00051`0300L700@700@01`000PL200@70`0010L000031`0700L71`0700031`0500L71`001@L01@07
1`L000D700D01`L700031`0300L000<700@01`L70`0010L000041`800PL200031`0700D700<01`L0
0`L01@071`L000D700<01`L00P041`0300L7008700<01`L01PL00`071`0d1`00=0L00`071`071`05
00L71`0010L200<70P051`0300L000D700<01`L01@L00`071`0400@70P0010L01`L200@700<01`00
0PL00`071`0200@700<01`L00PL200031`0000@700<01`L00PL2008700H01`L01`041`800PL01007
00041`@00PL00`071`051`0300L700<700<01`001@L200<70P041`0500L71`002@L00`071`0c1`00
<`L00`071`081`0400L700@70`031`0300L000D70P041`0300L700H700@01`L70P041`800PL01007
1`L200@700T01`L700L01`001@L02@071`L01`0700031`0300L700<700D01`0700031`0300L70087
0P031`0300L7008010L200<700<01`L01PL00`071`021`801@L00`0700031`<010L010071`0:1`03
00L70387000b1`0300L700T700<01`0010L200031`07008700@01`L00`L00`0700031`8020L00`07
1`0400870P031`0400L71`<00PL00`0700021`800PL00`071`041`0300L7008000<700000PL00`07
1`041`0300L700800PL00`0700021`<00`L010071`L2008710021`0300L700H70P031`0300L000<7
00@01`L00`L0100700041`0300L000/700<01`L0<@L0034700<01`L02@NU00/700<01`L0<0L00307
00<01`L02`L00`071`021`800`L01@071`L000@700L01`L700L0008700<01`L01PL300041`071`80
1@L01@071`L000870P041`800`L00`071`061`800`L200P700@01`L70P041`800PL01@071`L000D7
0P021`0300L0008020L01P071`0700<700<01`L00PL01@071`L000<70P041`0300L700/700<01`L0
;`L002l700<01`L02`L300870P041`0500L71`000`L00`0700021`8000@700L020L200041`001`@0
10L01P071`L01`@00PL00`0700031`0300L700D700<01`000`L00`0700071`0700L71`0700021`@0
00<700L00PL00`071`021`@000@700070P081`0400L01`800PL00`0700031`0500L71`0010L20087
0`0=1`0300L702h7000^1`0300L700/700@01`070`051`0500L71`000PL01`071`L01`000`L200L7
0P031`<00PL200<700@01`L70`021`<00PL2008700<01`L010L00`071`0200031`00008700<01`L0
10L00`071`0200870`021`<00`L010071`L200870`031`801`L200<700<01`000`L010071`031`03
00L700<70`0010L01`0=1`0300L702d7000]1`0300L700/7Z@0=1`0300L702`7000/1`0300L700/7
00@01`L70`000`L01`031`800`L200D700<01`0010L300<70P0010L01`L200031`0700<70P0010L0
1`L200@700<01`000PL00`071`0200@700<01`L00PL200031`0000@700<01`L00PL2008700H01`L0
1`041`800PL0100700041`0400L0008700@01`000`L300@700<01`001@L200<70P041`0300L00080
0`L00`071`0;1`0300L702/7000[1`0300L700/700<01`L00PL200<700<01`L00PL2008700<01`L0
0`L00`071`0200<700D01`001`02008700<01`000P021`0300L700870`0010L000031`0700L71`07
00031`0500L71`001@L01@071`L000D700D01`L700031`0300L000<700@01`L70`0010L000041`03
00L700<000@700L70P001@L000L000<70P021`0300L700<700<01`L00P041`0400L71`8010L00`07
1`0;1`0300L702X7000Z1`0300L700/700<01`L00PL200D700@01`L71@041`0700L71`0700021`03
00L700<00`L300031`07008700<01`L00PL400051`071`001@L200<70P000`L01`041`800`L200D7
00@01`000`L200D700D01`L01`0400@700H01`L700L300<70`021`0600L700L00`L00`071`021`D0
0`L00`071`031`8010L00`071`0;1`0300L702T7000Y1`0300L700/700<01`L00PL300H700D01`L0
1`0300<700<01`L00PL01P071`0700870`031`800PL00`071`021`0300L700870P021`0300L000L7
0P021`0300L000D700<01`000`L00`0700051`0300L000870P071`0300L000870P041`0300L70087
00<01`L00P031`<00PL00`0700021`0300L7008700@01`L70`001@L01`L000H70`041`0300L700/7
00<01`L0:0L002P700<01`L02`L00`071`021`8000<700L01PL01@07000700800PL00`071`031`04
00L71`8000@700070P000`L000031`0300L700<700<01`L00P000`L01`0200P70`001@L000L000<7
00@01`L00`L010071`031`0500L000L00`081`8000<700L00P021`0300L700<700@01`L70P0010L0
00L200031`0000<700<01`L00`L00`071`0200051`001`001`L0100700041`0300L700/700<01`L0
9`L002L700<01`L02`L00`071`021`800PL00`071`061`800`L300H700<01`L00PL300<710031`03
00L700@710021`802@L00`07000200<700<01`000`L01@071`L000<700<01`000`L300031`0700P7
0P021`@01PL010071`L400<70`041`0300L700@70`031`8020L00`071`0200@700<01`L02`L00`07
1`0V1`009PL00`071`0;1`0300L7008700<01`L00PL00`071`061`800`L300H700<01`L00PL200@7
10031`0300L700@70P0010L01`L200T700<01`L00P041`0300L7008700D01`L700041`0300L70087
0P021`0300L700L70P021`0400L000H700@01`L710041`8010L00`071`041`<00`L200P700@01`L7
0P041`0300L700/700<01`L09@L002D700<01`L02`L00`071`021`0300L700<700<01`L01@L01007
00021`0400L000D700<01`L00PL00`0700021`8000<700000`L00`071`031`8000H7000700L200P7
00@01`070P021`0300L000<700D01`L700031`0300L000870P0010L01`081`8000<700L00P000`L0
00051`0400L71`8000<700000PL00`0700041`0300L700<70P0010L01`L200031`0700H700<01`L0
0`L00`071`021`0300L700/700<01`L090L002@700<01`L02`L00`071`021`0300L700@700<01`L0
10L01@071`0700<00PL200@700@01`L70P021`<00`L2008700<01`L00PL200<70P021`0300L000L7
0P021`@00`L010071`031`0400L700<710021`801`L00`0700021`800`L200@700<01`L00P031`<0
0PL200<700<01`L00PL200870`001@L01`L000H700<01`L010L00`071`021`0300L700/700<01`L0
8`L002<700<01`L02`L00`071`021`801@NU00D70P041`0300L700/700<01`L08PL0028700<01`L0
2`L00`071`021`801`L00`071`021`0300L700870P000`L000041`800PL00`0700021`0600L000L0
0`L00`07000200870P041`8000@700L00`L00`071`021`800`L200031`0000@70P031`8010L20003
1`0000<70P041`0800L71`0700L200@70P021`<000<700L00PL01P070007008700<01`000PL200@7
0P000`L000041`0300L7008700<01`L01@L200@700<01`L02`L00`071`0Q1`008@L200`70P031`80
20L2008700<01`L00`L010071`L200@70P000`L000031`<00`L010071`021`8000<7000010L00`07
00021`8010L01P071`0700<700@01`L70P041`0500L71`0010L200<700L01`L700L0008700<01`L0
0PL2008700<01`0010L200031`00008700@01`L00`L300<70P000`L000041`800`L00`071`031`03
00L7008020L200<70P0<1`808PL0020700<01`002@L01@0700L000870P051`0600L71`070P051`80
0`L300@70`041`801@L00`0700031`<010L010071`031`0300L700<70P021`0300L7008010L200<7
0P000`L000031`8010L2008700<01`L00P051`0500L71`000PL00`071`021`<00`L00`0700051`80
10L300@70`031`801@L200031`07008700<01`L00`L2008700D01`0700091`0300L00247000O1n40
80L0028700<01`L01`L0100700L300L700@01`070P021`0400L7008700D01`L700021`800PL00`07
00021`<020L00`071`0200051`071`0010L01`071`L01`000PL01@07000700800PL00`071`041`80
00@700070P000`L000061`0300L7008000D7000700021`0300L000<700<01`L00PL01@071`070080
0PL00`071`061`<00PL00`0700021`800PL01@071`L0008700@01`L00PL200041`0700L70`0010L0
1`091`0300L70247000R1`0300L700H70P021`<020L00`071`0200@70P031`0500L71`000`L30087
10000`L01`071`D00PL200D700D01`L700021`800`L300<700<01`L01@L300<70`071`0400L71`<0
0`L2008700D01`L700051`800PL500P700<01`000`021`<00`L01@071`L000<70P041`800PL00`07
1`061`<00PL200P700<01`L08@L0028700<01`L01@L00`0700021`802@L00`071`0200@70P031`05
00L71`0010L200870`021`0300L700H70`0010L01`L200D700D01`L700021`8010L200<700<01`L0
1PL200<70P081`0400L71`8010L2008700D01`L700051`800PL00`07000200P700<01`L00`021`80
10L01@071`L000<70P041`800PL00`071`071`800PL00`0700071`0300L70247000R1`0300L700@7
00D01`L01`0400P700@01`070P021`0400L7008700D01`L700031`0500L000L00P0010L01`081`80
00D7000700021`0300L7008700L01`L700L0008700D01`L01`02008700<01`L01@L01@0700070080
00<700L01PL00`071`0200051`071`000PL00`0700031`0300L7008700D01`L01`0200031`0000P7
00@01`070P001@L000L000<700D01`L700021`0400L700870P0010L01`081`@000D700L700061`03
00L70247000R1`0300L700<700@01`L70`0010L01`071`800PL0100700041`0300L000<700@01`L0
0`L300<70P071`800`L200@700D01`L700031`8010L200870`000`L01`051`0300L700D00PL00`07
1`041`0300L000800PL200@70P031`0500L71`0010L200<70P071`800`L300<700@01`L00`L00`07
00041`8000@700L70P071`0400L01`<00`L00`071`031`0300L70247000R1`0300L7008700<01`L0
0PL2008700@01`L01PL01P071`L01`801@L200<700<01`001@L200@700<01`L010L300<70P051`04
00L700<700<01`L00`L2008700<01`000P051`0400L71`D00`L00`071`031`<000@700L70P051`05
00L71`000PL00`071`031`800`L300H700<01`L00PL200D700<01`000`L200D70P000`L01`021`03
00L700@700@01`L00PL200@700<01`L00PL00`071`0Q1`008PL01@071`L000@70P031`0500L71`00
10L200<70P021`0300L700<700@01`L70P051`0400L000<70P041`8000@700L70P000`L01`041`03
00L000870P041`0600L700L00PL200@700<01`L00PL200031`0000@700<01`L00PL2008700<01`00
0PL00`071`021`800PL00`0700051`0400L0008700@01`0010L200<70P000`L01`041`800`L00`07
1`031`0300L700800`L200@700D01`L700031`8010L01@071`L002<7000R1`0400L700@70`031`03
00L7008700H01`L01`031`0300L7008700<01`L00PL2008700<01`L00`L00`071`03008700<01`00
0PL2008700<01`000P021`0300L700<70P0010L01`031`0300L700870P031`800PL00`071`021`80
0`L200@700<01`L00P031`8010L020071`L01`070P051`0300L700<000@700L70P021`0300L00087
0`021`0300L700<700<01`L00P041`0300L7008700L01`L700L0008700<01`L00PL010071`L300@7
00@01`L08`L002870`041`8000<700L00PL200@70P021`0300L700801@L01P071`L01`<010L01P07
1`L01`8000@700L70`031`<000<700L00PL00`071`031`800PL010071`061`0400L71`@010L300<7
0`041`@00`L00`071`041`0400L700870P051`0600L71`070`031`<00PL01P07000700<700<01`L0
0PL300031`07008700<01`L00`L2008700<01`L00P041`800`L0100700041`<08`L001h700@01`L7
0`031ll00`L300<700<01`L07@L001h70P000`L000021`0400L000<700H01`L700L200061`071`07
0P021`0300L700D700@01`000PL010071`051`0400L71`8000D700L700021`800`L00`071`031`03
00L7008000<700000P081`0400L01`8000@700070P021`0500L71`000PL200041`001`8000@700L0
20L400031`00008700<01`L00`L010071`L2008700D01`L01`0200<700<01`L00`L010071`021`80
00<700L01PL00`071`0200061`071`070P000`L01`021`0400L71`8000@700L70P000`L0000O1`00
7PL00`07000200<70P041`0500L71`000PL200@70P031`0300L700H70P031`<01PL00`071`021`80
10L400<700<01`L010L200041`071`802@L00`071`0200<70`031`0500L71`000`L300<70P021`03
00L700L70P021`0400L000H700@01`L710041`8010L00`071`041`<00`L200P700@01`L70P041`80
0PL01@071`L000@70P031`<000<700L07PL001h71@021`<010L01@071`L000870`031`<00PL00`07
1`061`800`L300H700<01`L00PL200@70P000`L01`021`0300L700@70P0010L01`L300P700<01`00
0P031`<00`L01@071`L000<70`031`<000<700L01`L3008700@01`001PL01P071`L01`8010L200@7
00<01`L010L300<70P081`0300L700<00`L3008700D01`L700041`<00PL501l7000N1n<07`L001d7
0P031`<010L010071`031`8010L2008700<01`000P061`0500L700L00`031`0300L7008700H01`L0
1`021`0300L000<700D01`L700041`0300L700870P021`0400L000H70P021`0400L000<70P000`L0
1`021`0400L000<70P0010L01`L200H70P0010L01`L200@700<01`L00PL01@071`L000<700<01`00
0PL00`0700021`0300L7008700@01`L70`001@L01`L000H70`0010L01`L200@70P031`0400L700@7
0`031`807PL001`700<01`000`L300D700<01`000`L00`071`031`<000@700L70P051`0600L71`07
0`041`0700L71`0700021`0500L71`0010L2008700D01`L700041`<00PL00`071`0200@70P031`@0
10L300<70`041`@00`L200@70P021`0300L700<010L01@071`L000870P041`0500L71`000PL00`07
00031`0300L700870`000`L01`021`0300L700<70P021`0300L000801@L01`071`L01`001@L300<7
00<01`007@L001/700@01`L00PL2008700<01`L00`L200870P041`0300L700<00`L200<700<01`L0
0PL2008700<01`L00`L00`071`0200<700H01`L01`031`0500L01`000PL00`071`021`<000@700L0
0`L2008700<01`000`L2008700<01`L00PL200<70P041`0300L700800`L00`0700021`800`L01007
00L300@700P01`L01`0700<700<01`000PL010071`L2008700<01`L00`L00`071`0200@700@01`L7
0P031`<00PL00`071`021`800PL200D700<01`L00P021`0400L701`7000J1`0600L71`070`031`03
00L700<700D01`0700031`0300L700870P031`<000<700L010L010071`L200D700<01`0010L00`07
00031`0400L700870P000`L01`031`8000@700L70P041`<00PL00`071`0200@700<01`L00PL20003
1`0000@700<01`L00PL2008700<01`L00`041`800PL0100700041`0400L0008700@01`L00`L00`07
00041`0300L000D70P031`0300L700<700<01`000P031`8010L02@071`L01`0700051`0400L71`<0
00<700L00PL00`071`0I1`006@L00`071`021`<000<700L00`L00`071`021`800PL010071`061`80
0PL0100700051`800`L00`0700051`8010L200D700<01`000`L200@70P021`0500L71`001@L20087
00<01`000P051`0400L71`D00`L00`071`031`<000@700L70P051`0500L71`000PL200@70P031`03
00L000D70P041`801@L00`0700031`801@L200041`071`801PL010071`021`8010L00`071`021`03
00L0008010L00`071`0H1`0050L01@071`L000D70P021`0300L700<700/01`L700L01`0700071`<0
00<700L00`031`0300L000<700@01`L00`L00`0700041`0300L700D70P031`800`L200<700@01`L7
0P031`0500L000L00`000`L01`051`0300L700D00PL00`071`041`0300L0008000D7000700031`80
0`L010071`L200<70P031`801`L00`071`021`0300L000<700@01`L00`L00`0700031`<000<700L0
0`071`0700L01`0700031`0300L700<700<01`L00P051`0500L71`005@L001@70P000`L01`041`80
0`L00`071`041`0400L000870`081`0300L000<00PL200051`071`000`L01`071`L01`000PL20087
0P081`0300L7008000<700L00P041`0900L71`0700L000<710021`0300L700D700D01`001`020003
1`0700H700<01`L010031`0500L01`000`L00`071`021`8000<700L00P021`0300L700H70P021`80
0PL00`0700031`0500L71`000PL0100700021`@000<700L01`L300870P000`L01`051`0400L71`80
1@L01007000E1`0050L00`0700051`<00`L00`071`051`0300L000<700<01`L01`L00`071`0200@7
0P031`0500L71`0010L01P071`L01`8000<700L01`L300041`071`801@L01@071`L0008700<01`L0
0`L200<700<01`L01PL200<70P081`0400L71`801@L010071`031`0300L700<70P021`0300L00080
20L01P07000700<700<01`L00PL01@071`L000<70P041`800PL00`071`071`0700L71`0700071`04
00L71`<01@L00`07000E1`0050L200031`0700870P000`L01`021`0300L700@7c@061`0600L71`07
0P031`0400L001D7000D1`0700L71`0700031`0500L71`001@L02`071`L01`0700L000L700@01`07
1@021`8000<700L00PL010071`031`0400L000870P081`0300L700<00`L00`071`021`0400L71`80
0`L01@07000700<000<700L01@L200041`001`8000<700001PL00`07000200051`001`000`L200<7
00<01`L00PL00`071`04008700<01`L01PL200870P000`L01`021`0400L700<700@01`000PL30006
1`0700L01`L01`0700L01`000`L00`071`031`0500L71`000PL200031`07008700<01`L04`L001@7
00<01`L00PL00`071`021`0500L71`0010L00`071`021`800PL010071`061`800PL0100700041`<0
0`L00`0700051`8010L00`071`051`800`L200@700D01`L700031`0300L700<70P021`0300L00080
1@L2008700D01`0700021`801@L300041`071`801@L01@071`L000<700<01`L00PL200<70P071`03
00L700870P051`0300L000<70`041`8000@700L70P061`0400L700870P041`0300L7008700D01`L7
00041`0300L7008700<01`L04`L001@700L01`L700L000<700D01`L700031`0300L700<700D01`07
00031`0300L700<700@01`L70`000`L01`031`800`L200H70P041`801@L00`0700021`@010L01007
1`021`8010L3008700<01`L00P041`800`L200031`0000<70P041`800PL00`071`0300@70P021`04
00L700@710021`0300L000D70P041`801PL200<70P041`0300L000800`L00`071`031`0900L71`07
00L000D700D01`L700031`0700L71`0700031`0300L701<7000D1`0400L700<700@01`L00`L01007
1`051`800PL200@700<01`L00`031`800`L00`071`021`800PL00`071`041`0400L000<700<01`00
0`L02@071`0700L01`0200@700L01`0700L000<70P021`0300L000<70P021`8010L01@071`L000@7
0P021`800`L00`0700021`800`L0100700L300@70P001PL01`07008700L01`L700L000<70P000`L0
1`051`0300L7008010L010071`L200<70P031`0300L700870P021`801@L010071`031`0400L700<7
00@01`L05@L001@700<01`001@L00`0700031`0300L000D7b`051`0300L000<700<01`001@L00`07
000E1`0050L200L70P031`801@L010071`031`8010L2008700<01`000P061`0500L700L00`041`05
00L71`000PL00`0700031`0300L7008700D01`L700031`8010L2008700@01`001PL01P071`L01`80
10L00`0700031`0300L000@70P000`L01`021`0300L700@70P0010L01`L200@70P031`0500L71`00
10L01`071`L01`000PL01@071`L000@70`001@L01`L000H70`0010L01`L200@70P031`0400L700D7
0P031`801`L201D7000D1`0300L700L700D01`L700051`0500L71`000`L300870P000`L01`030003
1`0700H700@01`000PL01@071`L000@700@01`L70P021`0300L000870P031`0300L700870P021`@0
00@700001`L200870P000`L000021`0400L700<700@01`L00PL200031`0000870P071`<000<70000
0P021`8010L010071`L2008700<01`000PL200<700<01`L00PL01@071`L000870P000`L01`061`03
00L0008000<700L00P021`<00`L01@071`L000D700D01`L700091`0300L701<7000C1`802@L20003
1`0000@700<01`L00PL01P071`L01`@00`L3008700<01`L01PL200<70P000`L01`041`0300L70087
00<01`000`L200031`07008700<01`L00`L300031`0700@020L01@0700L000<70`031`0500L71`00
0`L300<700D01`0700081`@000<700L00`051`0600L71`070P031`0300L000@700<01`L00`L01007
00031`8020L00`071`0300<710000`L01`021`0300L7008700<01`L00PL200031`0000T70P0D1`00
4PL00`0700091`0500L01`000`L00`071`031`0500L71`000PL200@70P031`0300L700H70P031`03
00L000H700<01`L00PL200@70P000`L01`021`0300L700@70P0010L01`L200T700<01`L00P041`80
0`L01@071`L000<70P041`800PL00`071`071`800PL0100700061`0600L71`070P041`8010L00`07
1`041`0300L000<70P081`0400L71`8010L2008700D01`L700051`0900L71`0700L000T700<01`00
4`L0014700@01`L02@L200031`00008700<01`L010L01P071`L01`@00PL4008700<01`L01@L40087
0P000`L01`041`0300L7008700<01`000PL00`071`0200<700<01`L00`L00`07000200031`000080
20L01@0700L000<700@01`000PL01@071`L000870P000`L01`021`0500L01`0020L400061`0000L0
1@L010071`L2008700H01`L01`041`0300L700<700@01`000PL400L700<01`L010021`@000<700L0
0PL00`071`041`0300L7008000<700002@L010071`0B1`0040L01@071`L000T700L01`L700L000L7
00@01`L70`021`@000H700L01`061`8000<700L00`031`0300L7008700@01`L70P021`8010L01@07
1`L000@700@01`L7100010L000071`800PL200031`0700870P000`L01`021`0400L000<700@01`00
0PL200L70`000`L0000200<700<01`L00PL01@071`L000@70P021`800`L00`071`021`0400L71`<0
00<700L00P061`0600L01`0710021`<00`L00`071`051`0300L000<700<01`L01`L01@071`L00147
000?1`800`L00`071`061`800`L200P700@01`L70P041`800PL00`071`0200D70P021`0300L00080
10L01@071`L0008700<01`000PL200@70P021`0500L71`001@L2008700@01`001PL01`071`L01`00
1@L300<70`051`0300L000<700<01`L010L200041`071`801@L01@071`L000870P041`800PL00`07
00021`0500L71`0010L300041`071`801@L2008700<01`L00P041`800`L00`071`061`800`L200P7
00@01`L70P0@1`003PL00`0700031`0300L700D700<01`000`L00`0700071`0300L7008010L40003
1`07008700<01`L00PL200<70`000`L01`041`0600L700L00PL00`0700021`0900L71`0700L00087
00<01`L00`L400041`071`8010L200<70P000`L01`041`800`L200D700@01`000`L200@70P021`03
00L000<01@L020071`0700L00`L01P071`07008700<01`000PL00`071`031`0300L000800`L200@7
00H01`L700L400@70P021`0300L700D700<01`000`L00`0700071`0700L71`07000?1`003@Oo00H0
3PL0010700D01`L700051`0900L71`0700L000<70P041`<000@700L70P041`800`L00`07000200@7
0P031`0300L000D70P041`0300L700@700<01`000`L200D70P0010L01`L200@70`021`0300L70080
10L00`071`021`8000<7000010L00`071`021`800PL00`071`0300@70P021`0400L000D70P031`03
00L000H700<01`L00PL200D700<01`000`L200@70`000`L01`021`8010L2008700<01`000P041`80
0`L01@0700L000<700<01`L00`L01@071`L00147000@1`0500L71`0010L00`071`021`800PL00`07
1`021`800`L2008700@01`001PL2008700@01`0010L300<700@01`L010L200<70P071`800`L200@7
0P021`0400L71`8010L2008700D01`0700051`0900L71`0700L000<700<01`L00`L01@0700L00087
0P041`800`L00`071`0200@70P031`801`L200<70P041`0400L700<70`041`8000@700L70P061`80
00@700L70P031`8010L00`071`0200@700<01`L00PL01@071`L00147000@1`0500L71`000`L00`07
1`031`0500L71`001@L200061`001`070`071`<000H700001`021`8000<700L00PL01@071`L00087
00P01`001`0700P700<01`L00P0010L01`L200<700L01`L700L0008700D01`001`02008700<01`L0
10L00`071`0200031`00008700<01`L010L00`071`0200051`001`000PL00`0700031`0400L71`80
0PL0100700021`0300L700H700@01`070P001@L01`L000<700H01`L700L2008700<01`000P0010L0
00071`<000<700L00P000`L000051`0500L71`001@L01@071`L000<700<01`L03`L0010700D01`L7
00021`0300L700<70P031`0300L700@7c@061`0400L71`801@L010071`031`0300L700l7000@1`07
00L71`0700051`0300L000<700<01`L010L400870P091`0300L7008010L200<700D01`L700041`80
0PL400031`0700L70`0010L01`L200D700D01`L700021`8010L200<700<01`L01PL200<70P081`04
00L71`8010L2008700D01`L700051`800PL00`07000200P700<01`000`021`8010L01@071`L000<7
0P041`800PL00`071`071`800PL400H700L01`L700L000D700<01`000`L00`071`0?1`0040L01007
1`L200D700@01`L00`L00`071`031`8000@7000710081`0300L000<00PL010071`021`0500L71`00
0`L01@071`07008000@7000020L00`071`0200051`071`0010L01`071`L01`000PL01@071`070080
0PL00`071`051`0500L000L00P000`L01`061`0300L7008000D700L700021`0300L000<700<01`L0
0PL01@071`0700800PL00`071`061`<000D7000700021`0500L71`000`L010071`021`0300L700@0
00<700L01`L400041`001`801@L01@071`L0008700<01`L00`L200<700<01`L03`L0010700D01`L7
00051`0500L71`000`L00`071`021`800`L300041`0700L70`000`L01`0200@700<01`000`L01007
1`041`800`L200L70P031`8010L01@071`L000<70P041`800PL300031`0700D700<01`L01@021`03
00L700@700<01`000P021`8010L200<700D01`L700041`800`L200L70P031`8010L010071`031`03
00L000@70P000`L01`0300L700@01`070`031`8010L01@071`L000<700<01`L00`L01@071`L00147
000@1`0300L7008010L00`071`021`0500L71`000`L200@70`001@L01`L000H70P021`0400L000D7
0P031`0300L000@70`041`801@L00`0700031`801@L010071`031`0300L700<70P021`0300L00080
1@L010071`L500<700<01`L00`L300041`071`801@L01@071`L0008700<01`L00`L200<700<01`00
1@L200@70`041`0300L000<70P051`8000@700L70P061`0500L700L00`041`800`L01@071`L000@7
00<01`L00PL2008700<01`L03`L0010700D01`0700031`0300L700<700D01`L700021`8010L20004
1`0000<700<01`L00PL200<70P021`0300L700<700@01`L70P041`8000<700000`L300<700@01`L0
0PL200031`0700@700<01`000PL200@700H01`L01`021`8010L00`071`021`8000<7000010L00`07
1`021`800PL00`0700021`0300L700870P021`0300L000D700@01`000PL010071`031`<00`L20003
1`0000@70P031`0300L700<700<01`L00P031`8010L010071`L300031`0000@70P021`0500L71`00
1@L02@071`L01`07000A1`0040L2008700@01`L01PL01P071`L01`8010L300870P041`0300L700<0
0`L00`071`021`0300L700870P021`0300L700870P021`0300L0008700H01`001`031`0300L00080
0PL00`071`031`8000@700L00`L00`071`021`800`L2008700<01`L00PL200<70P041`0300L70080
0`L200@700P01`L700L01`801@L00`071`0300031`07008700H01`001`021`0300L000870P041`03
00L7008010L00`071`021`0400L71`<00PL00`071`021`800PL300@70P000`L01`021`0300L700@7
00@01`L00PL20147000@1`0700L71`0700071`0400L71`<010L200031`0700870P041`<000@700L7
0P051`0600L71`070`031`800`L01P071`0700870P041`<000<700L00PL00`071`031`800PL01007
1`061`0400L71`@010L300<70`041`@00`L00`071`041`0400L700870P051`0600L71`070`041`80
0PL00`0700021`0400L71`800`L300031`07008700<01`L00`L2008700<01`000P041`800`L01007
00041`<00`L00`071`051`0300L000<700<01`L03`L000l70P031`8020L010071`L200@70P021`04
00L71`<00`L2008700D01`0700061`0500L700L00`021`8010L010071`L200870`031`800PL00`07
1`021`0300L700870P021`0300L000L70P021`0400L000<70P000`L01`021`0400L000<70P0010L0
1`L200L700<01`000PL200@700<01`L00PL00`071`0200<70`021`800`L00`071`021`800PL30005
1`071`001PL01@0700L000870P031`<00`L00`071`0200@70P031`0300L700H70P031`8040L000h7
00@01`000PL00`071`071`8000D7000700021`800`L01P071`L01`8000H7000700L2008700<01`L0
1@L0100700021`0400L000D700@01`L70P0010L01`L200031`0000<700<01`L00`L00`071`020003
1`07008020L0100700L200041`001`800PL01@071`L000870P0010L000L200041`0700P70P000`L0
1`02008700<01`L00`L010071`L200031`00008700@01`000`L00`071`031`8000@700L70P000`L0
1`061`0300L7008000<700L00P001@L000L000<700@01`L70P021`0500L000L00P091`0300L70080
00<700L03PL000d7o`0600h7000@1`0300L000802@L500870`041`0500L71`000PL200@70P031`03
00L700H70P031`<01PL00`071`021`<00`L400<700<01`L010L200041`071`802@L00`071`0200<7
0`031`0500L71`000`L300<70P021`0300L700L70P021`0400L000H700@01`L710031`<010L00`07
1`041`<00`L200P700@01`L70P041`800PL01@071`L000@70`021`D02@L300031`070107000@1`80
0PL00`071`071`800PL01@07000700800`L01P071`L01`8000H700L700L2008700<01`L01@L01007
00021`0400L700D700@01`L70P0010L000L200031`0000<700<01`L00`L00`071`0200031`070080
20L0100700L200041`001`800PL01@071`L000870P0010L000L200041`0700P70P000`L01`020087
00<01`L00`L010071`L200041`001`8000<700000`L00`071`031`0400L700870P000`L01`061`03
00L7008000H700L700L200031`07008700@01`L70P001@L000L000870P091`0300L700804@L00107
00@01`L70P071`800`L300<70P021`0400L71`<00`L2008700D01`0700061`0300L700D00`L00`07
1`021`0600L700L00PL300<70P021`0300L7008700<01`L00PL2008700<01`001`L2008700@01`00
0`L200031`07008700@01`000`L200041`071`801`L00`0700021`8010L00`071`021`0300L70080
0`L3008700<01`000PL00`071`021`0400L71`D00PL00`071`041`0500L01`000PL200<70`031`03
00L700800`L300<70P071`800`L00`071`0?1`003`Oo008040L000h700<01`000`L010071`041`03
00L000870P021`0300L700870`021`8010L01P071`0700<700<01`L00PL00`071`021`8000<70000
1@L00`071`0200<700D01`001`02008700D01`0700021`0300L700<70P0010L01`031`0300L70087
0P031`800PL00`071`021`800`L200@700<01`L00P031`8010L020071`L01`070P051`0800L700L0
1`021`8000D7000700031`800PL00`071`031`8000<7000010L00`071`021`0700L71`0700021`03
00L700870P021`<010L00`071`02008700<01`0010L010071`031`0300L000l7000=1`0400L700<7
00D01`L700021`0500L700L00`031`0300L700870P0010L000031`0300L700870P031`800PL00`07
1`031`0400L71`801@L00`0700041`<00`L200041`071`8000<700L010L00`0700021`8010L01P07
1`0700870P041`0300L700870P000`L000041`0300L700870P021`0300L0008700<01`L00PL20087
00<01`001@L0100700021`0400L000<70`041`0300L000D70P031`0300L700<700<01`L00P031`80
10L010071`L300031`0000@700@01`L70`001@L01`L0008700D01`L700031`0400L700h7000<1`05
00L71`000`L00`071`021`800`L300031`0700<700<01`L00PL300051`071`001PL01P071`L01`80
1@L200<70`051`8010L200D70`031`801@L010071`031`0300L700<70P021`0500L01`001@L02@07
1`L01`0700031`0300L700<700D01`0700021`801@L01@071`L0008700<01`L00`L200<70`051`80
10L200D70`031`801@L200031`07008700<01`L010L01@071`0700<010L00`071`021`0300L00080
0`L200@700D01`L700031`0300L700/700061`0300L7008700<01`L00PL01@071`L000@70P031`80
0PL00`071`031`0400L71`<000@700L01`L2008700@01`0010L00`0700031`0400L000<700<01`00
0`L200L70P031`8010L01@071`L000<70P041`800PL2008700<01`L010L00`071`0200031`000087
00<01`L010L00`071`0200870P041`800`L01@071`L000@70P031`801`L200<700<01`000`L20003
1`07008700<01`0010L200041`071`801`L0100700L300<700<01`L00`L00`071`0200<70P041`05
00L71`0010L00`071`021`0300L700D700061`800PL00`071`031`0400L71`800PL01@071`070080
0`L00`071`041`0500L000L010081`0400L01`800PL010071`021`0500L71`000PL200041`071`80
00@7000020L200051`001`000PL00`071`021`0700L71`0700021`0600L700L00`L00`071`051`03
00L000<700<01`001`L01`071`L01`000PL01P071`0700<700<01`L00PL01@071`07008000<70000
20L300031`00008700@01`000PL01@071`L0008700@01`L00PL200041`0700P710001@L000L000H7
00@01`L70P001@L01`L000870P031`0300L700<700<01`L00P071`001PL0100700061`0600L71`07
0P041`0300L000<700<01`L01@L00`0700021`802@L00`071`0200@70P031`0500L71`000`L200<7
00H01`001`081`<000@700L70P051`0500L71`000PL200@70P031`0300L700H70P031`8020L01007
1`L200@70P021`0500L71`001@L2008700<01`000P081`0600L000L00`L200<700D01`L700031`80
10L2008700<01`L01`L2008700<01`001`L01`071`L01`0010L200031`07008700<01`L010L20003
1`0700H700061`0400L000H700H01`L700L200<700@01`000`L00`071`041`0400L000870`081`03
00L700<00`L200<700D01`L700031`<00PL400031`0700L71@021`801@L01@071`L000870P031`03
00L000<700<01`L01@L00`0700031`0300L000L700L01`L700L000<70P021`0500L71`001@L20087
1@081`0300L000<00PL300<700D01`L700031`800`L3008700<01`L01PL300870P000`L01`051`04
00L71`8000<700L00PL200031`07008700<01`L010L200031`0700H700061`800PL00`071`031`04
00L71`800PL00`0700031`0500L71`001@L02`071`L01`0700L000L700@01`070`001@L01`L00087
00D01`L700021`0300L7008000<700000PL200P700<01`L00P001@L01`L000@700L01`L700L00087
00<01`000PL2008700<01`L010L00`071`0200031`00008700<01`L010L00`071`02008700<01`00
0PL00`0700031`0300L7008700D01`L01`02008700<01`L01PL200870P000`L000021`0400L700<7
00@01`L00PL00`07000200041`0700L700L01`0700L000<700<01`L00`L01@071`L000<700<01`00
0PL200<700<01`L00`L00`071`0200L700061`0300L7008700<01`L00PL01@071`L000@700<01`L0
0PL2008700<01`L00PL00`071`021`800PL010071`061`800PL0100700041`0300L000<700<01`00
10L300@700<01`L01@L200<70P041`0500L71`000`L200@700T01`L700L01`001@L02@071`L01`07
00031`0300L700<700D01`0700031`0300L700870P031`0500L71`0010L200<70P071`0300L70087
0`041`0300L000<700<01`0010L200041`071`801PL010071`021`8010L00`071`021`0300L70080
10L00`071`021`0500L71`0010L00`071`021`0300L700D700061`0300L700<700D01`L700021`80
0`O_00<70P021`0500L71`001@L00`071`051`001PL00`071`041`0800L700L01`021`0500L71`00
0PL00`071`02008700<01`L00`L200870P031`800`L200<70P021`8010L010071`L200@70P000`L0
00031`0300L000<700@01`L00PL200031`0000@700<01`000PL200<700L01`L700L000<700D01`L7
00051`0500L71`001@L01@071`L000<700<01`000`L010071`L2008700<01`0010L200031`000087
00@01`L00`L00`0700031`8000<7000010L200<700<01`L00PL200870P031`800`L200<70P021`80
1@L00`071`02008700@01`L00`L020071`0700L00PL00`071`041`0300L700D700061`0300L700D7
00@01`000PL00`0700051`0300L000<700<01`001@L00`0700031`0300L700870P0010L01`031`03
00L700870P031`8000<7000010L200870`021`0600L700L00`L01@0700L000870P041`8000@700L0
0PL00`071`031`800`L200031`0700@70P031`801@L0100700031`801@L01`071`0700L00P041`80
0PL01@0700L000<700<01`000PL00`071`0300870P041`8000<700000`L200@700P01`L700L01`80
10L01`071`L01`001@L00`0700031`0300L000D700<01`000PL200031`0700H700<01`L01@L000H7
00<01`L01PL200<70P071`800`L200D700@01`L00`L200@70P021`0300L700801@L2008700<01`00
0P031`800`L01P07000700<700<01`L00PL2008700@01`L70P041`800PL00`0700071`0700L71`07
00051`0300L000<700<01`001@L00`0700031`0300L700D700<01`000PL200@70P031`0300L70080
10L01P071`L01`8000<700L00PL200<70`0010L01`L200D70P021`0300L7008010L200<700@01`L0
1@L200<70P071`800`L200P700<01`L01@L000H700<01`L01POo008020L00`071`051`001PL00`07
1`071`8000<700002@L200031`00008700<01`0010L01@071`L0008700<01`000PL4008700<01`L0
1@L4008700@01`001@L010071`L200031`07008700@01`000`L00`071`031`8000H7000700L200P7
00D01`0700031`0300L000<700D01`L700031`0300L000<700D01`0700081`8000<700L00P000`L0
00051`0400L71`8000<700L00PL0100700031`0300L700<70P0010L01`L400L700<01`L010021`03
00L0008700D01`L700041`0300L000870P000`L000091`8000<700002@L00`071`051`001PL00`07
1`071`0500L01`002@L01@0700L000<700<01`L00`L01@071`L000<700<01`L00PL200<700<01`L0
1PL200<70`061`0300L700870P051`0300L000<700<01`L010L200041`071`802@L00`071`0200@7
00<01`L00PL01@071`L000@700<01`L00PL2008700<01`L01`L2008700@01`001PL01`071`L01`00
1@L200@700<01`L010L300<70P081`0400L71`8010L01@071`L000<700<01`L00`L02@071`L01`07
00091`0500L01`002@L00`071`051`001PL00`071`071`8000<700002@L200031`00008700<01`00
10L01@071`L0008700<01`000`L3008700<01`L01PL300870`061`0300L700870`031`0400L000<7
00<01`L010L400041`0000T700D01`0700031`0300L000<700D01`L700031`0300L000<700D01`07
00091`<000<700000P061`0400L71`8000<700L00PL300@700<01`L010L300870`081`0300L700<0
0`L00`0700021`0500L71`0010L00`0700021`8000<700002@L200031`0000T700<01`L01@L000H7
00<01`L01`L01@071`L000T700L01`L700L000<700D01`L700031`0300L000<700@01`070`000`L0
1`061`0300L000@00PL00`071`031`0400L71`8000D7000700031`0500L71`001@L00`071`040003
1`0000P70P021`8000<700L00PL010071`031`0400L700<700@01`000PL200P70P000`L000020087
00<01`L00`L01@071`L000<700D01`001`0200<700<01`L00`L00`071`0500031`0700H700<01`00
0P0010L01`031`0300L000<700D01`L700031`0300L000<700<01`L01`L01@071`L000T700<01`L0
1@L000H700<01`L01`L010071`L200L70P031`801@L010071`031`801@L01@071`0700<01PL01@07
1`0700<00`L00`071`021`0300L700<00PL200@70P021`0300L7008700<01`L00PL2008700<01`00
1`L01`071`L01`001@L00`0700031`0300L000D700<01`000`L00`071`051`0300L000870P041`03
00L7008700<01`L00P041`800PL3008700<01`L00PL010071`L300051`071`001PL300051`071`00
1@L200<700@01`L01@L200<70P071`800`L00`071`071`0300L700D700061`0300L700L700L01`L7
00L000D700<01`000`L00`0700051`0300L000<700<01`L00`L01@0700L000870P051`0400L71`D0
10L01P071`L01`8000@700L70`031`0500L01`000`L00`071`021`@000D700L700051`800`L20003
1`0700@70P031`801@L0100700031`801@L01@071`0700@010L02@071`L01`0700031`<00PL01P07
000700<700<01`L00PL500<700<01`L00`L2008700D01`0700051`0700L71`0700051`0300L000<7
00<01`001@L00`0700031`0300L700L700<01`L01@L000H700<01`L01`L01@071`L0008700D01`L7
00021`0300L700800PL00`071`031`800PL200@700@01`L70P031`800`L00`071`021`800PL200@7
00<01`L00`021`0300L000870P021`0300L700800PL00`071`021`<000@700000`L01`071`L01`00
0`L01@071`L000D700D01`L700051`0500L71`000`L00`0700031`0400L71`<000@7000010L00`07
1`02008700<01`L00P021`0300L000870`021`0300L700870P021`8010L010071`L200<70P031`03
00L700870P021`801@L00`071`02008700@01`L00`L010071`031`0300L700L700<01`L01@L000H7
00<01`L01`L01@071`L000<700<01`000`L01@0700L000<700<01`L00`L01@0700L000<700<01`L0
0`L010071`L300031`0700<70P031`<010L0100700031`8010L200031`07008700<01`0010L20004
1`071`8010L00`0700021`0300L7008010L00`071`021`8000<7000010L00`071`021`800PL01P07
1`0700@70P021`0400L000@700<01`000`L0100700041`800`L200031`0700<70`031`8010L00`07
000200<700<01`L00`L02@071`L01`0700051`0900L71`0700L000<700<01`000`L01@071`L000T7
00<01`L01@L000H700<01`L01`L01@071`L000@700<01`L00PL2008700<01`L00PL00`071`021`80
0PL010071`061`800PL0100700041`<00`L0100700041`8010L00`071`041`<00`L200@70P021`04
00L71`8010L02@071`L01`0700051`0900L71`0700L000<700<01`L00`L01@0700L000<700<01`L0
0PL200<700<01`L00P041`800`L300H700<01`L00PL200@70P000`L01`021`<010L200041`071`80
1PL010071`021`8010L00`071`021`0300L7008010L00`071`021`0500L71`002@L00`071`051`00
1PL00`071`071`0500L71`000`O_00<700D01`L700091`0300L700D700061`0300L700L700D01`L7
00061`0400L000<700<01`L010L0100700021`<020L00`071`03008710021`0500L71`000`L40007
1`001`0700081`8000@7000710041`0900L71`0700L000<700<01`000`L00`071`051`0300L000<7
00<01`001`L01`071`L01`000`L01@0700L000<700<01`L00PL400041`001`8020L0100700L20003
1`0000800`L01@071`L0008710021`<00PL00`071`061`<00PL200031`0700D700@01`L70P000`L0
1`051`0500L71`002@L00`071`051`001PL00`071`071`0500L71`001`L00`0700031`0300L700D7
00<01`000`L00`071`071`0500L71`0010L200<700D01`L700041`800PL00`0700021`0300L700H7
00D01`0700021`801@L01@071`L0008700<01`L00`L200<700<01`L01PL200<70P081`0400L71`80
1@L010071`031`0300L700<70P021`0500L01`0020L01P071`0700870P041`0500L71`000`L200@7
00D01`L700091`0700L71`0700071`0700L71`0700071`0500L71`002@L00`071`051`001PL00`07
1`071`0500L71`001PL0100700031`0300L700@700@01`000PL300P700<01`L00`021`@00PL01@07
1`L000<710001`L000L01`0020L200041`001`@010L02@071`L01`0700031`0300L000<700<01`L0
1@L00`0700031`0300L000L700L01`L700L000<700D01`0700031`0300L70087100010L000L200P7
00@01`070P000`L0000200<700D01`L700021`@00PL3008700<01`L01PL300870P000`L01`051`04
00L71`8000<700L01@L01@071`L000T700<01`L01@L000H700<01`L01`L01@071`L000<7k`031`05
00L71`002@L00`071`051`001PL00`071`071`0500L71`0010L00`071`021`800PL00`071`021`03
00L700870P021`0400L700H70P021`0400L000@70`031`0400L000@70P041`0300L700@70`031`80
10L2008700@01`L70P041`0900L71`0700L000D700T01`L700L01`000`L00`071`031`0500L01`00
0`L00`071`021`800`L00`071`0200@70P031`<01PL00`071`021`8010L200031`0700870`041`80
00@700L70P061`0400L700870P041`0300L7008700<01`L00P041`0300L7008700D01`L700091`03
00L700D700061`0300L700L700D01`L700031`0300L000<700D01`0700031`0300L700<700D01`07
00031`0300L700<700@01`L70`000`L01`031`800`L300@700@01`000`L200@70P000`L01`021`03
00L000@70P0010L01`L200@700<01`000PL00`071`0200@700<01`L00PL200031`0000@700<01`L0
0PL2008700H01`L01`041`800PL0100700041`0300L000<700@01`0010L200<70P000`L01`031`<0
0`L200@700<01`000P031`0300L700<700T01`L700L01`001@L02@071`L01`0700031`0300L000<7
00D01`L700091`0300L700D700061`0300L700L700D01`L700021`0500L71`000PL00`071`020087
00<01`L00`L200870P041`0400L71`800`L200<700<01`L00PL200870P041`0300L700<00PL00`07
00021`800PL00`071`02008700<01`L00PL300041`0000<700L01`L700L000<700D01`L700051`05
00L71`001@L01@071`L000<700<01`000`L010071`L300041`0000@700<01`L00P021`0300L70080
0PL00`0700021`<00PL00`071`021`800PL200@700@01`L70P031`800`L00`071`021`800PL200D7
00<01`L00P021`0400L700<700@01`L00`L00`071`071`0300L700D700061`0300L700L700L01`L7
00L000D700<01`000`L00`0700051`0300L000<700<01`L00`L01@0700L000870P051`0400L71`D0
10L01P071`L01`8000@700L70`031`0500L01`000`L00`071`021`@000D700L700051`800`L20003
1`0700@70P031`801@L0100700031`801@L01@071`0700@010L02@071`L01`0700031`<00PL01P07
000700<700<01`L00PL500<700<01`L00`L2008700D01`0700051`0700L71`0700051`0300L000<7
00<01`001@L00`0700031`0300L700L700<01`L01@L000H700<01`L01`L010071`L200L70P031`80
1@L010071`031`801@L01@071`0700<01PL01@071`0700<00`L00`071`021`0300L700<00PL200@7
0P021`0300L7008700<01`L00PL2008700<01`001`L01`071`L01`001@L00`0700031`0300L000D7
00<01`000`L00`071`051`0300L000870P041`0300L7008700<01`L00P041`800PL3008700<01`L0
0PL010071`L300051`071`001PL300051`071`001@L200<700@01`L01@L200<70P071`800`L00`07
1`071`0300L700D700061`0300L700L700D01`L700091`0700L71`0700031`0500L71`000`L00`07
00031`0400L01`<000<700L01PL00`070004008700<01`L00`L010071`L200051`001`000`L01@07
1`L000D700<01`L010000`L000081`800PL200031`07008700@01`L00`L010071`031`0400L00087
0P081`8000<700000P021`0300L700<700D01`L700031`0500L000L00P031`0300L700<700<01`L0
1@000`L01`061`0300L0008000@700L00`L00`0700031`0500L71`000`L00`0700031`0300L700L7
00D01`L700091`0300L700D700061`0300L700L70P000`L000091`8000<700000PL00`0700041`05
00L71`000PL00`0700031`<00PL00`071`061`<00PL300H700<01`L00PL300<700@01`000`L00`07
1`041`@000@700002@L01@0700L000<700<01`000`L01@071`L000<700<01`000`L01@0700L000T7
0`000`L0000200H700@01`L70P000`L01`021`<010L00`071`041`<00PL300P700<01`L00`031`03
00L0008700D01`L700041`0300L000870P000`L000091`8000<700002@L00`071`051`001PL00`07
1`071`0500L01`002@L01@0700L000<700<01`L00`L01@071`L000<700<01`L00PL200<700<01`L0
1PL200<70`061`0300L700870P051`0300L000<700<01`L010L200041`071`802@L00`071`0200@7
00<01`L00PL01@071`L000@700<01`L00PL2008700<01`L01`L2008700@01`001PL01`071`L01`00
1@L200@700<01`L010L300<70P081`0400L71`8010L01@071`L000<700<01`L00`L02@071`L01`07
00091`0500L01`002@L00`071`051`001PL00`071`071`8000<700002@L200031`00008700<01`00
10L01@071`L0008700<01`000PL4008700<01`L01@L4008700@01`001@L010071`L200031`070087
00@01`000`L00`071`031`8000H7000700L200P700D01`0700031`0300L000<700D01`L700031`03
00L000<700D01`0700081`8000<700L00P000`L000051`0400L71`8000<700L00PL0100700031`03
00L700<70P0010L01`L400L700<01`L010021`0300L0008700D01`L700041`0300L000870P000`L0
00091`8000<700002@L00`071`051`001PL00`071`061ol00P081`0300L700D700061`0300L700H7
0P031`801`L200<70P051`0400L700<70P041`800PL00`071`0200D70P021`0300L000800`L200<7
00H01`001`031`0300L700870P021`0400L71`8010L2008700<01`001`L01`071`L01`001@L00`07
00031`0300L000D700<01`000`L00`071`051`0300L000870P041`800`L00`071`0200@700H01`L7
00L200031`0700870P031`<000@700L70P051`800PL00`071`0200@70P031`0400L700D70P031`80
1`L200<70P081`0300L700D700061`0300L700D700@01`000PL00`0700051`0300L000<700<01`00
1@L00`0700031`0300L700870P0010L01`031`0300L700870P031`8000<7000010L200870`021`06
00L700L00`L01@0700L000870P041`8000@700L00PL00`071`031`800`L200031`0700@70P031`80
1@L0100700031`801@L01`071`0700L00P041`800PL01@0700L000<700<01`000PL00`071`030087
0P041`8000<700000`L200@700P01`L700L01`8010L01`071`L01`001@L00`0700031`0300L000D7
00<01`000PL200031`0700H700<01`L01@L000H700<01`L010L020071`0700L00PL01@071`L00087
00<01`L00P021`0300L700<70P021`800`L200<70P031`800PL200@700@01`L70P041`8000<70000
0`L00`0700031`0400L700870P000`L000041`0300L000870P031`0700L71`0700031`0500L71`00
1@L01@071`L000D700D01`L700031`0300L000<700@01`L70P021`0300L000@70P000`L000021`04
00L700<700<01`000`L200031`0000@70P031`0300L700870P021`800`L200<70P031`800PL200D7
00<01`L00P021`0400L700<700P01`L01`07008700<01`L010L00`071`051`001PL00`071`031`05
00L71`000PL200<7k`031`800PL01@071`L000D700<01`L01@L000H700<01`L00PL00`071`021`05
00L71`0010L00`071`021`800PL00`071`021`0300L700870P021`0400L700H70P021`0400L000@7
00<01`000`L00`0700041`<010L00`071`051`800`L200@700D01`L700031`8010L02@071`L01`07
00051`0900L71`0700L000<700<01`L00`L01@0700L000<700<01`L00PL200<700D01`L700041`80
0`L200L700<01`L00PL300@700<01`000`L00`0700041`8000@700L70P061`0400L700870P041`03
00L7008700<01`L00P041`0300L7008700D01`L700041`0300L7008700<01`L01@L000H70P021`03
00L700<700@01`L70P021`0300L000<700D01`L700051`0;00L71`0700L01`001`L0100700L30005
1`071`000PL01@071`L0008700<01`L00P000`L000021`8020L00`071`0200051`071`0010L01`07
1`L01`000PL00`0700021`800PL00`071`041`0300L7008000<700000PL00`071`041`0300L70080
0PL00`0700021`0300L000<700<01`L00PL01@071`0700800PL00`071`061`800PL200031`000087
00@01`L00`L010071`021`0300L0008000@700L01`L01`0700L01`000`L00`071`031`0500L71`00
0`L00`0700021`800`L00`071`031`0300L700801`L000H700@01`001PL01P071`L01`800`L01007
00031`0300L700@700@01`000PL300P700<01`L00`031`800`L01@071`L000<70`021`@000<700L0
1`L500870P051`0500L71`000PL200<700<01`000`L00`071`051`0300L000<700<01`001`L01`07
1`L01`000`L2008700D01`L700051`800PL500P700<01`000`021`<00`L01@071`L000<70P031`<0
0PL00`071`061`<00PL200031`0700D700@01`L70P000`L01`021`8000<700L00PL00`071`041`80
00<700L01PL000H700@01`001PL01P071`L01`8010L00`0700031`0300L700D700<01`000PL200T7
00<01`L00P041`800`L01@071`L000<70P031`0600L000L020L300041`071`801@L01@071`L00087
0P041`800`L00`071`061`800`L200P700@01`L70P041`800PL01@071`L000D70P021`0300L00080
20L01P07000700<70P031`0500L71`000`L200@70P021`0300L700L70P021`0300L000L700L01`L7
00L000@70P000`L01`021`0300L700@70P000`L01`061`001PL2008700<01`L00`L010071`L20087
00D01`L01`0200<700<01`L010L01@07000700@020L0100700L2008700@01`L00PL01@071`L00087
0P0010L01`L200041`0000P70P001@L000L0008700<01`L00PL01`071`L01`000PL01P071`0700<7
00<01`L01@L00`0700031`0300L000L700L01`L700L0008700H01`L01`031`0300L7008700D01`L0
1`0200031`0000P70`000`L000021`0400L0008700D01`L700021`0400L700870P0010L01`081`@0
00D7000700061`0400L71`8000D700L700021`800`L00`071`031`0300L700801`L000H700<01`L0
0PL00`071`021`0500L71`0010L200<70P021`0300L700<700@01`L70`0010L01`071`800PL01007
00041`0300L000<700@01`000`L00`0700031`801`L200<70P041`0500L71`000`L200@70P021`80
0PL00`071`041`0300L7008000<700000PL00`071`041`0300L700800PL200@70P031`0500L71`00
10L200<70P071`800`L00`0700031`8000<700L00PL00`0700041`8000@700L70P071`0400L01`<0
0`L00`071`031`0300L700800`L200@700D01`L700041`0300L7008700<01`L01@L000`700D01`L7
00031`0300L700870P031`<000<700L00`L00`071`021`<000D700L700061`0600L71`070P051`80
0`L300D70P041`801@L300<70P051`0400L700<700<01`L00`L2008700D01`0700051`0900L71`07
00L000<700<01`L00`L01@0700L000870P051`0500L71`000PL00`071`031`800`L300D70P041`80
1@L300<70P051`8000<700L00PL00`071`041`0500L700L00`041`0300L7008700<01`000P031`80
10L01@071`L000<700<01`L02`L000d700@01`L00`L01@071`L0008700D01`L01`0300<700<01`L0
0PL200041`0000<700<01`L00PL200<70P021`0300L700<700@01`L70P051`0300L000@70`031`80
00@700L70P000`L01`041`0300L000870P041`0600L700L00PL200@700<01`L00PL200031`0000@7
00<01`L00PL2008700<01`000PL00`071`021`800PL00`0700051`0400L0008700@01`000`L300@7
00<01`001@L200<700<01`L00`L00`071`0200<70P041`0400L71`<000<7000010L010071`L30005
1`071`000PL01@071`L000<700@01`L03PL000h700<01`000`L010071`041`0300L000870P021`03
00L700870`021`8010L01P071`0700<700<01`L00PL00`071`021`8000<700001@L00`071`0200<7
00D01`001`02008700D01`0700021`0300L700<70P0010L01`031`0300L700870P031`800PL00`07
1`021`800`L200@700<01`L00P031`8010L020071`L01`070P051`0800L700L01`021`8000D70007
00031`800PL00`071`031`8000<7000010L00`071`021`0700L71`0700021`0300L700870P021`<0
10L00`071`02008700<01`0010L010071`031`0300L000l7000?1ol00P0@1`0040L010071`L200L7
0P031`<00`L2008700@01`L70`031`800PL01@0700L000H700<01`L01@031`0300L7008700H01`L0
1`021`<00`L2008700<01`L00PL00`071`021`800PL00`0700071`800PL0100700031`8000<700L0
0PL0100700031`8000@700L70P071`0300L000870P041`0300L7008700<01`L00P031`<00PL00`07
00021`0300L7008700@01`L71@021`0300L700@700D01`0700021`800`L300<700<01`L00P031`<0
0`L200L70P031`0300L700l7000@1`800PL00`071`071`800PL01@07000700800`L01P071`L01`80
00H700L700L2008700<01`L01@L0100700021`0400L700D700@01`L70P0010L000L200031`0000<7
00<01`L00`L00`071`0200031`07008020L0100700L200041`001`800PL01@071`L000870P0010L0
00L200041`0700P70P000`L01`02008700<01`L00`L010071`L200041`001`8000<700000`L00`07
1`031`0400L700870P000`L01`061`0300L7008000H700L700L200031`07008700@01`L70P001@L0
00L000870P091`0300L700804@L0010700<01`000P091`D00PL300@700D01`L700021`8010L200<7
00<01`L01PL200<70`061`0300L700870`031`@00`L00`071`041`8000@700L70P091`0300L70080
0`L300<700D01`L700031`<00`L2008700<01`L01`L2008700@01`001PL010071`L400<70`041`03
00L700@70`031`8020L010071`L200@70P021`0500L71`0010L300871@091`<000<700L040L000d7
o`0600h7000>1`0400L0008700<01`L01`L200051`001`000PL200<700H01`L700L200061`001`07
0P021`0300L700D700@01`000PL0100700051`0300L7008700<01`000PL200031`0000<700<01`L0
0`L00`071`0200031`07008020L0100700L200041`001`800PL01@071`L000870P0010L000L20004
1`0700P70P000`L01`02008700<01`L00`L010071`L200031`00008700<01`0010L00`071`031`80
00@700L70P000`L01`061`0300L7008000<700L00P001@L000L000<700@01`L70P021`0500L000L0
0P091`0300L7008000<700L03PL000l70P031`8020L010071`L200@70P021`0400L71`<00`L20087
00D01`0700061`0500L700L00`021`8010L010071`L200870`031`800PL00`071`021`0300L70087
0P021`0300L000L70P021`0400L000<70P000`L01`021`0400L000<70P0010L01`L200L700<01`00
0PL200@700<01`L00PL00`071`0200<70`021`800`L00`071`021`800PL300051`071`001PL01@07
00L000870P031`<00`L00`071`0200@70P031`0300L700H70P031`8040L0010700L01`L700L000L7
00@01`L70`041`8000<700L00PL200@70`0010L01`L200D700H01`L700L300<70P031`0600L700L0
0PL200@70`000`L01`021`0300L700<70P021`0400L700H700@01`L710041`<00`L300@710031`03
00L700@700@01`L00PL200D700H01`L700L300@70P021`0300L0008700@01`L70P031`<000<700L0
0PL00`071`031`800PL00`07000200@70P031`0400L000@70`031`0300L700D700<01`000`L00`07
1`0?1`0040L2008700@01`L01PL01P071`L01`8010L300870P041`0300L700<00`L00`071`021`03
00L700870P021`0300L700870P021`0300L0008700H01`001`031`0300L000800PL00`071`031`80
00@700L00`L00`071`021`800`L2008700<01`L00PL200<70P041`0300L700800`L200@700P01`L7
00L01`801@L00`071`0300031`07008700H01`001`021`0300L000870P041`0300L7008010L00`07
1`021`0400L71`<00PL00`071`021`800PL300@70P000`L01`021`0300L700@700@01`L00PL20147
000@1`0500L01`000`L00`071`031`0500L71`000PL200@70P0010L000031`0300L700870P031`80
0PL00`071`031`0400L71`8010L200031`0000<70`031`0400L700870P000`L01`041`0300L00087
0P041`0600L700L00PL200@700<01`L00PL200031`0000@700<01`L00PL2008700<01`000PL00`07
1`021`800PL00`0700051`0400L0008700@01`L00`L300<70P000`L000041`800`L00`071`031`03
00L700800`L200@700@01`L70`000`L000041`800PL01@071`L000D700T01`L700L01`004@L00107
00<01`L00P041`0300L7008700D01`L700031`8010L300051`071`001PL2008700@01`001@L200<7
00<01`0010L300@70P051`0300L000<70P051`0400L700<700<01`L00`L2008700<01`000P051`04
00L71`D00`L00`071`031`<000@700L70P051`0500L71`000PL00`071`031`800`L00`0700051`80
10L300@700<01`000`L200D70P0010L01`L200H700D01`L01`0300@70P031`0500L71`0010L00`07
1`021`800PL00`071`0?1`0040L01@071`L000D700D01`L700031`0300L700870P031`<000@700L0
1`L300031`07008010L00`0700031`0400L700@70P031`801`L200<70P041`0500L71`000`L200@7
0P021`<000<700L01@L00`071`05008700<01`L010L00`07000200870P041`800`L01@071`L000@7
0P031`801`L200<70P041`0400L700<700<01`0010L200031`0700<01`L0100700L300<70P041`05
00L71`000`L00`071`031`0500L71`004@L0010700@01`L70P051`0400L700<700<01`L00`L20004
1`001`@020L00`070003008700@01`L00PL01@071`L000<700H01`L01`021`<020L00`071`020005
1`071`0010L01`071`L01`000PL01@071`0700800PL00`071`051`0500L000L00P000`L01`061`03
00L7008000D700L700021`0300L000<700<01`L00PL01@071`0700800PL00`071`061`<00PL00`07
00021`0500L71`000`L010071`021`0300L700@000<700L01`L400041`001`801@L01@071`L00087
00<01`L00`L200<700<01`L03`L0010700L01`L700L000D700<01`000`L00`071`041`@00PL200T7
00<01`L00P041`800`L01@071`L000@70P021`@000<700L01`L300041`071`801@L01@071`L00087
0P041`800`L00`071`061`800`L200P700@01`L70P041`800PL01@071`L000D70P021`0300L00080
20L00`07000300870P041`0500L71`000`L200@70P021`0300L700L70P021`@01PL01`071`L01`00
1@L00`0700031`0300L700l7000@1`0500L71`000PL00`071`031`800`L00`071`041ld01PL01007
1`L200D700@01`L00`L00`071`0?1`0040L01@071`L000<700<01`L00`L01@071`L000D70P001PL0
00L01`<01`L300061`0000L00PL200031`07008700D01`L700021`0800L000L01`081`0300L70080
00@700L70P031`0700L71`0700021`0500L000L00P021`0300L700@700<01`L00P000`L000021`03
00L700@700<01`L00P001@L000L0008700<01`000`L010071`L2008700@01`000PL00`071`061`04
00L01`8000D700L700031`0600L71`070P021`0300L0008000@700001`L300031`07008000<70000
1@L01@071`L000D700D01`L700031`0300L700l7000@1`0500L71`0010L00`071`021`800PL00`07
1`021`800`L2008700@01`001PL2008700@01`0010L300<700@01`L010L200<70P071`800`L200@7
0P021`0400L71`8010L2008700D01`0700051`0900L71`0700L000<700<01`L00`L01@0700L00087
0P041`800`L00`071`0200@70P031`801`L200<70P041`0400L700<70`041`8000@700L70P061`80
00@700L70P031`8010L00`071`0200@700<01`L00PL01@071`L00147000@1`0500L71`001@L02@07
1`L01`0700031`8010L300041`071`8010L200<700<01`000P041`800`L00`0700051`8010L00`07
1`041`0300L000<70P051`8000@700L70P041`<00PL00`071`0200@700<01`L00PL200031`0000@7
00<01`L00PL2008700<01`L00`041`800PL0100700051`800`L00`0700061`0300L700870P051`03
00L000<70P041`<000<700L00PL200@70P021`0300L0008010L200<700D01`0700031`0300L700<7
00D01`L7000A1`003@Oo00H03PL000h700<01`000`L00`071`051`0300L000<700<01`001`L00`07
1`0200@710000`L01`021`0300L700870P031`<000<700L010L01P071`07008700<01`000PL02@07
1`L01`0700021`0300L700<7100010L01`L200@70P031`8000<700L010L200<70P051`0400L000<7
0P041`800PL00`07000300D700P01`L01`0700<700H01`L01`021`0300L0008700<01`L00`L00`07
000200<70P041`0600L71`0710041`800PL00`071`051`0300L000<700<01`001`L01`071`L01`00
3`L000l70P031`0300L700H70P031`8020L010071`L200@70P021`0300L700801@L2008700<01`00
0P041`0500L71`000PL00`0700021`8010L2008700D01`L700051`800PL0100700061`0700L71`07
00051`<00`L300D700<01`000`L00`071`041`8000@700L70P051`0500L71`000PL200@70P021`03
00L0008700D01`L700041`<000@700L70P051`800PL00`071`0200@70P031`0300L700H70P031`80
20L010071`L20107000@1`0500L71`002@L01`071`L01`001`L010071`L3008710001PL01`0700H7
0P000`L01`0300<700<01`L00PL010071`L200870P041`0500L71`0010L010071`L400041`0000L7
0P021`8000<700L00PL200031`07008700@01`000`L0100700021`801`L300031`0000800`L00`07
1`021`0500L71`0010L200870P031`0300L7008700@01`L70`000`L01`0200H700H01`0700L40087
0`031`0300L700D700<01`000`L00`071`071`0500L71`004@L0014700@01`L02@L200031`000087
00<01`L010L01P071`L01`@00PL4008700<01`L01@L400870P000`L01`041`0300L7008700<01`00
0PL00`071`0200<700<01`L00`L00`07000200031`00008020L01@0700L000<700@01`000PL01@07
1`L000870P000`L01`021`0500L01`0020L400061`0000L01@L010071`L2008700H01`L01`041`03
00L700<700@01`000PL400L700<01`L010021`@000<700L00PL00`071`041`0300L7008000<70000
2@L010071`0B1`004PL00`0700091`0500L01`000`L00`071`031`0500L71`000PL200@70P031`03
00L700H70P031`0300L000H700<01`L00PL200@70P000`L01`021`0300L700@70P0010L01`L200T7
00<01`L00P041`800`L01@071`L000<70P041`800PL00`071`071`800PL0100700061`0600L71`07
0P041`8010L00`071`041`0300L000<70P081`0400L71`8010L2008700D01`L700051`0900L71`07
00L000T700<01`004`L001<70P091`8000<7000010L00`071`021`0600L71`0710031`<00PL00`07
1`061`800`L200031`0700@700<01`L00PL00`0700031`8000<700L00PL00`071`031`<000<700L0
10081`0500L01`000`L300<700D01`L700031`<00`L01@0700L000P710000`L01`0300D700H01`L7
00L200<700<01`0010L00`071`031`0400L000<70P081`0300L700<00`L400031`07008700<01`L0
0PL00`071`021`8000<700002@L201@7000D1`0300L700L700D01`L700051`0500L71`000`L30087
0P000`L01`0300031`0700H700@01`000PL01@071`L000@700@01`L70P021`0300L000870P031`03
00L700870P021`@000@700001`L200870P000`L000021`0400L700<700@01`L00PL200031`000087
0P071`<000<700000P021`8010L010071`L2008700<01`000PL200<700<01`L00PL01@071`L00087
0P000`L01`061`0300L0008000<700L00P021`<00`L01@071`L000D700D01`L700091`0300L701<7
000D1`801`L200<70P051`0400L700<70P041`800PL00`07000200H700D01`L01`0300@700D01`L7
00021`0300L000<700<01`L00PL01@071`L000<70P041`800PL0100700061`0600L71`070P041`03
00L000<700<01`0010L200031`07008700<01`L010L200041`071`8010L200<700D01`L700041`07
00L71`0700021`0500L71`0010L300051`071`001PL300041`071`8010L200<700@01`L01@L200<7
0P071`805@L001@700<01`001@L00`0700031`0300L000D7b`051`0300L000<700<01`001@L00`07
000E1`0050L010071`031`0400L700<700@01`L01@L200870P041`0300L700<00`L200<700<01`L0
0PL2008700<01`L010L0100700031`0300L000<700T01`L01`0700L00P041`0700L01`0700031`80
0PL00`0700031`800PL200@700D01`L700041`800PL200<700<01`000PL200<700@01`070`041`80
00H700L01`021`0700L71`0700031`8000<700L01@L00`071`0200@700@01`L70P031`800`L00`07
1`021`800PL200D700@01`L00`L010071`031`0400L701D7000D1`0700L71`0700031`0500L71`00
0`L00`071`031`0500L01`000`L00`071`031`0400L71`<000<700L00`L200<70P061`8010L200D7
00<01`000PL400@700@01`L00PL200@70`021`0300L7008010L200<70P000`L000031`8010L20087
00<01`L00`041`800PL010071`041`@00PL00`0700051`8010L200H70P031`8010L00`07000200<7
00<01`L00`L02@071`L01`0700051`0500L71`000`L01`071`L01`000`L00`071`0C1`0050L00`07
1`021`0300L7008700D01`L700041`0300L700870P021`0400L700H70P021`0400L000@70`031`03
00L000D70P041`0300L700D70P031`8010L01@071`L000<700<01`L00`L2008700<01`000P051`80
0PL01@0700L000870P051`<000@700L70P051`0500L71`000`L00`071`021`800`L200L700<01`L0
0PL200D700<01`000`L300@70P0010L01`L200H700@01`L00PL200@700<01`L00PL01@071`L000@7
00<01`L00PL00`071`0C1`0050L01`071`L01`000`L01@071`L000D700/01`L700L01`0700071`04
00L01`D00PL200031`07008700@01`L00`L0100700021`8020L00`071`0300<700<01`L00PL01007
1`L200<700D01`001`0300031`0700D70P0010L000L200031`0000H700<01`000P001@L000L000<7
0P031`0300L7008700<01`L010021`0300L700H70P021`8000<700L00PL010071`031`0400L00087
0`001PL01`0700L700L01`0700L000<700<01`L00`L01@071`L000870P000`L01`021`0300L701<7
000D1`8000<700L00PL200031`07008700<01`L010O=00H700H01`L700L200<700@01`005@L001@7
00<01`001@L300<700<01`L01@L00`0700031`0300L700L700<01`L00P041`800`L01@071`L000@7
00H01`L700L200031`0700L70`0010L01`L200D700D01`L700021`0300L700<70P031`0300L700H7
0P031`8020L010071`L200D700@01`L00`L00`071`031`800PL00`07000200P700H01`001`031`03
00L7008700D01`L700031`8010L2008700<01`L01`L01`071`L01`001`L010071`L300D700<01`00
5@L001@70P000`L01`041`800`L00`071`041`0400L000870`081`0300L000<00PL200051`071`00
0`L01`071`L01`000PL200870P081`0300L7008000<700L00P041`0900L71`0700L000<710021`03
00L700D700D01`001`0200031`0700H700<01`L010031`0500L01`000`L00`071`021`8000<700L0
0P021`0300L700H70P021`800PL00`0700031`0500L71`000PL0100700021`@000<700L01`L30087
0P000`L01`051`0400L71`801@L01007000E1`0050L01@071`L000D70P021`0300L700<700/01`L7
00L01`0700071`<000<700L00`031`0300L000<700@01`L00`L00`0700041`0300L700D70P031`80
0`L200<700@01`L70P031`0500L000L00`000`L01`051`0300L700D00PL00`071`041`0300L00080
00D7000700031`800`L010071`L200<70P031`801`L00`071`021`0300L000<700@01`L00`L00`07
00031`<000<700L00`071`0700L01`0700031`0300L700<700<01`L00P051`0500L71`005@L001T7
00<01`L00PL300031`0700<700<01`L00PL2008700@01`L01PL2008700@01`001@L200<700<01`00
1@L200@70P051`0300L000<70P041`800PL01@071`L000D70P021`0300L000801@L010071`L500<7
00<01`L00`L300041`071`801@L01@071`L000870P041`800`L00`0700051`8010L200D700<01`00
0`L200D70P0010L01`L200H700@01`L00PL200@700<01`L00PL00`07000200@700<01`L060L001X7
00H01`L700L300<700<01`L00`L01@0700L000<700<01`L00PL200<70`000`L01`041`0400L71`80
1@L00`0700041`0300L000<700@01`L00PL200031`0700<70P0010L01`L200@70`021`0300L70080
10L00`071`021`8000<7000010L00`071`021`800PL00`071`0300@70P021`0400L000@700@01`00
0PL010071`031`0300L000@700<01`001@L200<700<01`L00`L00`07000200<70P041`0900L71`07
00L000D700@01`L70`000`L01`021`0300L701T7000K1`0400L700870P021`0300L700<70P021`80
10L00`071`0300<70P031`0300L700870P021`0300L700<700<01`L00P031`0600L700L00`L01@07
00L0008700<01`L00PL300041`0700<70P021`0300L000<70P021`0300L700870P031`8010L00`07
1`0200<700<01`000PL200<700@01`070`041`0800L700L01`031`0300L0008700@01`L70P021`03
00L700<700<01`L00P041`0400L71`800`L3008700<01`L00PL200870P051`0300L700800PL01007
1`0L1`0070L00`0700031`<01@L00`0700031`0300L700<70`0010L01`L200D700H01`L700L300@7
00L01`L700L0008700D01`L700041`800PL01@071`L000@70`021`0300L7008010L200<710041`<0
0`L300@710031`8010L2008700<01`L00`041`0500L71`000PL200@700D01`L700021`0300L000<7
00<01`L00PL300031`07008700<01`L00`L2008700<01`000P051`0700L71`0700051`<00`L00`07
000M1`007@L200<70`041`0400L700<70P041`800PL00`07000200H700D01`L01`0300<700<01`L0
0PL01P071`07008700<01`000`L01@071`L000@700<01`L00PL2008700@01`001PL2008700@01`00
0`L200031`07008700@01`000`L200041`071`801PL200041`071`8010L00`071`021`0500L71`00
0`L00`0700021`0300L0008700<01`L00PL010071`L300051`071`001PL300041`071`8010L200<7
00@01`L010L300<70P0N1`007POS01l7000N1`D00PL300@700D01`L700021`<00`L3008700<01`L0
1PL200<70`061`0300L700870P041`8000<700L00PL00`071`041`8000@700L70`081`0300L00080
0`L300<700D01`L700031`<00`L300031`0700L70`021`0400L000H700H01`L700L200@70P041`03
00L700@70`031`8020L00`071`0300<70`021`0500L71`0010L300871@0O1`007PL00`07000200<7
0P041`0500L71`000PL200@70P031`0300L700H70P031`<01PL00`071`021`8010L400<700<01`L0
10L200041`071`802@L00`071`0200<70`031`0500L71`000`L300<70P021`0300L700L70P021`04
00L000H700@01`L710041`8010L00`071`041`<00`L200P700@01`L70P041`800PL01@071`L000@7
0P031`<000<700L07PL001h70P000`L000021`0400L000<700H01`L700L200061`071`070P021`03
00L700D700@01`000PL010071`051`0400L71`8000D700L700021`800`L00`071`031`0300L70080
00<700000P081`0400L01`8000@700070P021`0500L71`000PL200041`001`8000@700L020L40003
1`00008700<01`L00`L010071`L2008700D01`L01`0200<700<01`L00`L010071`021`8000<700L0
1PL00`071`0200061`071`070P000`L01`021`0400L71`8000@700L70P000`L0000O1`007PL01007
1`L300<7c`031`<00`L00`071`0M1`008PL300@70P000`L01`021`8010L2008700<01`L00P051`06
00L71`070`041`0600L71`070P0010L01`L300<70`000`L01`021`0300L700<70P021`0400L700H7
00@01`L710041`<00`L300@710031`0300L700@700@01`L00PL200D700H01`L700L300<70`021`06
00L000L00`L00`071`021`<000<700L00PL00`071`031`800PL00`071`0200@70P031`0400L000@7
0`0S1`008PL010071`041`<00`L00`071`021`0600L700L00`L00`071`021`0300L700870P021`03
00L700<700<01`L00`021`0300L000870P021`0300L000800PL00`071`031`8000@700L00`L00`07
1`021`800`L2008700<01`L00PL200<70P041`0300L700800`L200@700P01`L700L01`801@L00`07
1`0300041`071`800PL00`0700021`<00PL00`071`031`0300L7008010L00`071`021`0700L71`07
00021`0300L7008700@01`L70`041`0400L702<7000R1`0500L71`0010L200<700D01`L700041`80
0`L2008700<01`L00`L010071`L200D700@01`000`L200@70P0010L01`L200031`0700@700<01`00
0PL200@700H01`L01`021`8010L00`071`021`8000<7000010L00`071`021`800PL00`0700021`03
00L700870P021`0300L000D700@01`000PL0100700041`800`L200031`0700@70P031`0300L700<7
00<01`L00P031`8010L01@071`L000<70P041`0500L71`008`L0028700<01`L00PL00`071`021`80
0PL010071`061`0600L71`070P051`800`L00`0700051`8010L00`071`041`<00`L200D700@01`L0
0`L00`071`031`800PL00`07000200D700@01`L71@031`0300L700<70`0010L01`L200D700D01`L7
00021`0300L700<70P031`<01PL00`071`021`801@L00`0700031`801@L200031`07008700<01`L0
10L010071`021`8010L00`071`021`0300L70247000R1`0300L700<700@01`L70`0010L01`071`80
0PL0100700041`0300L000<700@01`L00`L300<70P071`800`L200@700D01`L700031`8010L20087
0`000`L01`051`0300L700D00PL00`071`041`0300L000800PL200@70P031`0500L71`0010L200<7
0P071`800`L300<700@01`L00`L00`0700041`8000@700L70P071`0400L01`<00`L00`071`031`03
00L70247000R1`0300L700@700D01`L01`0400P700@01`070P021`0400L7008700D01`L700031`05
00L000L00P0010L01`081`8000D7000700021`0300L7008700L01`L700L0008700D01`L01`020087
00<01`L01@L01@070007008000<700L01PL00`071`0200051`071`000PL00`0700031`0300L70087
00D01`L01`0200031`0000P700@01`070P001@L000L000<700D01`L700021`0400L700870P0010L0
1`081`@000D700L700061`0300L70247000R1`0300L700D700<01`000PL200T700<01`L00P041`80
0`L01@071`L000@70P021`<00PL00`071`061`<000@700L70P051`0500L71`000PL200@70P031`03
00L700H70P031`8020L010071`L200@70P021`0500L71`001@L2008700<01`000P081`0300L700<0
0PL200@700D01`L700031`8010L2008700<01`L01`L2008700<01`001`L00`071`0Q1`008PL00`07
1`061`800PL300P700<01`L00P041`800`L01@071`L000<70`021`@000<700L01`L500870P051`05
00L71`000PL200<70`031`0300L700D70`031`<01`L010071`L300<70P021`0500L71`001@L20087
1@081`0300L000<00PL300<700D01`L700031`8010L2008700<01`L01PL300870P081`0300L70247
000R1`0300L700L700@01`070`071`0400L01`800PL010071`021`0500L71`000PL2008700D01`00
1`0300P700<01`L00P001@L01`L000@700L01`L700L0008700D01`001`02008700<01`L010L20004
1`001`8000<700001PL00`071`0200051`001`000PL00`0700031`0300L7008700D01`L01`020087
00<01`L01PL300051`001`000PL2008700D01`L700021`0400L700870P0010L01`071`<000@700L0
2@L00`071`0Q1`007`OQ0207000P1`0300L000T700D01`0700021`801@L01P071`L01`801@L200<7
0`041`<010L200D700<01`000`L300@700@01`L00`L00`071`031`800PL00`071`0200@70P031`80
00<700000`L200@70P021`0300L700801@L01@071`L0008700<01`L00PL300<700<01`001@L200@7
0`041`<00`L200D70P000`L01`021`0300L700<70P021`0500L01`002@L00`07000Q1`008@L200`7
0P031`8020L2008700<01`L00`L010071`L200@70P000`L000031`<00`L010071`021`8000<70000
10L00`0700021`8010L01P071`0700<700@01`L70P041`0500L71`0010L200<700L01`L700L00087
00<01`L00PL2008700<01`0010L200031`00008700@01`L00`L300<70P000`L000041`800`L00`07
1`031`0300L7008020L200<70P0<1`808PL0028700<01`L02`L00`071`021`801`L00`071`021`03
00L700870P000`L000041`800PL00`0700021`0600L000L00`L00`07000200870P041`8000@700L0
0`L00`071`021`800`L200031`0000@70P031`8010L200031`0000<70P041`0800L71`0700L200@7
0P021`<000<700L00PL01P070007008700<01`000PL200@70P000`L000041`0300L7008700<01`L0
1@L200@700<01`L02`L00`071`0Q1`008`L00`071`0;1`0300L7008700<01`L010NU00H700<01`L0
0PL00`071`0;1`0300L70287000T1`0300L700/700<01`L00PL00`071`041`0300L700@700D01`L0
1`0300870P041`0400L71`800PL300<70P021`0300L700870P031`800PL00`0700071`800PL400<7
00@01`L00`L010071`031`@00PL200L700<01`000PL200<70P041`0300L700800`L300870P031`03
00L700870P021`<000D700L700061`0300L700@700<01`L00PL00`071`0;1`0300L702<7000U1`03
00L700/700<01`L00PL00`071`031`0300L700D700@01`000PL0100700051`0400L71`8000@700L7
0P000`L000031`0300L700<70P001PL000L01`8020L0100700L2008700<01`000`L01@071`L000<7
00<01`000PL200041`0700P70P000`L01`0200031`0000D700@01`L70P000`L000021`0400L000<7
00<01`L00`L200041`071`8000<700L01PL00`071`031`0300L7008700<01`L02`L00`071`0T1`00
9PL00`071`0;1`0300L7008700<01`L00PL00`071`061`800`L300H700<01`L00PL200@710031`03
00L700@70P0010L01`L200T700<01`L00P041`0300L7008700D01`L700041`0300L700870P021`03
00L700L70P021`0400L000H700@01`L710041`8010L00`071`041`<00`L200P700@01`L70P041`03
00L700/700<01`L09@L002L700<01`L02`L00`071`021`800PL00`071`061`800`L300H700<01`L0
0PL300<710031`0300L700@710021`802@L00`07000200<700<01`000`L01@071`L000<700<01`00
0`L300031`0700P70P021`@01PL010071`L400<70`041`0300L700@70`031`8020L00`071`0200@7
00<01`L02`L00`071`0V1`00:0L00`071`0;1`0300L700870P000`L01`061`0500L000L00P021`03
00L700<700@01`L70P0010L000L200031`0000<700<01`L00`L00`071`0200031`07008020L30005
1`001`000`L010071`031`0400L700<700D01`001`0300P70P000`L01`02008700<01`L00`L01007
1`L200041`001`8000<700000`L00`071`031`0300L7008000D7000700071`0400L000@700<01`L0
2`L00`071`0W1`00:@L00`071`0;1`0300L700870`061`0500L700L00`031`0300L7008700H01`L0
1`021`<00`L2008700<01`L00PL00`071`021`800PL00`0700071`800PL00`0700051`0300L000<7
00<01`001@L00`0700021`801`L00`0700021`8010L00`071`021`0300L700800`L3008700<01`00
0PL00`071`021`0400L71`<000D700L700061`<010L00`071`0;1`0300L702P7000Z1`0300L700/7
00<01`L00PL200D700@01`L71@041`0700L71`0700021`0300L700<00`L300031`07008700<01`L0
0PL400051`071`001@L200<70P000`L01`041`800`L200D700@01`000`L200D700D01`L01`0400@7
00H01`L700L300<70`021`0600L700L00`L00`071`021`D00`L00`071`031`8010L00`071`0;1`03
00L702T7000[1`0300L700/700<01`L00PL200<700<01`L00PL2008700<01`L00`L00`071`0200<7
00D01`001`02008700<01`000P021`0300L700870`0010L000031`0700L71`0700031`0500L71`00
1@L01@071`L000D700D01`L700031`0300L000<700@01`L70`0010L000041`0300L700<000@700L7
0P001@L000L000<70P021`0300L700<700<01`L00P041`0400L71`8010L00`071`0;1`0300L702X7
000/1`0300L700/700@01`L70`000`L01`031`800`L200D700<01`0010L300<70P0010L01`L20003
1`0700<70P0010L01`L200@700<01`000PL00`071`0200@700<01`L00PL200031`0000@700<01`L0
0PL2008700H01`L01`041`800PL0100700041`0400L0008700@01`000`L300@700<01`001@L200<7
0P041`0300L000800`L00`071`0;1`0300L702/7000]1`0300L700/7Z@0=1`0300L702`7000^1`03
00L700/700@01`070`051`0500L71`000PL01`071`L01`000`L200L70P031`<00PL200<700@01`L7
0`021`<00PL2008700<01`L010L00`071`0200031`00008700<01`L010L00`071`0200870`021`<0
0`L010071`L200870`031`801`L200<700<01`000`L010071`031`0300L700<70`0010L01`0=1`03
00L702d7000_1`0300L700/70`021`8010L01@071`L000<700<01`000PL200041`0700P70P0010L0
00L400@700H01`L700L4008700<01`000`L00`071`051`0300L000<700<01`001`L01`071`L01`00
0PL400031`07008700<01`L00PL400041`001`8020L0100700L2008700<01`000`L01@071`L000@7
0P021`<03@L00`071`0^1`00<0L00`071`0;1`0300L700870P031`0500L71`0010L01`071`L01`00
0PL00`071`061`<000@700L70P051`0500L71`000PL200@70P031`0300L700H70P031`8020L01007
1`L200@70P021`0500L71`001@L2008700<01`000P081`0600L700L00`L00`071`021`0500L71`00
0`L200@700<01`L02`L00`071`0_1`00<@L00`071`091jD02`L00`071`0`1`00<PL00`071`091`03
00L000@70P000`L01`021`0400L700<700<01`000`L200P700<01`L010021`800`L010071`L30087
00<01`000PL2008700<01`L010L00`071`0200031`00008700<01`L010L00`071`02008700<01`00
0PL300<700@01`L70P021`@00PL00`071`061`800`L00`0700031`0400L700<700@01`0010L00`07
000;1`0300L70347000c1`0300L700P700@01`L010L300<700<01`001@L200@700<01`L01PL01007
1`L200@70P021`0400L71`8010L02@071`L01`0700051`0900L71`0700L000<700<01`L00`L01@07
00L000<700<01`L00PL200<700<01`L00P041`800`L00`071`061`0300L700870P051`0300L000<7
0`041`0400L700X700<01`L0<PL003@700<01`L01`L01@071`L000@70P031`801@L00`0700051`03
00L700D700<01`L010041`8000@700L70P041`0300L0008700<01`L00P041`0300L700870P000`L0
00041`0300L700870P021`0600L700L010L2008700@01`0010L4008700<01`L01@L00`071`031`03
00L000D70P031`8010L01@071`L000T700<01`L0<`L003D700<01`L01PL00`071`021`0300L70087
0P021`0300L700<700D01`L700051`0300L700@700@01`000PL200@70`0010L000031`0700L71`07
00031`0500L71`001@L01@071`L000D700D01`L700031`0300L000<700@01`L70`0010L000041`80
0PL200031`0700D700<01`L00`L01@071`L000D700<01`L00P041`0300L7008700<01`L01PL00`07
1`0d1`00=PL00`071`051`0300L700<700<01`L00PL400@700<01`L00`L00`071`031`0300L700<7
0`041`8010L400051`071`001@L200<70P000`L01`041`800`L200D700@01`000`L200D700D01`L0
1`0400@70P041`<01@L00`071`031`0300L700<700<01`L00PL400@700<01`L00`L00`071`051`03
00L703D7000g1`0300L700@700<01`L010L00`071`021`<00`L00`071`051`0300L700<700<01`L0
0PL200H70P041`800PL00`0700071`0700L71`0700051`0300L000<700<01`001@L00`0700031`03
00L700D700<01`000PL200@70P061`8010L00`071`031`0300L700D700@01`L70`041`0300L700@7
00<01`L010L00`071`0f1`00>0L00`071`031`0300L700D700D01`L01`02008700<01`L01`L00`07
1`031`0500L71`0020L200<70`000`L000081`800PL200031`07008700@01`L00`L010071`031`04
00L000870P081`8000@700000`L200P700D01`L700051`0300L700L700<01`L00P001@L01`L000L7
00<01`L00`L00`071`0g1`00>@L00`071`021`0300L700H70P031`<02`L00`071`031`0400L000T7
0P0010L000L300T700D01`0700031`0300L000<700D01`L700031`0300L000<700D01`0700091`<0
00@700070P091`8000<700L010L00`071`091`<00`L200P700<01`L00PL00`071`0h1`00>PL01@07
1`L000P70P031`<030L00`071`031`0300L000X70P0010L01`L200T700<01`L00P041`0300L70087
00D01`L700041`0300L700870P021`0300L700L70P021`0400L000X700<01`001@L00`071`0:1`<0
0`L200P700D01`L7000k1`00>`NY03`7000l1`0300L000X710021`8030L00`0700031`0300L700X7
0`021`<01`L200870P000`L01`021`0400L700<700@01`L00`L0100700021`801`L300870`0<1`07
00L71`07000<1`800PL400X700<01`00?@L003d70P0;1`<00`L200`700<01`L00PL200`70P021`04
00L000H700L01`L700L000D700<01`000`L00`0700051`0300L000<700<01`L010L200041`071`80
30L200@700<01`L02PL200<70`0;1`80?PL003h700<01`L020L0100700041`802PL00`0700031`03
00L000X7100010L01`L200@70P031`8000<700L010L200<70P051`0400L000<70P041`800PL00`07
000300X700<01`000`L00`07000:1`8010L200031`0700T700<01`L0?@L004P7S`191`00C@L00`07
1`031`801PL00`071`031`0300L000<700<01`L01`L00`071`0200@700<01`000PL00`071`0200@7
00<01`L00PL200031`0000@700<01`L00PL2008700H01`L01`041`800PL00`071`071`0700L71`07
00051`0300L700@70P051`0300L704`7001>1`0300L700<70P041`0300L700D70P041`0300L700H7
00@01`L70P041`0900L71`0700L000D700T01`L700L01`000`L00`071`031`0500L01`000`L00`07
1`021`800`L00`071`061`0300L700870P071`0300L700870P051`0300L704d7001?1`0300L700<7
00D01`L700091`0300L700<700<01`L01@L01`071`L01`000PL00`0700021`800PL00`071`041`03
00L7008000<700000PL00`071`041`0300L700800PL00`0700021`0300L000<700<01`L01@L00`07
1`031`0300L700L700D01`L700051`0300L704h7001@1`0300L700<700<01`002PL200D700<01`L0
10L01@071`L000870P031`0300L000<700<01`L01@L00`0700031`0300L000L700L01`L700L000<7
0P021`0500L71`001PL00`071`031`802PL00`0700051`0300L704l7001A1`0300L700<700<01`L0
2@L00`0700051`0300L700<700D01`L700021`8010L200<700<01`L01PL200<70P081`0400L71`80
10L2008700D01`L700051`0300L700<700<01`002`L00`071`031`0300L70507001B1`0700L71`07
000:1`0400L700D700<01`L00PL01`071`L01`000PL01P071`0700<700<01`L01@L00`0700031`03
00L000L700L01`L700L0008700H01`L01`031`0300L7008700<01`L00`L010071`0:1`0300L000<7
00<01`L0D@L005<700<01`000`L00`071`071`0500L71`001@L01@071`L000<70P041`800`L01007
1`061`0300L700L700<01`L010L010071`031`8010L200<700D01`L700051`0500L71`002@L01`07
1`L01`00E0L005@700<01`L00`L00`071`061`0300L7008700<01`L00`L010071`031`0300L700<7
0P041`0300L000D700<01`L02@L00`071`031`0300L000@70P051`0500L71`000PL00`071`031`03
00L7008700<01`L01PL00`071`031`0300L705<7001C1`0300L000D700<01`L01@L00`071`031`03
00L700<700<01`000PL200@700@01`L010L200@700<01`L02`L00`071`021`8010L010071`041`80
0PL00`0700051`0300L700<700<01`L01@L00`071`031`0300L005@7001B1g/0D`L005d700<01`L0
0`L00`071`051`0300L700<70P021`0300L700L700@01`L70P000`L01`0@1`0400L000<700<01`L0
1`L00`071`0200D700<01`L01@L00`071`031`0300L705`7001N1`0300L7008700<01`L01PL00`07
1`021`800PL00`071`081`0600L700L04`L00`0700021`0300L700P700<01`L00P041`0300L700H7
00<01`L00PL00`071`1M1`00G`L01@071`L000T700<01`L00P0010L01`0;1`0600L000L04@L01P07
000700/700@01`070P021`0300L700L700D01`L7001P1`00H0MO0647001Q1`0300L000/700<01`00
0`L00`071`0:1`805`L200`700L01`L700L000/700<01`00HPL006870P0<1`8010L00`071`081`03
00L701T700<01`L020L00`071`021`8030L206<7001S1`0300L700/700<01`L00`L00`071`061`03
00L701/700<01`L01PL00`071`031`0300L700/700<01`L0HPL007P700<01`L010L00`071`0M1`03
00L700@700<01`L0M`L007T700<01`L00PL00`071`0O1`0300L7008700<01`L0N0L007X700@01`L0
8`L010071`1k1`00N`L202D70P1l1`00N`L202D70P1l1`00NPL010071`0S1`0400L707/7001i1bd0
NPL00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.3463, -10.3463, 0.0720999, \
0.0720999}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[lattice31, \ lattice42]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0481025 0.5 0.0481025 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.42785 .04303 m
.52405 .04303 L
s
.42785 .04303 m
.42785 .13923 L
s
.52405 .04303 m
.62026 .04303 L
s
.52405 .04303 m
.52405 .13923 L
s
.62026 .04303 m
.62026 .13923 L
s
.23544 .13923 m
.33164 .13923 L
s
.23544 .13923 m
.23544 .23544 L
s
.33164 .13923 m
.42785 .13923 L
s
.33164 .13923 m
.33164 .23544 L
s
.42785 .13923 m
.52405 .13923 L
s
.42785 .13923 m
.42785 .23544 L
s
.52405 .13923 m
.62026 .13923 L
s
.52405 .13923 m
.52405 .23544 L
s
.62026 .13923 m
.71646 .13923 L
s
.62026 .13923 m
.62026 .23544 L
s
.71646 .13923 m
.81267 .13923 L
s
.71646 .13923 m
.71646 .23544 L
s
.81267 .13923 m
.81267 .23544 L
s
.13923 .23544 m
.23544 .23544 L
s
.13923 .23544 m
.13923 .33164 L
s
.23544 .23544 m
.33164 .23544 L
s
.23544 .23544 m
.23544 .33164 L
s
.33164 .23544 m
.42785 .23544 L
s
.33164 .23544 m
.33164 .33164 L
s
.42785 .23544 m
.52405 .23544 L
s
.42785 .23544 m
.42785 .33164 L
s
.52405 .23544 m
.62026 .23544 L
s
.52405 .23544 m
.52405 .33164 L
s
.62026 .23544 m
.71646 .23544 L
s
.62026 .23544 m
.62026 .33164 L
s
.71646 .23544 m
.81267 .23544 L
s
.71646 .23544 m
.71646 .33164 L
s
.81267 .23544 m
.81267 .33164 L
s
.13923 .33164 m
.23544 .33164 L
s
.13923 .33164 m
.13923 .42785 L
s
.23544 .33164 m
.33164 .33164 L
s
.23544 .33164 m
.23544 .42785 L
s
.33164 .33164 m
.42785 .33164 L
s
.33164 .33164 m
.33164 .42785 L
s
.42785 .33164 m
.52405 .33164 L
s
.42785 .33164 m
.42785 .42785 L
s
.52405 .33164 m
.62026 .33164 L
s
.52405 .33164 m
.52405 .42785 L
s
.62026 .33164 m
.71646 .33164 L
s
.62026 .33164 m
.62026 .42785 L
s
.71646 .33164 m
.81267 .33164 L
s
.71646 .33164 m
.71646 .42785 L
s
.81267 .33164 m
.90887 .33164 L
s
.81267 .33164 m
.81267 .42785 L
s
.90887 .33164 m
.90887 .42785 L
s
.04303 .42785 m
.13923 .42785 L
s
.04303 .42785 m
.04303 .52405 L
s
.13923 .42785 m
.23544 .42785 L
s
.13923 .42785 m
.13923 .52405 L
s
.23544 .42785 m
.33164 .42785 L
s
.23544 .42785 m
.23544 .52405 L
s
.33164 .42785 m
.42785 .42785 L
s
.33164 .42785 m
.33164 .52405 L
s
.42785 .42785 m
.52405 .42785 L
s
.42785 .42785 m
.42785 .52405 L
s
.52405 .42785 m
.62026 .42785 L
s
.52405 .42785 m
.52405 .52405 L
s
.62026 .42785 m
.71646 .42785 L
s
.62026 .42785 m
.62026 .52405 L
s
.71646 .42785 m
.81267 .42785 L
s
.71646 .42785 m
.71646 .52405 L
s
.81267 .42785 m
.90887 .42785 L
s
.81267 .42785 m
.81267 .52405 L
s
.90887 .42785 m
.90887 .52405 L
s
.04303 .52405 m
.13923 .52405 L
s
.04303 .52405 m
.04303 .62026 L
s
.13923 .52405 m
.23544 .52405 L
s
.13923 .52405 m
.13923 .62026 L
s
.23544 .52405 m
.33164 .52405 L
s
.23544 .52405 m
.23544 .62026 L
s
.33164 .52405 m
.42785 .52405 L
s
.33164 .52405 m
.33164 .62026 L
s
.42785 .52405 m
.52405 .52405 L
s
.42785 .52405 m
.42785 .62026 L
s
.52405 .52405 m
.62026 .52405 L
s
.52405 .52405 m
.52405 .62026 L
s
.62026 .52405 m
.71646 .52405 L
s
.62026 .52405 m
.62026 .62026 L
s
.71646 .52405 m
.81267 .52405 L
s
.71646 .52405 m
.71646 .62026 L
s
.81267 .52405 m
.90887 .52405 L
s
.81267 .52405 m
.81267 .62026 L
s
.90887 .52405 m
.90887 .62026 L
s
.04303 .62026 m
.13923 .62026 L
s
.13923 .62026 m
.23544 .62026 L
s
.13923 .62026 m
.13923 .71646 L
s
.23544 .62026 m
.33164 .62026 L
s
.23544 .62026 m
.23544 .71646 L
s
.33164 .62026 m
.42785 .62026 L
s
.33164 .62026 m
.33164 .71646 L
s
.42785 .62026 m
.52405 .62026 L
s
.42785 .62026 m
.42785 .71646 L
s
.52405 .62026 m
.62026 .62026 L
s
.52405 .62026 m
.52405 .71646 L
s
.62026 .62026 m
.71646 .62026 L
s
.62026 .62026 m
.62026 .71646 L
s
.71646 .62026 m
.81267 .62026 L
s
.71646 .62026 m
.71646 .71646 L
s
.81267 .62026 m
.90887 .62026 L
s
.81267 .62026 m
.81267 .71646 L
s
.90887 .62026 m
.90887 .71646 L
s
.13923 .71646 m
.23544 .71646 L
s
.13923 .71646 m
.13923 .81267 L
s
.23544 .71646 m
.33164 .71646 L
s
.23544 .71646 m
.23544 .81267 L
s
.33164 .71646 m
.42785 .71646 L
s
.33164 .71646 m
.33164 .81267 L
s
.42785 .71646 m
.52405 .71646 L
s
.42785 .71646 m
.42785 .81267 L
s
.52405 .71646 m
.62026 .71646 L
s
.52405 .71646 m
.52405 .81267 L
s
.62026 .71646 m
.71646 .71646 L
s
.62026 .71646 m
.62026 .81267 L
s
.71646 .71646 m
.81267 .71646 L
s
.71646 .71646 m
.71646 .81267 L
s
.81267 .71646 m
.90887 .71646 L
s
.81267 .71646 m
.81267 .81267 L
s
.13923 .81267 m
.23544 .81267 L
s
.23544 .81267 m
.33164 .81267 L
s
.33164 .81267 m
.42785 .81267 L
s
.33164 .81267 m
.33164 .90887 L
s
.42785 .81267 m
.52405 .81267 L
s
.42785 .81267 m
.42785 .90887 L
s
.52405 .81267 m
.62026 .81267 L
s
.52405 .81267 m
.52405 .90887 L
s
.62026 .81267 m
.71646 .81267 L
s
.62026 .81267 m
.62026 .90887 L
s
.71646 .81267 m
.81267 .81267 L
s
.71646 .81267 m
.71646 .90887 L
s
.33164 .90887 m
.42785 .90887 L
s
.42785 .90887 m
.52405 .90887 L
s
.52405 .90887 m
.62026 .90887 L
s
.62026 .90887 m
.71646 .90887 L
s
.33164 .09113 m
.42785 .09113 L
s
.33164 .09113 m
.33164 .18733 L
s
.42785 .09113 m
.52405 .09113 L
s
.42785 .09113 m
.42785 .18733 L
s
.52405 .09113 m
.62026 .09113 L
s
.52405 .09113 m
.52405 .18733 L
s
.62026 .09113 m
.71646 .09113 L
s
.62026 .09113 m
.62026 .18733 L
s
.71646 .09113 m
.71646 .18733 L
s
.13923 .18733 m
.23544 .18733 L
s
.13923 .18733 m
.13923 .28354 L
s
.23544 .18733 m
.33164 .18733 L
s
.23544 .18733 m
.23544 .28354 L
s
.33164 .18733 m
.42785 .18733 L
s
.33164 .18733 m
.33164 .28354 L
s
.42785 .18733 m
.52405 .18733 L
s
.42785 .18733 m
.42785 .28354 L
s
.52405 .18733 m
.62026 .18733 L
s
.52405 .18733 m
.52405 .28354 L
s
.62026 .18733 m
.71646 .18733 L
s
.62026 .18733 m
.62026 .28354 L
s
.71646 .18733 m
.81267 .18733 L
s
.71646 .18733 m
.71646 .28354 L
s
.81267 .18733 m
.81267 .28354 L
s
.13923 .28354 m
.23544 .28354 L
s
.13923 .28354 m
.13923 .37974 L
s
.23544 .28354 m
.33164 .28354 L
s
.23544 .28354 m
.23544 .37974 L
s
.33164 .28354 m
.42785 .28354 L
s
.33164 .28354 m
.33164 .37974 L
s
.42785 .28354 m
.52405 .28354 L
s
.42785 .28354 m
.42785 .37974 L
s
.52405 .28354 m
.62026 .28354 L
s
.52405 .28354 m
.52405 .37974 L
s
.62026 .28354 m
.71646 .28354 L
s
.62026 .28354 m
.62026 .37974 L
s
.71646 .28354 m
.81267 .28354 L
s
.71646 .28354 m
.71646 .37974 L
s
.81267 .28354 m
.90887 .28354 L
s
.81267 .28354 m
.81267 .37974 L
s
.90887 .28354 m
.90887 .37974 L
s
.04303 .37974 m
.13923 .37974 L
s
.04303 .37974 m
.04303 .47595 L
s
.13923 .37974 m
.23544 .37974 L
s
.13923 .37974 m
.13923 .47595 L
s
.23544 .37974 m
.33164 .37974 L
s
.23544 .37974 m
.23544 .47595 L
s
.33164 .37974 m
.42785 .37974 L
s
.33164 .37974 m
.33164 .47595 L
s
.42785 .37974 m
.52405 .37974 L
s
.42785 .37974 m
.42785 .47595 L
s
.52405 .37974 m
.62026 .37974 L
s
.52405 .37974 m
.52405 .47595 L
s
.62026 .37974 m
.71646 .37974 L
s
.62026 .37974 m
.62026 .47595 L
s
.71646 .37974 m
.81267 .37974 L
s
.71646 .37974 m
.71646 .47595 L
s
.81267 .37974 m
.90887 .37974 L
s
.81267 .37974 m
.81267 .47595 L
s
.90887 .37974 m
.90887 .47595 L
s
.04303 .47595 m
.13923 .47595 L
s
.04303 .47595 m
.04303 .57215 L
s
.13923 .47595 m
.23544 .47595 L
s
.13923 .47595 m
.13923 .57215 L
s
.23544 .47595 m
.33164 .47595 L
s
.23544 .47595 m
.23544 .57215 L
s
.33164 .47595 m
.42785 .47595 L
s
.33164 .47595 m
.33164 .57215 L
s
.42785 .47595 m
.52405 .47595 L
s
.42785 .47595 m
.42785 .57215 L
s
.52405 .47595 m
.62026 .47595 L
s
.52405 .47595 m
.52405 .57215 L
s
.62026 .47595 m
.71646 .47595 L
s
.62026 .47595 m
.62026 .57215 L
s
.71646 .47595 m
.81267 .47595 L
s
.71646 .47595 m
.71646 .57215 L
s
.81267 .47595 m
.90887 .47595 L
s
.81267 .47595 m
.81267 .57215 L
s
.90887 .47595 m
.90887 .57215 L
s
.04303 .57215 m
.13923 .57215 L
s
.13923 .57215 m
.23544 .57215 L
s
.13923 .57215 m
.13923 .66836 L
s
.23544 .57215 m
.33164 .57215 L
s
.23544 .57215 m
.23544 .66836 L
s
.33164 .57215 m
.42785 .57215 L
s
.33164 .57215 m
.33164 .66836 L
s
.42785 .57215 m
.52405 .57215 L
s
.42785 .57215 m
.42785 .66836 L
s
.52405 .57215 m
.62026 .57215 L
s
.52405 .57215 m
.52405 .66836 L
s
.62026 .57215 m
.71646 .57215 L
s
.62026 .57215 m
.62026 .66836 L
s
.71646 .57215 m
.81267 .57215 L
s
.71646 .57215 m
.71646 .66836 L
s
.81267 .57215 m
.90887 .57215 L
s
.81267 .57215 m
.81267 .66836 L
s
.90887 .57215 m
.90887 .66836 L
s
.13923 .66836 m
.23544 .66836 L
s
.13923 .66836 m
.13923 .76456 L
s
.23544 .66836 m
.33164 .66836 L
s
.23544 .66836 m
.23544 .76456 L
s
.33164 .66836 m
.42785 .66836 L
s
.33164 .66836 m
.33164 .76456 L
s
.42785 .66836 m
.52405 .66836 L
s
.42785 .66836 m
.42785 .76456 L
s
.52405 .66836 m
.62026 .66836 L
s
.52405 .66836 m
.52405 .76456 L
s
.62026 .66836 m
.71646 .66836 L
s
.62026 .66836 m
.62026 .76456 L
s
.71646 .66836 m
.81267 .66836 L
s
.71646 .66836 m
.71646 .76456 L
s
.81267 .66836 m
.90887 .66836 L
s
.81267 .66836 m
.81267 .76456 L
s
.13923 .76456 m
.23544 .76456 L
s
.23544 .76456 m
.33164 .76456 L
s
.23544 .76456 m
.23544 .86077 L
s
.33164 .76456 m
.42785 .76456 L
s
.33164 .76456 m
.33164 .86077 L
s
.42785 .76456 m
.52405 .76456 L
s
.42785 .76456 m
.42785 .86077 L
s
.52405 .76456 m
.62026 .76456 L
s
.52405 .76456 m
.52405 .86077 L
s
.62026 .76456 m
.71646 .76456 L
s
.62026 .76456 m
.62026 .86077 L
s
.71646 .76456 m
.81267 .76456 L
s
.71646 .76456 m
.71646 .86077 L
s
.81267 .76456 m
.81267 .86077 L
s
.23544 .86077 m
.33164 .86077 L
s
.33164 .86077 m
.42785 .86077 L
s
.42785 .86077 m
.52405 .86077 L
s
.42785 .86077 m
.42785 .95697 L
s
.52405 .86077 m
.62026 .86077 L
s
.52405 .86077 m
.52405 .95697 L
s
.62026 .86077 m
.71646 .86077 L
s
.62026 .86077 m
.62026 .95697 L
s
.71646 .86077 m
.81267 .86077 L
s
.42785 .95697 m
.52405 .95697 L
s
.52405 .95697 m
.62026 .95697 L
s
.37974 .04303 m
.47595 .04303 L
s
.37974 .04303 m
.37974 .13923 L
s
.47595 .04303 m
.57215 .04303 L
s
.47595 .04303 m
.47595 .13923 L
s
.57215 .04303 m
.57215 .13923 L
s
.18733 .13923 m
.28354 .13923 L
s
.18733 .13923 m
.18733 .23544 L
s
.28354 .13923 m
.37974 .13923 L
s
.28354 .13923 m
.28354 .23544 L
s
.37974 .13923 m
.47595 .13923 L
s
.37974 .13923 m
.37974 .23544 L
s
.47595 .13923 m
.57215 .13923 L
s
.47595 .13923 m
.47595 .23544 L
s
.57215 .13923 m
.66836 .13923 L
s
.57215 .13923 m
.57215 .23544 L
s
.66836 .13923 m
.76456 .13923 L
s
.66836 .13923 m
.66836 .23544 L
s
.76456 .13923 m
.76456 .23544 L
s
.18733 .23544 m
.28354 .23544 L
s
.18733 .23544 m
.18733 .33164 L
s
.28354 .23544 m
.37974 .23544 L
s
.28354 .23544 m
.28354 .33164 L
s
.37974 .23544 m
.47595 .23544 L
s
.37974 .23544 m
.37974 .33164 L
s
.47595 .23544 m
.57215 .23544 L
s
.47595 .23544 m
.47595 .33164 L
s
.57215 .23544 m
.66836 .23544 L
s
.57215 .23544 m
.57215 .33164 L
s
.66836 .23544 m
.76456 .23544 L
s
.66836 .23544 m
.66836 .33164 L
s
.76456 .23544 m
.86077 .23544 L
s
.76456 .23544 m
.76456 .33164 L
s
.86077 .23544 m
.86077 .33164 L
s
.09113 .33164 m
.18733 .33164 L
s
.09113 .33164 m
.09113 .42785 L
s
.18733 .33164 m
.28354 .33164 L
s
.18733 .33164 m
.18733 .42785 L
s
.28354 .33164 m
.37974 .33164 L
s
.28354 .33164 m
.28354 .42785 L
s
.37974 .33164 m
.47595 .33164 L
s
.37974 .33164 m
.37974 .42785 L
s
.47595 .33164 m
.57215 .33164 L
s
.47595 .33164 m
.47595 .42785 L
s
.57215 .33164 m
.66836 .33164 L
s
.57215 .33164 m
.57215 .42785 L
s
.66836 .33164 m
.76456 .33164 L
s
.66836 .33164 m
.66836 .42785 L
s
.76456 .33164 m
.86077 .33164 L
s
.76456 .33164 m
.76456 .42785 L
s
.86077 .33164 m
.86077 .42785 L
s
.09113 .42785 m
.18733 .42785 L
s
.09113 .42785 m
.09113 .52405 L
s
.18733 .42785 m
.28354 .42785 L
s
.18733 .42785 m
.18733 .52405 L
s
.28354 .42785 m
.37974 .42785 L
s
.28354 .42785 m
.28354 .52405 L
s
.37974 .42785 m
.47595 .42785 L
s
.37974 .42785 m
.37974 .52405 L
s
.47595 .42785 m
.57215 .42785 L
s
.47595 .42785 m
.47595 .52405 L
s
.57215 .42785 m
.66836 .42785 L
s
.57215 .42785 m
.57215 .52405 L
s
.66836 .42785 m
.76456 .42785 L
s
.66836 .42785 m
.66836 .52405 L
s
.76456 .42785 m
.86077 .42785 L
s
.76456 .42785 m
.76456 .52405 L
s
.86077 .42785 m
.95697 .42785 L
s
.86077 .42785 m
.86077 .52405 L
s
.95697 .42785 m
.95697 .52405 L
s
.09113 .52405 m
.18733 .52405 L
s
.09113 .52405 m
.09113 .62026 L
s
.18733 .52405 m
.28354 .52405 L
s
.18733 .52405 m
.18733 .62026 L
s
.28354 .52405 m
.37974 .52405 L
s
.28354 .52405 m
.28354 .62026 L
s
.37974 .52405 m
.47595 .52405 L
s
.37974 .52405 m
.37974 .62026 L
s
.47595 .52405 m
.57215 .52405 L
s
.47595 .52405 m
.47595 .62026 L
s
.57215 .52405 m
.66836 .52405 L
s
.57215 .52405 m
.57215 .62026 L
s
.66836 .52405 m
.76456 .52405 L
s
.66836 .52405 m
.66836 .62026 L
s
.76456 .52405 m
.86077 .52405 L
s
.76456 .52405 m
.76456 .62026 L
s
.86077 .52405 m
.95697 .52405 L
s
.86077 .52405 m
.86077 .62026 L
s
.95697 .52405 m
.95697 .62026 L
s
.09113 .62026 m
.18733 .62026 L
s
.09113 .62026 m
.09113 .71646 L
s
.18733 .62026 m
.28354 .62026 L
s
.18733 .62026 m
.18733 .71646 L
s
.28354 .62026 m
.37974 .62026 L
s
.28354 .62026 m
.28354 .71646 L
s
.37974 .62026 m
.47595 .62026 L
s
.37974 .62026 m
.37974 .71646 L
s
.47595 .62026 m
.57215 .62026 L
s
.47595 .62026 m
.47595 .71646 L
s
.57215 .62026 m
.66836 .62026 L
s
.57215 .62026 m
.57215 .71646 L
s
.66836 .62026 m
.76456 .62026 L
s
.66836 .62026 m
.66836 .71646 L
s
.76456 .62026 m
.86077 .62026 L
s
.76456 .62026 m
.76456 .71646 L
s
.86077 .62026 m
.95697 .62026 L
s
.86077 .62026 m
.86077 .71646 L
s
.09113 .71646 m
.18733 .71646 L
s
.18733 .71646 m
.28354 .71646 L
s
.18733 .71646 m
.18733 .81267 L
s
.28354 .71646 m
.37974 .71646 L
s
.28354 .71646 m
.28354 .81267 L
s
.37974 .71646 m
.47595 .71646 L
s
.37974 .71646 m
.37974 .81267 L
s
.47595 .71646 m
.57215 .71646 L
s
.47595 .71646 m
.47595 .81267 L
s
.57215 .71646 m
.66836 .71646 L
s
.57215 .71646 m
.57215 .81267 L
s
.66836 .71646 m
.76456 .71646 L
s
.66836 .71646 m
.66836 .81267 L
s
.76456 .71646 m
.86077 .71646 L
s
.76456 .71646 m
.76456 .81267 L
s
.86077 .71646 m
.86077 .81267 L
s
.18733 .81267 m
.28354 .81267 L
s
.28354 .81267 m
.37974 .81267 L
s
.28354 .81267 m
.28354 .90887 L
s
.37974 .81267 m
.47595 .81267 L
s
.37974 .81267 m
.37974 .90887 L
s
.47595 .81267 m
.57215 .81267 L
s
.47595 .81267 m
.47595 .90887 L
s
.57215 .81267 m
.66836 .81267 L
s
.57215 .81267 m
.57215 .90887 L
s
.66836 .81267 m
.76456 .81267 L
s
.66836 .81267 m
.66836 .90887 L
s
.76456 .81267 m
.86077 .81267 L
s
.28354 .90887 m
.37974 .90887 L
s
.37974 .90887 m
.47595 .90887 L
s
.47595 .90887 m
.57215 .90887 L
s
.57215 .90887 m
.66836 .90887 L
s
.28354 .09113 m
.37974 .09113 L
s
.28354 .09113 m
.28354 .18733 L
s
.37974 .09113 m
.47595 .09113 L
s
.37974 .09113 m
.37974 .18733 L
s
.47595 .09113 m
.57215 .09113 L
s
.47595 .09113 m
.47595 .18733 L
s
.57215 .09113 m
.66836 .09113 L
s
.57215 .09113 m
.57215 .18733 L
s
.66836 .09113 m
.66836 .18733 L
s
.18733 .18733 m
.28354 .18733 L
s
.18733 .18733 m
.18733 .28354 L
s
.28354 .18733 m
.37974 .18733 L
s
.28354 .18733 m
.28354 .28354 L
s
.37974 .18733 m
.47595 .18733 L
s
.37974 .18733 m
.37974 .28354 L
s
.47595 .18733 m
.57215 .18733 L
s
.47595 .18733 m
.47595 .28354 L
s
.57215 .18733 m
.66836 .18733 L
s
.57215 .18733 m
.57215 .28354 L
s
.66836 .18733 m
.76456 .18733 L
s
.66836 .18733 m
.66836 .28354 L
s
.76456 .18733 m
.86077 .18733 L
s
.76456 .18733 m
.76456 .28354 L
s
.86077 .18733 m
.86077 .28354 L
s
.09113 .28354 m
.18733 .28354 L
s
.09113 .28354 m
.09113 .37974 L
s
.18733 .28354 m
.28354 .28354 L
s
.18733 .28354 m
.18733 .37974 L
s
.28354 .28354 m
.37974 .28354 L
s
.28354 .28354 m
.28354 .37974 L
s
.37974 .28354 m
.47595 .28354 L
s
.37974 .28354 m
.37974 .37974 L
s
.47595 .28354 m
.57215 .28354 L
s
.47595 .28354 m
.47595 .37974 L
s
.57215 .28354 m
.66836 .28354 L
s
.57215 .28354 m
.57215 .37974 L
s
.66836 .28354 m
.76456 .28354 L
s
.66836 .28354 m
.66836 .37974 L
s
.76456 .28354 m
.86077 .28354 L
s
.76456 .28354 m
.76456 .37974 L
s
.86077 .28354 m
.86077 .37974 L
s
.09113 .37974 m
.18733 .37974 L
s
.09113 .37974 m
.09113 .47595 L
s
.18733 .37974 m
.28354 .37974 L
s
.18733 .37974 m
.18733 .47595 L
s
.28354 .37974 m
.37974 .37974 L
s
.28354 .37974 m
.28354 .47595 L
s
.37974 .37974 m
.47595 .37974 L
s
.37974 .37974 m
.37974 .47595 L
s
.47595 .37974 m
.57215 .37974 L
s
.47595 .37974 m
.47595 .47595 L
s
.57215 .37974 m
.66836 .37974 L
s
.57215 .37974 m
.57215 .47595 L
s
.66836 .37974 m
.76456 .37974 L
s
.66836 .37974 m
.66836 .47595 L
s
.76456 .37974 m
.86077 .37974 L
s
.76456 .37974 m
.76456 .47595 L
s
.86077 .37974 m
.95697 .37974 L
s
.86077 .37974 m
.86077 .47595 L
s
.95697 .37974 m
.95697 .47595 L
s
.09113 .47595 m
.18733 .47595 L
s
.09113 .47595 m
.09113 .57215 L
s
.18733 .47595 m
.28354 .47595 L
s
.18733 .47595 m
.18733 .57215 L
s
.28354 .47595 m
.37974 .47595 L
s
.28354 .47595 m
.28354 .57215 L
s
.37974 .47595 m
.47595 .47595 L
s
.37974 .47595 m
.37974 .57215 L
s
.47595 .47595 m
.57215 .47595 L
s
.47595 .47595 m
.47595 .57215 L
s
.57215 .47595 m
.66836 .47595 L
s
.57215 .47595 m
.57215 .57215 L
s
.66836 .47595 m
.76456 .47595 L
s
.66836 .47595 m
.66836 .57215 L
s
.76456 .47595 m
.86077 .47595 L
s
.76456 .47595 m
.76456 .57215 L
s
.86077 .47595 m
.95697 .47595 L
s
.86077 .47595 m
.86077 .57215 L
s
.95697 .47595 m
.95697 .57215 L
s
.09113 .57215 m
.18733 .57215 L
s
.09113 .57215 m
.09113 .66836 L
s
.18733 .57215 m
.28354 .57215 L
s
.18733 .57215 m
.18733 .66836 L
s
.28354 .57215 m
.37974 .57215 L
s
.28354 .57215 m
.28354 .66836 L
s
.37974 .57215 m
.47595 .57215 L
s
.37974 .57215 m
.37974 .66836 L
s
.47595 .57215 m
.57215 .57215 L
s
.47595 .57215 m
.47595 .66836 L
s
.57215 .57215 m
.66836 .57215 L
s
.57215 .57215 m
.57215 .66836 L
s
.66836 .57215 m
.76456 .57215 L
s
.66836 .57215 m
.66836 .66836 L
s
.76456 .57215 m
.86077 .57215 L
s
.76456 .57215 m
.76456 .66836 L
s
.86077 .57215 m
.95697 .57215 L
s
.86077 .57215 m
.86077 .66836 L
s
.09113 .66836 m
.18733 .66836 L
s
.18733 .66836 m
.28354 .66836 L
s
.18733 .66836 m
.18733 .76456 L
s
.28354 .66836 m
.37974 .66836 L
s
.28354 .66836 m
.28354 .76456 L
s
.37974 .66836 m
.47595 .66836 L
s
.37974 .66836 m
.37974 .76456 L
s
.47595 .66836 m
.57215 .66836 L
s
.47595 .66836 m
.47595 .76456 L
s
.57215 .66836 m
.66836 .66836 L
s
.57215 .66836 m
.57215 .76456 L
s
.66836 .66836 m
.76456 .66836 L
s
.66836 .66836 m
.66836 .76456 L
s
.76456 .66836 m
.86077 .66836 L
s
.76456 .66836 m
.76456 .76456 L
s
.86077 .66836 m
.86077 .76456 L
s
.18733 .76456 m
.28354 .76456 L
s
.18733 .76456 m
.18733 .86077 L
s
.28354 .76456 m
.37974 .76456 L
s
.28354 .76456 m
.28354 .86077 L
s
.37974 .76456 m
.47595 .76456 L
s
.37974 .76456 m
.37974 .86077 L
s
.47595 .76456 m
.57215 .76456 L
s
.47595 .76456 m
.47595 .86077 L
s
.57215 .76456 m
.66836 .76456 L
s
.57215 .76456 m
.57215 .86077 L
s
.66836 .76456 m
.76456 .76456 L
s
.66836 .76456 m
.66836 .86077 L
s
.76456 .76456 m
.86077 .76456 L
s
.76456 .76456 m
.76456 .86077 L
s
.18733 .86077 m
.28354 .86077 L
s
.28354 .86077 m
.37974 .86077 L
s
.37974 .86077 m
.47595 .86077 L
s
.37974 .86077 m
.37974 .95697 L
s
.47595 .86077 m
.57215 .86077 L
s
.47595 .86077 m
.47595 .95697 L
s
.57215 .86077 m
.66836 .86077 L
s
.57215 .86077 m
.57215 .95697 L
s
.66836 .86077 m
.76456 .86077 L
s
.37974 .95697 m
.47595 .95697 L
s
.47595 .95697 m
.57215 .95697 L
s
.77211 .12585 m
.84014 .19388 L
s
.77211 .12585 m
.70408 .19388 L
s
.84014 .19388 m
.90816 .2619 L
s
.84014 .19388 m
.77211 .2619 L
s
.90816 .2619 m
.84014 .32993 L
s
.56803 .05782 m
.63605 .12585 L
s
.56803 .05782 m
.5 .12585 L
s
.63605 .12585 m
.70408 .19388 L
s
.63605 .12585 m
.56803 .19388 L
s
.70408 .19388 m
.77211 .2619 L
s
.70408 .19388 m
.63605 .2619 L
s
.77211 .2619 m
.84014 .32993 L
s
.77211 .2619 m
.70408 .32993 L
s
.84014 .32993 m
.90816 .39796 L
s
.84014 .32993 m
.77211 .39796 L
s
.90816 .39796 m
.97619 .46599 L
s
.90816 .39796 m
.84014 .46599 L
s
.97619 .46599 m
.90816 .53401 L
s
.43197 .05782 m
.5 .12585 L
s
.43197 .05782 m
.36395 .12585 L
s
.5 .12585 m
.56803 .19388 L
s
.5 .12585 m
.43197 .19388 L
s
.56803 .19388 m
.63605 .2619 L
s
.56803 .19388 m
.5 .2619 L
s
.63605 .2619 m
.70408 .32993 L
s
.63605 .2619 m
.56803 .32993 L
s
.70408 .32993 m
.77211 .39796 L
s
.70408 .32993 m
.63605 .39796 L
s
.77211 .39796 m
.84014 .46599 L
s
.77211 .39796 m
.70408 .46599 L
s
.84014 .46599 m
.90816 .53401 L
s
.84014 .46599 m
.77211 .53401 L
s
.90816 .53401 m
.84014 .60204 L
s
.36395 .12585 m
.43197 .19388 L
s
.36395 .12585 m
.29592 .19388 L
s
.43197 .19388 m
.5 .2619 L
s
.43197 .19388 m
.36395 .2619 L
s
.5 .2619 m
.56803 .32993 L
s
.5 .2619 m
.43197 .32993 L
s
.56803 .32993 m
.63605 .39796 L
s
.56803 .32993 m
.5 .39796 L
s
.63605 .39796 m
.70408 .46599 L
s
.63605 .39796 m
.56803 .46599 L
s
.70408 .46599 m
.77211 .53401 L
s
.70408 .46599 m
.63605 .53401 L
s
.77211 .53401 m
.84014 .60204 L
s
.77211 .53401 m
.70408 .60204 L
s
.84014 .60204 m
.90816 .67007 L
s
.84014 .60204 m
.77211 .67007 L
s
.90816 .67007 m
.84014 .7381 L
s
.22789 .12585 m
.29592 .19388 L
s
.22789 .12585 m
.15986 .19388 L
s
.29592 .19388 m
.36395 .2619 L
s
.29592 .19388 m
.22789 .2619 L
s
.36395 .2619 m
.43197 .32993 L
s
.36395 .2619 m
.29592 .32993 L
s
.43197 .32993 m
.5 .39796 L
s
.43197 .32993 m
.36395 .39796 L
s
.5 .39796 m
.56803 .46599 L
s
.5 .39796 m
.43197 .46599 L
s
.56803 .46599 m
.63605 .53401 L
s
.56803 .46599 m
.5 .53401 L
s
.63605 .53401 m
.70408 .60204 L
s
.63605 .53401 m
.56803 .60204 L
s
.70408 .60204 m
.77211 .67007 L
s
.70408 .60204 m
.63605 .67007 L
s
.77211 .67007 m
.84014 .7381 L
s
.77211 .67007 m
.70408 .7381 L
s
.84014 .7381 m
.77211 .80612 L
s
.15986 .19388 m
.22789 .2619 L
s
.15986 .19388 m
.09184 .2619 L
s
.22789 .2619 m
.29592 .32993 L
s
.22789 .2619 m
.15986 .32993 L
s
.29592 .32993 m
.36395 .39796 L
s
.29592 .32993 m
.22789 .39796 L
s
.36395 .39796 m
.43197 .46599 L
s
.36395 .39796 m
.29592 .46599 L
s
.43197 .46599 m
.5 .53401 L
s
.43197 .46599 m
.36395 .53401 L
s
.5 .53401 m
.56803 .60204 L
s
.5 .53401 m
.43197 .60204 L
s
.56803 .60204 m
.63605 .67007 L
s
.56803 .60204 m
.5 .67007 L
s
.63605 .67007 m
.70408 .7381 L
s
.63605 .67007 m
.56803 .7381 L
s
.70408 .7381 m
.77211 .80612 L
s
.70408 .7381 m
.63605 .80612 L
s
.77211 .80612 m
.70408 .87415 L
s
.09184 .2619 m
.15986 .32993 L
s
.15986 .32993 m
.22789 .39796 L
s
.15986 .32993 m
.09184 .39796 L
s
.22789 .39796 m
.29592 .46599 L
s
.22789 .39796 m
.15986 .46599 L
s
.29592 .46599 m
.36395 .53401 L
s
.29592 .46599 m
.22789 .53401 L
s
.36395 .53401 m
.43197 .60204 L
s
.36395 .53401 m
.29592 .60204 L
s
.43197 .60204 m
.5 .67007 L
s
.43197 .60204 m
.36395 .67007 L
s
.5 .67007 m
.56803 .7381 L
s
.5 .67007 m
.43197 .7381 L
s
.56803 .7381 m
.63605 .80612 L
s
.56803 .7381 m
.5 .80612 L
s
.63605 .80612 m
.70408 .87415 L
s
.63605 .80612 m
.56803 .87415 L
s
.70408 .87415 m
.63605 .94218 L
s
.09184 .39796 m
.15986 .46599 L
s
.09184 .39796 m
.02381 .46599 L
s
.15986 .46599 m
.22789 .53401 L
s
.15986 .46599 m
.09184 .53401 L
s
.22789 .53401 m
.29592 .60204 L
s
.22789 .53401 m
.15986 .60204 L
s
.29592 .60204 m
.36395 .67007 L
s
.29592 .60204 m
.22789 .67007 L
s
.36395 .67007 m
.43197 .7381 L
s
.36395 .67007 m
.29592 .7381 L
s
.43197 .7381 m
.5 .80612 L
s
.43197 .7381 m
.36395 .80612 L
s
.5 .80612 m
.56803 .87415 L
s
.5 .80612 m
.43197 .87415 L
s
.56803 .87415 m
.63605 .94218 L
s
.56803 .87415 m
.5 .94218 L
s
.02381 .46599 m
.09184 .53401 L
s
.09184 .53401 m
.15986 .60204 L
s
.15986 .60204 m
.22789 .67007 L
s
.15986 .60204 m
.09184 .67007 L
s
.22789 .67007 m
.29592 .7381 L
s
.22789 .67007 m
.15986 .7381 L
s
.29592 .7381 m
.36395 .80612 L
s
.29592 .7381 m
.22789 .80612 L
s
.36395 .80612 m
.43197 .87415 L
s
.36395 .80612 m
.29592 .87415 L
s
.43197 .87415 m
.5 .94218 L
s
.43197 .87415 m
.36395 .94218 L
s
.09184 .67007 m
.15986 .7381 L
s
.15986 .7381 m
.22789 .80612 L
s
.22789 .80612 m
.29592 .87415 L
s
.29592 .87415 m
.36395 .94218 L
s
.67007 .09184 m
.7381 .15986 L
s
.67007 .09184 m
.60204 .15986 L
s
.7381 .15986 m
.80612 .22789 L
s
.7381 .15986 m
.67007 .22789 L
s
.80612 .22789 m
.87415 .29592 L
s
.80612 .22789 m
.7381 .29592 L
s
.87415 .29592 m
.94218 .36395 L
s
.87415 .29592 m
.80612 .36395 L
s
.94218 .36395 m
.87415 .43197 L
s
.46599 .02381 m
.53401 .09184 L
s
.46599 .02381 m
.39796 .09184 L
s
.53401 .09184 m
.60204 .15986 L
s
.53401 .09184 m
.46599 .15986 L
s
.60204 .15986 m
.67007 .22789 L
s
.60204 .15986 m
.53401 .22789 L
s
.67007 .22789 m
.7381 .29592 L
s
.67007 .22789 m
.60204 .29592 L
s
.7381 .29592 m
.80612 .36395 L
s
.7381 .29592 m
.67007 .36395 L
s
.80612 .36395 m
.87415 .43197 L
s
.80612 .36395 m
.7381 .43197 L
s
.87415 .43197 m
.94218 .5 L
s
.87415 .43197 m
.80612 .5 L
s
.94218 .5 m
.87415 .56803 L
s
.39796 .09184 m
.46599 .15986 L
s
.39796 .09184 m
.32993 .15986 L
s
.46599 .15986 m
.53401 .22789 L
s
.46599 .15986 m
.39796 .22789 L
s
.53401 .22789 m
.60204 .29592 L
s
.53401 .22789 m
.46599 .29592 L
s
.60204 .29592 m
.67007 .36395 L
s
.60204 .29592 m
.53401 .36395 L
s
.67007 .36395 m
.7381 .43197 L
s
.67007 .36395 m
.60204 .43197 L
s
.7381 .43197 m
.80612 .5 L
s
.7381 .43197 m
.67007 .5 L
s
.80612 .5 m
.87415 .56803 L
s
.80612 .5 m
.7381 .56803 L
s
.87415 .56803 m
.94218 .63605 L
s
.87415 .56803 m
.80612 .63605 L
s
.94218 .63605 m
.87415 .70408 L
s
.2619 .09184 m
.32993 .15986 L
s
.2619 .09184 m
.19388 .15986 L
s
.32993 .15986 m
.39796 .22789 L
s
.32993 .15986 m
.2619 .22789 L
s
.39796 .22789 m
.46599 .29592 L
s
.39796 .22789 m
.32993 .29592 L
s
.46599 .29592 m
.53401 .36395 L
s
.46599 .29592 m
.39796 .36395 L
s
.53401 .36395 m
.60204 .43197 L
s
.53401 .36395 m
.46599 .43197 L
s
.60204 .43197 m
.67007 .5 L
s
.60204 .43197 m
.53401 .5 L
s
.67007 .5 m
.7381 .56803 L
s
.67007 .5 m
.60204 .56803 L
s
.7381 .56803 m
.80612 .63605 L
s
.7381 .56803 m
.67007 .63605 L
s
.80612 .63605 m
.87415 .70408 L
s
.80612 .63605 m
.7381 .70408 L
s
.87415 .70408 m
.80612 .77211 L
s
.19388 .15986 m
.2619 .22789 L
s
.19388 .15986 m
.12585 .22789 L
s
.2619 .22789 m
.32993 .29592 L
s
.2619 .22789 m
.19388 .29592 L
s
.32993 .29592 m
.39796 .36395 L
s
.32993 .29592 m
.2619 .36395 L
s
.39796 .36395 m
.46599 .43197 L
s
.39796 .36395 m
.32993 .43197 L
s
.46599 .43197 m
.53401 .5 L
s
.46599 .43197 m
.39796 .5 L
s
.53401 .5 m
.60204 .56803 L
s
.53401 .5 m
.46599 .56803 L
s
.60204 .56803 m
.67007 .63605 L
s
.60204 .56803 m
.53401 .63605 L
s
.67007 .63605 m
.7381 .70408 L
s
.67007 .63605 m
.60204 .70408 L
s
.7381 .70408 m
.80612 .77211 L
s
.7381 .70408 m
.67007 .77211 L
s
.80612 .77211 m
.7381 .84014 L
s
.12585 .22789 m
.19388 .29592 L
s
.19388 .29592 m
.2619 .36395 L
s
.19388 .29592 m
.12585 .36395 L
s
.2619 .36395 m
.32993 .43197 L
s
.2619 .36395 m
.19388 .43197 L
s
.32993 .43197 m
.39796 .5 L
s
.32993 .43197 m
.2619 .5 L
s
.39796 .5 m
.46599 .56803 L
s
.39796 .5 m
.32993 .56803 L
s
.46599 .56803 m
.53401 .63605 L
s
.46599 .56803 m
.39796 .63605 L
s
.53401 .63605 m
.60204 .70408 L
s
.53401 .63605 m
.46599 .70408 L
s
.60204 .70408 m
.67007 .77211 L
s
.60204 .70408 m
.53401 .77211 L
s
.67007 .77211 m
.7381 .84014 L
s
.67007 .77211 m
.60204 .84014 L
s
.7381 .84014 m
.67007 .90816 L
s
.12585 .36395 m
.19388 .43197 L
s
.12585 .36395 m
.05782 .43197 L
s
.19388 .43197 m
.2619 .5 L
s
.19388 .43197 m
.12585 .5 L
s
.2619 .5 m
.32993 .56803 L
s
.2619 .5 m
.19388 .56803 L
s
.32993 .56803 m
.39796 .63605 L
s
.32993 .56803 m
.2619 .63605 L
s
.39796 .63605 m
.46599 .70408 L
s
.39796 .63605 m
.32993 .70408 L
s
.46599 .70408 m
.53401 .77211 L
s
.46599 .70408 m
.39796 .77211 L
s
.53401 .77211 m
.60204 .84014 L
s
.53401 .77211 m
.46599 .84014 L
s
.60204 .84014 m
.67007 .90816 L
s
.60204 .84014 m
.53401 .90816 L
s
.05782 .43197 m
.12585 .5 L
s
.12585 .5 m
.19388 .56803 L
s
.12585 .5 m
.05782 .56803 L
s
.19388 .56803 m
.2619 .63605 L
s
.19388 .56803 m
.12585 .63605 L
s
.2619 .63605 m
.32993 .70408 L
s
.2619 .63605 m
.19388 .70408 L
s
.32993 .70408 m
.39796 .77211 L
s
.32993 .70408 m
.2619 .77211 L
s
.39796 .77211 m
.46599 .84014 L
s
.39796 .77211 m
.32993 .84014 L
s
.46599 .84014 m
.53401 .90816 L
s
.46599 .84014 m
.39796 .90816 L
s
.53401 .90816 m
.46599 .97619 L
s
.05782 .56803 m
.12585 .63605 L
s
.12585 .63605 m
.19388 .70408 L
s
.19388 .70408 m
.2619 .77211 L
s
.19388 .70408 m
.12585 .77211 L
s
.2619 .77211 m
.32993 .84014 L
s
.2619 .77211 m
.19388 .84014 L
s
.32993 .84014 m
.39796 .90816 L
s
.32993 .84014 m
.2619 .90816 L
s
.39796 .90816 m
.46599 .97619 L
s
.12585 .77211 m
.19388 .84014 L
s
.19388 .84014 m
.2619 .90816 L
s
.7381 .09184 m
.80612 .15986 L
s
.7381 .09184 m
.67007 .15986 L
s
.80612 .15986 m
.87415 .22789 L
s
.80612 .15986 m
.7381 .22789 L
s
.87415 .22789 m
.80612 .29592 L
s
.53401 .02381 m
.60204 .09184 L
s
.53401 .02381 m
.46599 .09184 L
s
.60204 .09184 m
.67007 .15986 L
s
.60204 .09184 m
.53401 .15986 L
s
.67007 .15986 m
.7381 .22789 L
s
.67007 .15986 m
.60204 .22789 L
s
.7381 .22789 m
.80612 .29592 L
s
.7381 .22789 m
.67007 .29592 L
s
.80612 .29592 m
.87415 .36395 L
s
.80612 .29592 m
.7381 .36395 L
s
.87415 .36395 m
.94218 .43197 L
s
.87415 .36395 m
.80612 .43197 L
s
.94218 .43197 m
.87415 .5 L
s
.46599 .09184 m
.53401 .15986 L
s
.46599 .09184 m
.39796 .15986 L
s
.53401 .15986 m
.60204 .22789 L
s
.53401 .15986 m
.46599 .22789 L
s
.60204 .22789 m
.67007 .29592 L
s
.60204 .22789 m
.53401 .29592 L
s
.67007 .29592 m
.7381 .36395 L
s
.67007 .29592 m
.60204 .36395 L
s
.7381 .36395 m
.80612 .43197 L
s
.7381 .36395 m
.67007 .43197 L
s
.80612 .43197 m
.87415 .5 L
s
.80612 .43197 m
.7381 .5 L
s
.87415 .5 m
.94218 .56803 L
s
.87415 .5 m
.80612 .56803 L
s
.94218 .56803 m
.87415 .63605 L
s
.32993 .09184 m
.39796 .15986 L
s
.32993 .09184 m
.2619 .15986 L
s
.39796 .15986 m
.46599 .22789 L
s
.39796 .15986 m
.32993 .22789 L
s
.46599 .22789 m
.53401 .29592 L
s
.46599 .22789 m
.39796 .29592 L
s
.53401 .29592 m
.60204 .36395 L
s
.53401 .29592 m
.46599 .36395 L
s
.60204 .36395 m
.67007 .43197 L
s
.60204 .36395 m
.53401 .43197 L
s
.67007 .43197 m
.7381 .5 L
s
.67007 .43197 m
.60204 .5 L
s
.7381 .5 m
.80612 .56803 L
s
.7381 .5 m
.67007 .56803 L
s
.80612 .56803 m
.87415 .63605 L
s
.80612 .56803 m
.7381 .63605 L
s
.87415 .63605 m
.80612 .70408 L
s
.2619 .15986 m
.32993 .22789 L
s
.2619 .15986 m
.19388 .22789 L
s
.32993 .22789 m
.39796 .29592 L
s
.32993 .22789 m
.2619 .29592 L
s
.39796 .29592 m
.46599 .36395 L
s
.39796 .29592 m
.32993 .36395 L
s
.46599 .36395 m
.53401 .43197 L
s
.46599 .36395 m
.39796 .43197 L
s
.53401 .43197 m
.60204 .5 L
s
.53401 .43197 m
.46599 .5 L
s
.60204 .5 m
.67007 .56803 L
s
.60204 .5 m
.53401 .56803 L
s
.67007 .56803 m
.7381 .63605 L
s
.67007 .56803 m
.60204 .63605 L
s
.7381 .63605 m
.80612 .70408 L
s
.7381 .63605 m
.67007 .70408 L
s
.80612 .70408 m
.87415 .77211 L
s
.80612 .70408 m
.7381 .77211 L
s
.87415 .77211 m
.80612 .84014 L
s
.19388 .22789 m
.2619 .29592 L
s
.19388 .22789 m
.12585 .29592 L
s
.2619 .29592 m
.32993 .36395 L
s
.2619 .29592 m
.19388 .36395 L
s
.32993 .36395 m
.39796 .43197 L
s
.32993 .36395 m
.2619 .43197 L
s
.39796 .43197 m
.46599 .5 L
s
.39796 .43197 m
.32993 .5 L
s
.46599 .5 m
.53401 .56803 L
s
.46599 .5 m
.39796 .56803 L
s
.53401 .56803 m
.60204 .63605 L
s
.53401 .56803 m
.46599 .63605 L
s
.60204 .63605 m
.67007 .70408 L
s
.60204 .63605 m
.53401 .70408 L
s
.67007 .70408 m
.7381 .77211 L
s
.67007 .70408 m
.60204 .77211 L
s
.7381 .77211 m
.80612 .84014 L
s
.7381 .77211 m
.67007 .84014 L
s
.80612 .84014 m
.7381 .90816 L
s
.12585 .29592 m
.19388 .36395 L
s
.12585 .29592 m
.05782 .36395 L
s
.19388 .36395 m
.2619 .43197 L
s
.19388 .36395 m
.12585 .43197 L
s
.2619 .43197 m
.32993 .5 L
s
.2619 .43197 m
.19388 .5 L
s
.32993 .5 m
.39796 .56803 L
s
.32993 .5 m
.2619 .56803 L
s
.39796 .56803 m
.46599 .63605 L
s
.39796 .56803 m
.32993 .63605 L
s
.46599 .63605 m
.53401 .70408 L
s
.46599 .63605 m
.39796 .70408 L
s
.53401 .70408 m
.60204 .77211 L
s
.53401 .70408 m
.46599 .77211 L
s
.60204 .77211 m
.67007 .84014 L
s
.60204 .77211 m
.53401 .84014 L
s
.67007 .84014 m
.7381 .90816 L
s
.67007 .84014 m
.60204 .90816 L
s
.05782 .36395 m
.12585 .43197 L
s
.12585 .43197 m
.19388 .5 L
s
.12585 .43197 m
.05782 .5 L
s
.19388 .5 m
.2619 .56803 L
s
.19388 .5 m
.12585 .56803 L
s
.2619 .56803 m
.32993 .63605 L
s
.2619 .56803 m
.19388 .63605 L
s
.32993 .63605 m
.39796 .70408 L
s
.32993 .63605 m
.2619 .70408 L
s
.39796 .70408 m
.46599 .77211 L
s
.39796 .70408 m
.32993 .77211 L
s
.46599 .77211 m
.53401 .84014 L
s
.46599 .77211 m
.39796 .84014 L
s
.53401 .84014 m
.60204 .90816 L
s
.53401 .84014 m
.46599 .90816 L
s
.60204 .90816 m
.53401 .97619 L
s
.05782 .5 m
.12585 .56803 L
s
.12585 .56803 m
.19388 .63605 L
s
.12585 .56803 m
.05782 .63605 L
s
.19388 .63605 m
.2619 .70408 L
s
.19388 .63605 m
.12585 .70408 L
s
.2619 .70408 m
.32993 .77211 L
s
.2619 .70408 m
.19388 .77211 L
s
.32993 .77211 m
.39796 .84014 L
s
.32993 .77211 m
.2619 .84014 L
s
.39796 .84014 m
.46599 .90816 L
s
.39796 .84014 m
.32993 .90816 L
s
.46599 .90816 m
.53401 .97619 L
s
.05782 .63605 m
.12585 .70408 L
s
.12585 .70408 m
.19388 .77211 L
s
.19388 .77211 m
.2619 .84014 L
s
.2619 .84014 m
.32993 .90816 L
s
.63605 .05782 m
.70408 .12585 L
s
.63605 .05782 m
.56803 .12585 L
s
.70408 .12585 m
.77211 .19388 L
s
.70408 .12585 m
.63605 .19388 L
s
.77211 .19388 m
.84014 .2619 L
s
.77211 .19388 m
.70408 .2619 L
s
.84014 .2619 m
.90816 .32993 L
s
.84014 .2619 m
.77211 .32993 L
s
.90816 .32993 m
.84014 .39796 L
s
.5 .05782 m
.56803 .12585 L
s
.5 .05782 m
.43197 .12585 L
s
.56803 .12585 m
.63605 .19388 L
s
.56803 .12585 m
.5 .19388 L
s
.63605 .19388 m
.70408 .2619 L
s
.63605 .19388 m
.56803 .2619 L
s
.70408 .2619 m
.77211 .32993 L
s
.70408 .2619 m
.63605 .32993 L
s
.77211 .32993 m
.84014 .39796 L
s
.77211 .32993 m
.70408 .39796 L
s
.84014 .39796 m
.90816 .46599 L
s
.84014 .39796 m
.77211 .46599 L
s
.90816 .46599 m
.97619 .53401 L
s
.90816 .46599 m
.84014 .53401 L
s
.97619 .53401 m
.90816 .60204 L
s
.36395 .05782 m
.43197 .12585 L
s
.36395 .05782 m
.29592 .12585 L
s
.43197 .12585 m
.5 .19388 L
s
.43197 .12585 m
.36395 .19388 L
s
.5 .19388 m
.56803 .2619 L
s
.5 .19388 m
.43197 .2619 L
s
.56803 .2619 m
.63605 .32993 L
s
.56803 .2619 m
.5 .32993 L
s
.63605 .32993 m
.70408 .39796 L
s
.63605 .32993 m
.56803 .39796 L
s
.70408 .39796 m
.77211 .46599 L
s
.70408 .39796 m
.63605 .46599 L
s
.77211 .46599 m
.84014 .53401 L
s
.77211 .46599 m
.70408 .53401 L
s
.84014 .53401 m
.90816 .60204 L
s
.84014 .53401 m
.77211 .60204 L
s
.90816 .60204 m
.84014 .67007 L
s
.29592 .12585 m
.36395 .19388 L
s
.29592 .12585 m
.22789 .19388 L
s
.36395 .19388 m
.43197 .2619 L
s
.36395 .19388 m
.29592 .2619 L
s
.43197 .2619 m
.5 .32993 L
s
.43197 .2619 m
.36395 .32993 L
s
.5 .32993 m
.56803 .39796 L
s
.5 .32993 m
.43197 .39796 L
s
.56803 .39796 m
.63605 .46599 L
s
.56803 .39796 m
.5 .46599 L
s
.63605 .46599 m
.70408 .53401 L
s
.63605 .46599 m
.56803 .53401 L
s
.70408 .53401 m
.77211 .60204 L
s
.70408 .53401 m
.63605 .60204 L
s
.77211 .60204 m
.84014 .67007 L
s
.77211 .60204 m
.70408 .67007 L
s
.84014 .67007 m
.90816 .7381 L
s
.84014 .67007 m
.77211 .7381 L
s
.90816 .7381 m
.84014 .80612 L
s
.22789 .19388 m
.29592 .2619 L
s
.22789 .19388 m
.15986 .2619 L
s
.29592 .2619 m
.36395 .32993 L
s
.29592 .2619 m
.22789 .32993 L
s
.36395 .32993 m
.43197 .39796 L
s
.36395 .32993 m
.29592 .39796 L
s
.43197 .39796 m
.5 .46599 L
s
.43197 .39796 m
.36395 .46599 L
s
.5 .46599 m
.56803 .53401 L
s
.5 .46599 m
.43197 .53401 L
s
.56803 .53401 m
.63605 .60204 L
s
.56803 .53401 m
.5 .60204 L
s
.63605 .60204 m
.70408 .67007 L
s
.63605 .60204 m
.56803 .67007 L
s
.70408 .67007 m
.77211 .7381 L
s
.70408 .67007 m
.63605 .7381 L
s
.77211 .7381 m
.84014 .80612 L
s
.77211 .7381 m
.70408 .80612 L
s
.84014 .80612 m
.77211 .87415 L
s
.15986 .2619 m
.22789 .32993 L
s
.15986 .2619 m
.09184 .32993 L
s
.22789 .32993 m
.29592 .39796 L
s
.22789 .32993 m
.15986 .39796 L
s
.29592 .39796 m
.36395 .46599 L
s
.29592 .39796 m
.22789 .46599 L
s
.36395 .46599 m
.43197 .53401 L
s
.36395 .46599 m
.29592 .53401 L
s
.43197 .53401 m
.5 .60204 L
s
.43197 .53401 m
.36395 .60204 L
s
.5 .60204 m
.56803 .67007 L
s
.5 .60204 m
.43197 .67007 L
s
.56803 .67007 m
.63605 .7381 L
s
.56803 .67007 m
.5 .7381 L
s
.63605 .7381 m
.70408 .80612 L
s
.63605 .7381 m
.56803 .80612 L
s
.70408 .80612 m
.77211 .87415 L
s
.70408 .80612 m
.63605 .87415 L
s
.09184 .32993 m
.15986 .39796 L
s
.15986 .39796 m
.22789 .46599 L
s
.15986 .39796 m
.09184 .46599 L
s
.22789 .46599 m
.29592 .53401 L
s
.22789 .46599 m
.15986 .53401 L
s
.29592 .53401 m
.36395 .60204 L
s
.29592 .53401 m
.22789 .60204 L
s
.36395 .60204 m
.43197 .67007 L
s
.36395 .60204 m
.29592 .67007 L
s
.43197 .67007 m
.5 .7381 L
s
.43197 .67007 m
.36395 .7381 L
s
.5 .7381 m
.56803 .80612 L
s
.5 .7381 m
.43197 .80612 L
s
.56803 .80612 m
.63605 .87415 L
s
.56803 .80612 m
.5 .87415 L
s
.63605 .87415 m
.56803 .94218 L
s
.09184 .46599 m
.15986 .53401 L
s
.09184 .46599 m
.02381 .53401 L
s
.15986 .53401 m
.22789 .60204 L
s
.15986 .53401 m
.09184 .60204 L
s
.22789 .60204 m
.29592 .67007 L
s
.22789 .60204 m
.15986 .67007 L
s
.29592 .67007 m
.36395 .7381 L
s
.29592 .67007 m
.22789 .7381 L
s
.36395 .7381 m
.43197 .80612 L
s
.36395 .7381 m
.29592 .80612 L
s
.43197 .80612 m
.5 .87415 L
s
.43197 .80612 m
.36395 .87415 L
s
.5 .87415 m
.56803 .94218 L
s
.5 .87415 m
.43197 .94218 L
s
.02381 .53401 m
.09184 .60204 L
s
.09184 .60204 m
.15986 .67007 L
s
.15986 .67007 m
.22789 .7381 L
s
.15986 .67007 m
.09184 .7381 L
s
.22789 .7381 m
.29592 .80612 L
s
.22789 .7381 m
.15986 .80612 L
s
.29592 .80612 m
.36395 .87415 L
s
.29592 .80612 m
.22789 .87415 L
s
.36395 .87415 m
.43197 .94218 L
s
.09184 .7381 m
.15986 .80612 L
s
.15986 .80612 m
.22789 .87415 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{42, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;RLW9b40<?oo_`00?g=cLda<C820P8NZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmo
OiB;WMKBg2XX;H=kRhjYUM3KddiMD^GQY9no_m[ViUY]KD=EIB4Z<M_Vkl?Ei6F0V;2^]4U5CX61PFYo
L4mOGbL_;n;/k<oOggN?ShRZVHEhU000O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o
002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmo
Ocmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?glo
Oglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0
_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo
_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo
?oooOlS3cdDnCFmlS[g3bcU0B]C>N7j0VLG6dD52Cf]]PW5VO]_Ggd8lBVIbVOoo0_oo1mWIhEiPLko0
c3m0C1lO9FAJKk>ic=;EhC<iC1TL9DaELeioI[C3]c11=?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L008D700<01`L04@L00`071`241`00Q0L00`07000A1`0300L008D700231`05
00L71`003`L01@071`L008@700221`0300L700<700<01`L02`L00`071`031`0300L7084700211`03
00L700D700<01`L02@L00`071`051`0300L7080700201`0300L700L700<01`L01`L00`071`071`03
00L707l7001/1dL0K@L006`700<01`L02`L01@071`L000T700D01`L700051`0500L71`002@L01@07
1`L000d700<01`L0J`L006`700<01`L02`L010071`0:1`0300L7008700D01`L700041`0300L700P7
00@01`L03@L00`071`1[1`00K0L00`071`0;1`0300L000/700<01`L00`L00`0700051`0300L700T7
00<01`003@L00`071`1[1`00J0L01@071`L000d70`0;1`0300L700@700<01`L010L00`071`091`<0
3@L01@071`L006T7001W1`0300L0008700<01`L02`L300/700<01`L00`L00`0700051`0300L700T7
0`0=1`0600L700L0J0L006H700L01`L700L000`70P021`0300L700P700<01`L00PL01@071`L000@7
00<01`L020L00`071`0200`700<01`000`L00`071`1U1`00I@L00`071`031`802`L300<700<01`L0
1`L01@071`L000D700D01`L700091`0400L71`<02`L200D700<01`L0I0L006@700<01`L01@L00`07
1`081`8000<700L00`L00`071`061`0400L700L700@01`L020L00`071`021`0400L000X700<01`L0
1@L00`071`1S1`00H`L00`071`061`8020L2008700<01`L00`L00`071`051`0300L000T700<01`00
1`L00`071`031`0300L7008020L200P700<01`L0HPL0068700<01`L01`L00`0700061`800`L00`07
1`041`0300L700@70P0;1`801PL00`071`041`0400L71`801PL00`0700091`0300L70647001Q1`03
00L700P700@01`L010L200@700<01`L01@L00`071`031`0300L700/700<01`L00`L00`071`051`03
00L700870P041`0400L700X700<01`L0H0L0060700<01`L02@L01@071`L000870P051`0300L700H7
00@01`L70P0=1`800`L00`071`061`0300L700<70P021`0500L71`002`L00`071`1O1`00G`L00`07
1`0:1`0300L700870`061`0300L700L700D01`07000=1`0500L01`002@L00`071`041`<010L00`07
1`0:1`0300L705h7001;1`0300L700<7O@051`0300L704X7001:1`0300L000@700<01`L02@L00`07
000<1`0300L700870`061`0300L700L700D01`07000=1`0500L01`002@L00`071`041`<010L00`07
1`0:1`0300L000/700<01`L00PL00`07001;1`00B@L01@071`L000<700<01`L020L00`071`0200/7
00D01`L700021`801@L00`071`061`0400L71`803@L200<700<01`L01PL00`071`031`800PL01@07
1`L000/70P021`0300L700P700D01`L700031`0300L704P700181`0300L700<700@01`L02@L01`07
1`L01`002PL010071`041`8010L00`071`051`0300L700<700<01`L02`L00`071`031`0300L700D7
00<01`L00PL200@700@01`L02PL00`0700031`0300L700L700@01`L01@L00`071`171`00A`L00`07
1`051`0300L000P700<01`L00PL010071`091`0300L000H70P031`0300L700@700<01`L010L200/7
0P061`0300L700@700@01`L70P061`0300L000T700@01`L010L00`071`061`0300L000L700<01`L0
APL004H700<01`L01`L200L700<01`L00`L01@071`L000P70P081`800PL00`071`031`0300L700D7
00<01`002@L00`0700071`0300L700<700<01`L00P081`8020L01@071`L000D700<01`L01@L200T7
00<01`L0A@L004D700<01`L02@L00`071`041`0300L700@700<01`L00PL00`071`051`0300L700P7
0P000`L01`031`0300L700H700@01`L01`L010071`081`0300L7008700@01`002PL00`071`051`03
00L7008700<01`L010L00`071`041`0300L700T700<01`L0A0L004@700<01`L02PL200@700<01`L0
1@L00`071`031`0300L700<70P0;1`<00`L00`071`071`0500L71`001@L01@071`L000T700@01`L7
0`0;1`801@L00`071`031`0300L700D700<01`L00PL200`700<01`L0@`L004<700<01`L02`L00`07
00021`0300L700H700<01`L010L01`071`L01`0030L2008700<01`L020L00`071`021`0500L71`00
10L00`071`081`0300L7008030L00`0700031`0300L700@700<01`L01PL01P071`0700d700<01`L0
@PL004470P0>1`0300L700802@L00`071`051`<00PL00`071`0;1`<02`L00`071`031`<01@L00`07
1`091`<03@L00`071`0300L700<01`L01`L2008700<01`L030L00`071`111`00@0L200l700<01`L0
0P091`0300L700D70`021`0300L700/70`0;1`0300L700<70`051`0300L700T70`0=1`0300L700<0
1`L00`071`071`800PL00`071`0=1`80@@L003l70P000`L01`0=1`0400L01`8020L00`071`041`80
00D70007000=1`0400L000X700<01`L00PL200031`0000@700<01`L020L200031`0700`700D01`00
1`0200H700<01`L01PL200041`0700h700@01`00@0L003h70P031`0300L700/70P031`801`L00`07
1`031`800`L300`70P021`802@L010071`L200<70P031`0300L700L70P021`8030L300<70P051`03
00L700D70P031`803@L010071`L203l7000e1kD0=PL003D700<01`L010L200D700<01`002PL200H7
0P051`0400L71`801`L200T700@01`L010L200L700@01`001`L200031`0700H70P041`0400L700T7
0P071`800`L00`071`031`801PL200X700<01`001@L200H700<01`L0=0L003D700<01`L00`L200H7
00@01`L020L00`0700071`8010L00`071`0200P70`071`0500L71`001@L200H70`091`<01PL200D7
00D01`L700071`<020L2008700<01`L00PL200L700<01`0020L010071`061`801@L00`071`0d1`00
=@L00`071`021`801`L01@071`L000H700@01`L020L200<700@01`002@L0100700051`0300L70087
00<01`L010L200D70P0;1`801@L200H700<01`L00PL00`071`031`8000<700L020L200031`070087
0P081`0400L700H700D01`L700071`8010L00`071`0d1`00=@L010071`L200P700<01`L00PL00`07
1`021`0500L71`002@L200870`0:1`0300L700800`L00`071`031`0300L700D70P031`803@L200<7
0P071`0300L700<700@01`L70P021`0300L700P70`021`802@L01@071`L000@700<01`L00PL00`07
1`061`800`L00`071`0d1`00=@L00`071`0200T700<01`L00`L010071`041`0300L700P70P000`L0
000;1`0400L71`8000<700L01@L00`071`061`8000@700003@L300031`0000P700<01`L010L01007
00031`0300L700T70P000`L0000:1`0300L7008700@01`L01@L00`071`071`800PL00`071`0d1`00
=@L01007000:1`0300L700@70P051`0300L700T70`0<1`0300L700870P071`0300L700L70`000`L0
1`0<1`0300L000802@L00`071`051`8010L00`071`0:1`<02`L00`071`031`801PL00`071`081`80
00<700L0=@L003D70P000`L01`091`0300L700@70`041`0300L700T70`0<1`0300L700870`061`03
00L700L70`000`L01`0<1`0300L000802@L00`071`041`<010L00`071`0:1`<02`L00`071`021`<0
1PL00`071`081`@0=PL003D700D01`L700091`0300L700<700<01`L00P031`0300L700P700<01`L0
0P0;1`0500L71`000PL200D700<01`L01PL010071`L200d70P031`0300L700H700<01`L00`L20087
00D01`L7000;1`800PL00`071`081`0400L71`800PL00`071`031`0300L700L700D01`L7000f1`00
=0L200@700<01`L01PL00`071`021`0300L700870P021`0300L700L700L01`L700L000X700@01`L0
10L200@700<01`L01@L00`071`031`0300L700/700<01`L00`L00`071`051`0300L700870P041`04
00L700X700<01`000`L00`071`071`0300L7008010L00`071`021`0300L700H700<01`L00PL203D7
000c1`0300L000D700<01`L01@L01@071`L000H70P000`L01`071`0300L7008700@01`L02@L00`07
00061`800`L00`071`041`0300L700@70P0;1`801PL00`071`041`0400L71`801PL00`0700091`04
00L700@700<01`L01PL0100700061`0500L71`001`L00`071`031`0300L003@7000b1`0400L700H7
00<01`L010L010071`081`<01`L00`071`031`0500L71`0020L200P70P021`0300L700<700<01`L0
1@L00`0700091`0300L000L700<01`L00`L00`071`0200P70P081`0500L71`001@L00`071`051`<0
20L010071`061`0300L700@700@01`L0<`L0034700D01`L700071`0300L700<700<01`002PL200H7
00<01`L010L00`071`021`0300L700D700<01`L020L200031`0700<700<01`L01PL010071`071`04
00L700P700<01`L00PL01007000:1`0300L700D700<01`L00PL00`071`041`0300L700@70P0:1`03
00L000D700<01`L01@L01@071`L00387000`1`0300L7008700<01`L01PL00`071`021`8030L200@7
00<01`L01@L00`071`031`0300L700<70P0;1`<00`L00`071`071`0500L71`001@L01@071`L000T7
00@01`L70`0;1`801@L00`071`031`0300L700D700<01`L00PL200`70P041`0300L700H700<01`L0
0PL00`071`0_1`009`OA02P7000W1`0300L700@700<01`L010L00`071`081`0400L000d700<01`00
0P091`0300L700D700<01`000PL00`071`0;1`<02`L00`071`031`0300L000D700<01`L02@L300d7
00H01`L01`071`0300L700L70`000`L01`0<1`8000<700L02@L00`071`041`0300L700@700<01`L0
9PL002L700<01`L00`L200H700<01`L02@L00`07000=1`0300L700802@L00`071`061`0500L71`00
3@L300/700<01`L010L00`071`041`0300L700T70`0=1`0500L71`0020L00`071`071`800PL00`07
1`0;1`0300L000/700<01`L010L200D700<01`L09PL002L700<01`L00PL300H700<01`L020L01007
000=1`0300L000802@L00`071`051`0300L0008700<01`L02`L300/700<01`L00`L00`0700051`03
00L700T70`0=1`0600L700L01`L00`071`071`<000<700L030L200031`0700T700<01`L010L300@7
00<01`L09PL002L700@01`L70P021`0300L700<700<01`L01`L01@071`L000d70`021`0300L700H7
00<01`L010L01`071`L01`0030L2008700<01`L020L00`071`021`0500L71`0010L00`071`081`03
00L7008030L00`0700031`0300L700@700<01`L01PL00`071`0300d700D01`L700091`0300L700<7
00<01`L00P031`0300L702H7000W1`0300L7008010L00`071`021`0300L700H700<01`L00PL200`7
0P041`0300L700D700<01`L00`L00`071`031`802`L300<700<01`L01`L01@071`L000D700D01`L7
00091`0400L71`<02`L200D700<01`L00`L00`071`051`0300L700870P0<1`8010L00`071`061`03
00L7008700<01`L00PL2008700<01`L09PL002L700@01`001PL01@071`L000L700<01`L00`L00`07
000:1`801PL00`071`041`0300L7008700<01`L01@L00`071`081`8000<700L00`L00`071`061`04
00L700L700@01`L020L00`071`021`0400L000X700<01`L01@L00`071`021`0300L700@700<01`L0
10L200X700<01`001@L00`071`051`0500L71`001PL200031`0702L7000W1`<020L010071`061`03
00L700@700@01`L020L300L700<01`L00`L01@071`L000P70P081`800PL00`071`031`0300L700D7
00<01`002@L00`0700071`0300L700<700<01`L00P081`8020L01@071`L000D700<01`L01@L300P7
00@01`L01PL00`071`041`0400L700P70`0X1`009`L200X700<01`001@L00`071`051`0500L71`00
1PL200031`0700L700<01`L00PL010071`091`0300L000H70P031`0300L700@700<01`L010L200/7
0P061`0300L700@700@01`L70P061`0300L000T700@01`L010L00`071`061`0400L000H700D01`L7
00071`0300L700<700<01`002PL202P7000V1`8030L200@700<01`L01PL00`071`021`0300L70087
0P021`0300L700L700L01`L700L000X700@01`L010L200@700<01`L01@L00`071`031`0300L700/7
00<01`L00`L00`071`051`0300L700870P041`0400L700X700<01`000`L00`071`071`0300L70080
10L00`071`021`0300L700H700<01`L00PL200`70P0W1`009@L300d700D01`L700091`0300L700<7
00<01`L00P031`0300L700P700<01`L00P0;1`0500L71`000PL200D700<01`L01PL010071`L200d7
0P031`0300L700H700<01`L00`L2008700D01`L7000;1`800PL00`071`081`0400L71`800PL00`07
1`031`0300L700L700D01`L7000=1`<09PL002@70P000`L01`0<1`8000<700L02@L00`071`041`<0
10L00`071`091`0300L000`700<01`L00PL300H700<01`L01`L01@0700L000d700D01`0700091`03
00L700@70`041`0300L700X700<01`002`L00`071`021`<01PL00`071`081`0400L000d700@01`00
9@L002@700@01`L03@L00`07000;1`0300L700@70P051`0300L700X70P0<1`0300L700870P071`03
00L700P700@01`L03@L010071`0:1`0300L700D70P041`0300L700X70P0<1`0300L700<70P061`03
00L700T700<01`003@L010071`0U1`008`L01@0700L000d70P000`L01`091`0300L700@70`041`03
00L700T700<01`0030L00`071`021`<01PL00`071`071`0500L01`003@L01@0700L000T700<01`L0
10L300@700<01`L02PL00`07000;1`0300L700870`061`0300L700P700@01`003@L01@0700L002@7
000R1`0400L71m<00`L00`071`0Q1`008@L00`071`031`0300L700X70P041`0300L700H700<01`L0
0PL00`071`021`800PL00`071`071`0700L71`07000:1`0400L700@70P041`0300L700D700<01`L0
0`L00`071`0;1`0300L700<700<01`L01@L00`071`021`8010L010071`0:1`0300L000<700<01`L0
1`L00`071`0200@700<01`L00PL00`071`061`0300L700870P0<1`0300L700<700<01`L080L00207
00<01`L010L200X700<01`001@L00`071`051`0500L71`001PL200031`0700L700<01`L00PL01007
1`091`0300L000H70P031`0300L700@700<01`L010L200/70P061`0300L700@700@01`L70P061`03
00L000T700@01`L010L00`071`061`0400L000H700D01`L700071`0300L700<700<01`002PL200H7
00<01`L07`L001l700<01`L01@L00`0700081`0400L700H700<01`L010L010071`081`<01`L00`07
1`031`0500L71`0020L200P70P021`0300L700<700<01`L01@L00`0700091`0300L000L700<01`L0
0`L00`071`0200P70P081`0500L71`001@L00`071`051`<020L010071`061`0300L700@700@01`L0
20L00`0700071`0300L701h7000N1`0300L700H700@01`L01PL01@071`L000L700<01`L00`L00`07
000:1`801PL00`071`041`0300L7008700<01`L01@L00`071`081`8000<700L00`L00`071`061`04
00L700L700@01`L020L00`071`021`0400L000X700<01`L01@L00`071`021`0300L700@700<01`L0
10L200X700<01`001@L00`071`051`0500L71`001PL010071`081`0300L701d7000M1`0300L700L7
00D01`L700041`0300L7008700<01`L01PL00`071`021`8030L200@700<01`L01@L00`071`031`03
00L700<70P0;1`<00`L00`071`071`0500L71`001@L01@071`L000T700@01`L70`0;1`801@L00`07
1`031`0300L700D700<01`L00PL200`70P041`0300L700H700<01`L00PL00`071`021`0500L71`00
2@L00`071`0L1`0070L00`071`081`0300L7008700@01`L01@L00`071`071`0500L71`003@L30087
00<01`L01PL00`071`041`0700L71`07000<1`800PL00`071`081`0300L7008700D01`L700041`03
00L700P700<01`L00P0<1`0300L000<700<01`L010L00`071`061`0300L700<03@L01@071`L000T7
00<01`L00`L010071`041`0300L700P700<01`L06`L001/700<01`L02@L00`071`031`801PL00`07
1`081`@03@L00`07000200T700<01`L01@L3008700<01`L02`L300/700<01`L00`L300D700<01`L0
2@L300d700<01`L00`071`0300L700L70`000`L01`0<1`@02PL00`071`041`801@L00`071`091`03
00L701X7000J1`0300L700X700<01`L00`L200H700<01`L020L400d700<01`L00P091`0300L700D7
0`021`0300L700/70`0;1`0300L700<70`051`0300L700T70`0=1`0300L700<01`L00`071`071`80
0PL00`071`0;1`@02PL00`071`041`801@L00`071`0:1`0300L701T7000K1`0300L700T700<01`L0
0PL0100700051`0300L700L70P000`L0000=1`0400L01`8020L00`071`041`8000D70007000=1`04
00L000X700<01`L00PL200031`0000@700<01`L020L200031`0700`700D01`001`0200H700<01`L0
1PL200041`0700d70P000`L000091`0300L700<70P000`L01`031`0300L700T700<01`L06PL001`7
00<01`L020L01@071`L000<70P041`0300L700H70P031`8030L200<70P071`0300L700<70P031`<0
30L200870P091`0400L71`800`L200<700<01`L01`L200870P0<1`<00`L200D700<01`L01@L200<7
0P0<1`800`L200P700<01`L00PL200<700D01`L7000:1`0300L701/7000M1`0300L700L700@01`L0
1@L200<700<01`L01@L200@70`0;1`0300L700<70P061`0300L700870P051`802`L00`0700031`80
20L00`071`0200D70P021`0300L700H70P031`0300L000/70P051`8010L00`071`041`801@L00`07
1`091`<010L200L700@01`L70P051`0400L700T700<01`L070L001h700<01`L01PL00`0700071`80
0PL00`071`041`801@L0100700091`801PL200D700@01`L70P071`802@L010071`041`801`L01007
00071`8000<700L01PL200@700@01`L02@L200L70P031`0300L700<70P061`802@L200031`0700@7
0P061`0300L700801`L00`0700081`0300L701d7000O1`0300L700D70P091`8000<700L010L200H7
00<01`L00P071`0300L000L70P041`0300L7008020L300L700D01`L700051`801PL300T70`061`80
1@L01@071`L000L70`081`800PL00`071`021`801`L00`0700071`800PL00`071`041`801@L01007
00091`801`L00`071`0N1`006PO[01/7000J1`0300L700@700<01`L00PL200`70P031`8020L00`07
1`021`800`L01@071`L000T70P021`<02PL00`071`0200<700<01`L00`L00`071`051`800`L200d7
0P031`801`L00`071`031`0400L71`800PL00`071`081`<00PL200T700D01`L700031`8010L00`07
1`061`800`L200`70P041`0300L700@700<01`L06@L001X700<01`L01@L01P071`0700d70P000`L0
00091`0300L700<70P000`L01`031`0300L700P70P000`L0000;1`0400L71`8000<700L01@L00`07
1`061`8000@700003@L300031`0000P700<01`L010L0100700031`0300L700T70P000`L0000:1`03
00L7008700@01`001@L00`071`071`8000<700003@L00`0700021`0300L700D700<01`L06@L001X7
00<01`L01PL2008700<01`L02`L400X700<01`L010L200D700<01`L02@L300`700<01`L00PL200L7
00<01`L01`L300031`0700`700<01`000P091`0300L700D70P041`0300L700X70`0;1`0300L700<7
0P061`0300L700P7100=1`0300L7008020L00`071`0I1`006PL00`071`061`<000<700L030L400X7
00<01`L010L300@700<01`L02@L300`700<01`L00PL300H700<01`L01`L300031`0700`700<01`00
0P091`0300L700@70`041`0300L700X70`0;1`0300L700870`061`0300L700P7100=1`0300L00080
20L00`071`0I1`006PL00`071`051`0300L700<03@L01@071`L000T700<01`L00`L00`071`0200<7
00<01`L020L00`071`0200/700D01`L700021`801@L00`071`061`0400L71`803@L200<700<01`L0
1PL00`071`031`800PL01@071`L000/70P021`0300L700P700@01`L70P021`0300L700<700<01`L0
1`L01@071`L000d70`021`0300L700D700<01`L06@L001X700<01`L010L00`071`021`8030L200@7
00<01`L01PL00`071`021`0300L700870P021`0300L700L700L01`L700L000X700@01`L010L200@7
00<01`L01@L00`071`031`0300L700/700<01`L00`L00`071`051`0300L700870P041`0400L700X7
00<01`000`L00`071`071`0300L7008010L00`071`021`0300L700H700<01`L00PL200`70P041`03
00L700@700<01`L06@L001X700<01`L00`L00`071`041`802PL00`0700051`0300L700D700D01`L7
00061`8000<700L01`L00`071`021`0400L700T700<01`001PL200<700<01`L010L00`071`041`80
2`L200H700<01`L010L010071`L200H700<01`002@L010071`041`0300L700H700@01`001PL01@07
1`L000L700<01`L00`L00`07000:1`801PL00`071`031`0300L701T7000J1`0300L7008700<01`L0
1@L300P700@01`L01PL00`071`041`0400L700P70`071`0300L700<700D01`L700081`8020L20087
00<01`L00`L00`071`051`0300L000T700<01`001`L00`071`031`0300L7008020L200P700D01`L7
00051`0300L700D70`081`0400L700H700<01`L010L010071`081`<01`L00`071`021`0300L701T7
000J1`0500L71`0020L0100700061`0500L71`001`L00`071`031`0300L000X70P061`0300L700@7
00<01`L00PL00`071`051`0300L700P70P000`L01`031`0300L700H700@01`L01`L010071`081`03
00L7008700@01`002PL00`071`051`0300L7008700<01`L010L00`071`041`802PL00`0700051`03
00L700D700D01`L700061`8000<700L01`L01@071`L001/7000J1`0400L700T700<01`L00P041`03
00L7008700<01`L01PL00`071`021`8030L200@700<01`L01@L00`071`031`0300L700<70P0;1`<0
0`L00`071`071`0500L71`001@L01@071`L000T700@01`L70`0;1`801@L00`071`031`0300L700D7
00<01`L00PL200`70P041`0300L700H700<01`L00PL00`071`021`800PL00`071`071`0400L701/7
000J1`0300L000X700@01`L70P021`0300L700<700<01`L01`L01@071`L000d70`021`0300L700H7
00<01`L010L01`071`L01`0030L2008700<01`L020L00`071`021`0500L71`0010L00`071`081`03
00L7008030L00`0700031`0300L700@700<01`L01PL00`071`0300d700D01`L700091`0300L700<7
00<01`L00P031`0300L700P700<01`006`L001X70P0;1`0300L700870`061`0300L700P700@01`00
3@L00`07000200T700<01`L01@L00`0700021`0300L700/70`0;1`0300L700<700<01`001@L00`07
1`091`<03@L01P071`0700L700<01`L01`L300031`0700`70P000`L01`091`0300L700@70`041`03
00L700T70P0K1`006PL00`071`0:1`0300L700<70P061`0300L700T700<01`003@L00`071`0200T7
00<01`L01PL01@071`L000d70`0;1`0300L700@700<01`L010L00`071`091`<03@L01@071`L000P7
00<01`L01`L2008700<01`L02`L00`07000;1`0300L700@70P051`0300L700X700<01`L06@L001T7
k@0J1`0060L01@0700L000X700@01`L70P021`0300L700<700<01`L01`L01@071`L000d70`021`03
00L700H700<01`L010L01`071`L01`0030L2008700<01`L020L00`071`021`0500L71`0010L00`07
1`081`0300L7008030L00`0700031`0300L700@700<01`L01PL00`071`0300d700D01`L700091`03
00L700<700<01`L00P031`0300L700P700D01`07000I1`005`L010071`021`0300L700L700<01`L0
0P041`0300L7008700<01`L01PL00`071`021`8030L200@700<01`L01@L00`071`031`0300L700<7
0P0;1`<00`L00`071`071`0500L71`001@L01@071`L000T700@01`L70`0;1`801@L00`071`031`03
00L700D700<01`L00PL200`70P041`0300L700H700<01`L00PL00`071`021`800PL00`071`071`04
00L7008700<01`L05PL001H700D01`L700031`0300L700H700@01`001PL01@071`L000L700<01`L0
0`L00`07000:1`801PL00`071`041`0300L7008700<01`L01@L00`071`081`8000<700L00`L00`07
1`061`0400L700L700@01`L020L00`071`021`0400L000X700<01`L01@L00`071`021`0300L700@7
00<01`L010L200X700<01`001@L00`071`051`0500L71`001PL200031`0700L700D01`L700031`03
00L701D7000E1`0300L7008700<01`L00PL00`071`051`<020L010071`061`0300L700@700@01`L0
20L300L700<01`L00`L01@071`L000P70P081`800PL00`071`031`0300L700D700<01`002@L00`07
00071`0300L700<700<01`L00P081`8020L01@071`L000D700<01`L01@L300P700@01`L01PL00`07
1`041`0400L700P70`071`0300L7008700<01`L00PL00`071`0D1`0050L00`071`031`0300L700<7
00<01`L010L200X700<01`001@L00`071`051`0500L71`001PL200031`0700L700<01`L00PL01007
1`091`0300L000H70P031`0300L700@700<01`L010L200/70P061`0300L700@700@01`L70P061`03
00L000T700@01`L010L00`071`061`0400L000H700D01`L700071`0300L700<700<01`002PL200H7
00<01`L00`L00`071`031`0300L701<7000C1`0300L700@700<01`L010L00`071`021`8030L200@7
00<01`L01PL00`071`021`0300L700870P021`0300L700L700L01`L700L000X700@01`L010L200@7
00<01`L01@L00`071`031`0300L700/700<01`L00`L00`071`051`0300L700870P041`0400L700X7
00<01`000`L00`071`071`0300L7008010L00`071`021`0300L700H700<01`L00PL200`70P041`03
00L700@700<01`L010L00`071`0B1`004PL00`071`051`0300L700D700<01`L00`0=1`0500L71`00
2@L00`071`031`0300L700800`L00`071`081`0300L700802`L01@071`L000870P051`0300L700H7
00@01`L70P0=1`800`L00`071`061`0300L700<70P021`0500L71`002`L2008700<01`L020L01007
1`L2008700<01`L00`L00`071`071`0500L71`003@L3008700<01`L01@L00`071`051`0300L70147
000A1`0300L700H700<01`L01PL300031`0700`70P000`L01`091`0300L700@70`041`0300L700T7
00<01`0030L00`071`021`<01PL00`071`071`0500L01`003@L01@0700L000T700<01`L010L300@7
00<01`L02PL00`07000;1`0300L700870`061`0300L700P700@01`003@L00`07000200P700<01`L0
1PL00`071`0@1`0040L00`071`071`0300L700H70P021`0300L700/700<01`002`L00`071`041`80
1@L00`071`0:1`8030L00`071`021`801`L00`071`081`0400L700d700@01`L02PL00`071`051`80
10L00`071`0:1`8030L00`071`031`801PL00`071`091`0300L000d700<01`L00P081`0300L700L7
00<01`L03`L0014700<01`L01PL00`071`061`<000<700L030L200031`0700T700<01`L010L300@7
00<01`L02@L00`07000<1`0300L700870`061`0300L700L700D01`07000=1`0500L01`002@L00`07
1`041`<010L00`071`0:1`0300L000/700<01`L00PL300H700<01`L020L01007000=1`0300L00080
20L00`071`061`0300L70107000B1`0300L700D700<01`L01@L00`071`0300d700D01`L700091`03
00L700<700<01`L00P031`0300L700P700<01`L00P0;1`0500L71`000PL200D700<01`L01PL01007
1`L200d70P031`0300L700H700<01`L00`L2008700D01`L7000;1`800PL00`071`081`0400L71`80
0PL00`071`031`0300L700L700D01`L7000=1`<00PL00`071`051`0300L700D700<01`L04@L001<7
00<01`L010L00`071`041`0300L700870P0<1`8010L00`071`061`0300L7008700<01`L00PL20087
00<01`L01`L01`071`L01`002PL010071`041`8010L00`071`051`0300L700<700<01`L02`L00`07
1`031`0300L700D700<01`L00PL200@700@01`L02PL00`0700031`0300L700L700<01`L00P041`03
00L7008700<01`L01PL00`071`021`8030L200@700<01`L010L00`071`041`0300L70187000<1ol0
200=1`0030L00`071`061`0300L7008700<01`L00PL00`071`051`<020L010071`061`0300L700@7
00@01`L020L300L700<01`L00`L01@071`L000P70P081`800PL00`071`031`0300L700D700<01`00
2@L00`0700071`0300L700<700<01`L00P081`8020L01@071`L000D700<01`L01@L300P700@01`L0
1PL00`071`041`0400L700P70`071`0300L7008700<01`L00PL00`071`061`0300L700/7000<1`03
00L700L700D01`L700031`0300L700H700@01`001PL01@071`L000L700<01`L00`L00`07000:1`80
1PL00`071`041`0300L7008700<01`L01@L00`071`081`8000<700L00`L00`071`061`0400L700L7
00@01`L020L00`071`021`0400L000X700<01`L01@L00`071`021`0300L700@700<01`L010L200X7
00<01`001@L00`071`051`0500L71`001PL200031`0700L700D01`L700031`0300L700L700<01`L0
2`L000`700<01`L020L010071`021`0300L700L700<01`L00P041`0300L7008700<01`L01PL00`07
1`021`8030L200@700<01`L01@L00`071`031`0300L700<70P0;1`<00`L00`071`071`0500L71`00
1@L01@071`L000T700@01`L70`0;1`801@L00`071`031`0300L700D700<01`L00PL200`70P041`03
00L700H700<01`L00PL00`071`021`800PL00`071`071`0400L7008700<01`L020L00`071`0;1`00
30L00`071`091`0500L01`002PL010071`L2008700<01`L00`L00`071`071`0500L71`003@L30087
00<01`L01PL00`071`041`0700L71`07000<1`800PL00`071`081`0300L7008700D01`L700041`03
00L700P700<01`L00P0<1`0300L000<700<01`L010L00`071`061`0300L700<03@L01@071`L000T7
00<01`L00`L00`071`0200<700<01`L020L01@0700L000/700<01`L02`L000`700<01`L02PL300/7
00<01`L00PL300H700<01`L020L400d700<01`000P091`0300L700D70`021`0300L700/70`0;1`03
00L700<70`051`0300L700T70`0=1`0300L700<01`L00`071`071`<000<700L030L400X700<01`L0
10L300@700<01`L02@L300`700<01`L02`L000`700<01`L02PL300/700<01`L00`L200H700<01`L0
20L400d700<01`L00P091`0300L700D70`021`0300L700/70`0;1`0300L700<70`051`0300L700T7
0`0=1`0300L700<01`L00`071`071`800PL00`071`0;1`@02PL00`071`041`801@L00`071`091`<0
30L00`071`0;1`0030L00`071`091`D02PL00`071`021`0400L000D700<01`L01`L200031`0000d7
00@01`070P081`0300L700@70P001@L000L000d700@01`002PL00`071`021`8000<7000010L00`07
1`081`8000<700L030L01@07000700801PL00`071`061`8000@700L03@L200031`0000T700<01`L0
0`L200031`0700<700<01`L020L500/700<01`L02`L000`700<01`L020L200031`0700802@L01@07
1`L000<70P041`0300L700H70P031`8030L200<70P071`0300L700<70P031`<030L200870P091`04
00L71`800`L200<700<01`L01`L200870P0<1`<00`L200D700<01`L01@L200<70P0<1`800`L200P7
00<01`L00PL200<700D01`L700091`8000<700L00P0:1`0300L700/7000<1`0300L700L70P021`03
00L7008020L010071`051`800`L00`071`051`8010L300/700<01`L00`L200H700<01`L00PL200D7
0P0;1`0300L000<70P081`0300L700801@L2008700<01`L01PL200<700<01`002`L200D70P041`03
00L700@70P051`0300L700T70`041`801`L010071`L200D700@01`L020L2008700<01`L00P091`03
00L700/7000<1`0300L700H70P031`0400L71`801`L00`0700071`800PL00`071`041`801@L01007
00091`801PL200D700@01`L70P071`802@L010071`041`801`L0100700071`8000<700L01PL200@7
00@01`L02@L200L70P031`0300L700<70P061`802@L200031`0700@70P061`0300L700801`L00`07
00071`800`L010071`L200P700<01`L02`L000`700<01`L01@L200@700<01`L00PL200H70P091`80
00<700L010L200H700<01`L00P071`0300L000L70P041`0300L7008020L300L700D01`L700051`80
1PL300T70`061`801@L01@071`L000L70`081`800PL00`071`021`801`L00`0700071`800PL00`07
1`041`801@L0100700091`801PL200@700<01`L00PL200L700<01`L02`L000`700<01`L010L200D7
00<01`L00`L200D700<01`L02@L300@70P071`0400L71`801@L010071`081`800`L0100700091`04
00L000D700<01`L00PL00`071`041`801@L200/70P051`801PL00`071`021`0300L700<70P000`L0
1`081`8000<700L00PL200P700@01`L01@L200<700<01`L01@L200@70`0;1`0300L700<70P051`03
00L700<70P061`0300L700/7000<1`0300L700<70P061`0300L700@70P031`8030L200<70P081`03
00L700870P031`0500L71`002@L200870`0:1`0300L700800`L00`071`031`0300L700D70P031`80
3@L200<70P071`0300L700<700@01`L70P021`0300L700P70`021`802@L01@071`L000<70P041`03
00L700H70P031`8030L200<70P061`0300L700@70P051`0300L700/7000<1ol0200=1`0030L01007
1`L200P700<01`L01PL2008700<01`L02`L400X700<01`L010L200D700<01`L02@L300`700<01`L0
0PL200L700<01`L01`L300031`0700`700<01`000P091`0300L700D70P041`0300L700X70`0;1`03
00L700<70P061`0300L700P7100=1`0300L7008020L00`071`061`800`L00`071`0;1`0030L01P07
1`0700P700<01`L01PL300031`0700`7100:1`0300L700@70`041`0300L700T70`0<1`0300L70087
0`061`0300L700L70`000`L01`0<1`0300L000802@L00`071`041`<010L00`071`0:1`<02`L00`07
1`021`<01PL00`071`081`@03@L00`07000200P700<01`L01PL3008700<01`L02`L000`700<01`00
0`L00`071`051`0300L700D700<01`L00`0=1`0500L71`002@L00`071`031`0300L700800`L00`07
1`081`0300L700802`L01@071`L000870P051`0300L700H700@01`L70P0=1`800`L00`071`061`03
00L700<70P021`0500L71`002`L2008700<01`L020L010071`L2008700<01`L00`L00`071`071`05
00L71`003@L3008700<01`L01@L00`071`051`0700L71`07000=1`0030L200D700<01`L010L00`07
1`041`0300L700870P0<1`8010L00`071`061`0300L7008700<01`L00PL2008700<01`L01`L01`07
1`L01`002PL010071`041`8010L00`071`051`0300L700<700<01`L02`L00`071`031`0300L700D7
00<01`L00PL200@700@01`L02PL00`0700031`0300L700L700<01`L00P041`0300L7008700<01`L0
1PL00`071`021`8030L200@700<01`L010L00`071`041`0300L700<70P0=1`0030L00`071`051`03
00L700<700<01`L00`L00`071`041`802PL00`0700051`0300L700D700D01`L700061`8000<700L0
1`L00`071`021`0400L700T700<01`001PL200<700<01`L010L00`071`041`802`L200H700<01`L0
10L010071`L200H700<01`002@L010071`041`0300L700H700@01`001PL01@071`L000L700<01`L0
0`L00`07000:1`801PL00`071`031`0300L700<700<01`L01@L00`071`0;1`002`L200P700<01`L0
0PL00`071`021`0300L700D70`081`0400L700H700<01`L010L010071`081`<01`L00`071`031`05
00L71`0020L200P70P021`0300L700<700<01`L01@L00`0700091`0300L000L700<01`L00`L00`07
1`0200P70P081`0500L71`001@L00`071`051`<020L010071`061`0300L700@700@01`L020L300L7
00<01`L00PL00`071`021`0300L700H70P0<1`002PL00`0700091`0500L71`000`L00`071`061`04
00L000H700D01`L700071`0300L700<700<01`002PL200H700<01`L010L00`071`021`0300L700D7
00<01`L020L200031`0700<700<01`L01PL010071`071`0400L700P700<01`L00PL01007000:1`03
00L700D700<01`L00PL00`071`041`0300L700@70P0:1`0300L000D700<01`L01@L01@071`L000H7
0P000`L01`071`0500L71`000`L00`071`071`0300L000/700091`0400L700X700@01`L00PL00`07
1`071`0300L7008010L00`071`021`0300L700H700<01`L00PL200`70P041`0300L700D700<01`L0
0`L00`071`031`802`L300<700<01`L01`L01@071`L000D700D01`L700091`0400L71`<02`L200D7
00<01`L00`L00`071`051`0300L700870P0<1`8010L00`071`061`0300L7008700<01`L00PL20087
00<01`L01`L010071`021`0300L700P700@01`L02PL000P700D01`L7000;1`0500L01`002PL01007
1`L2008700<01`L00`L00`071`071`0500L71`003@L3008700<01`L01PL00`071`041`0700L71`07
000<1`800PL00`071`081`0300L7008700D01`L700041`0300L700P700<01`L00P0<1`0300L000<7
00<01`L010L00`071`061`0300L700<03@L01@071`L000T700<01`L00`L00`071`0200<700<01`L0
20L01@0700L000/700D01`L700091`001`L00`071`021`0300L700X70`0;1`0300L700870`061`03
00L700P700@01`003@L00`07000200T700<01`L01@L00`0700021`0300L700/70`0;1`0300L700<7
00<01`001@L00`071`091`<03@L01P071`0700L700<01`L01`L300031`0700`70P000`L01`091`03
00L700@70`041`0300L700T70`0<1`0300L7008700<01`L01PL000H700<01`L00`L00`071`0;1`03
00L700X700<01`L00`L200H700<01`L02@L00`07000=1`0300L700802@L00`071`061`0500L71`00
3@L300/700<01`L010L00`071`041`0300L700T70`0=1`0500L71`0020L00`071`071`800PL00`07
1`0;1`0300L000/700<01`L010L200D700<01`L02PL00`071`0;1`0300L700<700<01`L01@L000L7
00<01`L00PL00`071`0:1`<02`L00`071`021`<01PL00`071`081`0400L000d700<01`000P091`03
00L700D700<01`000PL00`071`0;1`<02`L00`071`031`0300L000D700<01`L02@L300d700H01`L0
1`071`0300L700L70`000`L01`0<1`8000<700L02@L00`071`041`<010L00`071`091`<030L00`07
1`021`0300L700H700081`0500L71`002`L01@0700L000X700@01`L70P021`0300L700<700<01`L0
1`L01@071`L000d70`021`0300L700H700<01`L010L01`071`L01`0030L2008700<01`L020L00`07
1`021`0500L71`0010L00`071`081`0300L7008030L00`0700031`0300L700@700<01`L01PL00`07
1`0300d700D01`L700091`0300L700<700<01`L00P031`0300L700P700D01`07000;1`0500L71`00
2@L000T700<01`L0o`08008700<01`L020L000X700<01`002@L01@071`L000<700<01`L01PL01007
00061`0500L71`001`L00`071`031`0300L000X70P061`0300L700@700<01`L00PL00`071`051`03
00L700P70P000`L01`031`0300L700H700@01`L01`L010071`081`0300L7008700@01`002PL00`07
1`051`0300L7008700<01`L010L00`071`041`802PL00`0700051`0300L700D700D01`L700061`80
00<700L01`L01@071`L000<700<01`L01`L00`07000;1`002`L200P700<01`L00PL00`071`021`03
00L700D70`081`0400L700H700<01`L010L010071`081`<01`L00`071`031`0500L71`0020L200P7
0P021`0300L700<700<01`L01@L00`0700091`0300L000L700<01`L00`L00`071`0200P70P081`05
00L71`001@L00`071`051`<020L010071`061`0300L700@700@01`L020L300L700<01`L00PL00`07
1`021`0300L700H70P0<1`0030L00`071`051`0300L700<700<01`L00`L00`071`041`802PL00`07
00051`0300L700D700D01`L700061`8000<700L01`L00`071`021`0400L700T700<01`001PL200<7
00<01`L010L00`071`041`802`L200H700<01`L010L010071`L200H700<01`002@L010071`041`03
00L700H700@01`001PL01@071`L000L700<01`L00`L00`07000:1`801PL00`071`031`0300L700<7
00<01`L01@L00`071`0;1`0030L200D700<01`L010L00`071`041`0300L700870P0<1`8010L00`07
1`061`0300L7008700<01`L00PL2008700<01`L01`L01`071`L01`002PL010071`041`8010L00`07
1`051`0300L700<700<01`L02`L00`071`031`0300L700D700<01`L00PL200@700@01`L02PL00`07
00031`0300L700L700<01`L00P041`0300L7008700<01`L01PL00`071`021`8030L200@700<01`L0
10L00`071`041`0300L700<70P0=1`0030L00`0700031`0300L700D700<01`L01@L00`071`0300d7
00D01`L700091`0300L700<700<01`L00P031`0300L700P700<01`L00P0;1`0500L71`000PL200D7
00<01`L01PL010071`L200d70P031`0300L700H700<01`L00`L2008700D01`L7000;1`800PL00`07
1`081`0400L71`800PL00`071`031`0300L700L700D01`L7000=1`<00PL00`071`051`0300L700D7
00L01`L700L000d7000<1`0600L700L020L00`071`061`<000<700L030L200031`0700T700<01`L0
10L300@700<01`L02@L00`07000<1`0300L700870`061`0300L700L700D01`07000=1`0500L01`00
2@L00`071`041`<010L00`071`0:1`0300L000/700<01`L00PL300H700<01`L020L01007000=1`03
00L0008020L00`071`061`0300L0008700<01`L02`L000`700D01`L700091`0300L700H70P021`03
00L700/700<01`002`L00`071`041`801@L00`071`0:1`8030L00`071`021`801`L00`071`081`04
00L700d700@01`L02PL00`071`051`8010L00`071`0:1`8030L00`071`031`801PL00`071`091`03
00L000d700<01`L00P081`0300L700L700D01`L7000=1`0030L01P071`0700P700<01`L01PL30003
1`0700`70P000`L01`091`0300L700@70`041`0300L700T700<01`0030L00`071`021`<01PL00`07
1`071`0500L01`003@L01@0700L000T700<01`L010L300@700<01`L02PL00`07000;1`0300L70087
0`061`0300L700P700@01`003@L00`07000200P700<01`L01PL00`0700021`0300L700/7000<1`03
00L000<700<01`L01@L00`071`051`0300L700<03@L01@071`L000T700<01`L00`L00`071`0200<7
00<01`L020L00`071`0200/700D01`L700021`801@L00`071`061`0400L71`803@L200<700<01`L0
1PL00`071`031`800PL01@071`L000/70P021`0300L700P700@01`L70P021`0300L700<700<01`L0
1`L01@071`L000d70`021`0300L700D700<01`L01@L01`071`L01`003@L000`70P051`0300L700@7
00<01`L010L00`071`021`8030L200@700<01`L01PL00`071`021`0300L700870P021`0300L700L7
00L01`L700L000X700@01`L010L200@700<01`L01@L00`071`031`0300L700/700<01`L00`L00`07
1`051`0300L700870P041`0400L700X700<01`000`L00`071`071`0300L7008010L00`071`021`03
00L700H700<01`L00PL200`70P041`0300L700@700<01`L010L00`071`031`803@L000`700<01`L0
1@L00`071`031`0300L700<700<01`L010L200X700<01`001@L00`071`051`0500L71`001PL20003
1`0700L700<01`L00PL010071`091`0300L000H70P031`0300L700@700<01`L010L200/70P061`03
00L700@700@01`L70P061`0300L000T700@01`L010L00`071`061`0400L000H700D01`L700071`03
00L700<700<01`002PL200H700<01`L00`L00`071`031`0300L700D700<01`L02`L000/70P081`03
00L7008700<01`L00PL00`071`051`<020L010071`061`0300L700@700@01`L020L300L700<01`L0
0`L01@071`L000P70P081`800PL00`071`031`0300L700D700<01`002@L00`0700071`0300L700<7
00<01`L00P081`8020L01@071`L000D700<01`L01@L300P700@01`L01PL00`071`041`0400L700P7
0`071`0300L7008700<01`L00PL00`071`061`8030L000X700<01`002@L01@071`L000<700<01`L0
1PL0100700061`0500L71`001`L00`071`031`0300L000X70P061`0300L700@700<01`L00PL00`07
1`051`0300L700P70P000`L01`031`0300L700H700@01`L01`L010071`081`0300L7008700@01`00
2PL00`071`051`0300L7008700<01`L010L00`071`041`802PL00`0700051`0300L700D700D01`L7
00061`8000<700L01`L01@071`L000<700<01`L01`L00`07000;1`002@L00`071`3o00P00PL00`07
1`081`0020L01@071`L000/700D01`07000:1`0400L71`800PL00`071`031`0300L700L700D01`L7
000=1`<00PL00`071`061`0300L700@700L01`L700L000`70P021`0300L700P700<01`L00PL01@07
1`L000@700<01`L020L00`071`0200`700<01`000`L00`071`041`0300L700H700<01`L00`0=1`05
00L71`002@L00`071`031`0300L700800`L00`071`081`0500L01`002`L01@071`L000T700071`03
00L7008700<01`L02PL300/700<01`L00PL300H700<01`L020L01007000=1`0300L000802@L00`07
1`051`0300L0008700<01`L02`L300/700<01`L00`L00`0700051`0300L700T70`0=1`0600L700L0
1`L00`071`071`<000<700L030L200031`0700T700<01`L010L300@700<01`L02@L300`700<01`L0
0PL00`071`061`001PL00`071`031`0300L700/700<01`L02PL00`071`031`801PL00`071`091`03
00L000d700<01`L00P091`0300L700H700D01`L7000=1`<02`L00`071`041`0300L700@700<01`L0
2@L300d700D01`L700081`0300L700L70P021`0300L700/700<01`002`L00`071`041`801@L00`07
1`0:1`0300L700/700<01`L00`L00`071`051`001`L00`071`021`0300L700X70`0;1`0300L70087
0`061`0300L700P700@01`003@L00`07000200T700<01`L01@L00`0700021`0300L700/70`0;1`03
00L700<700<01`001@L00`071`091`<03@L01P071`0700L700<01`L01`L300031`0700`70P000`L0
1`091`0300L700@70`041`0300L700T70`0<1`0300L7008700<01`L01PL000P700D01`L7000;1`05
00L01`002PL010071`L2008700<01`L00`L00`071`071`0500L71`003@L3008700<01`L01PL00`07
1`041`0700L71`07000<1`800PL00`071`081`0300L7008700D01`L700041`0300L700P700<01`L0
0P0<1`0300L000<700<01`L010L00`071`061`0300L700<03@L01@071`L000T700<01`L00`L00`07
1`0200<700<01`L020L01@0700L000/700D01`L700091`002@L010071`0:1`0400L7008700<01`L0
1`L00`071`0200@700<01`L00PL00`071`061`0300L700870P0<1`8010L00`071`051`0300L700<7
00<01`L00`L200/70`031`0300L700L700D01`L700051`0500L71`002@L010071`L300/70P051`03
00L700<700<01`L01@L00`071`021`8030L200@700<01`L01PL00`071`021`0300L700870P021`03
00L700L700@01`L00PL00`071`081`0400L700X7000:1`0300L000T700D01`L700031`0300L700H7
00@01`001PL01@071`L000L700<01`L00`L00`07000:1`801PL00`071`041`0300L7008700<01`L0
1@L00`071`081`8000<700L00`L00`071`061`0400L700L700@01`L020L00`071`021`0400L000X7
00<01`L01@L00`071`021`0300L700@700<01`L010L200X700<01`001@L00`071`051`0500L71`00
1PL200031`0700L700D01`L700031`0300L700L700<01`002`L000/70P081`0300L7008700<01`L0
0PL00`071`051`<020L010071`061`0300L700@700@01`L020L300L700<01`L00`L01@071`L000P7
0P081`800PL00`071`031`0300L700D700<01`002@L00`0700071`0300L700<700<01`L00P081`80
20L01@071`L000D700<01`L01@L300P700@01`L01PL00`071`041`0400L700P70`071`0300L70087
00<01`L00PL00`071`061`8030L000`700<01`L01@L00`071`031`0300L700<700<01`L010L200X7
00<01`001@L00`071`051`0500L71`001PL200031`0700L700<01`L00PL010071`091`0300L000H7
0P031`0300L700@700<01`L010L200/70P061`0300L700@700@01`L70P061`0300L000T700@01`L0
10L00`071`061`0400L000H700D01`L700071`0300L700<700<01`002PL200H700<01`L00`L00`07
1`031`0300L700D700<01`L02`L000`70P051`0300L700@700<01`L010L00`071`021`8030L200@7
00<01`L01PL00`071`021`0300L700870P021`0300L700L700L01`L700L000X700@01`L010L200@7
00<01`L01@L00`071`031`0300L700/700<01`L00`L00`071`051`0300L700870P041`0400L700X7
00<01`000`L00`071`071`0300L7008010L00`071`021`0300L700H700<01`L00PL200`70P041`03
00L700@700<01`L010L00`071`031`803@L000`700<01`000`L00`071`051`0300L700D700<01`L0
0`0=1`0500L71`002@L00`071`031`0300L700800`L00`071`081`0300L700802`L01@071`L00087
0P051`0300L700H700@01`L70P0=1`800`L00`071`061`0300L700<70P021`0500L71`002`L20087
00<01`L020L010071`L2008700<01`L00`L00`071`071`0500L71`003@L3008700<01`L01@L00`07
1`051`0700L71`07000=1`0030L01P071`0700P700<01`L01PL300031`0700`7100:1`0300L700@7
0`041`0300L700T70`0<1`0300L700870`061`0300L700L70`000`L01`0<1`0300L000802@L00`07
1`041`<010L00`071`0:1`<02`L00`071`021`<01PL00`071`081`@03@L00`07000200P700<01`L0
1PL3008700<01`L02`L000`700@01`L70P081`0300L700H70P021`0300L700/7100:1`0300L700@7
0P051`0300L700T70`0<1`0300L700870P071`0300L700L70`000`L01`0<1`0300L000802@L00`07
1`051`8010L00`071`0:1`<02`L00`071`031`801PL00`071`081`@03@L00`071`0200P700<01`L0
1PL200<700<01`L02`L000`7o`0800d7000<1`0300L700<70P061`0300L700@70P031`8030L200<7
0P081`0300L700870P031`0500L71`002@L200870`0:1`0300L700800`L00`071`031`0300L700D7
0P031`803@L200<70P071`0300L700<700@01`L70P021`0300L700P70`021`802@L01@071`L000<7
0P041`0300L700H70P031`8030L200<70P061`0300L700@70P051`0300L700/7000<1`0300L700@7
0P051`0300L700<70P051`0300L700T70`041`801`L010071`L200D700@01`L020L200<700@01`00
2@L0100700051`0300L7008700<01`L010L200D70P0;1`801@L200H700<01`L00PL00`071`031`80
00<700L020L200031`0700870P081`0400L700D70P031`0300L700D70P041`<02`L00`071`031`80
1@L00`071`031`801PL00`071`0;1`0030L00`071`051`8010L00`071`021`801PL200T70P000`L0
1`041`801PL00`071`0200L700<01`001`L200@700<01`L00P081`<01`L01@071`L000D70P061`<0
2@L300H70P051`0500L71`001`L300P70P021`0300L700870P071`0300L000L70P021`0300L700@7
0P051`0400L000T70P061`8010L00`071`021`801`L00`071`0;1`0030L00`071`061`800`L01007
1`L200L700<01`001`L2008700<01`L010L200D700@01`002@L200H70P051`0400L71`801`L200T7
00@01`L010L200L700@01`001`L200031`0700H70P041`0400L700T70P071`800`L00`071`031`80
1PL200T70P000`L01`041`801PL00`071`0200L700<01`001`L200<700@01`L70P081`0300L700/7
000<1`0300L700L70P021`0300L7008020L010071`051`800`L00`071`051`8010L300/700<01`L0
0`L200H700<01`L00PL200D70P0;1`0300L000<70P081`0300L700801@L2008700<01`L01PL200<7
00<01`002`L200D70P041`0300L700@70P051`0300L700T70`041`801`L010071`L200D700@01`L0
20L2008700<01`L00P091`0300L700/7000<1`0300L700P70P000`L01`0200T700D01`L700031`80
10L00`071`061`800`L200`70P031`801`L00`071`031`800`L300`70P021`802@L010071`L200<7
0P031`0300L700L70P021`8030L300<70P051`0300L700D70P031`8030L200<70P081`0300L70087
0P031`0500L71`002@L200031`0700802PL00`071`0;1`0030L00`071`091`D02PL00`071`021`04
00L000D700<01`L01`L200031`0000d700@01`070P081`0300L700@70P001@L000L000d700@01`00
2PL00`071`021`8000<7000010L00`071`081`8000<700L030L01@07000700801PL00`071`061`80
00@700L03@L200031`0000T700<01`L00`L200031`0700<700<01`L020L500/700<01`L02`L000`7
00<01`L02PL300/700<01`L00`L200H700<01`L020L400d700<01`L00P091`0300L700D70`021`03
00L700/70`0;1`0300L700<70`051`0300L700T70`0=1`0300L700<01`L00`071`071`800PL00`07
1`0;1`@02PL00`071`041`801@L00`071`091`<030L00`071`0;1`0030L00`071`0:1`<02`L00`07
1`021`<01PL00`071`081`@03@L00`07000200T700<01`L01@L3008700<01`L02`L300/700<01`L0
0`L300D700<01`L02@L300d700<01`L00`071`0300L700L70`000`L01`0<1`@02PL00`071`041`<0
10L00`071`091`<030L00`071`0;1`0030L00`071`091`0500L01`002PL010071`L2008700<01`L0
0`L00`071`071`0500L71`003@L3008700<01`L01PL00`071`041`0700L71`07000<1`800PL00`07
1`081`0300L7008700D01`L700041`0300L700P700<01`L00P0<1`0300L000<700<01`L010L00`07
1`061`0300L700<03@L01@071`L000T700<01`L00`L00`071`0200<700<01`L020L01@0700L000/7
00<01`L02`L000`700<01`L020L010071`021`0300L700L700<01`L00P041`0300L7008700<01`L0
1PL00`071`021`8030L200@700<01`L01@L00`071`031`0300L700<70P0;1`<00`L00`071`071`05
00L71`001@L01@071`L000T700@01`L70`0;1`801@L00`071`031`0300L700D700<01`L00PL200`7
0P041`0300L700H700<01`L00PL00`071`021`800PL00`071`071`0400L7008700<01`L020L00`07
1`0;1`0030L00`071`071`0500L71`000`L00`071`061`0400L000H700D01`L700071`0300L700<7
00<01`002PL200H700<01`L010L00`071`021`0300L700D700<01`L020L200031`0700<700<01`L0
1PL010071`071`0400L700P700<01`L00PL01007000:1`0300L700D700<01`L00PL00`071`041`03
00L700@70P0:1`0300L000D700<01`L01@L01@071`L000H70P000`L01`071`0500L71`000`L00`07
1`071`0300L700/7000<1`0300L700H700<01`L00PL00`071`021`0300L700D70`081`0400L700H7
00<01`L010L010071`081`<01`L00`071`031`0500L71`0020L200P70P021`0300L700<700<01`L0
1@L00`0700091`0300L000L700<01`L00`L00`071`0200P70P081`0500L71`001@L00`071`051`<0
20L010071`061`0300L700@700@01`L020L300L700<01`L00PL00`071`021`0300L700H700<01`L0
2`L000`7o`0800d7000C1`0300L700@700<01`L010L00`071`021`8030L200@700<01`L01PL00`07
1`021`0300L700870P021`0300L700L700L01`L700L000X700@01`L010L200@700<01`L01@L00`07
1`031`0300L700/700<01`L00`L00`071`051`0300L700870P041`0400L700X700<01`000`L00`07
1`071`0300L7008010L00`071`021`0300L700H700<01`L00PL200`70P041`0300L700@700<01`L0
10L00`071`0B1`004PL00`071`051`0300L700D700<01`L00`0=1`0500L71`002@L00`071`031`03
00L700800`L00`071`081`0300L700802`L01@071`L000870P051`0300L700H700@01`L70P0=1`80
0`L00`071`061`0300L700<70P021`0500L71`002`L2008700<01`L020L010071`L2008700<01`L0
0`L00`071`071`0500L71`003@L3008700<01`L01@L00`071`051`0300L70147000A1`0300L700H7
00<01`L01PL300031`0700`70P000`L01`091`0300L700@70`041`0300L700T700<01`0030L00`07
1`021`<01PL00`071`071`0500L01`003@L01@0700L000T700<01`L010L300@700<01`L02PL00`07
000;1`0300L700870`061`0300L700P700@01`003@L00`07000200P700<01`L01PL00`071`0@1`00
40L00`071`071`0300L700H70P021`0300L700/700<01`002`L00`071`041`801@L00`071`0:1`80
30L00`071`021`801`L00`071`081`0400L700d700@01`L02PL00`071`051`8010L00`071`0:1`80
30L00`071`031`801PL00`071`091`0300L000d700<01`L00P081`0300L700L700<01`L03`L00147
00<01`L01PL00`071`061`<000<700L030L200031`0700T700<01`L010L300@700<01`L02@L00`07
000<1`0300L700870`061`0300L700L700D01`07000=1`0500L01`002@L00`071`041`<010L00`07
1`0:1`0300L000/700<01`L00PL300H700<01`L020L01007000=1`0300L0008020L00`071`061`03
00L70107000B1`0300L700D700<01`L01@L00`071`0300d700D01`L700091`0300L700<700<01`L0
0P031`0300L700P700<01`L00P0;1`0500L71`000PL200D700<01`L01PL010071`L200d70P031`03
00L700H700<01`L00`L2008700D01`L7000;1`800PL00`071`081`0400L71`800PL00`071`031`03
00L700L700D01`L7000=1`<00PL00`071`051`0300L700D700<01`L04@L001<700<01`L010L00`07
1`041`0300L700870P0<1`8010L00`071`061`0300L7008700<01`L00PL2008700<01`L01`L01`07
1`L01`002PL010071`041`8010L00`071`051`0300L700<700<01`L02`L00`071`031`0300L700D7
00<01`L00PL200@700@01`L02PL00`0700031`0300L700L700<01`L00P041`0300L7008700<01`L0
1PL00`071`021`8030L200@700<01`L010L00`071`041`0300L70187000D1`0300L700<700<01`L0
0`L00`071`041`802PL00`0700051`0300L700D700D01`L700061`8000<700L01`L00`071`021`04
00L700T700<01`001PL200<700<01`L010L00`071`041`802`L200H700<01`L010L010071`L200H7
00<01`002@L010071`041`0300L700H700@01`001PL01@071`L000L700<01`L00`L00`07000:1`80
1PL00`071`031`0300L700<700<01`L04`L001D700<01`L00PL00`071`021`0300L700D70`081`04
00L700H700<01`L010L010071`081`<01`L00`071`031`0500L71`0020L200P70P021`0300L700<7
00<01`L01@L00`0700091`0300L000L700<01`L00`L00`071`0200P70P081`0500L71`001@L00`07
1`051`<020L010071`061`0300L700@700@01`L020L300L700<01`L00PL00`071`021`0300L701@7
000F1`0500L71`000`L00`071`061`0400L000H700D01`L700071`0300L700<700<01`002PL200H7
00<01`L010L00`071`021`0300L700D700<01`L020L200031`0700<700<01`L01PL010071`071`04
00L700P700<01`L00PL01007000:1`0300L700D700<01`L00PL00`071`041`0300L700@70P0:1`03
00L000D700<01`L01@L01@071`L000H70P000`L01`071`0500L71`000`L00`071`0E1`005`L01007
1`021`0300L700L700<01`L00P041`0300L7008700<01`L01PL00`071`021`8030L200@700<01`L0
1@L00`071`031`0300L700<70P0;1`<00`L00`071`071`0500L71`001@L01@071`L000T700@01`L7
0`0;1`801@L00`071`031`0300L700D700<01`L00PL200`70P041`0300L700H700<01`L00PL00`07
1`021`800PL00`071`071`0400L7008700<01`L05PL001P700D01`07000:1`0400L71`800PL00`07
1`031`0300L700L700D01`L7000=1`<00PL00`071`061`0300L700@700L01`L700L000`70P021`03
00L700P700<01`L00PL01@071`L000@700<01`L020L00`071`0200`700<01`000`L00`071`041`03
00L700H700<01`L00`0=1`0500L71`002@L00`071`031`0300L700800`L00`071`081`0500L01`00
6@L001T7k@0J1`006PL00`071`0:1`0300L700<70P061`0300L700T700<01`003@L00`071`0200T7
00<01`L01PL01@071`L000d70`0;1`0300L700@700<01`L010L00`071`091`<03@L01@071`L000P7
00<01`L01`L2008700<01`L02`L00`07000;1`0300L700@70P051`0300L700X700<01`L06@L001X7
0P0;1`0300L700870`061`0300L700P700@01`003@L00`07000200T700<01`L01@L00`0700021`03
00L700/70`0;1`0300L700<700<01`001@L00`071`091`<03@L01P071`0700L700<01`L01`L30003
1`0700`70P000`L01`091`0300L700@70`041`0300L700T70P0K1`006PL00`07000:1`0400L71`80
0PL00`071`031`0300L700L700D01`L7000=1`<00PL00`071`061`0300L700@700L01`L700L000`7
0P021`0300L700P700<01`L00PL01@071`L000@700<01`L020L00`071`0200`700<01`000`L00`07
1`041`0300L700H700<01`L00`0=1`0500L71`002@L00`071`031`0300L700800`L00`071`081`03
00L001/7000J1`0400L700T700<01`L00P041`0300L7008700<01`L01PL00`071`021`8030L200@7
00<01`L01@L00`071`031`0300L700<70P0;1`<00`L00`071`071`0500L71`001@L01@071`L000T7
00@01`L70`0;1`801@L00`071`031`0300L700D700<01`L00PL200`70P041`0300L700H700<01`L0
0PL00`071`021`800PL00`071`071`0400L701/7000J1`0500L71`0020L0100700061`0500L71`00
1`L00`071`031`0300L000X70P061`0300L700@700<01`L00PL00`071`051`0300L700P70P000`L0
1`031`0300L700H700@01`L01`L010071`081`0300L7008700@01`002PL00`071`051`0300L70087
00<01`L010L00`071`041`802PL00`0700051`0300L700D700D01`L700061`8000<700L01`L01@07
1`L001/7000J1`0300L7008700<01`L01@L300P700@01`L01PL00`071`041`0400L700P70`071`03
00L700<700D01`L700081`8020L2008700<01`L00`L00`071`051`0300L000T700<01`001`L00`07
1`031`0300L7008020L200P700D01`L700051`0300L700D70`081`0400L700H700<01`L010L01007
1`081`<01`L00`071`021`0300L701T7000J1`0300L700<700<01`L010L200X700<01`001@L00`07
1`051`0500L71`001PL200031`0700L700<01`L00PL010071`091`0300L000H70P031`0300L700@7
00<01`L010L200/70P061`0300L700@700@01`L70P061`0300L000T700@01`L010L00`071`061`04
00L000H700D01`L700071`0300L700<700<01`002PL200H700<01`L00`L00`071`0I1`006PL00`07
1`041`0300L700870P0<1`8010L00`071`061`0300L7008700<01`L00PL2008700<01`L01`L01`07
1`L01`002PL010071`041`8010L00`071`051`0300L700<700<01`L02`L00`071`031`0300L700D7
00<01`L00PL200@700@01`L02PL00`0700031`0300L700L700<01`L00P041`0300L7008700<01`L0
1PL00`071`021`8030L200@700<01`L010L00`071`0I1`006PL00`071`051`0300L700<03@L01@07
1`L000T700<01`L00`L00`071`0200<700<01`L020L00`071`0200/700D01`L700021`801@L00`07
1`061`0400L71`803@L200<700<01`L01PL00`071`031`800PL01@071`L000/70P021`0300L700P7
00@01`L70P021`0300L700<700<01`L01`L01@071`L000d70`021`0300L700D700<01`L06@L001X7
00<01`L01PL300031`0700`7100:1`0300L700@70`041`0300L700T70`0<1`0300L700870`061`03
00L700L70`000`L01`0<1`0300L000802@L00`071`041`<010L00`071`0:1`<02`L00`071`021`<0
1PL00`071`081`@03@L00`07000200P700<01`L06@L001X700<01`L01PL2008700<01`L02`L400X7
00<01`L010L200D700<01`L02@L300`700<01`L00PL200L700<01`L01`L300031`0700`700<01`00
0P091`0300L700D70P041`0300L700X70`0;1`0300L700<70P061`0300L700P7100=1`0300L70080
20L00`071`0I1`006PL00`071`051`0600L700L03@L200031`0000T700<01`L00`L200031`0700<7
00<01`L020L200031`0000/700@01`L70P000`L01`051`0300L700H70P0010L0000=1`<000<70000
20L00`071`041`0400L000<700<01`L02@L200031`0000X700<01`L00PL0100700051`0300L700L7
0P000`L0000=1`0300L0008700<01`L01@L00`071`0I1`006PL00`071`041`0300L700870P0<1`80
0`L200P700<01`L00PL200<700D01`L700091`800PL300X700<01`L00P031`0300L700<700<01`L0
1@L200<70P0=1`800`L200L700<01`L00`L010071`L2008700<01`L020L300870P091`0500L71`00
0`L200@700<01`L01PL200<70P0<1`8010L00`071`041`0300L701T7000J1n/06`L001l700<01`L0
1@L200T70P000`L01`041`801PL00`071`0200L700<01`001`L200@700<01`L00P081`<01`L01@07
1`L000D70P061`<02@L300H70P051`0500L71`001`L300P70P021`0300L700870P071`0300L000L7
0P021`0300L700@70P051`0400L000T70P071`0300L701h7000N1`0300L700H700<01`001`L20087
00<01`L010L200D700@01`002@L200H70P051`0400L71`801`L200T700@01`L010L200L700@01`00
1`L200031`0700H70P041`0400L700T70P071`800`L00`071`031`801PL200T70P000`L01`041`80
1PL00`071`0200L700<01`0020L00`071`0M1`007@L00`071`071`0400L700D70P031`0300L700D7
0P041`<02`L00`071`031`801PL00`071`021`801@L200/700<01`000`L200P700<01`L00P051`80
0PL00`071`061`800`L00`07000;1`801@L200@700<01`L010L200D700<01`L02@L300@70P071`04
00L71`801@L010071`091`0300L701`7000L1`0300L700P700D01`L700031`8010L00`071`061`80
0`L200`70P031`801`L00`071`031`800`L300`70P021`802@L010071`L200<70P031`0300L700L7
0P021`8030L300<70P051`0300L700D70P031`8030L200<70P081`0300L700870P031`0500L71`00
2PL00`071`0K1`006`L00`071`091`0300L7008700@01`001@L00`071`071`8000<700003@L01007
00L200P700<01`L010L200051`001`003@L01007000:1`0300L700870P000`L000041`0300L700P7
0P000`L01`0<1`0500L000L00P061`0300L700H70P0010L01`0=1`8000<700002@L00`071`031`80
00<700L00`L00`071`091`0300L701X7000J1`0300L700X700<01`L00`L200H700<01`L020L400d7
00<01`L00P091`0300L700D70`021`0300L700/70`0;1`0300L700<70`051`0300L700T70`0=1`03
00L700<01`L00`071`071`800PL00`071`0;1`@02PL00`071`041`801@L00`071`0:1`0300L701T7
000K1`0300L700T700<01`L00`L200H700<01`L020L400d700<01`000P091`0300L700D70`021`03
00L700/70`0;1`0300L700<70`051`0300L700T70`0=1`0300L700<01`L00`071`071`<000<700L0
30L400X700<01`L010L200D700<01`L02@L00`071`0J1`0070L00`071`081`0300L7008700@01`L0
1@L00`071`071`0500L71`003@L3008700<01`L01PL00`071`041`0700L71`07000<1`800PL00`07
1`081`0300L7008700D01`L700041`0300L700P700<01`L00P0<1`0300L000<700<01`L010L00`07
1`061`0300L700<03@L01@071`L000T700<01`L00`L010071`041`0300L700P700<01`L06`L001d7
00<01`L01`L01@071`L000@700<01`L00PL00`071`061`0300L700870P0<1`8010L00`071`051`03
00L700<700<01`L00`L200/70`031`0300L700L700D01`L700051`0500L71`002@L010071`L300/7
0P051`0300L700<700<01`L01@L00`071`021`8030L200@700<01`L01PL00`071`021`0300L70087
00D01`L700091`0300L701`7000N1`0300L700H700@01`L01PL01@071`L000L700<01`L00`L00`07
000:1`801PL00`071`041`0300L7008700<01`L01@L00`071`081`8000<700L00`L00`071`061`04
00L700L700@01`L020L00`071`021`0400L000X700<01`L01@L00`071`021`0300L700@700<01`L0
10L200X700<01`001@L00`071`051`0500L71`001PL010071`081`0300L701d7000O1`0300L700D7
00<01`0020L010071`061`0300L700@700@01`L020L300L700<01`L00`L01@071`L000P70P081`80
0PL00`071`031`0300L700D700<01`002@L00`0700071`0300L700<700<01`L00P081`8020L01@07
1`L000D700<01`L01@L300P700@01`L01PL00`071`041`0400L700P700<01`001`L00`071`0N1`00
80L00`071`041`802PL00`0700051`0300L700D700D01`L700061`8000<700L01`L00`071`021`04
00L700T700<01`001PL200<700<01`L010L00`071`041`802`L200H700<01`L010L010071`L200H7
00<01`002@L010071`041`0300L700H700@01`001PL01@071`L000L700<01`L00`L00`07000:1`80
1PL00`071`0O1`008@L00`071`031`0300L700X70P041`0300L700H700<01`L00PL00`071`021`80
0PL00`071`071`0700L71`07000:1`0400L700@70P041`0300L700D700<01`L00`L00`071`0;1`03
00L700<700<01`L01@L00`071`021`8010L010071`0:1`0300L000<700<01`L01`L00`071`0200@7
00<01`L00PL00`071`061`0300L700870P0<1`0300L700<700<01`L080L0028700@01`L7d`031`03
00L70247000S1`0500L01`003@L200031`0700T700<01`L010L300@700<01`L02@L00`07000<1`03
00L700870`061`0300L700L700D01`07000=1`0500L01`002@L00`071`041`<010L00`071`0:1`03
00L000/700<01`L00PL300H700<01`L020L01007000=1`0500L01`0090L002<70P021`0300L700/7
00<01`002`L00`071`041`801@L00`071`0:1`8030L00`071`021`801`L00`071`081`0400L700d7
00@01`L02PL00`071`051`8010L00`071`0:1`8030L00`071`031`801PL00`071`091`0300L000d7
00<01`L00P0T1`0090L200031`0700`70P000`L01`091`0300L700@70`041`0300L700T700<01`00
30L00`071`021`<01PL00`071`071`0500L01`003@L01@0700L000T700<01`L010L300@700<01`L0
2PL00`07000;1`0300L700870`061`0300L700P700@01`003@L01007000U1`009@L300d700D01`L7
00091`0300L700<700<01`L00P031`0300L700P700<01`L00P0;1`0500L71`000PL200D700<01`L0
1PL010071`L200d70P031`0300L700H700<01`L00`L2008700D01`L7000;1`800PL00`071`081`04
00L71`800PL00`071`031`0300L700L700D01`L7000=1`<09PL002H70P0<1`8010L00`071`061`03
00L7008700<01`L00PL2008700<01`L01`L01`071`L01`002PL010071`041`8010L00`071`051`03
00L700<700<01`L02`L00`071`031`0300L700D700<01`L00PL200@700@01`L02PL00`0700031`03
00L700L700<01`L00P041`0300L7008700<01`L01PL00`071`021`8030L202L7000W1`802PL00`07
00051`0300L700D700D01`L700061`8000<700L01`L00`071`021`0400L700T700<01`001PL200<7
00<01`L010L00`071`041`802`L200H700<01`L010L010071`L200H700<01`002@L010071`041`03
00L700H700@01`001PL01@071`L000L700<01`L00`L00`07000:1`80:0L002L70`081`0400L700H7
00<01`L010L010071`081`<01`L00`071`031`0500L71`0020L200P70P021`0300L700<700<01`L0
1@L00`0700091`0300L000L700<01`L00`L00`071`0200P70P081`0500L71`001@L00`071`051`<0
20L010071`061`0300L700@700@01`L020L302P7000W1`0400L000H700D01`L700071`0300L700<7
00<01`002PL200H700<01`L010L00`071`021`0300L700D700<01`L020L200031`0700<700<01`L0
1PL010071`071`0400L700P700<01`L00PL01007000:1`0300L700D700<01`L00PL00`071`041`03
00L700@70P0:1`0300L000D700<01`L01@L01@071`L000H70P000`L01`0W1`009`L00`071`0200@7
00<01`L00PL00`071`061`0300L700870P0<1`8010L00`071`051`0300L700<700<01`L00`L200/7
0`031`0300L700L700D01`L700051`0500L71`002@L010071`L300/70P051`0300L700<700<01`L0
1@L00`071`021`8030L200@700<01`L01PL00`071`021`0300L700870P021`0300L702H7000W1`04
00L71`800PL00`071`031`0300L700L700D01`L7000=1`<00PL00`071`061`0300L700@700L01`L7
00L000`70P021`0300L700P700<01`L00PL01@071`L000@700<01`L020L00`071`0200`700<01`00
0`L00`071`041`0300L700H700<01`L00`0=1`0500L71`002@L00`071`031`0300L700800`L00`07
1`0V1`009`L00`071`021`<01PL00`071`081`0400L000d700<01`000P091`0300L700D700<01`00
0PL00`071`0;1`<02`L00`071`031`0300L000D700<01`L02@L300d700H01`L01`071`0300L700L7
0`000`L01`0<1`8000<700L02@L00`071`041`<010L00`071`0V1`009`L00`071`031`0300L700D7
00<01`L02@L00`07000=1`0300L700802@L00`071`061`0500L71`003@L300/700<01`L010L00`07
1`041`0300L700T70`0=1`0500L71`0020L00`071`071`800PL00`071`0;1`0300L000/700<01`L0
1@L00`071`031`0300L702H7000W1`0300L700@700<01`L010L00`071`081`0400L000d700<01`00
0P091`0300L700D700<01`000PL00`071`0;1`<02`L00`071`031`0300L000D700<01`L02@L300d7
00H01`L01`071`0300L700L70`000`L01`0<1`8000<700L02@L00`071`041`0300L700@700<01`L0
9PL002L7d@0X1`00<0L00`071`021`0300L700H700<01`L00PL200`70P041`0300L700D700<01`L0
0`L00`071`031`802`L300<700<01`L01`L01@071`L000D700D01`L700091`0400L71`<02`L200D7
00<01`L00`L00`071`051`0300L700870P0<1`8010L00`071`061`0300L7008700<01`L0;`L00347
00D01`L700071`0300L700<700<01`002PL200H700<01`L010L00`071`021`0300L700D700<01`L0
20L200031`0700<700<01`L01PL010071`071`0400L700P700<01`L00PL01007000:1`0300L700D7
00<01`L00PL00`071`041`0300L700@70P0:1`0300L000D700<01`L01@L01@071`L00387000b1`04
00L700H700<01`L010L010071`081`<01`L00`071`031`0500L71`0020L200P70P021`0300L700<7
00<01`L01@L00`0700091`0300L000L700<01`L00`L00`071`0200P70P081`0500L71`001@L00`07
1`051`<020L010071`061`0300L700@700@01`L0<`L003<700<01`001@L00`071`051`0500L71`00
1PL200031`0700L700<01`L00PL010071`091`0300L000H70P031`0300L700@700<01`L010L200/7
0P061`0300L700@700@01`L70P061`0300L000T700@01`L010L00`071`061`0400L000H700D01`L7
00071`0300L700<700<01`00=0L003@70P041`0300L700H700<01`L00PL00`071`021`800PL00`07
1`071`0700L71`07000:1`0400L700@70P041`0300L700D700<01`L00`L00`071`0;1`0300L700<7
00<01`L01@L00`071`021`8010L010071`0:1`0300L000<700<01`L01`L00`071`0200@700<01`L0
0PL00`071`061`0300L700870P0e1`00=@L01@071`L000T700<01`L00`L00`071`0200<700<01`L0
20L00`071`0200/700D01`L700021`801@L00`071`061`0400L71`803@L200<700<01`L01PL00`07
1`031`800PL01@071`L000/70P021`0300L700P700@01`L70P021`0300L700<700<01`L01`L01@07
1`L003H7000e1`8000<700L02@L00`071`041`<010L00`071`091`<030L00`071`021`<01PL00`07
1`071`<000<700L030L00`07000200T700<01`L010L300@700<01`L02PL300/700<01`L00PL300H7
00<01`L020L403H7000e1`0400L000X700<01`L010L200D700<01`L02@L300`700<01`L00PL200L7
00<01`L01`L300031`0700`700<01`000P091`0300L700D70P041`0300L700X70`0;1`0300L700<7
0P061`0300L700P70P000`L01`0e1`00=@L00`071`0200T700<01`L00`L010071`041`0300L700P7
0P000`L0000;1`0400L71`8000<700L01@L00`071`061`8000@700003@L300031`0000P700<01`L0
10L0100700031`0300L700T70P000`L0000:1`0300L7008700@01`L01@L00`071`071`800PL00`07
1`0d1`00=@L010071`L200P700<01`L00PL00`071`021`0500L71`002@L200870`0:1`0300L70080
0`L00`071`031`0300L700D70P031`803@L200<70P071`0300L700<700@01`L70P021`0300L700P7
0`021`802@L01@071`L000@700<01`L00PL00`071`061`800`L00`071`0d1`00=@L00`071`021`80
1`L01@071`L000H700@01`L020L200<700@01`002@L0100700051`0300L7008700<01`L010L200D7
0P0;1`801@L200H700<01`L00PL00`071`031`8000<700L020L200031`0700870P081`0400L700H7
00D01`L700071`8010L00`071`0d1`00=@L00`071`031`801PL010071`081`0300L000L70P041`03
00L7008020L300L700D01`L700051`801PL300T70`061`801@L01@071`L000L70`081`800PL00`07
1`021`801`L00`0700081`0400L700H70P051`0300L703@7000e1`0300L700@70P051`0300L000X7
0P061`801@L010071`L200L70P091`0400L700@70P071`0400L000L70P000`L01`061`8010L01007
1`091`801`L200<700<01`L00`L200H70P0:1`0300L000D70P061`0300L703@7000e1kD0=PL003h7
0P031`0300L700/70P031`801`L00`071`031`800`L300`70P021`802@L010071`L200<70P031`03
00L700L70P021`8030L300<70P051`0300L700D70P031`803@L010071`L203l7000o1`8000<700L0
3@L0100700L200P700<01`L010L200051`001`003@L01007000:1`0300L700870P000`L000041`03
00L700P70P000`L01`0<1`0500L000L00P061`0300L700H70P0010L01`0>1`0400L0040700101`80
3`L00`071`0200T700<01`L01@L3008700<01`L02`L300/700<01`L00`L300D700<01`L02@L300d7
00<01`L00`071`0300L700L70P021`0300L700d70P111`00@@L200h700<01`L00P091`0300L700D7
0`021`0300L700/70`0;1`0300L700<70`051`0300L700T70`0=1`0300L700<01`L00`071`071`80
0PL00`071`0<1`0300L7044700131`0300L700/700<01`000PL00`071`061`0300L700@700L01`L7
00L000`70P021`0300L700P700<01`L00PL01@071`L000@700<01`L020L00`071`0200`700<01`00
0`L00`071`041`0300L700H700H01`L01`0=1`0300L7048700141`0300L700X70P041`0300L700D7
00<01`L00`L00`071`031`802`L300<700<01`L01`L01@071`L000D700D01`L700091`0400L71`<0
2`L200D700<01`L00`L00`071`051`0300L700870P0<1`0300L704<700151`0300L700T700<01`L0
10L00`071`041`0300L7008700<01`L01@L00`071`081`8000<700L00`L00`071`061`0400L700L7
00@01`L020L00`071`021`0400L000X700<01`L01@L00`071`021`0300L700@700<01`L010L00`07
1`091`0300L704@700161`0300L700L70P071`0300L700<700D01`L700081`8020L2008700<01`L0
0`L00`071`051`0300L000T700<01`001`L00`071`031`0300L7008020L200P700D01`L700051`03
00L700D70P091`0300L704D700171`0300L700D700<01`0020L00`071`021`0400L700T700<01`00
1PL200<700<01`L010L00`071`041`802`L200H700<01`L010L010071`L200H700<01`002@L01007
1`041`0300L700H700<01`001`L00`071`161`00B0L00`071`031`0400L700T700L01`L700L000X7
00@01`L010L200@700<01`L01@L00`071`031`0300L700/700<01`L00`L00`071`051`0300L70087
0P041`0400L700X700<01`000`L00`071`071`0400L700D700<01`L0A`L004T700D01`L700031`03
00L700P700<01`L00P0;1`0500L71`000PL200D700<01`L01PL010071`L200d70P031`0300L700H7
00<01`L00`L2008700D01`L7000;1`800PL00`071`081`0500L71`000`L00`071`181`00BPL00`07
00041`0300L700T700<01`0030L00`071`021`<01PL00`071`071`0500L01`003@L01@0700L000T7
00<01`L010L300@700<01`L02PL00`07000;1`0300L7008700<01`00B`L004/700<01`L00`Mm00D7
00<01`L0BPL005l700<01`L02PL00`071`021`<01PL00`071`071`0500L01`003@L01@0700L000T7
00<01`L010L300@700<01`L02PL00`071`1N1`00H0L00`071`091`0500L71`000PL200D700<01`L0
1PL010071`L200d70P031`0300L700H700<01`L00`L2008700D01`L7000;1`0300L705l7001Q1`03
00L700P700@01`L010L200@700<01`L01@L00`071`031`0300L700/700<01`L00`L00`071`051`03
00L700870P041`0400L700X700<01`L0H0L0068700<01`L01`L00`0700061`800`L00`071`041`03
00L700@70P0;1`801PL00`071`041`0400L71`801PL00`0700091`0300L70647001S1`0300L700H7
0P081`800PL00`071`031`0300L700D700<01`002@L00`0700071`0300L700<700<01`L00P081`80
20L00`071`1R1`00I0L00`071`051`0300L700P70P000`L01`031`0300L700H700@01`L01`L01007
1`081`0300L7008700@01`002PL00`071`051`0300L706<7001U1`0300L700<70P0;1`<00`L00`07
1`071`0500L71`001@L01@071`L000T700@01`L70`0;1`801@L00`071`1T1`00IPL01`071`L01`00
30L2008700<01`L020L00`071`021`0500L71`0010L00`071`081`0300L7008030L00`0700031`03
00L706D7001W1`0300L0008700<01`L02`L300/700<01`L00`L00`0700051`0300L700T70`0=1`06
00L700L0J0L006P700D01`L7000=1`8030L00`071`041`0300L700@700<01`L02PL200d700D01`L7
001Y1`00K0L00`071`0;1`0300L000/700<01`L00`L00`0700051`0300L700T700<01`003@L00`07
1`1[1`00K0L00`071`0;1`0400L700X700<01`L00PL01@071`L000@700<01`L020L010071`0=1`03
00L706/7001/1`0300L700/700D01`L700091`0500L71`001@L01@071`L000T700D01`L7000=1`03
00L706/7001/1dL0K@L0080700<01`L01`L00`071`071`0300L700L700<01`L0O`L0084700<01`L0
1@L00`071`091`0300L700D700<01`L0P0L0088700<01`L00`L00`071`0;1`0300L700<700<01`L0
P@L008<700D01`L7000?1`0500L71`00Q0L008@700<01`004@L00`0700251`00Q@L00`071`0A1`03
00L708@7003o1b47003o1b47003o1b47003o1b47003o1b47003o1b470000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.3946, -10.3946, 0.0724361, \
0.0724361}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[lattice21, \ lattice32, \ lattice43, \ lattice41, \ lattice31, 
      lattice42]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0481025 0.5 0.0481025 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.12222 .20747 m
.21843 .11126 L
s
.12222 .20747 m
.12222 .34352 L
s
.21843 .11126 m
.21843 .24732 L
s
.02602 .43973 m
.12222 .34352 L
s
.02602 .43973 m
.02602 .57578 L
s
.12222 .34352 m
.21843 .24732 L
s
.12222 .34352 m
.12222 .47957 L
s
.21843 .24732 m
.31463 .15111 L
s
.21843 .24732 m
.21843 .38337 L
s
.31463 .15111 m
.41084 .05491 L
s
.31463 .15111 m
.31463 .28716 L
s
.41084 .05491 m
.41084 .19096 L
s
.02602 .57578 m
.12222 .47957 L
s
.12222 .47957 m
.21843 .38337 L
s
.12222 .47957 m
.12222 .61563 L
s
.21843 .38337 m
.31463 .28716 L
s
.21843 .38337 m
.21843 .51942 L
s
.31463 .28716 m
.41084 .19096 L
s
.31463 .28716 m
.31463 .42322 L
s
.41084 .19096 m
.50704 .09475 L
s
.41084 .19096 m
.41084 .32701 L
s
.50704 .09475 m
.50704 .23081 L
s
.12222 .61563 m
.21843 .51942 L
s
.12222 .61563 m
.12222 .75168 L
s
.21843 .51942 m
.31463 .42322 L
s
.21843 .51942 m
.21843 .65548 L
s
.31463 .42322 m
.41084 .32701 L
s
.31463 .42322 m
.31463 .55927 L
s
.41084 .32701 m
.50704 .23081 L
s
.41084 .32701 m
.41084 .46307 L
s
.50704 .23081 m
.60325 .1346 L
s
.50704 .23081 m
.50704 .36686 L
s
.60325 .1346 m
.60325 .27066 L
s
.12222 .75168 m
.21843 .65548 L
s
.21843 .65548 m
.31463 .55927 L
s
.21843 .65548 m
.21843 .79153 L
s
.31463 .55927 m
.41084 .46307 L
s
.31463 .55927 m
.31463 .69533 L
s
.41084 .46307 m
.50704 .36686 L
s
.41084 .46307 m
.41084 .59912 L
s
.50704 .36686 m
.60325 .27066 L
s
.50704 .36686 m
.50704 .50292 L
s
.60325 .27066 m
.69945 .17445 L
s
.60325 .27066 m
.60325 .40671 L
s
.69945 .17445 m
.69945 .31051 L
s
.21843 .79153 m
.31463 .69533 L
s
.31463 .69533 m
.41084 .59912 L
s
.31463 .69533 m
.31463 .83138 L
s
.41084 .59912 m
.50704 .50292 L
s
.41084 .59912 m
.41084 .73518 L
s
.50704 .50292 m
.60325 .40671 L
s
.50704 .50292 m
.50704 .63897 L
s
.60325 .40671 m
.69945 .31051 L
s
.60325 .40671 m
.60325 .54277 L
s
.69945 .31051 m
.79566 .2143 L
s
.69945 .31051 m
.69945 .44656 L
s
.79566 .2143 m
.79566 .35036 L
s
.31463 .83138 m
.41084 .73518 L
s
.41084 .73518 m
.50704 .63897 L
s
.41084 .73518 m
.41084 .87123 L
s
.50704 .63897 m
.60325 .54277 L
s
.50704 .63897 m
.50704 .77503 L
s
.60325 .54277 m
.69945 .44656 L
s
.60325 .54277 m
.60325 .67882 L
s
.69945 .44656 m
.79566 .35036 L
s
.69945 .44656 m
.69945 .58262 L
s
.79566 .35036 m
.89186 .25415 L
s
.79566 .35036 m
.79566 .48641 L
s
.89186 .25415 m
.89186 .39021 L
s
.41084 .87123 m
.50704 .77503 L
s
.50704 .77503 m
.60325 .67882 L
s
.50704 .77503 m
.50704 .91108 L
s
.60325 .67882 m
.69945 .58262 L
s
.60325 .67882 m
.60325 .81488 L
s
.69945 .58262 m
.79566 .48641 L
s
.69945 .58262 m
.69945 .71867 L
s
.79566 .48641 m
.89186 .39021 L
s
.79566 .48641 m
.79566 .62247 L
s
.89186 .39021 m
.89186 .52626 L
s
.50704 .91108 m
.60325 .81488 L
s
.60325 .81488 m
.69945 .71867 L
s
.60325 .81488 m
.60325 .95093 L
s
.69945 .71867 m
.79566 .62247 L
s
.69945 .71867 m
.69945 .85473 L
s
.79566 .62247 m
.89186 .52626 L
s
.79566 .62247 m
.79566 .75852 L
s
.89186 .52626 m
.89186 .66232 L
s
.60325 .95093 m
.69945 .85473 L
s
.69945 .85473 m
.79566 .75852 L
s
.79566 .75852 m
.89186 .66232 L
s
.06003 .33768 m
.15624 .24148 L
s
.06003 .33768 m
.06003 .47374 L
s
.15624 .24148 m
.25244 .14527 L
s
.15624 .24148 m
.15624 .37753 L
s
.25244 .14527 m
.34865 .04907 L
s
.25244 .14527 m
.25244 .28133 L
s
.34865 .04907 m
.34865 .18512 L
s
.06003 .47374 m
.15624 .37753 L
s
.06003 .47374 m
.06003 .60979 L
s
.15624 .37753 m
.25244 .28133 L
s
.15624 .37753 m
.15624 .51359 L
s
.25244 .28133 m
.34865 .18512 L
s
.25244 .28133 m
.25244 .41738 L
s
.34865 .18512 m
.44485 .08892 L
s
.34865 .18512 m
.34865 .32118 L
s
.44485 .08892 m
.44485 .22497 L
s
.06003 .60979 m
.15624 .51359 L
s
.15624 .51359 m
.25244 .41738 L
s
.15624 .51359 m
.15624 .64964 L
s
.25244 .41738 m
.34865 .32118 L
s
.25244 .41738 m
.25244 .55344 L
s
.34865 .32118 m
.44485 .22497 L
s
.34865 .32118 m
.34865 .45723 L
s
.44485 .22497 m
.54106 .12877 L
s
.44485 .22497 m
.44485 .36103 L
s
.54106 .12877 m
.54106 .26482 L
s
.15624 .64964 m
.25244 .55344 L
s
.15624 .64964 m
.15624 .7857 L
s
.25244 .55344 m
.34865 .45723 L
s
.25244 .55344 m
.25244 .68949 L
s
.34865 .45723 m
.44485 .36103 L
s
.34865 .45723 m
.34865 .59329 L
s
.44485 .36103 m
.54106 .26482 L
s
.44485 .36103 m
.44485 .49708 L
s
.54106 .26482 m
.63726 .16862 L
s
.54106 .26482 m
.54106 .40088 L
s
.63726 .16862 m
.63726 .30467 L
s
.15624 .7857 m
.25244 .68949 L
s
.25244 .68949 m
.34865 .59329 L
s
.25244 .68949 m
.25244 .82555 L
s
.34865 .59329 m
.44485 .49708 L
s
.34865 .59329 m
.34865 .72934 L
s
.44485 .49708 m
.54106 .40088 L
s
.44485 .49708 m
.44485 .63314 L
s
.54106 .40088 m
.63726 .30467 L
s
.54106 .40088 m
.54106 .53693 L
s
.63726 .30467 m
.73347 .20847 L
s
.63726 .30467 m
.63726 .44073 L
s
.73347 .20847 m
.73347 .34452 L
s
.25244 .82555 m
.34865 .72934 L
s
.34865 .72934 m
.44485 .63314 L
s
.34865 .72934 m
.34865 .8654 L
s
.44485 .63314 m
.54106 .53693 L
s
.44485 .63314 m
.44485 .76919 L
s
.54106 .53693 m
.63726 .44073 L
s
.54106 .53693 m
.54106 .67299 L
s
.63726 .44073 m
.73347 .34452 L
s
.63726 .44073 m
.63726 .57678 L
s
.73347 .34452 m
.82967 .24832 L
s
.73347 .34452 m
.73347 .48058 L
s
.82967 .24832 m
.82967 .38437 L
s
.34865 .8654 m
.44485 .76919 L
s
.44485 .76919 m
.54106 .67299 L
s
.44485 .76919 m
.44485 .90525 L
s
.54106 .67299 m
.63726 .57678 L
s
.54106 .67299 m
.54106 .80904 L
s
.63726 .57678 m
.73347 .48058 L
s
.63726 .57678 m
.63726 .71284 L
s
.73347 .48058 m
.82967 .38437 L
s
.73347 .48058 m
.73347 .61663 L
s
.82967 .38437 m
.92588 .28817 L
s
.82967 .38437 m
.82967 .52043 L
s
.92588 .28817 m
.92588 .42422 L
s
.44485 .90525 m
.54106 .80904 L
s
.54106 .80904 m
.63726 .71284 L
s
.54106 .80904 m
.54106 .94509 L
s
.63726 .71284 m
.73347 .61663 L
s
.63726 .71284 m
.63726 .84889 L
s
.73347 .61663 m
.82967 .52043 L
s
.73347 .61663 m
.73347 .75268 L
s
.82967 .52043 m
.92588 .42422 L
s
.82967 .52043 m
.82967 .65648 L
s
.92588 .42422 m
.92588 .56027 L
s
.54106 .94509 m
.63726 .84889 L
s
.63726 .84889 m
.73347 .75268 L
s
.73347 .75268 m
.82967 .65648 L
s
.73347 .75268 m
.73347 .88874 L
s
.82967 .65648 m
.92588 .56027 L
s
.82967 .65648 m
.82967 .79253 L
s
.92588 .56027 m
.92588 .69633 L
s
.73347 .88874 m
.82967 .79253 L
s
.82967 .79253 m
.92588 .69633 L
s
.07412 .30367 m
.17033 .20747 L
s
.07412 .30367 m
.07412 .43973 L
s
.17033 .20747 m
.26653 .11126 L
s
.17033 .20747 m
.17033 .34352 L
s
.26653 .11126 m
.26653 .24732 L
s
.07412 .43973 m
.17033 .34352 L
s
.07412 .43973 m
.07412 .57578 L
s
.17033 .34352 m
.26653 .24732 L
s
.17033 .34352 m
.17033 .47957 L
s
.26653 .24732 m
.36274 .15111 L
s
.26653 .24732 m
.26653 .38337 L
s
.36274 .15111 m
.45894 .05491 L
s
.36274 .15111 m
.36274 .28716 L
s
.45894 .05491 m
.45894 .19096 L
s
.07412 .57578 m
.17033 .47957 L
s
.07412 .57578 m
.07412 .71183 L
s
.17033 .47957 m
.26653 .38337 L
s
.17033 .47957 m
.17033 .61563 L
s
.26653 .38337 m
.36274 .28716 L
s
.26653 .38337 m
.26653 .51942 L
s
.36274 .28716 m
.45894 .19096 L
s
.36274 .28716 m
.36274 .42322 L
s
.45894 .19096 m
.55515 .09475 L
s
.45894 .19096 m
.45894 .32701 L
s
.55515 .09475 m
.55515 .23081 L
s
.07412 .71183 m
.17033 .61563 L
s
.17033 .61563 m
.26653 .51942 L
s
.17033 .61563 m
.17033 .75168 L
s
.26653 .51942 m
.36274 .42322 L
s
.26653 .51942 m
.26653 .65548 L
s
.36274 .42322 m
.45894 .32701 L
s
.36274 .42322 m
.36274 .55927 L
s
.45894 .32701 m
.55515 .23081 L
s
.45894 .32701 m
.45894 .46307 L
s
.55515 .23081 m
.65135 .1346 L
s
.55515 .23081 m
.55515 .36686 L
s
.65135 .1346 m
.65135 .27066 L
s
.17033 .75168 m
.26653 .65548 L
s
.26653 .65548 m
.36274 .55927 L
s
.26653 .65548 m
.26653 .79153 L
s
.36274 .55927 m
.45894 .46307 L
s
.36274 .55927 m
.36274 .69533 L
s
.45894 .46307 m
.55515 .36686 L
s
.45894 .46307 m
.45894 .59912 L
s
.55515 .36686 m
.65135 .27066 L
s
.55515 .36686 m
.55515 .50292 L
s
.65135 .27066 m
.74756 .17445 L
s
.65135 .27066 m
.65135 .40671 L
s
.74756 .17445 m
.74756 .31051 L
s
.26653 .79153 m
.36274 .69533 L
s
.36274 .69533 m
.45894 .59912 L
s
.36274 .69533 m
.36274 .83138 L
s
.45894 .59912 m
.55515 .50292 L
s
.45894 .59912 m
.45894 .73518 L
s
.55515 .50292 m
.65135 .40671 L
s
.55515 .50292 m
.55515 .63897 L
s
.65135 .40671 m
.74756 .31051 L
s
.65135 .40671 m
.65135 .54277 L
s
.74756 .31051 m
.84376 .2143 L
s
.74756 .31051 m
.74756 .44656 L
s
.84376 .2143 m
.84376 .35036 L
s
.36274 .83138 m
.45894 .73518 L
s
.45894 .73518 m
.55515 .63897 L
s
.45894 .73518 m
.45894 .87123 L
s
.55515 .63897 m
.65135 .54277 L
s
.55515 .63897 m
.55515 .77503 L
s
.65135 .54277 m
.74756 .44656 L
s
.65135 .54277 m
.65135 .67882 L
s
.74756 .44656 m
.84376 .35036 L
s
.74756 .44656 m
.74756 .58262 L
s
.84376 .35036 m
.84376 .48641 L
s
.45894 .87123 m
.55515 .77503 L
s
.55515 .77503 m
.65135 .67882 L
s
.55515 .77503 m
.55515 .91108 L
s
.65135 .67882 m
.74756 .58262 L
s
.65135 .67882 m
.65135 .81488 L
s
.74756 .58262 m
.84376 .48641 L
s
.74756 .58262 m
.74756 .71867 L
s
.84376 .48641 m
.93997 .39021 L
s
.84376 .48641 m
.84376 .62247 L
s
.93997 .39021 m
.93997 .52626 L
s
.55515 .91108 m
.65135 .81488 L
s
.65135 .81488 m
.74756 .71867 L
s
.65135 .81488 m
.65135 .95093 L
s
.74756 .71867 m
.84376 .62247 L
s
.74756 .71867 m
.74756 .85473 L
s
.84376 .62247 m
.93997 .52626 L
s
.84376 .62247 m
.84376 .75852 L
s
.93997 .52626 m
.93997 .66232 L
s
.65135 .95093 m
.74756 .85473 L
s
.74756 .85473 m
.84376 .75852 L
s
.84376 .75852 m
.93997 .66232 L
s
.10814 .33768 m
.20434 .24148 L
s
.10814 .33768 m
.10814 .47374 L
s
.20434 .24148 m
.30055 .14527 L
s
.20434 .24148 m
.20434 .37753 L
s
.30055 .14527 m
.39675 .04907 L
s
.30055 .14527 m
.30055 .28133 L
s
.39675 .04907 m
.39675 .18512 L
s
.10814 .47374 m
.20434 .37753 L
s
.10814 .47374 m
.10814 .60979 L
s
.20434 .37753 m
.30055 .28133 L
s
.20434 .37753 m
.20434 .51359 L
s
.30055 .28133 m
.39675 .18512 L
s
.30055 .28133 m
.30055 .41738 L
s
.39675 .18512 m
.49296 .08892 L
s
.39675 .18512 m
.39675 .32118 L
s
.49296 .08892 m
.49296 .22497 L
s
.10814 .60979 m
.20434 .51359 L
s
.10814 .60979 m
.10814 .74585 L
s
.20434 .51359 m
.30055 .41738 L
s
.20434 .51359 m
.20434 .64964 L
s
.30055 .41738 m
.39675 .32118 L
s
.30055 .41738 m
.30055 .55344 L
s
.39675 .32118 m
.49296 .22497 L
s
.39675 .32118 m
.39675 .45723 L
s
.49296 .22497 m
.58916 .12877 L
s
.49296 .22497 m
.49296 .36103 L
s
.58916 .12877 m
.58916 .26482 L
s
.10814 .74585 m
.20434 .64964 L
s
.20434 .64964 m
.30055 .55344 L
s
.20434 .64964 m
.20434 .7857 L
s
.30055 .55344 m
.39675 .45723 L
s
.30055 .55344 m
.30055 .68949 L
s
.39675 .45723 m
.49296 .36103 L
s
.39675 .45723 m
.39675 .59329 L
s
.49296 .36103 m
.58916 .26482 L
s
.49296 .36103 m
.49296 .49708 L
s
.58916 .26482 m
.68537 .16862 L
s
.58916 .26482 m
.58916 .40088 L
s
.68537 .16862 m
.68537 .30467 L
s
.20434 .7857 m
.30055 .68949 L
s
.30055 .68949 m
.39675 .59329 L
s
.30055 .68949 m
.30055 .82555 L
s
.39675 .59329 m
.49296 .49708 L
s
.39675 .59329 m
.39675 .72934 L
s
.49296 .49708 m
.58916 .40088 L
s
.49296 .49708 m
.49296 .63314 L
s
.58916 .40088 m
.68537 .30467 L
s
.58916 .40088 m
.58916 .53693 L
s
.68537 .30467 m
.78157 .20847 L
s
.68537 .30467 m
.68537 .44073 L
s
.78157 .20847 m
.78157 .34452 L
s
.30055 .82555 m
.39675 .72934 L
s
.39675 .72934 m
.49296 .63314 L
s
.39675 .72934 m
.39675 .8654 L
s
.49296 .63314 m
.58916 .53693 L
s
.49296 .63314 m
.49296 .76919 L
s
.58916 .53693 m
.68537 .44073 L
s
.58916 .53693 m
.58916 .67299 L
s
.68537 .44073 m
.78157 .34452 L
s
.68537 .44073 m
.68537 .57678 L
s
.78157 .34452 m
.87778 .24832 L
s
.78157 .34452 m
.78157 .48058 L
s
.87778 .24832 m
.87778 .38437 L
s
.39675 .8654 m
.49296 .76919 L
s
.49296 .76919 m
.58916 .67299 L
s
.49296 .76919 m
.49296 .90525 L
s
.58916 .67299 m
.68537 .57678 L
s
.58916 .67299 m
.58916 .80904 L
s
.68537 .57678 m
.78157 .48058 L
s
.68537 .57678 m
.68537 .71284 L
s
.78157 .48058 m
.87778 .38437 L
s
.78157 .48058 m
.78157 .61663 L
s
.87778 .38437 m
.87778 .52043 L
s
.49296 .90525 m
.58916 .80904 L
s
.58916 .80904 m
.68537 .71284 L
s
.58916 .80904 m
.58916 .94509 L
s
.68537 .71284 m
.78157 .61663 L
s
.68537 .71284 m
.68537 .84889 L
s
.78157 .61663 m
.87778 .52043 L
s
.78157 .61663 m
.78157 .75268 L
s
.87778 .52043 m
.97398 .42422 L
s
.87778 .52043 m
.87778 .65648 L
s
.97398 .42422 m
.97398 .56027 L
s
.58916 .94509 m
.68537 .84889 L
s
.68537 .84889 m
.78157 .75268 L
s
.78157 .75268 m
.87778 .65648 L
s
.78157 .75268 m
.78157 .88874 L
s
.87778 .65648 m
.97398 .56027 L
s
.87778 .65648 m
.87778 .79253 L
s
.78157 .88874 m
.87778 .79253 L
s
.43973 .02602 m
.57578 .02602 L
s
.43973 .02602 m
.34352 .12222 L
s
.57578 .02602 m
.47957 .12222 L
s
.20747 .12222 m
.34352 .12222 L
s
.20747 .12222 m
.11126 .21843 L
s
.34352 .12222 m
.47957 .12222 L
s
.34352 .12222 m
.24732 .21843 L
s
.47957 .12222 m
.61563 .12222 L
s
.47957 .12222 m
.38337 .21843 L
s
.61563 .12222 m
.75168 .12222 L
s
.61563 .12222 m
.51942 .21843 L
s
.75168 .12222 m
.65548 .21843 L
s
.11126 .21843 m
.24732 .21843 L
s
.24732 .21843 m
.38337 .21843 L
s
.24732 .21843 m
.15111 .31463 L
s
.38337 .21843 m
.51942 .21843 L
s
.38337 .21843 m
.28716 .31463 L
s
.51942 .21843 m
.65548 .21843 L
s
.51942 .21843 m
.42322 .31463 L
s
.65548 .21843 m
.79153 .21843 L
s
.65548 .21843 m
.55927 .31463 L
s
.79153 .21843 m
.69533 .31463 L
s
.15111 .31463 m
.28716 .31463 L
s
.15111 .31463 m
.05491 .41084 L
s
.28716 .31463 m
.42322 .31463 L
s
.28716 .31463 m
.19096 .41084 L
s
.42322 .31463 m
.55927 .31463 L
s
.42322 .31463 m
.32701 .41084 L
s
.55927 .31463 m
.69533 .31463 L
s
.55927 .31463 m
.46307 .41084 L
s
.69533 .31463 m
.83138 .31463 L
s
.69533 .31463 m
.59912 .41084 L
s
.83138 .31463 m
.73518 .41084 L
s
.05491 .41084 m
.19096 .41084 L
s
.19096 .41084 m
.32701 .41084 L
s
.19096 .41084 m
.09475 .50704 L
s
.32701 .41084 m
.46307 .41084 L
s
.32701 .41084 m
.23081 .50704 L
s
.46307 .41084 m
.59912 .41084 L
s
.46307 .41084 m
.36686 .50704 L
s
.59912 .41084 m
.73518 .41084 L
s
.59912 .41084 m
.50292 .50704 L
s
.73518 .41084 m
.87123 .41084 L
s
.73518 .41084 m
.63897 .50704 L
s
.87123 .41084 m
.77503 .50704 L
s
.09475 .50704 m
.23081 .50704 L
s
.23081 .50704 m
.36686 .50704 L
s
.23081 .50704 m
.1346 .60325 L
s
.36686 .50704 m
.50292 .50704 L
s
.36686 .50704 m
.27066 .60325 L
s
.50292 .50704 m
.63897 .50704 L
s
.50292 .50704 m
.40671 .60325 L
s
.63897 .50704 m
.77503 .50704 L
s
.63897 .50704 m
.54277 .60325 L
s
.77503 .50704 m
.91108 .50704 L
s
.77503 .50704 m
.67882 .60325 L
s
.91108 .50704 m
.81488 .60325 L
s
.1346 .60325 m
.27066 .60325 L
s
.27066 .60325 m
.40671 .60325 L
s
.27066 .60325 m
.17445 .69945 L
s
.40671 .60325 m
.54277 .60325 L
s
.40671 .60325 m
.31051 .69945 L
s
.54277 .60325 m
.67882 .60325 L
s
.54277 .60325 m
.44656 .69945 L
s
.67882 .60325 m
.81488 .60325 L
s
.67882 .60325 m
.58262 .69945 L
s
.81488 .60325 m
.95093 .60325 L
s
.81488 .60325 m
.71867 .69945 L
s
.95093 .60325 m
.85473 .69945 L
s
.17445 .69945 m
.31051 .69945 L
s
.31051 .69945 m
.44656 .69945 L
s
.31051 .69945 m
.2143 .79566 L
s
.44656 .69945 m
.58262 .69945 L
s
.44656 .69945 m
.35036 .79566 L
s
.58262 .69945 m
.71867 .69945 L
s
.58262 .69945 m
.48641 .79566 L
s
.71867 .69945 m
.85473 .69945 L
s
.71867 .69945 m
.62247 .79566 L
s
.85473 .69945 m
.75852 .79566 L
s
.2143 .79566 m
.35036 .79566 L
s
.35036 .79566 m
.48641 .79566 L
s
.35036 .79566 m
.25415 .89186 L
s
.48641 .79566 m
.62247 .79566 L
s
.48641 .79566 m
.39021 .89186 L
s
.62247 .79566 m
.75852 .79566 L
s
.62247 .79566 m
.52626 .89186 L
s
.75852 .79566 m
.66232 .89186 L
s
.25415 .89186 m
.39021 .89186 L
s
.39021 .89186 m
.52626 .89186 L
s
.52626 .89186 m
.66232 .89186 L
s
.30367 .07412 m
.43973 .07412 L
s
.30367 .07412 m
.20747 .17033 L
s
.43973 .07412 m
.57578 .07412 L
s
.43973 .07412 m
.34352 .17033 L
s
.57578 .07412 m
.71183 .07412 L
s
.57578 .07412 m
.47957 .17033 L
s
.71183 .07412 m
.61563 .17033 L
s
.20747 .17033 m
.34352 .17033 L
s
.20747 .17033 m
.11126 .26653 L
s
.34352 .17033 m
.47957 .17033 L
s
.34352 .17033 m
.24732 .26653 L
s
.47957 .17033 m
.61563 .17033 L
s
.47957 .17033 m
.38337 .26653 L
s
.61563 .17033 m
.75168 .17033 L
s
.61563 .17033 m
.51942 .26653 L
s
.75168 .17033 m
.65548 .26653 L
s
.11126 .26653 m
.24732 .26653 L
s
.24732 .26653 m
.38337 .26653 L
s
.24732 .26653 m
.15111 .36274 L
s
.38337 .26653 m
.51942 .26653 L
s
.38337 .26653 m
.28716 .36274 L
s
.51942 .26653 m
.65548 .26653 L
s
.51942 .26653 m
.42322 .36274 L
s
.65548 .26653 m
.79153 .26653 L
s
.65548 .26653 m
.55927 .36274 L
s
.79153 .26653 m
.69533 .36274 L
s
.15111 .36274 m
.28716 .36274 L
s
.15111 .36274 m
.05491 .45894 L
s
.28716 .36274 m
.42322 .36274 L
s
.28716 .36274 m
.19096 .45894 L
s
.42322 .36274 m
.55927 .36274 L
s
.42322 .36274 m
.32701 .45894 L
s
.55927 .36274 m
.69533 .36274 L
s
.55927 .36274 m
.46307 .45894 L
s
.69533 .36274 m
.83138 .36274 L
s
.69533 .36274 m
.59912 .45894 L
s
.83138 .36274 m
.73518 .45894 L
s
.05491 .45894 m
.19096 .45894 L
s
.19096 .45894 m
.32701 .45894 L
s
.19096 .45894 m
.09475 .55515 L
s
.32701 .45894 m
.46307 .45894 L
s
.32701 .45894 m
.23081 .55515 L
s
.46307 .45894 m
.59912 .45894 L
s
.46307 .45894 m
.36686 .55515 L
s
.59912 .45894 m
.73518 .45894 L
s
.59912 .45894 m
.50292 .55515 L
s
.73518 .45894 m
.87123 .45894 L
s
.73518 .45894 m
.63897 .55515 L
s
.87123 .45894 m
.77503 .55515 L
s
.09475 .55515 m
.23081 .55515 L
s
.23081 .55515 m
.36686 .55515 L
s
.23081 .55515 m
.1346 .65135 L
s
.36686 .55515 m
.50292 .55515 L
s
.36686 .55515 m
.27066 .65135 L
s
.50292 .55515 m
.63897 .55515 L
s
.50292 .55515 m
.40671 .65135 L
s
.63897 .55515 m
.77503 .55515 L
s
.63897 .55515 m
.54277 .65135 L
s
.77503 .55515 m
.91108 .55515 L
s
.77503 .55515 m
.67882 .65135 L
s
.91108 .55515 m
.81488 .65135 L
s
.1346 .65135 m
.27066 .65135 L
s
.27066 .65135 m
.40671 .65135 L
s
.27066 .65135 m
.17445 .74756 L
s
.40671 .65135 m
.54277 .65135 L
s
.40671 .65135 m
.31051 .74756 L
s
.54277 .65135 m
.67882 .65135 L
s
.54277 .65135 m
.44656 .74756 L
s
.67882 .65135 m
.81488 .65135 L
s
.67882 .65135 m
.58262 .74756 L
s
.81488 .65135 m
.95093 .65135 L
s
.81488 .65135 m
.71867 .74756 L
s
.95093 .65135 m
.85473 .74756 L
s
.17445 .74756 m
.31051 .74756 L
s
.31051 .74756 m
.44656 .74756 L
s
.31051 .74756 m
.2143 .84376 L
s
.44656 .74756 m
.58262 .74756 L
s
.44656 .74756 m
.35036 .84376 L
s
.58262 .74756 m
.71867 .74756 L
s
.58262 .74756 m
.48641 .84376 L
s
.71867 .74756 m
.85473 .74756 L
s
.71867 .74756 m
.62247 .84376 L
s
.85473 .74756 m
.75852 .84376 L
s
.2143 .84376 m
.35036 .84376 L
s
.35036 .84376 m
.48641 .84376 L
s
.48641 .84376 m
.62247 .84376 L
s
.48641 .84376 m
.39021 .93997 L
s
.62247 .84376 m
.75852 .84376 L
s
.62247 .84376 m
.52626 .93997 L
s
.75852 .84376 m
.66232 .93997 L
s
.39021 .93997 m
.52626 .93997 L
s
.52626 .93997 m
.66232 .93997 L
s
.33768 .06003 m
.47374 .06003 L
s
.33768 .06003 m
.24148 .15624 L
s
.47374 .06003 m
.60979 .06003 L
s
.47374 .06003 m
.37753 .15624 L
s
.60979 .06003 m
.51359 .15624 L
s
.24148 .15624 m
.37753 .15624 L
s
.24148 .15624 m
.14527 .25244 L
s
.37753 .15624 m
.51359 .15624 L
s
.37753 .15624 m
.28133 .25244 L
s
.51359 .15624 m
.64964 .15624 L
s
.51359 .15624 m
.41738 .25244 L
s
.64964 .15624 m
.7857 .15624 L
s
.64964 .15624 m
.55344 .25244 L
s
.7857 .15624 m
.68949 .25244 L
s
.14527 .25244 m
.28133 .25244 L
s
.14527 .25244 m
.04907 .34865 L
s
.28133 .25244 m
.41738 .25244 L
s
.28133 .25244 m
.18512 .34865 L
s
.41738 .25244 m
.55344 .25244 L
s
.41738 .25244 m
.32118 .34865 L
s
.55344 .25244 m
.68949 .25244 L
s
.55344 .25244 m
.45723 .34865 L
s
.68949 .25244 m
.82555 .25244 L
s
.68949 .25244 m
.59329 .34865 L
s
.82555 .25244 m
.72934 .34865 L
s
.04907 .34865 m
.18512 .34865 L
s
.18512 .34865 m
.32118 .34865 L
s
.18512 .34865 m
.08892 .44485 L
s
.32118 .34865 m
.45723 .34865 L
s
.32118 .34865 m
.22497 .44485 L
s
.45723 .34865 m
.59329 .34865 L
s
.45723 .34865 m
.36103 .44485 L
s
.59329 .34865 m
.72934 .34865 L
s
.59329 .34865 m
.49708 .44485 L
s
.72934 .34865 m
.8654 .34865 L
s
.72934 .34865 m
.63314 .44485 L
s
.8654 .34865 m
.76919 .44485 L
s
.08892 .44485 m
.22497 .44485 L
s
.22497 .44485 m
.36103 .44485 L
s
.22497 .44485 m
.12877 .54106 L
s
.36103 .44485 m
.49708 .44485 L
s
.36103 .44485 m
.26482 .54106 L
s
.49708 .44485 m
.63314 .44485 L
s
.49708 .44485 m
.40088 .54106 L
s
.63314 .44485 m
.76919 .44485 L
s
.63314 .44485 m
.53693 .54106 L
s
.76919 .44485 m
.90525 .44485 L
s
.76919 .44485 m
.67299 .54106 L
s
.90525 .44485 m
.80904 .54106 L
s
.12877 .54106 m
.26482 .54106 L
s
.26482 .54106 m
.40088 .54106 L
s
.26482 .54106 m
.16862 .63726 L
s
.40088 .54106 m
.53693 .54106 L
s
.40088 .54106 m
.30467 .63726 L
s
.53693 .54106 m
.67299 .54106 L
s
.53693 .54106 m
.44073 .63726 L
s
.67299 .54106 m
.80904 .54106 L
s
.67299 .54106 m
.57678 .63726 L
s
.80904 .54106 m
.94509 .54106 L
s
.80904 .54106 m
.71284 .63726 L
s
.94509 .54106 m
.84889 .63726 L
s
.16862 .63726 m
.30467 .63726 L
s
.30467 .63726 m
.44073 .63726 L
s
.30467 .63726 m
.20847 .73347 L
s
.44073 .63726 m
.57678 .63726 L
s
.44073 .63726 m
.34452 .73347 L
s
.57678 .63726 m
.71284 .63726 L
s
.57678 .63726 m
.48058 .73347 L
s
.71284 .63726 m
.84889 .63726 L
s
.71284 .63726 m
.61663 .73347 L
s
.84889 .63726 m
.75268 .73347 L
s
.20847 .73347 m
.34452 .73347 L
s
.34452 .73347 m
.48058 .73347 L
s
.34452 .73347 m
.24832 .82967 L
s
.48058 .73347 m
.61663 .73347 L
s
.48058 .73347 m
.38437 .82967 L
s
.61663 .73347 m
.75268 .73347 L
s
.61663 .73347 m
.52043 .82967 L
s
.75268 .73347 m
.88874 .73347 L
s
.75268 .73347 m
.65648 .82967 L
s
.88874 .73347 m
.79253 .82967 L
s
.24832 .82967 m
.38437 .82967 L
s
.38437 .82967 m
.52043 .82967 L
s
.38437 .82967 m
.28817 .92588 L
s
.52043 .82967 m
.65648 .82967 L
s
.52043 .82967 m
.42422 .92588 L
s
.65648 .82967 m
.79253 .82967 L
s
.65648 .82967 m
.56027 .92588 L
s
.79253 .82967 m
.69633 .92588 L
s
.28817 .92588 m
.42422 .92588 L
s
.42422 .92588 m
.56027 .92588 L
s
.56027 .92588 m
.69633 .92588 L
s
.33768 .10814 m
.47374 .10814 L
s
.33768 .10814 m
.24148 .20434 L
s
.47374 .10814 m
.60979 .10814 L
s
.47374 .10814 m
.37753 .20434 L
s
.60979 .10814 m
.74585 .10814 L
s
.60979 .10814 m
.51359 .20434 L
s
.74585 .10814 m
.64964 .20434 L
s
.24148 .20434 m
.37753 .20434 L
s
.24148 .20434 m
.14527 .30055 L
s
.37753 .20434 m
.51359 .20434 L
s
.37753 .20434 m
.28133 .30055 L
s
.51359 .20434 m
.64964 .20434 L
s
.51359 .20434 m
.41738 .30055 L
s
.64964 .20434 m
.7857 .20434 L
s
.64964 .20434 m
.55344 .30055 L
s
.7857 .20434 m
.68949 .30055 L
s
.14527 .30055 m
.28133 .30055 L
s
.14527 .30055 m
.04907 .39675 L
s
.28133 .30055 m
.41738 .30055 L
s
.28133 .30055 m
.18512 .39675 L
s
.41738 .30055 m
.55344 .30055 L
s
.41738 .30055 m
.32118 .39675 L
s
.55344 .30055 m
.68949 .30055 L
s
.55344 .30055 m
.45723 .39675 L
s
.68949 .30055 m
.82555 .30055 L
s
.68949 .30055 m
.59329 .39675 L
s
.82555 .30055 m
.72934 .39675 L
s
.04907 .39675 m
.18512 .39675 L
s
.18512 .39675 m
.32118 .39675 L
s
.18512 .39675 m
.08892 .49296 L
s
.32118 .39675 m
.45723 .39675 L
s
.32118 .39675 m
.22497 .49296 L
s
.45723 .39675 m
.59329 .39675 L
s
.45723 .39675 m
.36103 .49296 L
s
.59329 .39675 m
.72934 .39675 L
s
.59329 .39675 m
.49708 .49296 L
s
.72934 .39675 m
.8654 .39675 L
s
.72934 .39675 m
.63314 .49296 L
s
.8654 .39675 m
.76919 .49296 L
s
.08892 .49296 m
.22497 .49296 L
s
.22497 .49296 m
.36103 .49296 L
s
.22497 .49296 m
.12877 .58916 L
s
.36103 .49296 m
.49708 .49296 L
s
.36103 .49296 m
.26482 .58916 L
s
.49708 .49296 m
.63314 .49296 L
s
.49708 .49296 m
.40088 .58916 L
s
.63314 .49296 m
.76919 .49296 L
s
.63314 .49296 m
.53693 .58916 L
s
.76919 .49296 m
.90525 .49296 L
s
.76919 .49296 m
.67299 .58916 L
s
.90525 .49296 m
.80904 .58916 L
s
.12877 .58916 m
.26482 .58916 L
s
.26482 .58916 m
.40088 .58916 L
s
.26482 .58916 m
.16862 .68537 L
s
.40088 .58916 m
.53693 .58916 L
s
.40088 .58916 m
.30467 .68537 L
s
.53693 .58916 m
.67299 .58916 L
s
.53693 .58916 m
.44073 .68537 L
s
.67299 .58916 m
.80904 .58916 L
s
.67299 .58916 m
.57678 .68537 L
s
.80904 .58916 m
.94509 .58916 L
s
.80904 .58916 m
.71284 .68537 L
s
.94509 .58916 m
.84889 .68537 L
s
.16862 .68537 m
.30467 .68537 L
s
.30467 .68537 m
.44073 .68537 L
s
.30467 .68537 m
.20847 .78157 L
s
.44073 .68537 m
.57678 .68537 L
s
.44073 .68537 m
.34452 .78157 L
s
.57678 .68537 m
.71284 .68537 L
s
.57678 .68537 m
.48058 .78157 L
s
.71284 .68537 m
.84889 .68537 L
s
.71284 .68537 m
.61663 .78157 L
s
.84889 .68537 m
.75268 .78157 L
s
.20847 .78157 m
.34452 .78157 L
s
.34452 .78157 m
.48058 .78157 L
s
.34452 .78157 m
.24832 .87778 L
s
.48058 .78157 m
.61663 .78157 L
s
.48058 .78157 m
.38437 .87778 L
s
.61663 .78157 m
.75268 .78157 L
s
.61663 .78157 m
.52043 .87778 L
s
.75268 .78157 m
.88874 .78157 L
s
.75268 .78157 m
.65648 .87778 L
s
.88874 .78157 m
.79253 .87778 L
s
.24832 .87778 m
.38437 .87778 L
s
.38437 .87778 m
.52043 .87778 L
s
.52043 .87778 m
.65648 .87778 L
s
.52043 .87778 m
.42422 .97398 L
s
.65648 .87778 m
.79253 .87778 L
s
.65648 .87778 m
.56027 .97398 L
s
.42422 .97398 m
.56027 .97398 L
s
.79253 .12222 m
.88874 .21843 L
s
.79253 .12222 m
.65648 .12222 L
s
.88874 .21843 m
.75268 .21843 L
s
.56027 .02602 m
.65648 .12222 L
s
.56027 .02602 m
.42422 .02602 L
s
.65648 .12222 m
.75268 .21843 L
s
.65648 .12222 m
.52043 .12222 L
s
.75268 .21843 m
.84889 .31463 L
s
.75268 .21843 m
.61663 .21843 L
s
.84889 .31463 m
.94509 .41084 L
s
.84889 .31463 m
.71284 .31463 L
s
.94509 .41084 m
.80904 .41084 L
s
.42422 .02602 m
.52043 .12222 L
s
.52043 .12222 m
.61663 .21843 L
s
.52043 .12222 m
.38437 .12222 L
s
.61663 .21843 m
.71284 .31463 L
s
.61663 .21843 m
.48058 .21843 L
s
.71284 .31463 m
.80904 .41084 L
s
.71284 .31463 m
.57678 .31463 L
s
.80904 .41084 m
.90525 .50704 L
s
.80904 .41084 m
.67299 .41084 L
s
.90525 .50704 m
.76919 .50704 L
s
.38437 .12222 m
.48058 .21843 L
s
.38437 .12222 m
.24832 .12222 L
s
.48058 .21843 m
.57678 .31463 L
s
.48058 .21843 m
.34452 .21843 L
s
.57678 .31463 m
.67299 .41084 L
s
.57678 .31463 m
.44073 .31463 L
s
.67299 .41084 m
.76919 .50704 L
s
.67299 .41084 m
.53693 .41084 L
s
.76919 .50704 m
.8654 .60325 L
s
.76919 .50704 m
.63314 .50704 L
s
.8654 .60325 m
.72934 .60325 L
s
.24832 .12222 m
.34452 .21843 L
s
.34452 .21843 m
.44073 .31463 L
s
.34452 .21843 m
.20847 .21843 L
s
.44073 .31463 m
.53693 .41084 L
s
.44073 .31463 m
.30467 .31463 L
s
.53693 .41084 m
.63314 .50704 L
s
.53693 .41084 m
.40088 .41084 L
s
.63314 .50704 m
.72934 .60325 L
s
.63314 .50704 m
.49708 .50704 L
s
.72934 .60325 m
.82555 .69945 L
s
.72934 .60325 m
.59329 .60325 L
s
.82555 .69945 m
.68949 .69945 L
s
.20847 .21843 m
.30467 .31463 L
s
.30467 .31463 m
.40088 .41084 L
s
.30467 .31463 m
.16862 .31463 L
s
.40088 .41084 m
.49708 .50704 L
s
.40088 .41084 m
.26482 .41084 L
s
.49708 .50704 m
.59329 .60325 L
s
.49708 .50704 m
.36103 .50704 L
s
.59329 .60325 m
.68949 .69945 L
s
.59329 .60325 m
.45723 .60325 L
s
.68949 .69945 m
.7857 .79566 L
s
.68949 .69945 m
.55344 .69945 L
s
.7857 .79566 m
.64964 .79566 L
s
.16862 .31463 m
.26482 .41084 L
s
.26482 .41084 m
.36103 .50704 L
s
.26482 .41084 m
.12877 .41084 L
s
.36103 .50704 m
.45723 .60325 L
s
.36103 .50704 m
.22497 .50704 L
s
.45723 .60325 m
.55344 .69945 L
s
.45723 .60325 m
.32118 .60325 L
s
.55344 .69945 m
.64964 .79566 L
s
.55344 .69945 m
.41738 .69945 L
s
.64964 .79566 m
.74585 .89186 L
s
.64964 .79566 m
.51359 .79566 L
s
.74585 .89186 m
.60979 .89186 L
s
.12877 .41084 m
.22497 .50704 L
s
.22497 .50704 m
.32118 .60325 L
s
.22497 .50704 m
.08892 .50704 L
s
.32118 .60325 m
.41738 .69945 L
s
.32118 .60325 m
.18512 .60325 L
s
.41738 .69945 m
.51359 .79566 L
s
.41738 .69945 m
.28133 .69945 L
s
.51359 .79566 m
.60979 .89186 L
s
.51359 .79566 m
.37753 .79566 L
s
.60979 .89186 m
.47374 .89186 L
s
.08892 .50704 m
.18512 .60325 L
s
.18512 .60325 m
.28133 .69945 L
s
.18512 .60325 m
.04907 .60325 L
s
.28133 .69945 m
.37753 .79566 L
s
.28133 .69945 m
.14527 .69945 L
s
.37753 .79566 m
.47374 .89186 L
s
.37753 .79566 m
.24148 .79566 L
s
.47374 .89186 m
.33768 .89186 L
s
.04907 .60325 m
.14527 .69945 L
s
.14527 .69945 m
.24148 .79566 L
s
.24148 .79566 m
.33768 .89186 L
s
.66232 .06003 m
.75852 .15624 L
s
.66232 .06003 m
.52626 .06003 L
s
.75852 .15624 m
.85473 .25244 L
s
.75852 .15624 m
.62247 .15624 L
s
.85473 .25244 m
.95093 .34865 L
s
.85473 .25244 m
.71867 .25244 L
s
.95093 .34865 m
.81488 .34865 L
s
.52626 .06003 m
.62247 .15624 L
s
.52626 .06003 m
.39021 .06003 L
s
.62247 .15624 m
.71867 .25244 L
s
.62247 .15624 m
.48641 .15624 L
s
.71867 .25244 m
.81488 .34865 L
s
.71867 .25244 m
.58262 .25244 L
s
.81488 .34865 m
.91108 .44485 L
s
.81488 .34865 m
.67882 .34865 L
s
.91108 .44485 m
.77503 .44485 L
s
.39021 .06003 m
.48641 .15624 L
s
.48641 .15624 m
.58262 .25244 L
s
.48641 .15624 m
.35036 .15624 L
s
.58262 .25244 m
.67882 .34865 L
s
.58262 .25244 m
.44656 .25244 L
s
.67882 .34865 m
.77503 .44485 L
s
.67882 .34865 m
.54277 .34865 L
s
.77503 .44485 m
.87123 .54106 L
s
.77503 .44485 m
.63897 .44485 L
s
.87123 .54106 m
.73518 .54106 L
s
.35036 .15624 m
.44656 .25244 L
s
.35036 .15624 m
.2143 .15624 L
s
.44656 .25244 m
.54277 .34865 L
s
.44656 .25244 m
.31051 .25244 L
s
.54277 .34865 m
.63897 .44485 L
s
.54277 .34865 m
.40671 .34865 L
s
.63897 .44485 m
.73518 .54106 L
s
.63897 .44485 m
.50292 .44485 L
s
.73518 .54106 m
.83138 .63726 L
s
.73518 .54106 m
.59912 .54106 L
s
.83138 .63726 m
.69533 .63726 L
s
.2143 .15624 m
.31051 .25244 L
s
.31051 .25244 m
.40671 .34865 L
s
.31051 .25244 m
.17445 .25244 L
s
.40671 .34865 m
.50292 .44485 L
s
.40671 .34865 m
.27066 .34865 L
s
.50292 .44485 m
.59912 .54106 L
s
.50292 .44485 m
.36686 .44485 L
s
.59912 .54106 m
.69533 .63726 L
s
.59912 .54106 m
.46307 .54106 L
s
.69533 .63726 m
.79153 .73347 L
s
.69533 .63726 m
.55927 .63726 L
s
.79153 .73347 m
.65548 .73347 L
s
.17445 .25244 m
.27066 .34865 L
s
.27066 .34865 m
.36686 .44485 L
s
.27066 .34865 m
.1346 .34865 L
s
.36686 .44485 m
.46307 .54106 L
s
.36686 .44485 m
.23081 .44485 L
s
.46307 .54106 m
.55927 .63726 L
s
.46307 .54106 m
.32701 .54106 L
s
.55927 .63726 m
.65548 .73347 L
s
.55927 .63726 m
.42322 .63726 L
s
.65548 .73347 m
.75168 .82967 L
s
.65548 .73347 m
.51942 .73347 L
s
.75168 .82967 m
.61563 .82967 L
s
.1346 .34865 m
.23081 .44485 L
s
.23081 .44485 m
.32701 .54106 L
s
.23081 .44485 m
.09475 .44485 L
s
.32701 .54106 m
.42322 .63726 L
s
.32701 .54106 m
.19096 .54106 L
s
.42322 .63726 m
.51942 .73347 L
s
.42322 .63726 m
.28716 .63726 L
s
.51942 .73347 m
.61563 .82967 L
s
.51942 .73347 m
.38337 .73347 L
s
.61563 .82967 m
.71183 .92588 L
s
.61563 .82967 m
.47957 .82967 L
s
.71183 .92588 m
.57578 .92588 L
s
.09475 .44485 m
.19096 .54106 L
s
.19096 .54106 m
.28716 .63726 L
s
.19096 .54106 m
.05491 .54106 L
s
.28716 .63726 m
.38337 .73347 L
s
.28716 .63726 m
.15111 .63726 L
s
.38337 .73347 m
.47957 .82967 L
s
.38337 .73347 m
.24732 .73347 L
s
.47957 .82967 m
.57578 .92588 L
s
.47957 .82967 m
.34352 .82967 L
s
.57578 .92588 m
.43973 .92588 L
s
.05491 .54106 m
.15111 .63726 L
s
.15111 .63726 m
.24732 .73347 L
s
.24732 .73347 m
.34352 .82967 L
s
.24732 .73347 m
.11126 .73347 L
s
.34352 .82967 m
.43973 .92588 L
s
.34352 .82967 m
.20747 .82967 L
s
.43973 .92588 m
.30367 .92588 L
s
.11126 .73347 m
.20747 .82967 L
s
.20747 .82967 m
.30367 .92588 L
s
.69633 .07412 m
.79253 .17033 L
s
.69633 .07412 m
.56027 .07412 L
s
.79253 .17033 m
.88874 .26653 L
s
.79253 .17033 m
.65648 .17033 L
s
.88874 .26653 m
.75268 .26653 L
s
.56027 .07412 m
.65648 .17033 L
s
.56027 .07412 m
.42422 .07412 L
s
.65648 .17033 m
.75268 .26653 L
s
.65648 .17033 m
.52043 .17033 L
s
.75268 .26653 m
.84889 .36274 L
s
.75268 .26653 m
.61663 .26653 L
s
.84889 .36274 m
.94509 .45894 L
s
.84889 .36274 m
.71284 .36274 L
s
.94509 .45894 m
.80904 .45894 L
s
.42422 .07412 m
.52043 .17033 L
s
.42422 .07412 m
.28817 .07412 L
s
.52043 .17033 m
.61663 .26653 L
s
.52043 .17033 m
.38437 .17033 L
s
.61663 .26653 m
.71284 .36274 L
s
.61663 .26653 m
.48058 .26653 L
s
.71284 .36274 m
.80904 .45894 L
s
.71284 .36274 m
.57678 .36274 L
s
.80904 .45894 m
.90525 .55515 L
s
.80904 .45894 m
.67299 .45894 L
s
.90525 .55515 m
.76919 .55515 L
s
.28817 .07412 m
.38437 .17033 L
s
.38437 .17033 m
.48058 .26653 L
s
.38437 .17033 m
.24832 .17033 L
s
.48058 .26653 m
.57678 .36274 L
s
.48058 .26653 m
.34452 .26653 L
s
.57678 .36274 m
.67299 .45894 L
s
.57678 .36274 m
.44073 .36274 L
s
.67299 .45894 m
.76919 .55515 L
s
.67299 .45894 m
.53693 .45894 L
s
.76919 .55515 m
.8654 .65135 L
s
.76919 .55515 m
.63314 .55515 L
s
.8654 .65135 m
.72934 .65135 L
s
.24832 .17033 m
.34452 .26653 L
s
.34452 .26653 m
.44073 .36274 L
s
.34452 .26653 m
.20847 .26653 L
s
.44073 .36274 m
.53693 .45894 L
s
.44073 .36274 m
.30467 .36274 L
s
.53693 .45894 m
.63314 .55515 L
s
.53693 .45894 m
.40088 .45894 L
s
.63314 .55515 m
.72934 .65135 L
s
.63314 .55515 m
.49708 .55515 L
s
.72934 .65135 m
.82555 .74756 L
s
.72934 .65135 m
.59329 .65135 L
s
.82555 .74756 m
.68949 .74756 L
s
.20847 .26653 m
.30467 .36274 L
s
.30467 .36274 m
.40088 .45894 L
s
.30467 .36274 m
.16862 .36274 L
s
.40088 .45894 m
.49708 .55515 L
s
.40088 .45894 m
.26482 .45894 L
s
.49708 .55515 m
.59329 .65135 L
s
.49708 .55515 m
.36103 .55515 L
s
.59329 .65135 m
.68949 .74756 L
s
.59329 .65135 m
.45723 .65135 L
s
.68949 .74756 m
.7857 .84376 L
s
.68949 .74756 m
.55344 .74756 L
s
.7857 .84376 m
.64964 .84376 L
s
.16862 .36274 m
.26482 .45894 L
s
.26482 .45894 m
.36103 .55515 L
s
.26482 .45894 m
.12877 .45894 L
s
.36103 .55515 m
.45723 .65135 L
s
.36103 .55515 m
.22497 .55515 L
s
.45723 .65135 m
.55344 .74756 L
s
.45723 .65135 m
.32118 .65135 L
s
.55344 .74756 m
.64964 .84376 L
s
.55344 .74756 m
.41738 .74756 L
s
.64964 .84376 m
.51359 .84376 L
s
.12877 .45894 m
.22497 .55515 L
s
.22497 .55515 m
.32118 .65135 L
s
.22497 .55515 m
.08892 .55515 L
s
.32118 .65135 m
.41738 .74756 L
s
.32118 .65135 m
.18512 .65135 L
s
.41738 .74756 m
.51359 .84376 L
s
.41738 .74756 m
.28133 .74756 L
s
.51359 .84376 m
.60979 .93997 L
s
.51359 .84376 m
.37753 .84376 L
s
.60979 .93997 m
.47374 .93997 L
s
.08892 .55515 m
.18512 .65135 L
s
.18512 .65135 m
.28133 .74756 L
s
.18512 .65135 m
.04907 .65135 L
s
.28133 .74756 m
.37753 .84376 L
s
.28133 .74756 m
.14527 .74756 L
s
.37753 .84376 m
.47374 .93997 L
s
.37753 .84376 m
.24148 .84376 L
s
.47374 .93997 m
.33768 .93997 L
s
.04907 .65135 m
.14527 .74756 L
s
.14527 .74756 m
.24148 .84376 L
s
.24148 .84376 m
.33768 .93997 L
s
.66232 .10814 m
.75852 .20434 L
s
.66232 .10814 m
.52626 .10814 L
s
.75852 .20434 m
.85473 .30055 L
s
.75852 .20434 m
.62247 .20434 L
s
.85473 .30055 m
.95093 .39675 L
s
.85473 .30055 m
.71867 .30055 L
s
.95093 .39675 m
.81488 .39675 L
s
.52626 .10814 m
.62247 .20434 L
s
.52626 .10814 m
.39021 .10814 L
s
.62247 .20434 m
.71867 .30055 L
s
.62247 .20434 m
.48641 .20434 L
s
.71867 .30055 m
.81488 .39675 L
s
.71867 .30055 m
.58262 .30055 L
s
.81488 .39675 m
.91108 .49296 L
s
.81488 .39675 m
.67882 .39675 L
s
.91108 .49296 m
.77503 .49296 L
s
.39021 .10814 m
.48641 .20434 L
s
.39021 .10814 m
.25415 .10814 L
s
.48641 .20434 m
.58262 .30055 L
s
.48641 .20434 m
.35036 .20434 L
s
.58262 .30055 m
.67882 .39675 L
s
.58262 .30055 m
.44656 .30055 L
s
.67882 .39675 m
.77503 .49296 L
s
.67882 .39675 m
.54277 .39675 L
s
.77503 .49296 m
.87123 .58916 L
s
.77503 .49296 m
.63897 .49296 L
s
.87123 .58916 m
.73518 .58916 L
s
.25415 .10814 m
.35036 .20434 L
s
.35036 .20434 m
.44656 .30055 L
s
.35036 .20434 m
.2143 .20434 L
s
.44656 .30055 m
.54277 .39675 L
s
.44656 .30055 m
.31051 .30055 L
s
.54277 .39675 m
.63897 .49296 L
s
.54277 .39675 m
.40671 .39675 L
s
.63897 .49296 m
.73518 .58916 L
s
.63897 .49296 m
.50292 .49296 L
s
.73518 .58916 m
.83138 .68537 L
s
.73518 .58916 m
.59912 .58916 L
s
.83138 .68537 m
.69533 .68537 L
s
.2143 .20434 m
.31051 .30055 L
s
.31051 .30055 m
.40671 .39675 L
s
.31051 .30055 m
.17445 .30055 L
s
.40671 .39675 m
.50292 .49296 L
s
.40671 .39675 m
.27066 .39675 L
s
.50292 .49296 m
.59912 .58916 L
s
.50292 .49296 m
.36686 .49296 L
s
.59912 .58916 m
.69533 .68537 L
s
.59912 .58916 m
.46307 .58916 L
s
.69533 .68537 m
.79153 .78157 L
s
.69533 .68537 m
.55927 .68537 L
s
.79153 .78157 m
.65548 .78157 L
s
.17445 .30055 m
.27066 .39675 L
s
.27066 .39675 m
.36686 .49296 L
s
.27066 .39675 m
.1346 .39675 L
s
.36686 .49296 m
.46307 .58916 L
s
.36686 .49296 m
.23081 .49296 L
s
.46307 .58916 m
.55927 .68537 L
s
.46307 .58916 m
.32701 .58916 L
s
.55927 .68537 m
.65548 .78157 L
s
.55927 .68537 m
.42322 .68537 L
s
.65548 .78157 m
.75168 .87778 L
s
.65548 .78157 m
.51942 .78157 L
s
.75168 .87778 m
.61563 .87778 L
s
.1346 .39675 m
.23081 .49296 L
s
.23081 .49296 m
.32701 .58916 L
s
.23081 .49296 m
.09475 .49296 L
s
.32701 .58916 m
.42322 .68537 L
s
.32701 .58916 m
.19096 .58916 L
s
.42322 .68537 m
.51942 .78157 L
s
.42322 .68537 m
.28716 .68537 L
s
.51942 .78157 m
.61563 .87778 L
s
.51942 .78157 m
.38337 .78157 L
s
.61563 .87778 m
.47957 .87778 L
s
.09475 .49296 m
.19096 .58916 L
s
.19096 .58916 m
.28716 .68537 L
s
.19096 .58916 m
.05491 .58916 L
s
.28716 .68537 m
.38337 .78157 L
s
.28716 .68537 m
.15111 .68537 L
s
.38337 .78157 m
.47957 .87778 L
s
.38337 .78157 m
.24732 .78157 L
s
.47957 .87778 m
.57578 .97398 L
s
.47957 .87778 m
.34352 .87778 L
s
.57578 .97398 m
.43973 .97398 L
s
.05491 .58916 m
.15111 .68537 L
s
.15111 .68537 m
.24732 .78157 L
s
.24732 .78157 m
.34352 .87778 L
s
.24732 .78157 m
.11126 .78157 L
s
.34352 .87778 m
.43973 .97398 L
s
.34352 .87778 m
.20747 .87778 L
s
.11126 .78157 m
.20747 .87778 L
s
.73347 .11126 m
.82967 .20747 L
s
.73347 .11126 m
.73347 .24732 L
s
.82967 .20747 m
.92588 .30367 L
s
.82967 .20747 m
.82967 .34352 L
s
.92588 .30367 m
.92588 .43973 L
s
.54106 .05491 m
.63726 .15111 L
s
.54106 .05491 m
.54106 .19096 L
s
.63726 .15111 m
.73347 .24732 L
s
.63726 .15111 m
.63726 .28716 L
s
.73347 .24732 m
.82967 .34352 L
s
.73347 .24732 m
.73347 .38337 L
s
.82967 .34352 m
.92588 .43973 L
s
.82967 .34352 m
.82967 .47957 L
s
.92588 .43973 m
.92588 .57578 L
s
.44485 .09475 m
.54106 .19096 L
s
.44485 .09475 m
.44485 .23081 L
s
.54106 .19096 m
.63726 .28716 L
s
.54106 .19096 m
.54106 .32701 L
s
.63726 .28716 m
.73347 .38337 L
s
.63726 .28716 m
.63726 .42322 L
s
.73347 .38337 m
.82967 .47957 L
s
.73347 .38337 m
.73347 .51942 L
s
.82967 .47957 m
.92588 .57578 L
s
.82967 .47957 m
.82967 .61563 L
s
.92588 .57578 m
.92588 .71183 L
s
.34865 .1346 m
.44485 .23081 L
s
.34865 .1346 m
.34865 .27066 L
s
.44485 .23081 m
.54106 .32701 L
s
.44485 .23081 m
.44485 .36686 L
s
.54106 .32701 m
.63726 .42322 L
s
.54106 .32701 m
.54106 .46307 L
s
.63726 .42322 m
.73347 .51942 L
s
.63726 .42322 m
.63726 .55927 L
s
.73347 .51942 m
.82967 .61563 L
s
.73347 .51942 m
.73347 .65548 L
s
.82967 .61563 m
.92588 .71183 L
s
.82967 .61563 m
.82967 .75168 L
s
.25244 .17445 m
.34865 .27066 L
s
.25244 .17445 m
.25244 .31051 L
s
.34865 .27066 m
.44485 .36686 L
s
.34865 .27066 m
.34865 .40671 L
s
.44485 .36686 m
.54106 .46307 L
s
.44485 .36686 m
.44485 .50292 L
s
.54106 .46307 m
.63726 .55927 L
s
.54106 .46307 m
.54106 .59912 L
s
.63726 .55927 m
.73347 .65548 L
s
.63726 .55927 m
.63726 .69533 L
s
.73347 .65548 m
.82967 .75168 L
s
.73347 .65548 m
.73347 .79153 L
s
.15624 .2143 m
.25244 .31051 L
s
.15624 .2143 m
.15624 .35036 L
s
.25244 .31051 m
.34865 .40671 L
s
.25244 .31051 m
.25244 .44656 L
s
.34865 .40671 m
.44485 .50292 L
s
.34865 .40671 m
.34865 .54277 L
s
.44485 .50292 m
.54106 .59912 L
s
.44485 .50292 m
.44485 .63897 L
s
.54106 .59912 m
.63726 .69533 L
s
.54106 .59912 m
.54106 .73518 L
s
.63726 .69533 m
.73347 .79153 L
s
.63726 .69533 m
.63726 .83138 L
s
.15624 .35036 m
.25244 .44656 L
s
.15624 .35036 m
.15624 .48641 L
s
.25244 .44656 m
.34865 .54277 L
s
.25244 .44656 m
.25244 .58262 L
s
.34865 .54277 m
.44485 .63897 L
s
.34865 .54277 m
.34865 .67882 L
s
.44485 .63897 m
.54106 .73518 L
s
.44485 .63897 m
.44485 .77503 L
s
.54106 .73518 m
.63726 .83138 L
s
.54106 .73518 m
.54106 .87123 L
s
.06003 .39021 m
.15624 .48641 L
s
.06003 .39021 m
.06003 .52626 L
s
.15624 .48641 m
.25244 .58262 L
s
.15624 .48641 m
.15624 .62247 L
s
.25244 .58262 m
.34865 .67882 L
s
.25244 .58262 m
.25244 .71867 L
s
.34865 .67882 m
.44485 .77503 L
s
.34865 .67882 m
.34865 .81488 L
s
.44485 .77503 m
.54106 .87123 L
s
.44485 .77503 m
.44485 .91108 L
s
.06003 .52626 m
.15624 .62247 L
s
.06003 .52626 m
.06003 .66232 L
s
.15624 .62247 m
.25244 .71867 L
s
.15624 .62247 m
.15624 .75852 L
s
.25244 .71867 m
.34865 .81488 L
s
.25244 .71867 m
.25244 .85473 L
s
.34865 .81488 m
.44485 .91108 L
s
.34865 .81488 m
.34865 .95093 L
s
.06003 .66232 m
.15624 .75852 L
s
.15624 .75852 m
.25244 .85473 L
s
.25244 .85473 m
.34865 .95093 L
s
.60325 .04907 m
.69945 .14527 L
s
.60325 .04907 m
.60325 .18512 L
s
.69945 .14527 m
.79566 .24148 L
s
.69945 .14527 m
.69945 .28133 L
s
.79566 .24148 m
.89186 .33768 L
s
.79566 .24148 m
.79566 .37753 L
s
.89186 .33768 m
.89186 .47374 L
s
.50704 .08892 m
.60325 .18512 L
s
.50704 .08892 m
.50704 .22497 L
s
.60325 .18512 m
.69945 .28133 L
s
.60325 .18512 m
.60325 .32118 L
s
.69945 .28133 m
.79566 .37753 L
s
.69945 .28133 m
.69945 .41738 L
s
.79566 .37753 m
.89186 .47374 L
s
.79566 .37753 m
.79566 .51359 L
s
.89186 .47374 m
.89186 .60979 L
s
.41084 .12877 m
.50704 .22497 L
s
.41084 .12877 m
.41084 .26482 L
s
.50704 .22497 m
.60325 .32118 L
s
.50704 .22497 m
.50704 .36103 L
s
.60325 .32118 m
.69945 .41738 L
s
.60325 .32118 m
.60325 .45723 L
s
.69945 .41738 m
.79566 .51359 L
s
.69945 .41738 m
.69945 .55344 L
s
.79566 .51359 m
.89186 .60979 L
s
.79566 .51359 m
.79566 .64964 L
s
.89186 .60979 m
.89186 .74585 L
s
.31463 .16862 m
.41084 .26482 L
s
.31463 .16862 m
.31463 .30467 L
s
.41084 .26482 m
.50704 .36103 L
s
.41084 .26482 m
.41084 .40088 L
s
.50704 .36103 m
.60325 .45723 L
s
.50704 .36103 m
.50704 .49708 L
s
.60325 .45723 m
.69945 .55344 L
s
.60325 .45723 m
.60325 .59329 L
s
.69945 .55344 m
.79566 .64964 L
s
.69945 .55344 m
.69945 .68949 L
s
.79566 .64964 m
.89186 .74585 L
s
.79566 .64964 m
.79566 .7857 L
s
.21843 .20847 m
.31463 .30467 L
s
.21843 .20847 m
.21843 .34452 L
s
.31463 .30467 m
.41084 .40088 L
s
.31463 .30467 m
.31463 .44073 L
s
.41084 .40088 m
.50704 .49708 L
s
.41084 .40088 m
.41084 .53693 L
s
.50704 .49708 m
.60325 .59329 L
s
.50704 .49708 m
.50704 .63314 L
s
.60325 .59329 m
.69945 .68949 L
s
.60325 .59329 m
.60325 .72934 L
s
.69945 .68949 m
.79566 .7857 L
s
.69945 .68949 m
.69945 .82555 L
s
.12222 .24832 m
.21843 .34452 L
s
.12222 .24832 m
.12222 .38437 L
s
.21843 .34452 m
.31463 .44073 L
s
.21843 .34452 m
.21843 .48058 L
s
.31463 .44073 m
.41084 .53693 L
s
.31463 .44073 m
.31463 .57678 L
s
.41084 .53693 m
.50704 .63314 L
s
.41084 .53693 m
.41084 .67299 L
s
.50704 .63314 m
.60325 .72934 L
s
.50704 .63314 m
.50704 .76919 L
s
.60325 .72934 m
.69945 .82555 L
s
.60325 .72934 m
.60325 .8654 L
s
.12222 .38437 m
.21843 .48058 L
s
.12222 .38437 m
.12222 .52043 L
s
.21843 .48058 m
.31463 .57678 L
s
.21843 .48058 m
.21843 .61663 L
s
.31463 .57678 m
.41084 .67299 L
s
.31463 .57678 m
.31463 .71284 L
s
.41084 .67299 m
.50704 .76919 L
s
.41084 .67299 m
.41084 .80904 L
s
.50704 .76919 m
.60325 .8654 L
s
.50704 .76919 m
.50704 .90525 L
s
.02602 .42422 m
.12222 .52043 L
s
.02602 .42422 m
.02602 .56027 L
s
.12222 .52043 m
.21843 .61663 L
s
.12222 .52043 m
.12222 .65648 L
s
.21843 .61663 m
.31463 .71284 L
s
.21843 .61663 m
.21843 .75268 L
s
.31463 .71284 m
.41084 .80904 L
s
.31463 .71284 m
.31463 .84889 L
s
.41084 .80904 m
.50704 .90525 L
s
.41084 .80904 m
.41084 .94509 L
s
.02602 .56027 m
.12222 .65648 L
s
.12222 .65648 m
.21843 .75268 L
s
.12222 .65648 m
.12222 .79253 L
s
.21843 .75268 m
.31463 .84889 L
s
.21843 .75268 m
.21843 .88874 L
s
.31463 .84889 m
.41084 .94509 L
s
.12222 .79253 m
.21843 .88874 L
s
.78157 .11126 m
.87778 .20747 L
s
.78157 .11126 m
.78157 .24732 L
s
.87778 .20747 m
.87778 .34352 L
s
.58916 .05491 m
.68537 .15111 L
s
.58916 .05491 m
.58916 .19096 L
s
.68537 .15111 m
.78157 .24732 L
s
.68537 .15111 m
.68537 .28716 L
s
.78157 .24732 m
.87778 .34352 L
s
.78157 .24732 m
.78157 .38337 L
s
.87778 .34352 m
.97398 .43973 L
s
.87778 .34352 m
.87778 .47957 L
s
.97398 .43973 m
.97398 .57578 L
s
.49296 .09475 m
.58916 .19096 L
s
.49296 .09475 m
.49296 .23081 L
s
.58916 .19096 m
.68537 .28716 L
s
.58916 .19096 m
.58916 .32701 L
s
.68537 .28716 m
.78157 .38337 L
s
.68537 .28716 m
.68537 .42322 L
s
.78157 .38337 m
.87778 .47957 L
s
.78157 .38337 m
.78157 .51942 L
s
.87778 .47957 m
.97398 .57578 L
s
.87778 .47957 m
.87778 .61563 L
s
.39675 .1346 m
.49296 .23081 L
s
.39675 .1346 m
.39675 .27066 L
s
.49296 .23081 m
.58916 .32701 L
s
.49296 .23081 m
.49296 .36686 L
s
.58916 .32701 m
.68537 .42322 L
s
.58916 .32701 m
.58916 .46307 L
s
.68537 .42322 m
.78157 .51942 L
s
.68537 .42322 m
.68537 .55927 L
s
.78157 .51942 m
.87778 .61563 L
s
.78157 .51942 m
.78157 .65548 L
s
.87778 .61563 m
.87778 .75168 L
s
.30055 .17445 m
.39675 .27066 L
s
.30055 .17445 m
.30055 .31051 L
s
.39675 .27066 m
.49296 .36686 L
s
.39675 .27066 m
.39675 .40671 L
s
.49296 .36686 m
.58916 .46307 L
s
.49296 .36686 m
.49296 .50292 L
s
.58916 .46307 m
.68537 .55927 L
s
.58916 .46307 m
.58916 .59912 L
s
.68537 .55927 m
.78157 .65548 L
s
.68537 .55927 m
.68537 .69533 L
s
.78157 .65548 m
.87778 .75168 L
s
.78157 .65548 m
.78157 .79153 L
s
.20434 .2143 m
.30055 .31051 L
s
.20434 .2143 m
.20434 .35036 L
s
.30055 .31051 m
.39675 .40671 L
s
.30055 .31051 m
.30055 .44656 L
s
.39675 .40671 m
.49296 .50292 L
s
.39675 .40671 m
.39675 .54277 L
s
.49296 .50292 m
.58916 .59912 L
s
.49296 .50292 m
.49296 .63897 L
s
.58916 .59912 m
.68537 .69533 L
s
.58916 .59912 m
.58916 .73518 L
s
.68537 .69533 m
.78157 .79153 L
s
.68537 .69533 m
.68537 .83138 L
s
.10814 .25415 m
.20434 .35036 L
s
.10814 .25415 m
.10814 .39021 L
s
.20434 .35036 m
.30055 .44656 L
s
.20434 .35036 m
.20434 .48641 L
s
.30055 .44656 m
.39675 .54277 L
s
.30055 .44656 m
.30055 .58262 L
s
.39675 .54277 m
.49296 .63897 L
s
.39675 .54277 m
.39675 .67882 L
s
.49296 .63897 m
.58916 .73518 L
s
.49296 .63897 m
.49296 .77503 L
s
.58916 .73518 m
.68537 .83138 L
s
.58916 .73518 m
.58916 .87123 L
s
.10814 .39021 m
.20434 .48641 L
s
.10814 .39021 m
.10814 .52626 L
s
.20434 .48641 m
.30055 .58262 L
s
.20434 .48641 m
.20434 .62247 L
s
.30055 .58262 m
.39675 .67882 L
s
.30055 .58262 m
.30055 .71867 L
s
.39675 .67882 m
.49296 .77503 L
s
.39675 .67882 m
.39675 .81488 L
s
.49296 .77503 m
.58916 .87123 L
s
.49296 .77503 m
.49296 .91108 L
s
.10814 .52626 m
.20434 .62247 L
s
.10814 .52626 m
.10814 .66232 L
s
.20434 .62247 m
.30055 .71867 L
s
.20434 .62247 m
.20434 .75852 L
s
.30055 .71867 m
.39675 .81488 L
s
.30055 .71867 m
.30055 .85473 L
s
.39675 .81488 m
.49296 .91108 L
s
.39675 .81488 m
.39675 .95093 L
s
.10814 .66232 m
.20434 .75852 L
s
.20434 .75852 m
.30055 .85473 L
s
.30055 .85473 m
.39675 .95093 L
s
.65135 .04907 m
.74756 .14527 L
s
.65135 .04907 m
.65135 .18512 L
s
.74756 .14527 m
.84376 .24148 L
s
.74756 .14527 m
.74756 .28133 L
s
.84376 .24148 m
.93997 .33768 L
s
.84376 .24148 m
.84376 .37753 L
s
.93997 .33768 m
.93997 .47374 L
s
.55515 .08892 m
.65135 .18512 L
s
.55515 .08892 m
.55515 .22497 L
s
.65135 .18512 m
.74756 .28133 L
s
.65135 .18512 m
.65135 .32118 L
s
.74756 .28133 m
.84376 .37753 L
s
.74756 .28133 m
.74756 .41738 L
s
.84376 .37753 m
.93997 .47374 L
s
.84376 .37753 m
.84376 .51359 L
s
.93997 .47374 m
.93997 .60979 L
s
.45894 .12877 m
.55515 .22497 L
s
.45894 .12877 m
.45894 .26482 L
s
.55515 .22497 m
.65135 .32118 L
s
.55515 .22497 m
.55515 .36103 L
s
.65135 .32118 m
.74756 .41738 L
s
.65135 .32118 m
.65135 .45723 L
s
.74756 .41738 m
.84376 .51359 L
s
.74756 .41738 m
.74756 .55344 L
s
.84376 .51359 m
.93997 .60979 L
s
.84376 .51359 m
.84376 .64964 L
s
.36274 .16862 m
.45894 .26482 L
s
.36274 .16862 m
.36274 .30467 L
s
.45894 .26482 m
.55515 .36103 L
s
.45894 .26482 m
.45894 .40088 L
s
.55515 .36103 m
.65135 .45723 L
s
.55515 .36103 m
.55515 .49708 L
s
.65135 .45723 m
.74756 .55344 L
s
.65135 .45723 m
.65135 .59329 L
s
.74756 .55344 m
.84376 .64964 L
s
.74756 .55344 m
.74756 .68949 L
s
.84376 .64964 m
.84376 .7857 L
s
.26653 .20847 m
.36274 .30467 L
s
.26653 .20847 m
.26653 .34452 L
s
.36274 .30467 m
.45894 .40088 L
s
.36274 .30467 m
.36274 .44073 L
s
.45894 .40088 m
.55515 .49708 L
s
.45894 .40088 m
.45894 .53693 L
s
.55515 .49708 m
.65135 .59329 L
s
.55515 .49708 m
.55515 .63314 L
s
.65135 .59329 m
.74756 .68949 L
s
.65135 .59329 m
.65135 .72934 L
s
.74756 .68949 m
.84376 .7857 L
s
.74756 .68949 m
.74756 .82555 L
s
.17033 .24832 m
.26653 .34452 L
s
.17033 .24832 m
.17033 .38437 L
s
.26653 .34452 m
.36274 .44073 L
s
.26653 .34452 m
.26653 .48058 L
s
.36274 .44073 m
.45894 .53693 L
s
.36274 .44073 m
.36274 .57678 L
s
.45894 .53693 m
.55515 .63314 L
s
.45894 .53693 m
.45894 .67299 L
s
.55515 .63314 m
.65135 .72934 L
s
.55515 .63314 m
.55515 .76919 L
s
.65135 .72934 m
.74756 .82555 L
s
.65135 .72934 m
.65135 .8654 L
s
.07412 .28817 m
.17033 .38437 L
s
.07412 .28817 m
.07412 .42422 L
s
.17033 .38437 m
.26653 .48058 L
s
.17033 .38437 m
.17033 .52043 L
s
.26653 .48058 m
.36274 .57678 L
s
.26653 .48058 m
.26653 .61663 L
s
.36274 .57678 m
.45894 .67299 L
s
.36274 .57678 m
.36274 .71284 L
s
.45894 .67299 m
.55515 .76919 L
s
.45894 .67299 m
.45894 .80904 L
s
.55515 .76919 m
.65135 .8654 L
s
.55515 .76919 m
.55515 .90525 L
s
.07412 .42422 m
.17033 .52043 L
s
.07412 .42422 m
.07412 .56027 L
s
.17033 .52043 m
.26653 .61663 L
s
.17033 .52043 m
.17033 .65648 L
s
.26653 .61663 m
.36274 .71284 L
s
.26653 .61663 m
.26653 .75268 L
s
.36274 .71284 m
.45894 .80904 L
s
.36274 .71284 m
.36274 .84889 L
s
.45894 .80904 m
.55515 .90525 L
s
.45894 .80904 m
.45894 .94509 L
s
.07412 .56027 m
.17033 .65648 L
s
.07412 .56027 m
.07412 .69633 L
s
.17033 .65648 m
.26653 .75268 L
s
.17033 .65648 m
.17033 .79253 L
s
.26653 .75268 m
.36274 .84889 L
s
.26653 .75268 m
.26653 .88874 L
s
.36274 .84889 m
.45894 .94509 L
s
.07412 .69633 m
.17033 .79253 L
s
.17033 .79253 m
.26653 .88874 L
s
.42785 .04303 m
.52405 .04303 L
s
.42785 .04303 m
.42785 .13923 L
s
.52405 .04303 m
.62026 .04303 L
s
.52405 .04303 m
.52405 .13923 L
s
.62026 .04303 m
.62026 .13923 L
s
.23544 .13923 m
.33164 .13923 L
s
.23544 .13923 m
.23544 .23544 L
s
.33164 .13923 m
.42785 .13923 L
s
.33164 .13923 m
.33164 .23544 L
s
.42785 .13923 m
.52405 .13923 L
s
.42785 .13923 m
.42785 .23544 L
s
.52405 .13923 m
.62026 .13923 L
s
.52405 .13923 m
.52405 .23544 L
s
.62026 .13923 m
.71646 .13923 L
s
.62026 .13923 m
.62026 .23544 L
s
.71646 .13923 m
.81267 .13923 L
s
.71646 .13923 m
.71646 .23544 L
s
.81267 .13923 m
.81267 .23544 L
s
.13923 .23544 m
.23544 .23544 L
s
.13923 .23544 m
.13923 .33164 L
s
.23544 .23544 m
.33164 .23544 L
s
.23544 .23544 m
.23544 .33164 L
s
.33164 .23544 m
.42785 .23544 L
s
.33164 .23544 m
.33164 .33164 L
s
.42785 .23544 m
.52405 .23544 L
s
.42785 .23544 m
.42785 .33164 L
s
.52405 .23544 m
.62026 .23544 L
s
.52405 .23544 m
.52405 .33164 L
s
.62026 .23544 m
.71646 .23544 L
s
.62026 .23544 m
.62026 .33164 L
s
.71646 .23544 m
.81267 .23544 L
s
.71646 .23544 m
.71646 .33164 L
s
.81267 .23544 m
.81267 .33164 L
s
.13923 .33164 m
.23544 .33164 L
s
.13923 .33164 m
.13923 .42785 L
s
.23544 .33164 m
.33164 .33164 L
s
.23544 .33164 m
.23544 .42785 L
s
.33164 .33164 m
.42785 .33164 L
s
.33164 .33164 m
.33164 .42785 L
s
.42785 .33164 m
.52405 .33164 L
s
.42785 .33164 m
.42785 .42785 L
s
.52405 .33164 m
.62026 .33164 L
s
.52405 .33164 m
.52405 .42785 L
s
.62026 .33164 m
.71646 .33164 L
s
.62026 .33164 m
.62026 .42785 L
s
.71646 .33164 m
.81267 .33164 L
s
.71646 .33164 m
.71646 .42785 L
s
.81267 .33164 m
.90887 .33164 L
s
.81267 .33164 m
.81267 .42785 L
s
.90887 .33164 m
.90887 .42785 L
s
.04303 .42785 m
.13923 .42785 L
s
.04303 .42785 m
.04303 .52405 L
s
.13923 .42785 m
.23544 .42785 L
s
.13923 .42785 m
.13923 .52405 L
s
.23544 .42785 m
.33164 .42785 L
s
.23544 .42785 m
.23544 .52405 L
s
.33164 .42785 m
.42785 .42785 L
s
.33164 .42785 m
.33164 .52405 L
s
.42785 .42785 m
.52405 .42785 L
s
.42785 .42785 m
.42785 .52405 L
s
.52405 .42785 m
.62026 .42785 L
s
.52405 .42785 m
.52405 .52405 L
s
.62026 .42785 m
.71646 .42785 L
s
.62026 .42785 m
.62026 .52405 L
s
.71646 .42785 m
.81267 .42785 L
s
.71646 .42785 m
.71646 .52405 L
s
.81267 .42785 m
.90887 .42785 L
s
.81267 .42785 m
.81267 .52405 L
s
.90887 .42785 m
.90887 .52405 L
s
.04303 .52405 m
.13923 .52405 L
s
.04303 .52405 m
.04303 .62026 L
s
.13923 .52405 m
.23544 .52405 L
s
.13923 .52405 m
.13923 .62026 L
s
.23544 .52405 m
.33164 .52405 L
s
.23544 .52405 m
.23544 .62026 L
s
.33164 .52405 m
.42785 .52405 L
s
.33164 .52405 m
.33164 .62026 L
s
.42785 .52405 m
.52405 .52405 L
s
.42785 .52405 m
.42785 .62026 L
s
.52405 .52405 m
.62026 .52405 L
s
.52405 .52405 m
.52405 .62026 L
s
.62026 .52405 m
.71646 .52405 L
s
.62026 .52405 m
.62026 .62026 L
s
.71646 .52405 m
.81267 .52405 L
s
.71646 .52405 m
.71646 .62026 L
s
.81267 .52405 m
.90887 .52405 L
s
.81267 .52405 m
.81267 .62026 L
s
.90887 .52405 m
.90887 .62026 L
s
.04303 .62026 m
.13923 .62026 L
s
.13923 .62026 m
.23544 .62026 L
s
.13923 .62026 m
.13923 .71646 L
s
.23544 .62026 m
.33164 .62026 L
s
.23544 .62026 m
.23544 .71646 L
s
.33164 .62026 m
.42785 .62026 L
s
.33164 .62026 m
.33164 .71646 L
s
.42785 .62026 m
.52405 .62026 L
s
.42785 .62026 m
.42785 .71646 L
s
.52405 .62026 m
.62026 .62026 L
s
.52405 .62026 m
.52405 .71646 L
s
.62026 .62026 m
.71646 .62026 L
s
.62026 .62026 m
.62026 .71646 L
s
.71646 .62026 m
.81267 .62026 L
s
.71646 .62026 m
.71646 .71646 L
s
.81267 .62026 m
.90887 .62026 L
s
.81267 .62026 m
.81267 .71646 L
s
.90887 .62026 m
.90887 .71646 L
s
.13923 .71646 m
.23544 .71646 L
s
.13923 .71646 m
.13923 .81267 L
s
.23544 .71646 m
.33164 .71646 L
s
.23544 .71646 m
.23544 .81267 L
s
.33164 .71646 m
.42785 .71646 L
s
.33164 .71646 m
.33164 .81267 L
s
.42785 .71646 m
.52405 .71646 L
s
.42785 .71646 m
.42785 .81267 L
s
.52405 .71646 m
.62026 .71646 L
s
.52405 .71646 m
.52405 .81267 L
s
.62026 .71646 m
.71646 .71646 L
s
.62026 .71646 m
.62026 .81267 L
s
.71646 .71646 m
.81267 .71646 L
s
.71646 .71646 m
.71646 .81267 L
s
.81267 .71646 m
.90887 .71646 L
s
.81267 .71646 m
.81267 .81267 L
s
.13923 .81267 m
.23544 .81267 L
s
.23544 .81267 m
.33164 .81267 L
s
.33164 .81267 m
.42785 .81267 L
s
.33164 .81267 m
.33164 .90887 L
s
.42785 .81267 m
.52405 .81267 L
s
.42785 .81267 m
.42785 .90887 L
s
.52405 .81267 m
.62026 .81267 L
s
.52405 .81267 m
.52405 .90887 L
s
.62026 .81267 m
.71646 .81267 L
s
.62026 .81267 m
.62026 .90887 L
s
.71646 .81267 m
.81267 .81267 L
s
.71646 .81267 m
.71646 .90887 L
s
.33164 .90887 m
.42785 .90887 L
s
.42785 .90887 m
.52405 .90887 L
s
.52405 .90887 m
.62026 .90887 L
s
.62026 .90887 m
.71646 .90887 L
s
.33164 .09113 m
.42785 .09113 L
s
.33164 .09113 m
.33164 .18733 L
s
.42785 .09113 m
.52405 .09113 L
s
.42785 .09113 m
.42785 .18733 L
s
.52405 .09113 m
.62026 .09113 L
s
.52405 .09113 m
.52405 .18733 L
s
.62026 .09113 m
.71646 .09113 L
s
.62026 .09113 m
.62026 .18733 L
s
.71646 .09113 m
.71646 .18733 L
s
.13923 .18733 m
.23544 .18733 L
s
.13923 .18733 m
.13923 .28354 L
s
.23544 .18733 m
.33164 .18733 L
s
.23544 .18733 m
.23544 .28354 L
s
.33164 .18733 m
.42785 .18733 L
s
.33164 .18733 m
.33164 .28354 L
s
.42785 .18733 m
.52405 .18733 L
s
.42785 .18733 m
.42785 .28354 L
s
.52405 .18733 m
.62026 .18733 L
s
.52405 .18733 m
.52405 .28354 L
s
.62026 .18733 m
.71646 .18733 L
s
.62026 .18733 m
.62026 .28354 L
s
.71646 .18733 m
.81267 .18733 L
s
.71646 .18733 m
.71646 .28354 L
s
.81267 .18733 m
.81267 .28354 L
s
.13923 .28354 m
.23544 .28354 L
s
.13923 .28354 m
.13923 .37974 L
s
.23544 .28354 m
.33164 .28354 L
s
.23544 .28354 m
.23544 .37974 L
s
.33164 .28354 m
.42785 .28354 L
s
.33164 .28354 m
.33164 .37974 L
s
.42785 .28354 m
.52405 .28354 L
s
.42785 .28354 m
.42785 .37974 L
s
.52405 .28354 m
.62026 .28354 L
s
.52405 .28354 m
.52405 .37974 L
s
.62026 .28354 m
.71646 .28354 L
s
.62026 .28354 m
.62026 .37974 L
s
.71646 .28354 m
.81267 .28354 L
s
.71646 .28354 m
.71646 .37974 L
s
.81267 .28354 m
.90887 .28354 L
s
.81267 .28354 m
.81267 .37974 L
s
.90887 .28354 m
.90887 .37974 L
s
.04303 .37974 m
.13923 .37974 L
s
.04303 .37974 m
.04303 .47595 L
s
.13923 .37974 m
.23544 .37974 L
s
.13923 .37974 m
.13923 .47595 L
s
.23544 .37974 m
.33164 .37974 L
s
.23544 .37974 m
.23544 .47595 L
s
.33164 .37974 m
.42785 .37974 L
s
.33164 .37974 m
.33164 .47595 L
s
.42785 .37974 m
.52405 .37974 L
s
.42785 .37974 m
.42785 .47595 L
s
.52405 .37974 m
.62026 .37974 L
s
.52405 .37974 m
.52405 .47595 L
s
.62026 .37974 m
.71646 .37974 L
s
.62026 .37974 m
.62026 .47595 L
s
.71646 .37974 m
.81267 .37974 L
s
.71646 .37974 m
.71646 .47595 L
s
.81267 .37974 m
.90887 .37974 L
s
.81267 .37974 m
.81267 .47595 L
s
.90887 .37974 m
.90887 .47595 L
s
.04303 .47595 m
.13923 .47595 L
s
.04303 .47595 m
.04303 .57215 L
s
.13923 .47595 m
.23544 .47595 L
s
.13923 .47595 m
.13923 .57215 L
s
.23544 .47595 m
.33164 .47595 L
s
.23544 .47595 m
.23544 .57215 L
s
.33164 .47595 m
.42785 .47595 L
s
.33164 .47595 m
.33164 .57215 L
s
.42785 .47595 m
.52405 .47595 L
s
.42785 .47595 m
.42785 .57215 L
s
.52405 .47595 m
.62026 .47595 L
s
.52405 .47595 m
.52405 .57215 L
s
.62026 .47595 m
.71646 .47595 L
s
.62026 .47595 m
.62026 .57215 L
s
.71646 .47595 m
.81267 .47595 L
s
.71646 .47595 m
.71646 .57215 L
s
.81267 .47595 m
.90887 .47595 L
s
.81267 .47595 m
.81267 .57215 L
s
.90887 .47595 m
.90887 .57215 L
s
.04303 .57215 m
.13923 .57215 L
s
.13923 .57215 m
.23544 .57215 L
s
.13923 .57215 m
.13923 .66836 L
s
.23544 .57215 m
.33164 .57215 L
s
.23544 .57215 m
.23544 .66836 L
s
.33164 .57215 m
.42785 .57215 L
s
.33164 .57215 m
.33164 .66836 L
s
.42785 .57215 m
.52405 .57215 L
s
.42785 .57215 m
.42785 .66836 L
s
.52405 .57215 m
.62026 .57215 L
s
.52405 .57215 m
.52405 .66836 L
s
.62026 .57215 m
.71646 .57215 L
s
.62026 .57215 m
.62026 .66836 L
s
.71646 .57215 m
.81267 .57215 L
s
.71646 .57215 m
.71646 .66836 L
s
.81267 .57215 m
.90887 .57215 L
s
.81267 .57215 m
.81267 .66836 L
s
.90887 .57215 m
.90887 .66836 L
s
.13923 .66836 m
.23544 .66836 L
s
.13923 .66836 m
.13923 .76456 L
s
.23544 .66836 m
.33164 .66836 L
s
.23544 .66836 m
.23544 .76456 L
s
.33164 .66836 m
.42785 .66836 L
s
.33164 .66836 m
.33164 .76456 L
s
.42785 .66836 m
.52405 .66836 L
s
.42785 .66836 m
.42785 .76456 L
s
.52405 .66836 m
.62026 .66836 L
s
.52405 .66836 m
.52405 .76456 L
s
.62026 .66836 m
.71646 .66836 L
s
.62026 .66836 m
.62026 .76456 L
s
.71646 .66836 m
.81267 .66836 L
s
.71646 .66836 m
.71646 .76456 L
s
.81267 .66836 m
.90887 .66836 L
s
.81267 .66836 m
.81267 .76456 L
s
.13923 .76456 m
.23544 .76456 L
s
.23544 .76456 m
.33164 .76456 L
s
.23544 .76456 m
.23544 .86077 L
s
.33164 .76456 m
.42785 .76456 L
s
.33164 .76456 m
.33164 .86077 L
s
.42785 .76456 m
.52405 .76456 L
s
.42785 .76456 m
.42785 .86077 L
s
.52405 .76456 m
.62026 .76456 L
s
.52405 .76456 m
.52405 .86077 L
s
.62026 .76456 m
.71646 .76456 L
s
.62026 .76456 m
.62026 .86077 L
s
.71646 .76456 m
.81267 .76456 L
s
.71646 .76456 m
.71646 .86077 L
s
.81267 .76456 m
.81267 .86077 L
s
.23544 .86077 m
.33164 .86077 L
s
.33164 .86077 m
.42785 .86077 L
s
.42785 .86077 m
.52405 .86077 L
s
.42785 .86077 m
.42785 .95697 L
s
.52405 .86077 m
.62026 .86077 L
s
.52405 .86077 m
.52405 .95697 L
s
.62026 .86077 m
.71646 .86077 L
s
.62026 .86077 m
.62026 .95697 L
s
.71646 .86077 m
.81267 .86077 L
s
.42785 .95697 m
.52405 .95697 L
s
.52405 .95697 m
.62026 .95697 L
s
.37974 .04303 m
.47595 .04303 L
s
.37974 .04303 m
.37974 .13923 L
s
.47595 .04303 m
.57215 .04303 L
s
.47595 .04303 m
.47595 .13923 L
s
.57215 .04303 m
.57215 .13923 L
s
.18733 .13923 m
.28354 .13923 L
s
.18733 .13923 m
.18733 .23544 L
s
.28354 .13923 m
.37974 .13923 L
s
.28354 .13923 m
.28354 .23544 L
s
.37974 .13923 m
.47595 .13923 L
s
.37974 .13923 m
.37974 .23544 L
s
.47595 .13923 m
.57215 .13923 L
s
.47595 .13923 m
.47595 .23544 L
s
.57215 .13923 m
.66836 .13923 L
s
.57215 .13923 m
.57215 .23544 L
s
.66836 .13923 m
.76456 .13923 L
s
.66836 .13923 m
.66836 .23544 L
s
.76456 .13923 m
.76456 .23544 L
s
.18733 .23544 m
.28354 .23544 L
s
.18733 .23544 m
.18733 .33164 L
s
.28354 .23544 m
.37974 .23544 L
s
.28354 .23544 m
.28354 .33164 L
s
.37974 .23544 m
.47595 .23544 L
s
.37974 .23544 m
.37974 .33164 L
s
.47595 .23544 m
.57215 .23544 L
s
.47595 .23544 m
.47595 .33164 L
s
.57215 .23544 m
.66836 .23544 L
s
.57215 .23544 m
.57215 .33164 L
s
.66836 .23544 m
.76456 .23544 L
s
.66836 .23544 m
.66836 .33164 L
s
.76456 .23544 m
.86077 .23544 L
s
.76456 .23544 m
.76456 .33164 L
s
.86077 .23544 m
.86077 .33164 L
s
.09113 .33164 m
.18733 .33164 L
s
.09113 .33164 m
.09113 .42785 L
s
.18733 .33164 m
.28354 .33164 L
s
.18733 .33164 m
.18733 .42785 L
s
.28354 .33164 m
.37974 .33164 L
s
.28354 .33164 m
.28354 .42785 L
s
.37974 .33164 m
.47595 .33164 L
s
.37974 .33164 m
.37974 .42785 L
s
.47595 .33164 m
.57215 .33164 L
s
.47595 .33164 m
.47595 .42785 L
s
.57215 .33164 m
.66836 .33164 L
s
.57215 .33164 m
.57215 .42785 L
s
.66836 .33164 m
.76456 .33164 L
s
.66836 .33164 m
.66836 .42785 L
s
.76456 .33164 m
.86077 .33164 L
s
.76456 .33164 m
.76456 .42785 L
s
.86077 .33164 m
.86077 .42785 L
s
.09113 .42785 m
.18733 .42785 L
s
.09113 .42785 m
.09113 .52405 L
s
.18733 .42785 m
.28354 .42785 L
s
.18733 .42785 m
.18733 .52405 L
s
.28354 .42785 m
.37974 .42785 L
s
.28354 .42785 m
.28354 .52405 L
s
.37974 .42785 m
.47595 .42785 L
s
.37974 .42785 m
.37974 .52405 L
s
.47595 .42785 m
.57215 .42785 L
s
.47595 .42785 m
.47595 .52405 L
s
.57215 .42785 m
.66836 .42785 L
s
.57215 .42785 m
.57215 .52405 L
s
.66836 .42785 m
.76456 .42785 L
s
.66836 .42785 m
.66836 .52405 L
s
.76456 .42785 m
.86077 .42785 L
s
.76456 .42785 m
.76456 .52405 L
s
.86077 .42785 m
.95697 .42785 L
s
.86077 .42785 m
.86077 .52405 L
s
.95697 .42785 m
.95697 .52405 L
s
.09113 .52405 m
.18733 .52405 L
s
.09113 .52405 m
.09113 .62026 L
s
.18733 .52405 m
.28354 .52405 L
s
.18733 .52405 m
.18733 .62026 L
s
.28354 .52405 m
.37974 .52405 L
s
.28354 .52405 m
.28354 .62026 L
s
.37974 .52405 m
.47595 .52405 L
s
.37974 .52405 m
.37974 .62026 L
s
.47595 .52405 m
.57215 .52405 L
s
.47595 .52405 m
.47595 .62026 L
s
.57215 .52405 m
.66836 .52405 L
s
.57215 .52405 m
.57215 .62026 L
s
.66836 .52405 m
.76456 .52405 L
s
.66836 .52405 m
.66836 .62026 L
s
.76456 .52405 m
.86077 .52405 L
s
.76456 .52405 m
.76456 .62026 L
s
.86077 .52405 m
.95697 .52405 L
s
.86077 .52405 m
.86077 .62026 L
s
.95697 .52405 m
.95697 .62026 L
s
.09113 .62026 m
.18733 .62026 L
s
.09113 .62026 m
.09113 .71646 L
s
.18733 .62026 m
.28354 .62026 L
s
.18733 .62026 m
.18733 .71646 L
s
.28354 .62026 m
.37974 .62026 L
s
.28354 .62026 m
.28354 .71646 L
s
.37974 .62026 m
.47595 .62026 L
s
.37974 .62026 m
.37974 .71646 L
s
.47595 .62026 m
.57215 .62026 L
s
.47595 .62026 m
.47595 .71646 L
s
.57215 .62026 m
.66836 .62026 L
s
.57215 .62026 m
.57215 .71646 L
s
.66836 .62026 m
.76456 .62026 L
s
.66836 .62026 m
.66836 .71646 L
s
.76456 .62026 m
.86077 .62026 L
s
.76456 .62026 m
.76456 .71646 L
s
.86077 .62026 m
.95697 .62026 L
s
.86077 .62026 m
.86077 .71646 L
s
.09113 .71646 m
.18733 .71646 L
s
.18733 .71646 m
.28354 .71646 L
s
.18733 .71646 m
.18733 .81267 L
s
.28354 .71646 m
.37974 .71646 L
s
.28354 .71646 m
.28354 .81267 L
s
.37974 .71646 m
.47595 .71646 L
s
.37974 .71646 m
.37974 .81267 L
s
.47595 .71646 m
.57215 .71646 L
s
.47595 .71646 m
.47595 .81267 L
s
.57215 .71646 m
.66836 .71646 L
s
.57215 .71646 m
.57215 .81267 L
s
.66836 .71646 m
.76456 .71646 L
s
.66836 .71646 m
.66836 .81267 L
s
.76456 .71646 m
.86077 .71646 L
s
.76456 .71646 m
.76456 .81267 L
s
.86077 .71646 m
.86077 .81267 L
s
.18733 .81267 m
.28354 .81267 L
s
.28354 .81267 m
.37974 .81267 L
s
.28354 .81267 m
.28354 .90887 L
s
.37974 .81267 m
.47595 .81267 L
s
.37974 .81267 m
.37974 .90887 L
s
.47595 .81267 m
.57215 .81267 L
s
.47595 .81267 m
.47595 .90887 L
s
.57215 .81267 m
.66836 .81267 L
s
.57215 .81267 m
.57215 .90887 L
s
.66836 .81267 m
.76456 .81267 L
s
.66836 .81267 m
.66836 .90887 L
s
.76456 .81267 m
.86077 .81267 L
s
.28354 .90887 m
.37974 .90887 L
s
.37974 .90887 m
.47595 .90887 L
s
.47595 .90887 m
.57215 .90887 L
s
.57215 .90887 m
.66836 .90887 L
s
.28354 .09113 m
.37974 .09113 L
s
.28354 .09113 m
.28354 .18733 L
s
.37974 .09113 m
.47595 .09113 L
s
.37974 .09113 m
.37974 .18733 L
s
.47595 .09113 m
.57215 .09113 L
s
.47595 .09113 m
.47595 .18733 L
s
.57215 .09113 m
.66836 .09113 L
s
.57215 .09113 m
.57215 .18733 L
s
.66836 .09113 m
.66836 .18733 L
s
.18733 .18733 m
.28354 .18733 L
s
.18733 .18733 m
.18733 .28354 L
s
.28354 .18733 m
.37974 .18733 L
s
.28354 .18733 m
.28354 .28354 L
s
.37974 .18733 m
.47595 .18733 L
s
.37974 .18733 m
.37974 .28354 L
s
.47595 .18733 m
.57215 .18733 L
s
.47595 .18733 m
.47595 .28354 L
s
.57215 .18733 m
.66836 .18733 L
s
.57215 .18733 m
.57215 .28354 L
s
.66836 .18733 m
.76456 .18733 L
s
.66836 .18733 m
.66836 .28354 L
s
.76456 .18733 m
.86077 .18733 L
s
.76456 .18733 m
.76456 .28354 L
s
.86077 .18733 m
.86077 .28354 L
s
.09113 .28354 m
.18733 .28354 L
s
.09113 .28354 m
.09113 .37974 L
s
.18733 .28354 m
.28354 .28354 L
s
.18733 .28354 m
.18733 .37974 L
s
.28354 .28354 m
.37974 .28354 L
s
.28354 .28354 m
.28354 .37974 L
s
.37974 .28354 m
.47595 .28354 L
s
.37974 .28354 m
.37974 .37974 L
s
.47595 .28354 m
.57215 .28354 L
s
.47595 .28354 m
.47595 .37974 L
s
.57215 .28354 m
.66836 .28354 L
s
.57215 .28354 m
.57215 .37974 L
s
.66836 .28354 m
.76456 .28354 L
s
.66836 .28354 m
.66836 .37974 L
s
.76456 .28354 m
.86077 .28354 L
s
.76456 .28354 m
.76456 .37974 L
s
.86077 .28354 m
.86077 .37974 L
s
.09113 .37974 m
.18733 .37974 L
s
.09113 .37974 m
.09113 .47595 L
s
.18733 .37974 m
.28354 .37974 L
s
.18733 .37974 m
.18733 .47595 L
s
.28354 .37974 m
.37974 .37974 L
s
.28354 .37974 m
.28354 .47595 L
s
.37974 .37974 m
.47595 .37974 L
s
.37974 .37974 m
.37974 .47595 L
s
.47595 .37974 m
.57215 .37974 L
s
.47595 .37974 m
.47595 .47595 L
s
.57215 .37974 m
.66836 .37974 L
s
.57215 .37974 m
.57215 .47595 L
s
.66836 .37974 m
.76456 .37974 L
s
.66836 .37974 m
.66836 .47595 L
s
.76456 .37974 m
.86077 .37974 L
s
.76456 .37974 m
.76456 .47595 L
s
.86077 .37974 m
.95697 .37974 L
s
.86077 .37974 m
.86077 .47595 L
s
.95697 .37974 m
.95697 .47595 L
s
.09113 .47595 m
.18733 .47595 L
s
.09113 .47595 m
.09113 .57215 L
s
.18733 .47595 m
.28354 .47595 L
s
.18733 .47595 m
.18733 .57215 L
s
.28354 .47595 m
.37974 .47595 L
s
.28354 .47595 m
.28354 .57215 L
s
.37974 .47595 m
.47595 .47595 L
s
.37974 .47595 m
.37974 .57215 L
s
.47595 .47595 m
.57215 .47595 L
s
.47595 .47595 m
.47595 .57215 L
s
.57215 .47595 m
.66836 .47595 L
s
.57215 .47595 m
.57215 .57215 L
s
.66836 .47595 m
.76456 .47595 L
s
.66836 .47595 m
.66836 .57215 L
s
.76456 .47595 m
.86077 .47595 L
s
.76456 .47595 m
.76456 .57215 L
s
.86077 .47595 m
.95697 .47595 L
s
.86077 .47595 m
.86077 .57215 L
s
.95697 .47595 m
.95697 .57215 L
s
.09113 .57215 m
.18733 .57215 L
s
.09113 .57215 m
.09113 .66836 L
s
.18733 .57215 m
.28354 .57215 L
s
.18733 .57215 m
.18733 .66836 L
s
.28354 .57215 m
.37974 .57215 L
s
.28354 .57215 m
.28354 .66836 L
s
.37974 .57215 m
.47595 .57215 L
s
.37974 .57215 m
.37974 .66836 L
s
.47595 .57215 m
.57215 .57215 L
s
.47595 .57215 m
.47595 .66836 L
s
.57215 .57215 m
.66836 .57215 L
s
.57215 .57215 m
.57215 .66836 L
s
.66836 .57215 m
.76456 .57215 L
s
.66836 .57215 m
.66836 .66836 L
s
.76456 .57215 m
.86077 .57215 L
s
.76456 .57215 m
.76456 .66836 L
s
.86077 .57215 m
.95697 .57215 L
s
.86077 .57215 m
.86077 .66836 L
s
.09113 .66836 m
.18733 .66836 L
s
.18733 .66836 m
.28354 .66836 L
s
.18733 .66836 m
.18733 .76456 L
s
.28354 .66836 m
.37974 .66836 L
s
.28354 .66836 m
.28354 .76456 L
s
.37974 .66836 m
.47595 .66836 L
s
.37974 .66836 m
.37974 .76456 L
s
.47595 .66836 m
.57215 .66836 L
s
.47595 .66836 m
.47595 .76456 L
s
.57215 .66836 m
.66836 .66836 L
s
.57215 .66836 m
.57215 .76456 L
s
.66836 .66836 m
.76456 .66836 L
s
.66836 .66836 m
.66836 .76456 L
s
.76456 .66836 m
.86077 .66836 L
s
.76456 .66836 m
.76456 .76456 L
s
.86077 .66836 m
.86077 .76456 L
s
.18733 .76456 m
.28354 .76456 L
s
.18733 .76456 m
.18733 .86077 L
s
.28354 .76456 m
.37974 .76456 L
s
.28354 .76456 m
.28354 .86077 L
s
.37974 .76456 m
.47595 .76456 L
s
.37974 .76456 m
.37974 .86077 L
s
.47595 .76456 m
.57215 .76456 L
s
.47595 .76456 m
.47595 .86077 L
s
.57215 .76456 m
.66836 .76456 L
s
.57215 .76456 m
.57215 .86077 L
s
.66836 .76456 m
.76456 .76456 L
s
.66836 .76456 m
.66836 .86077 L
s
.76456 .76456 m
.86077 .76456 L
s
.76456 .76456 m
.76456 .86077 L
s
.18733 .86077 m
.28354 .86077 L
s
.28354 .86077 m
.37974 .86077 L
s
.37974 .86077 m
.47595 .86077 L
s
.37974 .86077 m
.37974 .95697 L
s
.47595 .86077 m
.57215 .86077 L
s
.47595 .86077 m
.47595 .95697 L
s
.57215 .86077 m
.66836 .86077 L
s
.57215 .86077 m
.57215 .95697 L
s
.66836 .86077 m
.76456 .86077 L
s
.37974 .95697 m
.47595 .95697 L
s
.47595 .95697 m
.57215 .95697 L
s
.77211 .12585 m
.84014 .19388 L
s
.77211 .12585 m
.70408 .19388 L
s
.84014 .19388 m
.90816 .2619 L
s
.84014 .19388 m
.77211 .2619 L
s
.90816 .2619 m
.84014 .32993 L
s
.56803 .05782 m
.63605 .12585 L
s
.56803 .05782 m
.5 .12585 L
s
.63605 .12585 m
.70408 .19388 L
s
.63605 .12585 m
.56803 .19388 L
s
.70408 .19388 m
.77211 .2619 L
s
.70408 .19388 m
.63605 .2619 L
s
.77211 .2619 m
.84014 .32993 L
s
.77211 .2619 m
.70408 .32993 L
s
.84014 .32993 m
.90816 .39796 L
s
.84014 .32993 m
.77211 .39796 L
s
.90816 .39796 m
.97619 .46599 L
s
.90816 .39796 m
.84014 .46599 L
s
.97619 .46599 m
.90816 .53401 L
s
.43197 .05782 m
.5 .12585 L
s
.43197 .05782 m
.36395 .12585 L
s
.5 .12585 m
.56803 .19388 L
s
.5 .12585 m
.43197 .19388 L
s
.56803 .19388 m
.63605 .2619 L
s
.56803 .19388 m
.5 .2619 L
s
.63605 .2619 m
.70408 .32993 L
s
.63605 .2619 m
.56803 .32993 L
s
.70408 .32993 m
.77211 .39796 L
s
.70408 .32993 m
.63605 .39796 L
s
.77211 .39796 m
.84014 .46599 L
s
.77211 .39796 m
.70408 .46599 L
s
.84014 .46599 m
.90816 .53401 L
s
.84014 .46599 m
.77211 .53401 L
s
.90816 .53401 m
.84014 .60204 L
s
.36395 .12585 m
.43197 .19388 L
s
.36395 .12585 m
.29592 .19388 L
s
.43197 .19388 m
.5 .2619 L
s
.43197 .19388 m
.36395 .2619 L
s
.5 .2619 m
.56803 .32993 L
s
.5 .2619 m
.43197 .32993 L
s
.56803 .32993 m
.63605 .39796 L
s
.56803 .32993 m
.5 .39796 L
s
.63605 .39796 m
.70408 .46599 L
s
.63605 .39796 m
.56803 .46599 L
s
.70408 .46599 m
.77211 .53401 L
s
.70408 .46599 m
.63605 .53401 L
s
.77211 .53401 m
.84014 .60204 L
s
.77211 .53401 m
.70408 .60204 L
s
.84014 .60204 m
.90816 .67007 L
s
.84014 .60204 m
.77211 .67007 L
s
.90816 .67007 m
.84014 .7381 L
s
.22789 .12585 m
.29592 .19388 L
s
.22789 .12585 m
.15986 .19388 L
s
.29592 .19388 m
.36395 .2619 L
s
.29592 .19388 m
.22789 .2619 L
s
.36395 .2619 m
.43197 .32993 L
s
.36395 .2619 m
.29592 .32993 L
s
.43197 .32993 m
.5 .39796 L
s
.43197 .32993 m
.36395 .39796 L
s
.5 .39796 m
.56803 .46599 L
s
.5 .39796 m
.43197 .46599 L
s
.56803 .46599 m
.63605 .53401 L
s
.56803 .46599 m
.5 .53401 L
s
.63605 .53401 m
.70408 .60204 L
s
.63605 .53401 m
.56803 .60204 L
s
.70408 .60204 m
.77211 .67007 L
s
.70408 .60204 m
.63605 .67007 L
s
.77211 .67007 m
.84014 .7381 L
s
.77211 .67007 m
.70408 .7381 L
s
.84014 .7381 m
.77211 .80612 L
s
.15986 .19388 m
.22789 .2619 L
s
.15986 .19388 m
.09184 .2619 L
s
.22789 .2619 m
.29592 .32993 L
s
.22789 .2619 m
.15986 .32993 L
s
.29592 .32993 m
.36395 .39796 L
s
.29592 .32993 m
.22789 .39796 L
s
.36395 .39796 m
.43197 .46599 L
s
.36395 .39796 m
.29592 .46599 L
s
.43197 .46599 m
.5 .53401 L
s
.43197 .46599 m
.36395 .53401 L
s
.5 .53401 m
.56803 .60204 L
s
.5 .53401 m
.43197 .60204 L
s
.56803 .60204 m
.63605 .67007 L
s
.56803 .60204 m
.5 .67007 L
s
.63605 .67007 m
.70408 .7381 L
s
.63605 .67007 m
.56803 .7381 L
s
.70408 .7381 m
.77211 .80612 L
s
.70408 .7381 m
.63605 .80612 L
s
.77211 .80612 m
.70408 .87415 L
s
.09184 .2619 m
.15986 .32993 L
s
.15986 .32993 m
.22789 .39796 L
s
.15986 .32993 m
.09184 .39796 L
s
.22789 .39796 m
.29592 .46599 L
s
.22789 .39796 m
.15986 .46599 L
s
.29592 .46599 m
.36395 .53401 L
s
.29592 .46599 m
.22789 .53401 L
s
.36395 .53401 m
.43197 .60204 L
s
.36395 .53401 m
.29592 .60204 L
s
.43197 .60204 m
.5 .67007 L
s
.43197 .60204 m
.36395 .67007 L
s
.5 .67007 m
.56803 .7381 L
s
.5 .67007 m
.43197 .7381 L
s
.56803 .7381 m
.63605 .80612 L
s
.56803 .7381 m
.5 .80612 L
s
.63605 .80612 m
.70408 .87415 L
s
.63605 .80612 m
.56803 .87415 L
s
.70408 .87415 m
.63605 .94218 L
s
.09184 .39796 m
.15986 .46599 L
s
.09184 .39796 m
.02381 .46599 L
s
.15986 .46599 m
.22789 .53401 L
s
.15986 .46599 m
.09184 .53401 L
s
.22789 .53401 m
.29592 .60204 L
s
.22789 .53401 m
.15986 .60204 L
s
.29592 .60204 m
.36395 .67007 L
s
.29592 .60204 m
.22789 .67007 L
s
.36395 .67007 m
.43197 .7381 L
s
.36395 .67007 m
.29592 .7381 L
s
.43197 .7381 m
.5 .80612 L
s
.43197 .7381 m
.36395 .80612 L
s
.5 .80612 m
.56803 .87415 L
s
.5 .80612 m
.43197 .87415 L
s
.56803 .87415 m
.63605 .94218 L
s
.56803 .87415 m
.5 .94218 L
s
.02381 .46599 m
.09184 .53401 L
s
.09184 .53401 m
.15986 .60204 L
s
.15986 .60204 m
.22789 .67007 L
s
.15986 .60204 m
.09184 .67007 L
s
.22789 .67007 m
.29592 .7381 L
s
.22789 .67007 m
.15986 .7381 L
s
.29592 .7381 m
.36395 .80612 L
s
.29592 .7381 m
.22789 .80612 L
s
.36395 .80612 m
.43197 .87415 L
s
.36395 .80612 m
.29592 .87415 L
s
.43197 .87415 m
.5 .94218 L
s
.43197 .87415 m
.36395 .94218 L
s
.09184 .67007 m
.15986 .7381 L
s
.15986 .7381 m
.22789 .80612 L
s
.22789 .80612 m
.29592 .87415 L
s
.29592 .87415 m
.36395 .94218 L
s
.67007 .09184 m
.7381 .15986 L
s
.67007 .09184 m
.60204 .15986 L
s
.7381 .15986 m
.80612 .22789 L
s
.7381 .15986 m
.67007 .22789 L
s
.80612 .22789 m
.87415 .29592 L
s
.80612 .22789 m
.7381 .29592 L
s
.87415 .29592 m
.94218 .36395 L
s
.87415 .29592 m
.80612 .36395 L
s
.94218 .36395 m
.87415 .43197 L
s
.46599 .02381 m
.53401 .09184 L
s
.46599 .02381 m
.39796 .09184 L
s
.53401 .09184 m
.60204 .15986 L
s
.53401 .09184 m
.46599 .15986 L
s
.60204 .15986 m
.67007 .22789 L
s
.60204 .15986 m
.53401 .22789 L
s
.67007 .22789 m
.7381 .29592 L
s
.67007 .22789 m
.60204 .29592 L
s
.7381 .29592 m
.80612 .36395 L
s
.7381 .29592 m
.67007 .36395 L
s
.80612 .36395 m
.87415 .43197 L
s
.80612 .36395 m
.7381 .43197 L
s
.87415 .43197 m
.94218 .5 L
s
.87415 .43197 m
.80612 .5 L
s
.94218 .5 m
.87415 .56803 L
s
.39796 .09184 m
.46599 .15986 L
s
.39796 .09184 m
.32993 .15986 L
s
.46599 .15986 m
.53401 .22789 L
s
.46599 .15986 m
.39796 .22789 L
s
.53401 .22789 m
.60204 .29592 L
s
.53401 .22789 m
.46599 .29592 L
s
.60204 .29592 m
.67007 .36395 L
s
.60204 .29592 m
.53401 .36395 L
s
.67007 .36395 m
.7381 .43197 L
s
.67007 .36395 m
.60204 .43197 L
s
.7381 .43197 m
.80612 .5 L
s
.7381 .43197 m
.67007 .5 L
s
.80612 .5 m
.87415 .56803 L
s
.80612 .5 m
.7381 .56803 L
s
.87415 .56803 m
.94218 .63605 L
s
.87415 .56803 m
.80612 .63605 L
s
.94218 .63605 m
.87415 .70408 L
s
.2619 .09184 m
.32993 .15986 L
s
.2619 .09184 m
.19388 .15986 L
s
.32993 .15986 m
.39796 .22789 L
s
.32993 .15986 m
.2619 .22789 L
s
.39796 .22789 m
.46599 .29592 L
s
.39796 .22789 m
.32993 .29592 L
s
.46599 .29592 m
.53401 .36395 L
s
.46599 .29592 m
.39796 .36395 L
s
.53401 .36395 m
.60204 .43197 L
s
.53401 .36395 m
.46599 .43197 L
s
.60204 .43197 m
.67007 .5 L
s
.60204 .43197 m
.53401 .5 L
s
.67007 .5 m
.7381 .56803 L
s
.67007 .5 m
.60204 .56803 L
s
.7381 .56803 m
.80612 .63605 L
s
.7381 .56803 m
.67007 .63605 L
s
.80612 .63605 m
.87415 .70408 L
s
.80612 .63605 m
.7381 .70408 L
s
.87415 .70408 m
.80612 .77211 L
s
.19388 .15986 m
.2619 .22789 L
s
.19388 .15986 m
.12585 .22789 L
s
.2619 .22789 m
.32993 .29592 L
s
.2619 .22789 m
.19388 .29592 L
s
.32993 .29592 m
.39796 .36395 L
s
.32993 .29592 m
.2619 .36395 L
s
.39796 .36395 m
.46599 .43197 L
s
.39796 .36395 m
.32993 .43197 L
s
.46599 .43197 m
.53401 .5 L
s
.46599 .43197 m
.39796 .5 L
s
.53401 .5 m
.60204 .56803 L
s
.53401 .5 m
.46599 .56803 L
s
.60204 .56803 m
.67007 .63605 L
s
.60204 .56803 m
.53401 .63605 L
s
.67007 .63605 m
.7381 .70408 L
s
.67007 .63605 m
.60204 .70408 L
s
.7381 .70408 m
.80612 .77211 L
s
.7381 .70408 m
.67007 .77211 L
s
.80612 .77211 m
.7381 .84014 L
s
.12585 .22789 m
.19388 .29592 L
s
.19388 .29592 m
.2619 .36395 L
s
.19388 .29592 m
.12585 .36395 L
s
.2619 .36395 m
.32993 .43197 L
s
.2619 .36395 m
.19388 .43197 L
s
.32993 .43197 m
.39796 .5 L
s
.32993 .43197 m
.2619 .5 L
s
.39796 .5 m
.46599 .56803 L
s
.39796 .5 m
.32993 .56803 L
s
.46599 .56803 m
.53401 .63605 L
s
.46599 .56803 m
.39796 .63605 L
s
.53401 .63605 m
.60204 .70408 L
s
.53401 .63605 m
.46599 .70408 L
s
.60204 .70408 m
.67007 .77211 L
s
.60204 .70408 m
.53401 .77211 L
s
.67007 .77211 m
.7381 .84014 L
s
.67007 .77211 m
.60204 .84014 L
s
.7381 .84014 m
.67007 .90816 L
s
.12585 .36395 m
.19388 .43197 L
s
.12585 .36395 m
.05782 .43197 L
s
.19388 .43197 m
.2619 .5 L
s
.19388 .43197 m
.12585 .5 L
s
.2619 .5 m
.32993 .56803 L
s
.2619 .5 m
.19388 .56803 L
s
.32993 .56803 m
.39796 .63605 L
s
.32993 .56803 m
.2619 .63605 L
s
.39796 .63605 m
.46599 .70408 L
s
.39796 .63605 m
.32993 .70408 L
s
.46599 .70408 m
.53401 .77211 L
s
.46599 .70408 m
.39796 .77211 L
s
.53401 .77211 m
.60204 .84014 L
s
.53401 .77211 m
.46599 .84014 L
s
.60204 .84014 m
.67007 .90816 L
s
.60204 .84014 m
.53401 .90816 L
s
.05782 .43197 m
.12585 .5 L
s
.12585 .5 m
.19388 .56803 L
s
.12585 .5 m
.05782 .56803 L
s
.19388 .56803 m
.2619 .63605 L
s
.19388 .56803 m
.12585 .63605 L
s
.2619 .63605 m
.32993 .70408 L
s
.2619 .63605 m
.19388 .70408 L
s
.32993 .70408 m
.39796 .77211 L
s
.32993 .70408 m
.2619 .77211 L
s
.39796 .77211 m
.46599 .84014 L
s
.39796 .77211 m
.32993 .84014 L
s
.46599 .84014 m
.53401 .90816 L
s
.46599 .84014 m
.39796 .90816 L
s
.53401 .90816 m
.46599 .97619 L
s
.05782 .56803 m
.12585 .63605 L
s
.12585 .63605 m
.19388 .70408 L
s
.19388 .70408 m
.2619 .77211 L
s
.19388 .70408 m
.12585 .77211 L
s
.2619 .77211 m
.32993 .84014 L
s
.2619 .77211 m
.19388 .84014 L
s
.32993 .84014 m
.39796 .90816 L
s
.32993 .84014 m
.2619 .90816 L
s
.39796 .90816 m
.46599 .97619 L
s
.12585 .77211 m
.19388 .84014 L
s
.19388 .84014 m
.2619 .90816 L
s
.7381 .09184 m
.80612 .15986 L
s
.7381 .09184 m
.67007 .15986 L
s
.80612 .15986 m
.87415 .22789 L
s
.80612 .15986 m
.7381 .22789 L
s
.87415 .22789 m
.80612 .29592 L
s
.53401 .02381 m
.60204 .09184 L
s
.53401 .02381 m
.46599 .09184 L
s
.60204 .09184 m
.67007 .15986 L
s
.60204 .09184 m
.53401 .15986 L
s
.67007 .15986 m
.7381 .22789 L
s
.67007 .15986 m
.60204 .22789 L
s
.7381 .22789 m
.80612 .29592 L
s
.7381 .22789 m
.67007 .29592 L
s
.80612 .29592 m
.87415 .36395 L
s
.80612 .29592 m
.7381 .36395 L
s
.87415 .36395 m
.94218 .43197 L
s
.87415 .36395 m
.80612 .43197 L
s
.94218 .43197 m
.87415 .5 L
s
.46599 .09184 m
.53401 .15986 L
s
.46599 .09184 m
.39796 .15986 L
s
.53401 .15986 m
.60204 .22789 L
s
.53401 .15986 m
.46599 .22789 L
s
.60204 .22789 m
.67007 .29592 L
s
.60204 .22789 m
.53401 .29592 L
s
.67007 .29592 m
.7381 .36395 L
s
.67007 .29592 m
.60204 .36395 L
s
.7381 .36395 m
.80612 .43197 L
s
.7381 .36395 m
.67007 .43197 L
s
.80612 .43197 m
.87415 .5 L
s
.80612 .43197 m
.7381 .5 L
s
.87415 .5 m
.94218 .56803 L
s
.87415 .5 m
.80612 .56803 L
s
.94218 .56803 m
.87415 .63605 L
s
.32993 .09184 m
.39796 .15986 L
s
.32993 .09184 m
.2619 .15986 L
s
.39796 .15986 m
.46599 .22789 L
s
.39796 .15986 m
.32993 .22789 L
s
.46599 .22789 m
.53401 .29592 L
s
.46599 .22789 m
.39796 .29592 L
s
.53401 .29592 m
.60204 .36395 L
s
.53401 .29592 m
.46599 .36395 L
s
.60204 .36395 m
.67007 .43197 L
s
.60204 .36395 m
.53401 .43197 L
s
.67007 .43197 m
.7381 .5 L
s
.67007 .43197 m
.60204 .5 L
s
.7381 .5 m
.80612 .56803 L
s
.7381 .5 m
.67007 .56803 L
s
.80612 .56803 m
.87415 .63605 L
s
.80612 .56803 m
.7381 .63605 L
s
.87415 .63605 m
.80612 .70408 L
s
.2619 .15986 m
.32993 .22789 L
s
.2619 .15986 m
.19388 .22789 L
s
.32993 .22789 m
.39796 .29592 L
s
.32993 .22789 m
.2619 .29592 L
s
.39796 .29592 m
.46599 .36395 L
s
.39796 .29592 m
.32993 .36395 L
s
.46599 .36395 m
.53401 .43197 L
s
.46599 .36395 m
.39796 .43197 L
s
.53401 .43197 m
.60204 .5 L
s
.53401 .43197 m
.46599 .5 L
s
.60204 .5 m
.67007 .56803 L
s
.60204 .5 m
.53401 .56803 L
s
.67007 .56803 m
.7381 .63605 L
s
.67007 .56803 m
.60204 .63605 L
s
.7381 .63605 m
.80612 .70408 L
s
.7381 .63605 m
.67007 .70408 L
s
.80612 .70408 m
.87415 .77211 L
s
.80612 .70408 m
.7381 .77211 L
s
.87415 .77211 m
.80612 .84014 L
s
.19388 .22789 m
.2619 .29592 L
s
.19388 .22789 m
.12585 .29592 L
s
.2619 .29592 m
.32993 .36395 L
s
.2619 .29592 m
.19388 .36395 L
s
.32993 .36395 m
.39796 .43197 L
s
.32993 .36395 m
.2619 .43197 L
s
.39796 .43197 m
.46599 .5 L
s
.39796 .43197 m
.32993 .5 L
s
.46599 .5 m
.53401 .56803 L
s
.46599 .5 m
.39796 .56803 L
s
.53401 .56803 m
.60204 .63605 L
s
.53401 .56803 m
.46599 .63605 L
s
.60204 .63605 m
.67007 .70408 L
s
.60204 .63605 m
.53401 .70408 L
s
.67007 .70408 m
.7381 .77211 L
s
.67007 .70408 m
.60204 .77211 L
s
.7381 .77211 m
.80612 .84014 L
s
.7381 .77211 m
.67007 .84014 L
s
.80612 .84014 m
.7381 .90816 L
s
.12585 .29592 m
.19388 .36395 L
s
.12585 .29592 m
.05782 .36395 L
s
.19388 .36395 m
.2619 .43197 L
s
.19388 .36395 m
.12585 .43197 L
s
.2619 .43197 m
.32993 .5 L
s
.2619 .43197 m
.19388 .5 L
s
.32993 .5 m
.39796 .56803 L
s
.32993 .5 m
.2619 .56803 L
s
.39796 .56803 m
.46599 .63605 L
s
.39796 .56803 m
.32993 .63605 L
s
.46599 .63605 m
.53401 .70408 L
s
.46599 .63605 m
.39796 .70408 L
s
.53401 .70408 m
.60204 .77211 L
s
.53401 .70408 m
.46599 .77211 L
s
.60204 .77211 m
.67007 .84014 L
s
.60204 .77211 m
.53401 .84014 L
s
.67007 .84014 m
.7381 .90816 L
s
.67007 .84014 m
.60204 .90816 L
s
.05782 .36395 m
.12585 .43197 L
s
.12585 .43197 m
.19388 .5 L
s
.12585 .43197 m
.05782 .5 L
s
.19388 .5 m
.2619 .56803 L
s
.19388 .5 m
.12585 .56803 L
s
.2619 .56803 m
.32993 .63605 L
s
.2619 .56803 m
.19388 .63605 L
s
.32993 .63605 m
.39796 .70408 L
s
.32993 .63605 m
.2619 .70408 L
s
.39796 .70408 m
.46599 .77211 L
s
.39796 .70408 m
.32993 .77211 L
s
.46599 .77211 m
.53401 .84014 L
s
.46599 .77211 m
.39796 .84014 L
s
.53401 .84014 m
.60204 .90816 L
s
.53401 .84014 m
.46599 .90816 L
s
.60204 .90816 m
.53401 .97619 L
s
.05782 .5 m
.12585 .56803 L
s
.12585 .56803 m
.19388 .63605 L
s
.12585 .56803 m
.05782 .63605 L
s
.19388 .63605 m
.2619 .70408 L
s
.19388 .63605 m
.12585 .70408 L
s
.2619 .70408 m
.32993 .77211 L
s
.2619 .70408 m
.19388 .77211 L
s
.32993 .77211 m
.39796 .84014 L
s
.32993 .77211 m
.2619 .84014 L
s
.39796 .84014 m
.46599 .90816 L
s
.39796 .84014 m
.32993 .90816 L
s
.46599 .90816 m
.53401 .97619 L
s
.05782 .63605 m
.12585 .70408 L
s
.12585 .70408 m
.19388 .77211 L
s
.19388 .77211 m
.2619 .84014 L
s
.2619 .84014 m
.32993 .90816 L
s
.63605 .05782 m
.70408 .12585 L
s
.63605 .05782 m
.56803 .12585 L
s
.70408 .12585 m
.77211 .19388 L
s
.70408 .12585 m
.63605 .19388 L
s
.77211 .19388 m
.84014 .2619 L
s
.77211 .19388 m
.70408 .2619 L
s
.84014 .2619 m
.90816 .32993 L
s
.84014 .2619 m
.77211 .32993 L
s
.90816 .32993 m
.84014 .39796 L
s
.5 .05782 m
.56803 .12585 L
s
.5 .05782 m
.43197 .12585 L
s
.56803 .12585 m
.63605 .19388 L
s
.56803 .12585 m
.5 .19388 L
s
.63605 .19388 m
.70408 .2619 L
s
.63605 .19388 m
.56803 .2619 L
s
.70408 .2619 m
.77211 .32993 L
s
.70408 .2619 m
.63605 .32993 L
s
.77211 .32993 m
.84014 .39796 L
s
.77211 .32993 m
.70408 .39796 L
s
.84014 .39796 m
.90816 .46599 L
s
.84014 .39796 m
.77211 .46599 L
s
.90816 .46599 m
.97619 .53401 L
s
.90816 .46599 m
.84014 .53401 L
s
.97619 .53401 m
.90816 .60204 L
s
.36395 .05782 m
.43197 .12585 L
s
.36395 .05782 m
.29592 .12585 L
s
.43197 .12585 m
.5 .19388 L
s
.43197 .12585 m
.36395 .19388 L
s
.5 .19388 m
.56803 .2619 L
s
.5 .19388 m
.43197 .2619 L
s
.56803 .2619 m
.63605 .32993 L
s
.56803 .2619 m
.5 .32993 L
s
.63605 .32993 m
.70408 .39796 L
s
.63605 .32993 m
.56803 .39796 L
s
.70408 .39796 m
.77211 .46599 L
s
.70408 .39796 m
.63605 .46599 L
s
.77211 .46599 m
.84014 .53401 L
s
.77211 .46599 m
.70408 .53401 L
s
.84014 .53401 m
.90816 .60204 L
s
.84014 .53401 m
.77211 .60204 L
s
.90816 .60204 m
.84014 .67007 L
s
.29592 .12585 m
.36395 .19388 L
s
.29592 .12585 m
.22789 .19388 L
s
.36395 .19388 m
.43197 .2619 L
s
.36395 .19388 m
.29592 .2619 L
s
.43197 .2619 m
.5 .32993 L
s
.43197 .2619 m
.36395 .32993 L
s
.5 .32993 m
.56803 .39796 L
s
.5 .32993 m
.43197 .39796 L
s
.56803 .39796 m
.63605 .46599 L
s
.56803 .39796 m
.5 .46599 L
s
.63605 .46599 m
.70408 .53401 L
s
.63605 .46599 m
.56803 .53401 L
s
.70408 .53401 m
.77211 .60204 L
s
.70408 .53401 m
.63605 .60204 L
s
.77211 .60204 m
.84014 .67007 L
s
.77211 .60204 m
.70408 .67007 L
s
.84014 .67007 m
.90816 .7381 L
s
.84014 .67007 m
.77211 .7381 L
s
.90816 .7381 m
.84014 .80612 L
s
.22789 .19388 m
.29592 .2619 L
s
.22789 .19388 m
.15986 .2619 L
s
.29592 .2619 m
.36395 .32993 L
s
.29592 .2619 m
.22789 .32993 L
s
.36395 .32993 m
.43197 .39796 L
s
.36395 .32993 m
.29592 .39796 L
s
.43197 .39796 m
.5 .46599 L
s
.43197 .39796 m
.36395 .46599 L
s
.5 .46599 m
.56803 .53401 L
s
.5 .46599 m
.43197 .53401 L
s
.56803 .53401 m
.63605 .60204 L
s
.56803 .53401 m
.5 .60204 L
s
.63605 .60204 m
.70408 .67007 L
s
.63605 .60204 m
.56803 .67007 L
s
.70408 .67007 m
.77211 .7381 L
s
.70408 .67007 m
.63605 .7381 L
s
.77211 .7381 m
.84014 .80612 L
s
.77211 .7381 m
.70408 .80612 L
s
.84014 .80612 m
.77211 .87415 L
s
.15986 .2619 m
.22789 .32993 L
s
.15986 .2619 m
.09184 .32993 L
s
.22789 .32993 m
.29592 .39796 L
s
.22789 .32993 m
.15986 .39796 L
s
.29592 .39796 m
.36395 .46599 L
s
.29592 .39796 m
.22789 .46599 L
s
.36395 .46599 m
.43197 .53401 L
s
.36395 .46599 m
.29592 .53401 L
s
.43197 .53401 m
.5 .60204 L
s
.43197 .53401 m
.36395 .60204 L
s
.5 .60204 m
.56803 .67007 L
s
.5 .60204 m
.43197 .67007 L
s
.56803 .67007 m
.63605 .7381 L
s
.56803 .67007 m
.5 .7381 L
s
.63605 .7381 m
.70408 .80612 L
s
.63605 .7381 m
.56803 .80612 L
s
.70408 .80612 m
.77211 .87415 L
s
.70408 .80612 m
.63605 .87415 L
s
.09184 .32993 m
.15986 .39796 L
s
.15986 .39796 m
.22789 .46599 L
s
.15986 .39796 m
.09184 .46599 L
s
.22789 .46599 m
.29592 .53401 L
s
.22789 .46599 m
.15986 .53401 L
s
.29592 .53401 m
.36395 .60204 L
s
.29592 .53401 m
.22789 .60204 L
s
.36395 .60204 m
.43197 .67007 L
s
.36395 .60204 m
.29592 .67007 L
s
.43197 .67007 m
.5 .7381 L
s
.43197 .67007 m
.36395 .7381 L
s
.5 .7381 m
.56803 .80612 L
s
.5 .7381 m
.43197 .80612 L
s
.56803 .80612 m
.63605 .87415 L
s
.56803 .80612 m
.5 .87415 L
s
.63605 .87415 m
.56803 .94218 L
s
.09184 .46599 m
.15986 .53401 L
s
.09184 .46599 m
.02381 .53401 L
s
.15986 .53401 m
.22789 .60204 L
s
.15986 .53401 m
.09184 .60204 L
s
.22789 .60204 m
.29592 .67007 L
s
.22789 .60204 m
.15986 .67007 L
s
.29592 .67007 m
.36395 .7381 L
s
.29592 .67007 m
.22789 .7381 L
s
.36395 .7381 m
.43197 .80612 L
s
.36395 .7381 m
.29592 .80612 L
s
.43197 .80612 m
.5 .87415 L
s
.43197 .80612 m
.36395 .87415 L
s
.5 .87415 m
.56803 .94218 L
s
.5 .87415 m
.43197 .94218 L
s
.02381 .53401 m
.09184 .60204 L
s
.09184 .60204 m
.15986 .67007 L
s
.15986 .67007 m
.22789 .7381 L
s
.15986 .67007 m
.09184 .7381 L
s
.22789 .7381 m
.29592 .80612 L
s
.22789 .7381 m
.15986 .80612 L
s
.29592 .80612 m
.36395 .87415 L
s
.29592 .80612 m
.22789 .87415 L
s
.36395 .87415 m
.43197 .94218 L
s
.09184 .7381 m
.15986 .80612 L
s
.15986 .80612 m
.22789 .87415 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000180P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;RLW9b40<?oo_`00?g=cLda<C820P8NZb/kMjT]OLIFO_Ooo7YF<W];>eU1;EK:_]Bl]<gmo
OiB;WMKBg2XX;H=kRhjYUM3KddiMD^GQY9no_m[ViUY]KD=EIB4Z<M_Vkl?Ei6F0V;2^]4U5CX61PFYo
L4mOGbL_;n;/k<oOggN?ShRZVHEhU000O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o
002o?`2oO`2o_`2oo`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmo
Ocmo_cmoocno03no?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?glo
Oglo_gloogmo07mo?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0
_kl0oklo0;lo?kloOklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo
_kooool0?ol0Ool0_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo
?oooOlS3cdDnCFmlS[g3bcU0B]C>N7j0VLG6dD52Cf]]PW5VO]_Ggd8lBVIbVOoo0_oo1mWIhEiPLko0
c3m0C1lO9FAJKk>ic=;EhC<iC1TL9DaELeioI[C3]c11=?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L008D700<01`L04@L00`071`241`00N@L]07X7001j1`0400L700D700D01`L7
000?1`0500L71`001@L010071`1k1`00N`L200D700<01`L00`L00`071`0;1`0300L700<700<01`L0
0`L207`7001k1`8010L00`071`051`0300L700T700<01`L01@L00`071`021`80O0L007X700@01`L0
0PL00`071`071`0300L700L700<01`L01`L010071`021`0300L707T7001/1dL0K@L006`700<01`L0
2@L00`0700031`8020L01@071`L000D700D01`L700081`800`L00`07000;1`0300L706/7001T1`03
00L700D700<01`L00PL00`071`031`0400L7008700@01`L01`L00`071`021`0500L71`0010L00`07
1`051`0400L7008700@01`L01@L00`071`021`0300L700D700<01`L0H`L006<70P071`0400L71`80
0`L200<700<01`0010L00`0700041`0300L700<700<01`001@L00`071`021`0300L000@700<01`00
0`L200<70P031`0300L700D70P1T1`00HPL00`0700031`0500L71`000PL00`0700021`8010L300D7
0P041`0300L700@700<01`L010L00`071`021`801@L300@70P021`0300L0008700D01`L700031`03
00L006<7001P1el0H@L005l70P031`0300L000<700@01`000PL400031`0700870P021`0400L70087
0P0010L01`041`0500L71`0010L0100700L2008700@01`L00PL200<700<01`000`021`8000<700L0
0PL00`0700031`80H0L005h70P041`801@L200@70P021`0300L700<00`L200<700<01`000PL01@07
1`L000D700D01`L700021`0300L000<70P031`<00PL00`071`0200@70P051`8010L205l7001M1`80
1@L00`071`041`800`L3008700H01`001`031`800`L200041`07008700<01`L01@L01`071`0700L0
0P031`800`L01P07000700870`031`801PL00`071`031`80GPL00587N`1C1`00D`L010071`041`80
1@L00`0700041`0500L700L00P0010L01`L300<700@01`000`L300@70P0;1`8010L300<70P000`L0
1`021`<00PL01P070007008700<01`L00PL00`0700051`8010L010071`1D1`00E0L200@70P051`04
00L700<700@01`L7100010L01`L200@70`041`<010L200/70P041`<010L300@70P021`0300L000<0
0`L01@071`L0008700<01`L00`L200@70P1E1`00E0L200<70P051`0500L71`000PL00`071`021`80
0PL200031`0000800`L300<700@01`L00`L200031`0700P700@01`000`L010071`031`<00`L40003
1`0000870P041`0400L700<700<01`L00`L200<70P1E1`00D`L01@071`0700801@L00`071`021`03
00L000@70P041`<000D700L01`02008700<01`000`L200041`07008700<01`000`L00`0700021`04
00L01`800`L00`0700021`8000D700L01`0300@70P041`0300L000@700<01`L00`L200051`071`00
E0L004/700<01`L00`Mm00D700<01`L0BPL004X700<01`0010L00`071`021`<010L00`0700041`03
00L700870P000`L01`031`<000<700L010021`0300L000<70P0010L01`021`0300L000<700<01`00
0PL0100700L200<700<01`000PL400031`0700<010L0100700041`0300L7008700<01`0010L300@7
00<01`L00PL00`07001;1`00B@L01@071`L000870P031`0500L71`000PL00`071`0200870P031`80
0PL010071`L200031`0000<00PL00`0700021`800PL010071`L200041`071`8000<700000PL01007
00031`0300L700800PL00`0700021`D000<700000`L00`071`0200<70P021`800PL010071`021`80
0`L2008700D01`L7001:1`00B0L00`071`031`8000D700L700051`800`L01P07000700<700D01`L7
00021`0300L000870`031`800`L00`07000200@70P031`0500L01`000`L200@70`000`L01`021`80
0`L3008700<01`000PL01@071`L000<700H01`001`031`801@L01@071`0700801@L00`071`171`00
A`L00`071`041`8000@700L01PL200<700H01`001`021`0300L7008700<01`000PL010071`L200<7
00<01`000PL00`07000200@70P031`8000<700000`L200@70`000`L01`0200031`0700870P031`06
00L700L010L01@071`07008000<700L00PL200H700@01`070P061`0300L704H7000n1`0300L700D7
00<01`00SP000`L01`061`0300L703d7000m1`801PL01P071`L01`8010L00`071`041`0300L70087
00<01`0010L200H700@01`L70P001@L01`07008000<700L00`L010071`L200041`0700870`031`<0
0PL0100700L200<700<01`L00PL02@07000700L01`0200<700<01`L010L200@700<01`0010L00`07
1`041`0300L700870P000`L01`021`0300L700@70P0n1`00?0L00`0700051`0300L700<70`031`<0
10L00`071`041`8010L200D70P041`800PL00`07000300<70`021`0300L0008700<01`L00`031`<0
0PL01P071`0700870`031`@000@700L70P041`801@L200@70P061`0300L700870`031`<01@L00`07
1`031`0300L003d7000k1`0400L700@700<01`L00`L4008700D01`0700021`0300L700@700<01`00
0`L200031`07008700<01`000`L300870P021`800PL01P0700L01`8000H700L01`021`0500L71`00
0PL00`07000200091`001`0700L000870P021`800PL200@700<01`000`L0100700021`8000<700L0
1@L020071`0700L00PL400D700<01`L00PL010071`0l1`00>PN[03/7000i1`800`L0100700051`80
0`L200<700<01`L00P051`0600L71`070P0010L01`L3008700H01`001`021`8010L3008700<01`L0
0P041`800`L500<70P041`800PL00`071`0300@70P021`0600L000L00PL3008700H01`001`031`03
00L700<70P021`0400L71`800`L200D70P000`L01`021`80>PL003P70P041`<000<700L00PL01007
1`021`0300L0008700@01`070P031`0300L700870P021`8000@700070P001@L00007008000<700L0
0P031`0900L000L01`0700800PL400870P000`L000021`@00PL200051`0700L00P000`L01`021`80
00<700L00P001@L00007008000@700070P021`8010L010071`L200041`07008700<01`000PL01007
1`031`0300L0008010L203T7000g1`801@L200<700<01`0010L3008700@01`000`L200031`0700@7
00<01`L00PL300<710031`800PL300031`00008710021`0700L000L01`0400<710000`L01`020004
1`071`@00PL200041`0000870P031`@00`L300@700<01`L00`L0100700031`8000@700L70`041`03
00L000<70P051`80>0L003D7]@0f1`00=@L200D70`041`0300L000<700@01`L00`L200D70`031`03
00L000<70P000`L01`021`@00PL200051`0700L010031`<00PL200870P000`L0000200<710000`L0
00021`800PL300<710001@L01`0700800PL400<700@01`000`L00`0700031`<01@L200<700@01`L0
0`L00`0700041`<01@L203H7000d1`801@L200031`0700870P021`0300L000<70P000`L01`0200<7
00<01`L00P001@L01`L000870`021`0500L000L01P021`<00PL2008700<01`0010041`<00PL20003
1`0000870`041`D000@700L70P021`<00PL600051`001`000PL3008700D01`L01`02008700@01`L7
0P000`L01`0200<700<01`000PL200<700@01`001@L203D7000c1`<010L2008700H01`L01`031`80
0`L00`0700021`0400L01`800`L200<700H01`001`031`800PL01P07000700<700<01`L00PL30087
00<01`000P041`800`L01@0700L000<70P041`<000@700L70`041`0600L71`070P0010L01`L200<7
00H01`001`031`800`L200041`07008700<01`000`L200<700<01`000PL00`071`0200@70`0d1`00
<PL200031`0700870P031`0300L0008700H01`L01`031`8000@700L00PL00`0700031`<00PL30087
00<01`L00`021`H00PL300<70`021`D00`L200041`071`8000<700000PL0100700031`D00PL300<7
0`021`H00PL3008700<01`L00`021`<00`L00`0700021`0400L01`800`L00`0700021`0600L700L0
0`L200<700@01`00<`L003470P021`0300L700800`NU00<70P021`0300L70080<PL0034700H01`L7
00L200D700<01`L00PL200<700<01`000P041`800`L300041`071`<010L300041`071`8010L20087
00<01`L00`021`<00`L400031`0700870P031`800`L00`07000300<70P031`<00PL00`071`0200@7
0P021`0300L0008010L3008700<01`000P031`8010L300031`0700870P041`0300L700<70P000`L0
1`021`0300L70307000`1`0300L700870P000`L01`031`<00`L00`071`021`0300L0008010L200<7
0`0010L01`L300@70`000`L01`0300@70`0010L01`L300870`031`@000L700L700L000<700<01`00
0PL00`07000300<70`021`<00PL00`07000200@70`000`L01`0300@70`021`0300L000800`L200@7
0`000`L01`031`0400L71`<010L400@700<01`L0;`L002l700<01`L00`L01@071`L0008700H01`07
00L200@70P021`800PL200051`071`000PL200041`071`800PL2008710000`L000021`8000H70000
1`021`0500L000L00P021`0400L71`8000@700L70P000`L000021`0400L000<700<01`L00P001@L0
00L0008700<01`000P000`L000021`8000<700000P021`800PL2008700@01`000PL01@071`070080
0PL200870P041`8000H700L01`021`0500L71`001@L00`071`0^1`00;@L200D70P041j/010L200D7
00<01`L0;@L002`70P051`0300L000@70P021`0400L01`800`L200<700L01`001`0700@00`L200<7
00H01`001`021`<00PL01P07000700<70P031`<00PL00`07000200@70P031`8000<700000`L200@7
0`0010L01`L300<70P031`0600L000L00PL3008700H01`001`031`800`L400031`07008000<700L0
0PL200<70P0010L01`021`8010L00`0700051`80;@L002/70P051`0400L700<700D01`L01`0200<7
00D01`L01`0200870P000`L00003008700<01`L00P0010L01`L300041`001`<000<700L00P021`80
0PL400031`00008700@01`000PL010071`L200051`071`000`L01@071`0700800`L00`071`020004
1`071`8000<700000P021`800PL200031`0700<000@700070`021`0400L0008700<01`L01@000`L0
00021`8000D700L700031`8000D700L700031`0400L700D70P0/1`00:PL200D700D01`L700021`03
00L700870P041`<00PL300031`0700870`031`<000H700L700L200<70`0010L01`L200@700H01`07
00L400<70P031`8000@700L00PL300<70`021`0400L01`800`L200<710001PL01`0700@70P021`03
00L000800`L200061`071`070`031`<00`L00`07000200870`041`8010L010071`031`0300L700<7
0P0[1`00:@L200D700<01`L00PL00`0700051`8010L3008700<01`000P031`<00`L300031`070087
0P041`800PL00`071`0200@70P021`0300L000<00`L200<700<01`000PL00`071`0300<70`021`06
00L700L00`L200<7100010L01`L200@70P021`0300L7008010L200<700<01`000P031`<00`L30004
1`071`<010L200D700<01`0010L00`071`031`80:PL002L7d@0X1`009`L200D700<01`L010L00`07
1`031`0700L700L01`0200<70`021`@000<700L010031`0500L000L00P0010L000021`<00PL01007
00L200031`0000800`L3008700D01`0700031`<00`L200031`0000<70`031`0500L01`000PL300<7
10001`L000L01`000PL300870`0010L000L200031`07008710000`L01`0400870`031`8000@700L0
0PL00`071`031`0300L700@700<01`L00`L202P7000V1`801@L200D70P041`0500L71`000PL00`07
00041`0400L71`<00PL00`071`0300<70`021`0600L000L00`L01@071`L0008700<01`000PL200@7
0`021`0300L7008010L00`071`021`0500L01`0010L00`071`021`800PL00`071`0300@70P021`03
00L0008700D01`L700031`0600L000L00PL300<70`021`0300L700<00`L00`071`021`0300L00087
00D01`L700041`801@L200D70P0W1`009@L300@70`041`0300L000<700<01`L00PL0100700L200<7
0`021`@000<700L010031`<00PL400041`071`<00PL0100700L200031`0000800`L3008700D01`07
00031`<00`L200031`0000<70`031`0500L01`000PL300<710001`L000L01`000PL3008700<01`00
0`021`<00`L400031`0700@00PL300<70P0010L01`041`0700L71`0700041`<010L302H7000T1`80
00<700L00PL2008700@01`L00PL010071`051`800`L01`071`0700L00`021`D00PL00`071`020087
00@01`000PL200071`0700L01`0200<70`001@L0000700800PL0100700021`8000H700L01`021`05
00L71`000PL01P0700L01`800PL200041`071`8000D700001`0300<70P001`L01`0700L00P021`80
00@700L70P021`0300L700D00PL300041`07008700@01`L70P051`0400L7008700@01`L00PL200<7
00@01`009@L002<70P021`0300L7008010L200<700<01`001@NU00D700<01`000`L200@70P021`03
00L7008090L002870P031`0400L000D70P031`801PL200@70`021`800PL010071`L300<70`0010L0
1`L300@70P021`0300L700800`L200051`0700L010031`800`L200041`0700870`031`<00PL01007
00L200<70P031`@000D700L01`0200<70P021`0300L7008010L3008700<01`000P031`<00`L00`07
1`0200870`041`801PL200<70P051`8000<700L00PL202<7000Q1`0300L000<70`051`8000D700L7
00061`0400L000<700H01`L01`031`8000<700000`021`0300L7008000@700070P021`8000L700L0
1`07008000@700000PL400031`00008700@01`000PL010071`L200051`071`000`L01@071`070080
0`L00`071`0200041`071`8000<700000P021`<000X7000700L01`070P021`8000@700070P021`03
00L700D000<700000`L00`0700021`0400L71`8000<700L01@L01@071`0700801@L300<700<01`00
8PL0020700@01`L00`L200<700D01`0700021`<010L2008700@01`070P031`800`L01`07000700L0
10031`<00PL01P07000700870`021`0600L000L00`L200<70`021`0300L0008010L200<70P000`L0
00031`8010L300041`071`<00`L200<700H01`001`021`<00PL01P07000700870`031`@000<700L0
0P000`L01`021`800`L200041`0700870P041`<00PL01@0700L000<70P031`0400L70247000O1n40
80L002<700<01`000P041`0700L01`0700021`0400L71`8000L700L01`07008000@700L70P021`80
0PL200031`0700800PL200041`071`800PL200870`021`800PL200031`0000<00PL300870P021`04
00L71`8000@700L70P000`L000021`0400L000<700<01`L00P021`<00PL500031`0000870P021`<0
0PL200870P021`0400L000870P000`L01`0200870P021`800PL02`07000700L01`0700800`L02P07
1`0700L01`041`<000<700L08`L002<70`000`L01`021`800PL300<70P0010L01`021`<00`L200<7
00<01`000P041`800`L5008700<01`0010L0100700L500@70`000`L01`04008700<01`000`L20004
1`07008700<01`000`L00`0700021`0400L01`800`L00`0700021`@000<700L00`041`D000@700L0
10L00`0700021`D00`L200@70`000`L01`021`800`L3008700@01`070P031`<00PL200<700<01`00
0P0T1`008`L2008700H01`L01`031`0300L7008700<01`000PL01@071`L000@70P031`0300L00080
10L200<70`000`L01`021`8010L2008700<01`000P041`800PL00`071`0300<70P031`0300L00087
00@01`L70P031`800`L01P071`0700<70P031`<00PL00`071`0200@70`0010L01`L200@70P031`03
00L000800`L200@70`000`L01`021`8010L01@071`L0008700<01`0010L01`071`L01`000PL00`07
1`0202@7000S1`0700L01`0700021`0300L700<00`L200041`0700870`021`8000H700L700L300<7
0P0010L01`L5008700<01`0010L0100700L500@70`000`L01`04008700<01`000`L200041`070087
00<01`000`L00`0700021`0400L01`800`L00`0700021`@000<700L00`041`D000@700L010L00`07
00021`D00PL0100700031`<000H700L700L200870`021`0400L01`800`L3008700X01`L01`0700L0
90L002870P021m<00PL202<7000Q1`0300L000<700<01`L00PL2008700<01`L00`041`800PL01P07
000700<70P031`<00PL00`071`0300<70P031`0600L000L00`L010071`L400041`071`<00`L30087
00<01`000P041`800`L01@0700L000<70P041`<000@700L70`031`<00PL00`07000300<700H01`L7
00L200031`0700870P031`<00PL00`071`0300<70P031`0600L000L00PL200@70`021`0300L70080
10L01`071`L01`008PL0020700@01`L00PL300<700D01`L700021`<010L200870P021`800`L200<7
100010L01`021`0400L71`<00PL01P07000700870`021`0600L000L00`L200<700L01`001`0700<0
10L200<70P000`L000031`8010L300031`07008000<700L00PL200<700H01`001`021`<00PL01P07
000700870`031`0700L700L01`0400<70P031`800PL200870P041`<00PL01@071`L000<70`021`04
00L70247000O1`0<00L71`0700L01`070P031`0300L0008700@01`L70P0010L01`041`0500L700L0
0P021`0300L700@00`L200041`001`8000<700000PL200071`0700L01`0200041`00008710000`L0
00021`@00PL010071`L200051`071`000`L01@071`0700800`L00`071`0400870P000`L000020087
0`002PL000L01`0700L200870P0010L000L200031`0000<710021`0300L7008000D700L700041`04
00L01`800`L01P071`0700<70P0020L01`0700L00`L00`071`0N1`007PL00`071`021`800PL01P07
1`0700<70P031`8000@700L00PL200@70`021`0300L000800`L200@700D01`0700021`<010L20087
00<01`L00P031`8000D700L01`0200031`0700870P031`8000@700L00PL300<70`021`0400L01`80
0`L200<700T01`001`0700L00P031`800PL00`071`0200@70`021`0500L01`0010L200<70`0010L0
1`L300@70P021`0400L01`800`L200<700<01`000PL00`071`0200@700<01`L07@L001d700<01`00
0`L2008700<01`00c00010L01`L200<700<01`007PL001`700<01`L00P001PL000L01`800`L00`07
1`0200041`001`8000<700L00P021`800`L01@071`0700800PL01@071`0700<00PL01@071`L00087
00@01`000PL200071`0700L01`0200<70`000`L000021`800PL00`07000200091`001`0700L00087
00D01`L700021`0600L01`070P001PL0000700870P021`8000@700000`L200071`0700L01`020087
0P001@L01`L000<700<01`L00`001@L01`L000870P001@L01`L000<70P021`8000<700L00P0010L0
00L2008700@01`L70P000`L01`0200031`00008700<01`L06`L001/700H01`L700L300870P041`<0
00@700L70`031`800`L00`07000300<70P031`<00PL00`07000300<70`021`@000@700L70`021`04
00L01`8000@7000010L3008700<01`000P031`<00`L500<70`031`<000@700L70`041`<000L70007
00L000870`021`0300L000<00PL300<7100010L01`L300<70P031`@000<700L00PL200<70`021`03
00L0008010L200870`000`L01`021`0300L701X7000J1`0300L700871@021`8010L300031`070087
0P031`800`L00`07000300<70P031`<00PL00`071`0300<70`021`0600L000L00PL3008700H01`L0
1`021`8010L3008700<01`L00P041`0300L700871@041`0300L700870P021`0300L700<010L20087
00<01`000PL00`071`03008700H01`001`021`<00`L3008700<01`L00`031`800`L400031`070087
0P031`800`L00`07000200@70P021`D010L00`071`0I1`006`L010071`OQ00<700<01`L06PL001`7
00@01`L00`L2008700@01`070P021`8000@700L710001@L01`0700800`L3008700<01`000P031`<0
0`L200031`0000<70P031`@000<700L010031`800PL300031`00008710021`@000D700L01`0200<7
0P001@L01`0700@00PL400870P0010L000021`800`L400031`0700@00`L200<70P000`L000031`<0
0`L300041`071`<00`L200051`0700L010021`0400L000870P0010L01`021`800`L010071`0M1`00
7@L300<700D01`0700021`0300L000<70P031`@000@700L70P041`<00PL00`07000200@700<01`L0
0PL300031`0700870P041`800PL00`071`0200@70P021`0600L000L00`L200<700H01`001`021`<0
0`L3008700H01`001`031`800`L01P07000700870P041`800PL00`071`0200@70P031`0300L00080
10L00`071`021`<000@700L70`041`800PL00`07000300<70P031`0300L0008700D01`0700031`<0
7PL001d70`021`800PL200031`0700800`L300870P001@L0000700<010L01@07000700800PL01007
1`L300<71@021`0400L00087100010L01`L300870P001@L01`0700@00`L300870P001@L0000700@0
0`L400051`0000L00P021`<00`L400051`0700L00P021`<00PL00`07000300870P0010L01`L500<7
0`031`0300L7008000D7000700041`<000D700001`0200870`031`8000<700L00P021`800PL301h7
000L1`0800L700L01`031`800`L00`071`0200031`0000800`L400031`0000870P021`<00`L20006
1`0700L00PL00`071`0200061`071`0710001`L0000700L01P021`<00PL2008700<01`0010031`@0
0PL200031`00008710031`D000@700L70P021`<00PL600031`0700<000<700000P001PL01`L01`80
0PL02@071`0700L01`0200<70`021`800PL200031`0000800`L400031`00008700@01`L70P031`05
00L01`000PL00`071`0K1`006PO[01/7000E1`0300L7008700<01`L00PL01@0700L000870P0010L0
1`L300031`0700@00`L400031`07008000H700L700L200870P0010L01`021`<00`L300870`000`L0
00031`800PL600870`031`<00PL500<710021`D00PL400<71@021`<00`L300871P021`800`L20004
1`0000870`031`<00PL0100700L200870P001PL01`L01`8000<700L010031`@000<700L00`021`04
00L0008700D01`0700041`0300L7008700<01`L050L001D70P021`800`L200870P0010L01`021`03
00L0008710021`8000D700001`0400870P0010L01`L300031`0700870P001@L01`L000870P0010L0
00L200<700<01`L010000`L000021`8000H700L01`021`0500L000L00P021`8000D700001`020004
1`001`8000@700070`000`L000021`8000D7000700021`0600L01`070P021`8000<700000P021`04
00L71`8000@700070P021`0500L700L00P031`0300L000800PL0100700021`@000D700001`020087
10021`0300L0008700@01`070P021`800`L200870P0F1`005@L01P070007008700<01`000`L20087
00@01`L70P031`800`L400041`071`8010L200<700<01`000P041`800`L300041`071`<010L30003
1`0700<010L2008700<01`L00`021`<00`L400041`071`<00`L3008700<01`000`031`<00PL30087
00<01`L00P041`<000<700L00`041`<00PL00`07000200<70P041`<000<700L00PL200@70P021`03
00L000<00`L200<70P031`0300L700800`L00`0700021`0600L000L05PL001D700P01`001`070087
00@01`L70`001`L01`L01`000`L200<7100010L01`L300<70P031`0300L0008010L200<70`0010L0
1`L300@70`000`L01`0300@70`0010L01`L300870`031`@000@700L70`031`<00PL00`07000300<7
0`021`<00PL00`07000200@70`000`L01`0300@70`021`0300L000800`L200@70`000`L01`021`80
0`L3008700<01`000`031`800`L00`0700021`0300L000800`L01`071`0700L00P000`L01`0E1`00
5@L2008710021`0300L7008000D700001`3=00051`0000L00P021`0300L700@00PL201H7000E1`03
00L700870P031`0500L01`000PL300<70`0010L01`L300@70P021`0300L000<00PL00`0700031`@0
00@700L70`031`800`L0100700L200870`021`@000@700L70`031`<00PL500@70`021`8000<70000
0PL300@71@021`<00`L3008700<01`000`021`<00PL200041`0700<70P031`<00PL00`07000300<7
00<01`000PL400041`071`8010L3008700<01`000P031`<00PL01@0700L000<70P041`0300L701@7
000E1`0400L71`<00`L2008700@01`L70P031`<000@700L70`041`800PL00`07000300<70P031`06
00L000L00PL300<70P031`0600L700L00`L2008700H01`001`031`800`L3008700<01`000P041`80
0`L01@0700L000<70P041`<000@700L70`031`800`L01P07000700870P031`0300L0008700@01`L7
0P031`<00PL01P07000700<70P031`@000@700L70P041`<00PL00`07000200<70P031`0300L70080
0`L300<700<01`L050L001D700<01`L00`001@L01`L000<700<01`L010021`0300L7008000D700L7
00031`8000<700L00`000`L000021`0300L000<70P001PL00007008700<01`L00P0020L01`L01`07
0P021`@000@700070`021`@000<700000PL01@07000700800`L200041`071`8000<700000PL01007
00031`8000D7000700021`8000<700000P021`<000@7000710021`8000@700L00PL0100700021`05
00L700L00`000`L000031`0300L000870P001`L0000700L00P031`0500L700L00P021`0300L700@0
0PL01@071`L0008700<01`000P021`0300L701@7000E1`0600L000L00PL300<700H01`0700O=0006
1`0700L00`L3008700H01`001`0F1`005@L3008700<01`L00`031`800PL00`071`0300<70P031`06
00L000L00PL200@70`021`0300L0008010L200<70`000`L01`021`8010L2008700<01`L00P041`80
0PL00`07000300<70P031`0600L000L00PL300<70`021`0600L000L00`L200<7100010L01`L200@7
0P021`0300L7008010L200<700<01`000P031`8010L300041`071`<010L2008700H01`001`031`80
0`L3008700<01`L00P031`<00PL00`071`0301H7000E1`800`L00`0700021`0500L71`000`L01007
00L200870P0010L01`L400031`0700@00`L01`07000700L00`031`@00PL00`071`0200<70P041`08
00L01`0700L200<70P021`<000<700000PL0100700021`@000<700L00P000`L01`021`0700L000L0
1`0400870P0010L01`L200041`0000870P031`8000P700L01`0700@70P031`800PL00`071`0400<7
0`000`L01`0200031`07008710000`L01`04008700@01`000PL200041`0700<700D01`L700021`03
00L000<70P0F1`0050L200@70P031`8000<700000`L200<70`001PL01`L01`800PL400051`0700L0
0P021`@00PL01`071`0700L010031`0500L700L00P021`800PL300870`001PL000L01`800`L30087
00@01`070P021`@00PL200031`00008710021`8000@700L00PL300<70P000`L01`0200041`000087
0`021`800PL200051`071`000`L400041`07008700<01`L010021`8000D700L01`0400870P001PL0
1`L01`<00`L200<70P000`L000031`8010L201D7000C1`<010L00`071`021`0500L01`000`L00`07
1`021`<000<700L00PL200@70P021`0600L700L00`L200<70`021`0300L700<00`L3008700H01`00
1`031`0600L71`070P0010L01`L200@70`021`0300L7008010L200<700D01`0700031`8010L20087
00<01`L00`041`800PL01P07000700<700H01`L700L200041`071`<00`L3008700<01`L00`031`80
0`L00`0700021`0300L7008010L200<700<01`000P041`0900L71`0700L000@700<01`L00PL301@7
000B1`8000<700L00PO]00<700@01`004`L001470P021`0800L700L01`021`0300L7008000@700L0
0`L200870P0010L000L200071`0000L01`0200<700D01`L01`0300061`071`070`021`0500L71`00
0PL0100700021`8000L700L01`0700800PL400031`0000870P021`0300L0008000@700070`001@L0
1`L000<700D01`L01`0300041`001`<000@700L70P021`8000<700000P021`8000L700L01`070080
0PL200051`071`000`L00`071`0300061`071`070`001@L01`L000<70P000`L01`0300041`001`80
00<700000PL200<700@01`070P021`0800L700L01`021`0300L700804PL0014700L01`L700L00087
00<01`L00`031`800PL00`071`0300<70`021`0600L000L00PL200@70`021`0300L000800`L300<7
0P000`L000031`8010L2008700<01`L00P041`800PL00`07000300<70`021`0600L000L00PL300<7
0`021`0600L000L00PL300<7100010L01`L200@70P021`0300L7008010L200<70P000`L000031`<0
0`L300041`071`<010L2008700H01`001`021`<00`L3008700<01`L00P031`<00PL01P071`0700<7
00<01`L040L001070P031`800`L00`071`0300<70P021`0600L000L00`L200<7100010L01`L200@7
0`021`0300L000800`L200@700D01`0700031`8010L2008700<01`L00P031`@000<700L00P000`L0
1`021`800`L400041`071`<00`L3008700<01`000`031`800`L01`07000700L010031`800PL00`07
1`0200@70P031`0500L01`0010L200<70`0010L01`L300@70P021`0300L000<00`L200<700H01`00
1`021`800`L3008700@01`L70P031`804@L000l700<01`000`L00`071`021`0300L0008700<01`L0
0P000`L01`03008700<01`L00P0010L01`L200870P000`L01`0200<700D01`L01`0200870P000`L0
000200<70P000`L000021`0400L000870P001`L01`0700L00P001@L0000700D000<700000PL40087
0P021`8000D700L700031`0500L700L00P021`800PL400870P000`L0000300051`0000L00P001`L0
1`0700L00P021`8000@700L70P000`L000031`@000<700000PL200051`071`000`L200031`070080
0PL2008700@01`000PL00`071`0300031`0700800PL01P071`0700@700L01`L700L00107000>1ol0
100?1`004@L01@0700L000@700<01`L00PL300041`071`8010L300041`071`<010L2008700H01`L0
1`031`800`L400041`071`<00`L200<700H01`001`021`800`L400041`071`8010L3008700<01`00
0P041`800`L01@0700L000<70P041`<000@700L70`041`800PL00`07000300<70P021`0600L000L0
0`L200<70`021`0300L000<00`L200<700<01`000PL00`071`0200@70`021`0300L0008010L20087
00<01`000P041`0300L7008700D01`07000B1`004@L2008700@01`L70P041`0300L7008000<70000
0P031`<000<700L00P000`L01`021`8000L700L01`0700800PL0100700021`8000@700000PL300<7
00<01`000PL200870P021`<00PL200870P000`L0000200<70`021`<000<700L00PL200041`071`80
00<700000PL0100700031`0300L000800PL300<710000`L000021`800PL300870P021`800PL00`07
00031`<00PL300031`0000870P0010L01`L200071`0700L01`0200<700L01`001`0700<00`L40003
1`00008700<01`L00PL200<700<01`L00P0B1`004@L01@071`L0008700<01`000PL300<70`001@L0
1`0700800PL400870P0010L01`021`<00`L3008700<01`000P031`8000@700L70P000`L000021`03
00L000@700@01`071@041`<000D700L01`02008700@01`000PL200041`07008700<01`000`L30087
00@01`070P021`8000@700L70P001@L01`0700<010L500041`0000@700<01`000PL200031`000087
00@01`000`L300071`071`0700031`<00PL0100700L2008710021`8000D700L01`0300<70P031`03
00L0008700D01`L7000B1`0040L200<700<01`000PL01P07000700<70P021`0300L70</00PL00`07
1`0200<700H01`001`021`0300L000<70P0A1`004@L010071`L200<70`021`0400L71`<000<700L0
10021`<00`L200041`07008710001@L000L0008700<01`000P041`<00PL5008700<01`0010L00`07
000300031`0000@70`000`L01`0400870`031`8000@700L00PL01@070007008000P700L700L01`80
0`L3008710000`L01`0300@70P000`L0000200031`0700<700<01`000PL500870`041`<000H700L7
00L200031`0000800PL0100700L200<70`021`@000<700L00`031`0300L700<00`L200<700<01`L0
40L001470P021`0300L700870P031`0300L7008000<700000`021`0300L0008000D700L700031`80
00D700L01`04008700@01`000PL200870P000`L0000200870P0010L01`L200870P021`800`L20087
0P000`L00003008700D01`001`02008700@01`L70P0010L01`L5008700@01`000`L00`071`020005
1`001`000PL500031`0000870P031`800PL200870P021`0400L0008710000`L000021`800PL20004
1`071`@000D700L01`0200<700D01`L01`0300041`071`D000<700000PL010071`L200@700<01`L0
0P0B1`004@L00`07000200<70P041`0500L01`000PL300<70`0010L01`L300@70P021`0300L000<0
0`L200<7100010L01`L300<70P031`0600L000L00PL30087100010L01`L300<70`021`0300L00080
10L200<71@031`8010L300041`071`<00`L3008700<01`000`021`<00PL01P07000700<70P031`<0
0PL00`07000300<70P031`@000@700L70P041`<00PL00`07000200<70`021`0500L01`0010L200<7
0`000`L01`0A1`0030Oo00P03@L000`700<01`L00PL2008700H01`001`041`0600L71`071@000`L0
00021`8000D700L700031`8000<700L00P031`8000<700L00P021`8000<700000`021`8000@70007
0P000`L000021`@000<700L0100010L000021`@000<700000PL0100700021`0400L71`8000<700L0
0P031`8000<700L00P031`0300L7008000@700L70P000`L0000200870`000`L0000200031`0700@0
0PL200041`001`8000<700000PL500031`0000870P000`L01`0200<70P000`L01`0200<700D01`L0
1`0200870P000`L0000300031`07008700<01`L00PL01P07000700870P041`0300L700/7000<1`03
00L7008700@01`L70`021`0400L71`800`L300031`0700@00`L200<70P0010L01`021`8010L30087
00D01`0700031`<00`L300041`071`<010L2008700<01`L00P031`8000D700L01`0400<70P031`80
00@700L00PL300<70`021`0400L01`800`L200<710001@L01`0700800`L2008700<01`L00P041`<0
0PL00`07000200<70`031`0500L01`000PL300@70P021`0400L01`800`L200<710000`L01`0300<7
0P031`0300L700<00`L00`071`021`0300L700/7000<1`0400L71`800`L3008700H01`L01`031`80
0PL00`07000300<70P031`0300L0008700<01`000P041`@000@700L70P031`<00`L500<70P031`<0
0PL00`071`0300<70P021`0300L000<00`L200<700<01`000PL00`07000300<710001`L01`L01`00
0`L200<7100010L01`L200<70`021`0300L700<00`L200<71@031`<00`L2008700<01`000`041`<0
00L700L700L000<70P031`@000@700L70P031`0300L0008700<01`L00`031`800`L00`071`0;1`00
30L01@071`07008000<700000PL01@0700L000870P021`0400L01`<000<700000PL200041`071`80
00<700L00`000`L000031`0300L700<000@700L00PL5008700<01`L00P021`0500L000L00`001`L0
1`0700L00`021`<000D700001`02008700@01`000PL200031`0700<00PL01@071`L000870`000`L0
1`0200870P0010L01`L200051`0000L00`021`<000L700L01`0700<000D7000700021`800PL00`07
1`05008700@01`070`021`0400L71`8000L700001`0700800PL0100700021`8000P700001`070087
0P021`0500L01`000PL200051`001`000PL00`071`0;1`0030L00`07003o00<000<700L030L000`7
00<01`L00PL500<70`031`0300L000800PL200@70`000`L01`021`800`L200<700<01`000`041`80
0PL3008700<01`L00`031`<00PL400041`071`<00PL00`071`0300870P041`<00PL00`071`0200<7
0P041`D010L200<70P021`0300L700<010L200870`021`0300L700<00PL00`07000300870`031`<0
0PL00`071`0300870P041`@000<700L00PL200<70P031`0300L0008010L200870`000`L01`021`<0
0`L500@700<01`L02`L000`700<01`L00PL2008700<01`L01@021`800PL0100700L200<700<01`00
0P021`0500L000L010021`<000<700000`L4000:1`071`0700L01`800`L01@071`07008000D70000
1`0500051`0700L00P000`L01`0200<700T01`001`0700L00P000`L0000200<70P000`L000031`@0
00P7000700L01`8000<700L00PL200031`07008000D700L01`0500051`0000L00P001@L01`L000<7
0P001PL01`07008700<01`000`031`8000@700000PL400051`001`000PL300031`0700870P0010L0
1`021`800PL5008700<01`L00P041`0300L700/7000<1`0400L71`800`L400031`07008000<700L0
0PL2008700@01`070P021`8000@700L710001@L01`0700800`L200051`0700L00`031`<00`L20003
1`0000<70P031`@000<700L010031`800PL300031`00008710021`@000D700L01`0200<70P001@L0
1`0700@00PL400870P0010L000021`800`L400031`0700@00`L200<70P000`L000031`<00`L30005
1`0700L00P031`8000D700L01`04008700@01`000PL200041`0700870P031`0700L000L01`0400<7
0P031`0300L700/7000<1`0300L70?l00P021`0300L700/7000<1`0600L700L00`L200051`0700L0
10021`8000L700001`0700800`L300870P001@L0000700@00`L400031`0000870P021`<00`L50004
1`001`800PL400031`0700@00PL200051`0000L010031`<00PL200051`0000L010031`@000D70000
1`0200870`031`@000D700001`02008710001@L01`0700800PL200041`001`D00`L300870P021`80
00<700000P031`@000D700001`0200870`031`8000<700L00`000`L000021`@000D700L01`0200<7
00<01`000PL00`071`0;1`0030L00`0700021`0300L700800`L400870`0010L01`L300<700<01`L0
0P000`L0000200<710001@L0000700800PL300<7100010L01`021`0300L700@00PL00`0700030087
10000`L0000400870`021`800PL00`07000400<710021`8000<700000PL400<71@0010L01`L20087
0`021`H000<700000P021`@000@700L710021`0700L700L01`0400<70`021`8000D700001`0400<7
10000`L000021`0400L71`<00PL00`070002008710031`800PL01P071`0700d7000<1`800`L00`07
000200@70P031`<000<700L00PL200<70`0010L01`L300@70P021`0300L000<00`L200<700H01`00
1`021`<00`L200<700H01`001`031`800PL01P07000700<70P031`<00PL00`07000200@70P031`05
00L01`000`L200@70`0010L01`L300<70P031`0600L000L00PL200<700H01`001`031`800`L30087
00H01`001`031`800`L400041`071`8010L3008700<01`000P031`800`L00`07000200<70P041`<0
00<700L00PL200d700071`0300L7008700<01`L00PL300031`0700870`031`0300L000800PL40087
0`000`L01`0400<710000`L01`04008700@01`000PL200041`0000870`021`@00PL300031`000087
0`021`H00PL400870`021`8000<700000`L400870P000`L000021`@00`L200031`0000870`021`@0
0PL600870`021`8000@700000PL400870`021`<000<700000PL200041`071`@000<700L010031`@0
00<700L00`021`@00PL300031`0700870`031`0300L0008010L00`071`021`0300L700H700071`80
0POo00X00PL200P700071`0600L000L00`L200<700H01`001`021`0300L000<70P021`0300L700<0
0`L200<7100010L01`L300<70P031`0300L0008010L200<70`0010L01`L300@70`0010L01`L200@7
0P021`0300L700<00PL300<7100010L01`L300<70`021`0300L000<00`L300870`021`0300L70080
10L2008700<01`000P041`<00PL00`07000200<70P041`<000<700L00PL200<70`021`0300L000<0
0`L200<70`021`0300L700800`L00`0700021`0600L000L00`L200<700H01`001`081`001`L01P07
0007008700<01`000`L400051`0700L00P031`<000@700L70`021`<00`L400041`071`<00`L30087
00<01`000P041`<00PL300041`071`<010L300031`0700<010L300041`071`<00PL300<7100010L0
1`L300<70`021`0300L000<00`L300870`021`0300L0008010L300031`0700<010L3008700<01`00
0P021`<010L300041`071`<00`L3008700<01`000`031`<00PL3008700<01`000P031`8000D700L0
1`0400<70`021`0600L000L020L000L70P021`8000@700L70P021`800PL300870P021`8000H70000
1`021`0300L0008000D700L700031`8000L700L01`07008000@700070P021`800PL200031`000080
0PL200041`071`800PL2008710000`L000021`8000H700001`021`<00PL2008700@01`L70P0010L0
1`L200031`00008700@01`000`L00`071`0200870`021`0300L0008000<700000PL200031`000080
0PL200870P021`0400L0008710000`L000021`800PL200041`001`8000L700L01`0700800`L01@07
1`0700<000H700L700L300031`0000870P021`<00PL200870P021`0400L000870P081`001`L00`07
1`021`800`L00`07000200@700<01`L00PL01@0700L000870`031`<000@700L70`041`800PL01P07
1`0700870`031`@000@700L70`031`800`L00`07000300<70P021`0600L000L00PL300<70`021`D0
10L200<71@031`8010L500870`031`<00PL01P07000700870P031`@000<700L00PL200<70`021`03
00L000<00`L3008700<01`000PL00`071`0200@70`021`0300L000800`L3008700D01`0700041`03
00L700870`000`L01`021`8010L00`071`061`001`L00`071`021`800`L00`07000200<7k@031`<0
00<700L00PL200@700<01`L01PL000L700@01`L70P0010L01`L2008700P01`L01`07008700D01`07
00021`@000<700000PL200051`071`000`L200031`0700800`L01@071`0700800PL200031`0000<0
0PL200051`001`000PL300041`001`<000<700L00P021`800PL400031`00008710000`L000031`80
00@700L70P000`L000021`0400L000<70P000`L0000200870P000`L0000200870P021`8000<700L0
0`0010L000L3008700D01`001`0200871@000`L000021`8000D700L700031`8000<700L00P031`05
00L700L00P021`8000<700000P021`0500L01`000PL01@0700L0008700<01`L00P021`0400L000<7
00<01`L01PL000L700H01`L01`021`0300L000<70`021`0300L700<00PL200051`0700L010031`80
0`L200041`0700870P041`<00PL300031`0700870`031`<000H700L700L200<70`0010L01`L200@7
00H01`0700L200031`0700870P031`8000@700L00PL300<70`021`0400L01`800`L200<700X01`00
1`0700L010L2008700<01`000P031`8000H700L700L300<70`031`0300L000800PL300@70P021`04
00L01`800`L200<710001@L01`0700800PL3008700<01`L00`031`0300L0008700<01`000PL00`07
1`061`001`L00`0700021`0400L71`800`L3008700<01`L00`031`800PL00`07000300<70P031`03
00L0008700<01`L00P041`<00PL00`07000200<70`031`D00`L200@70P021`0300L7008010L20087
00<01`000`031`<00PL00`0700021`0300L700<00`L3008700H01`L01`021`<00`L400041`071`80
10L2008700<01`L00P041`800`L500<70`031`<000@700L70`041`800PL01P071`0700<70P031`@0
00@700L70P031`<00PL00`071`0300<70P031`0600L700L020L000L70P031`0300L70?l00P021`04
00L71`8020L000L700<01`L00PL00`071`021`8000<700000`L300<70P001PL000L01`800`L30007
1`071`0700031`<00PL0100700L200<70`021`8000D700L01`0400<700D01`001`0200041`000087
0`021`0400L01`8000<700000P031`<00PL01@0700L000<70`031`8000<700000`L300<700D01`07
00021`<00`L400071`001`0700021`<00PL300041`001`8000<700L00PL400051`0700L00P021`<0
0`L200041`0700870`031`0300L0008700<01`000P031`8000<700L00P000`L000031`<00`L20003
1`0000@700<01`L00PL00`071`061`001PL200@700<01`L00PL01@0700L000@700<01`L00PL01@07
00L000870P041`<000<700L00PL200@700D01`L700021`0300L000@700@01`L70`021`0300L700<0
0`L3008700H01`001`031`0500L71`000PL00`0700021`8010L3008700<01`L00P041`0300L70087
00D01`0700041`0300L700870P021`0300L700<010L2008700<01`000PL01@071`L000<700H01`00
1`021`<00`L3008700<01`L00`031`0300L7008700<01`000PL01@071`L000@70P031`0300L00080
10L2008700D01`0700041`0300L7008700D01`0700041`0300L700870P071`001`L00`071`021`03
00L700870P000`L000031`<00`L200031`0000870P041`<000L700L700L000<70`021`0400L01`80
0`L3008710000`L01`0400<70`021`@000@700L70`021`0400L01`8000<700000P031`<00PL01@07
00L000<70`031`8000<700000`L300<700D01`0700021`<00`L400071`001`0700021`<00PL00`07
000300870`031`@000<700L010021`<00`L200041`0700870`031`0300L0008700<01`000P041`80
0PL200031`0000<70`031`8000<7000010L00`071`021`0300L700H700071`800`L00`071`021`05
00L71`000PL01@0700L0008700<01`L00P000`L01`0200870P021`8000@700L70P001`L01`0700L0
0P031`0:00L700L01`0700871@021`0300L700800PL0100700021`8000L700L01`0700800`L30005
1`0000L00P021`0400L000870P001PL01`07008700D01`L700021`0600L01`070P021`8000@700L7
0P001@L0000700<00`L200071`0700L01`0200870P0010L01`L2008700<01`L01@021`0700L01`07
00021`0400L71`8000L700L01`0700800PL0100700021`800PL200031`0700800PL020071`0700L0
0PL01@071`L000@700@01`L70P081`001`L00`0700021ol020021`0300L000P700071`0600L700L0
10L010071`L3008700<01`L00`031`<000<700L00P000`L01`021`800`L200041`0700870P041`<0
0PL01@0700L000<70`031`<000@700L70`041`800PL00`071`0200<70P001@L01`0700@00`L200<7
0P0010L01`021`<00`L3008700@01`070P031`800`L400051`0700L00P031`800PL00`071`0200@7
0`021`0300L000800`L300<700D01`0700021`<010L2008700@01`070P031`800`L01`07000700L0
0`031`<00PL00`071`0300<700<01`L00PL00`0700021`0300L700H700071`0400L71`8010L01@07
1`L0008700D01`0700021`0300L7008000<700000`000`L000021`8000D700L700031`8000<700L0
0P031`0500L700L00P021`8000<700000`021`8000@700070P000`L000021`8000L700L01`070080
00@700000PL400031`00008700@01`000PL010071`L200051`071`000`L01@071`0700800`L00`07
1`0200041`071`8000<700000P021`<000X7000700L01`070P021`8000@700070P000`L000021`D0
00<700000PL200051`071`000`L200031`0700800`L01@071`0700800PL200031`0000<000<70000
0PL020071`0700L00PL01@071`L000@70P031`0300L700H700071`0300L7008700<01`L00PL00`07
1`0200<70`031`<000@700L70`031`0500L01`000PL300@70P021`0400L01`800`L200<700L01`00
1`0700@00`L3008700H01`001`021`<00PL01P07000700<70P031`<00PL00`07000200@70P031`80
00<700000`L200@70`0010L01`L300<70P031`0600L000L00PL3008700H01`001`021`<00`L40003
1`07008000<700L00PL200<70P0010L01`021`8010L3008700D01`0700031`<00PL00`07000200<7
0`031`800PL00`071`021`0300L7008700<01`L01PL000L700<01`L00PL200<700D01`0700041`03
00L700870`0010L01`L300<70P021`0300L700<010L2008700H01`L01`031`800`L400041`071`<0
0`L200<700H01`001`021`800`L400041`071`<00`L3008700<01`000P041`800`L01@0700L000<7
0P041`<000@700L70`031`<00PL00`07000300<70P021`0600L000L00`L200<70`021`0300L000<0
0`L200<700<01`000PL00`071`0200@70`021`0300L700800`L3008700<01`000P041`0300L70087
00D01`0700031`8010L00`071`061`001`L00`071`021`0300L000870P021`0400L71nd00`L00`07
1`02008700<01`0010L00`071`061`001`L00`071`021`0600L700L00`L00`071`021`0400L01`80
0`L300051`0700L00P021`<00`L200041`0700870`031`0300L0008700<01`000P031`@00PL20003
1`00008700<01`0010L0100700L500@70`001@L01`0700800PL400870P0010L01`021`0300L000<7
00<01`000PL0100700L2008710021`8000D700L01`0300@71@0010L01`041`0300L000870P000`L0
00021`@00`L300071`071`0700031`<00PL0100700L200<70`021`8000D700L01`0300<70P0010L0
1`041`0700L71`0700021`0300L7008700<01`L01PL000L700<01`L00PL010071`L200<700<01`L0
0PL01P071`0700<70P021`0600L700L00`L00`071`021`0300L0008700D01`L700041`800`L00`07
000200@70P031`0500L01`000`L200@70P021`0300L0008010L2008700H01`L01`031`800`L00`07
00021`0400L71`800`L200<700H01`L01`031`800`L00`0700021`0300L7008010L300041`071`80
10L200<700D01`0700031`8010L300031`0700870P041`0500L71`000PL00`0700041`0700L71`07
00021`0300L700800`L00`0700021`0300L7008700@01`L70P031`0300L7008700<01`L01PL000L7
00<01`L00PL01P071`0700<700<01`L00PL0100700L200<70`001@L01`0700800PL300<70P0010L0
1`021`<00`L00`0700021`0300L000800`L400870P000`L000021`0300L000@700@01`071@041`<0
00D700L01`02008710021`8000@700L00PL00`0700031`0300L0008700@01`070P021`@00PL20005
1`0700L00`041`D000@700L010L00`0700021`8000<700000PL400<70`001`L01`L01`000`L30087
00@01`070P031`<00PL200051`0700L00`031`8000@700L010L01`071`L01`000PL00`071`021`03
00L700H700071`0300L7008700<01`000PL2008700@01`L7k@031`0300L700800PL00`0700041`03
00L700H700071`0300L700870P031`0500L01`0010L00`071`021`<000@700L70`031`800PL00`07
1`0300@70P021`0600L700L00`L200<7100010L01`L300<70P031`0600L000L00`L010071`L40004
1`071`<00`L3008700<01`000P041`800`L01@0700L000<70P041`<000@700L70`031`<00PL00`07
000300<700H01`L700L200031`0700870P031`<00PL00`07000300<70P031`0300L0008700<01`L0
0P041`<00PL00`071`0200<70`021`0300L0008010L00`071`021`0500L01`000`L200@700<01`L0
1PL000L700<01`L00PL00`071`021`0300L700800`L300<70`0010L01`L300<700D01`0700021`<0
10L2008700@01`070P031`800`L01`07000700L010031`<00PL01P07000700870`021`0600L000L0
0`L200<70`021`0300L0008010L200<70P000`L000031`8010L300041`071`<00`L200<700H01`00
1`021`<00PL01P07000700870`031`@000<700L00P000`L01`021`800`L200041`0700870P041`<0
0PL01@0700L000<70`021`0300L000800`L300<70P021`0300L7008700<01`L00PL00`071`061`00
1`L010071`L200@700D01`L700021`0500L01`000PL00`071`0200031`0000<000<700000PL20005
1`071`000`L200031`0700800`L01@071`0700800PL200031`0000<00PL200041`001`8000<70000
0PL200071`0700L01`0200041`00008710000`L000021`0400L0008700@01`L70P001@L01`L000<7
00D01`L01`0200<700<01`L00P0010L01`L200031`0000800PL3000:1`001`0700L01`800PL20004
1`001`8000<700000PL500031`0000870P001@L01`L000<70P000`L01`0200<700D01`L01`020087
0P000`L0000300031`00008700P01`L01`07008700D01`L700041`800`L00`071`061`001`L01P07
1`0700@700@01`L70`021`0300L700<00`L300031`07008000<700L00PL200<70P0010L01`021`80
10L3008700D01`0700031`<00`L300041`071`<010L2008700<01`L00P031`8000D700L01`0400<7
0P031`8000@700L00PL300<70`021`0400L01`800`L200<710001@L01`0700800`L2008700<01`L0
0P041`<00PL00`07000200<70`031`0500L01`000PL300@70P021`0400L01`800`L200<700L01`00
1`0700<00`L3008700<01`L00`031`0300L7008700<01`000PL00`071`061`001`L00`0700021ol0
20021`0300L000P700071`800`L00`071`021`0500L71`000PL01@0700L0008700P01`L700L01`80
0PL200870P0010L01`L200071`0700L01`0200<700X01`L01`0700L00PL5008700<01`L00P021`04
00L000870P001`L01`0700L00P031`<000D700001`02008700@01`000PL200061`0700L00PL01@07
1`L0008700H01`0700L200870P0010L01`L200051`0000L00`031`8000L700L01`0700800PL20004
1`071`800PL00`071`05008700L01`0700L0008700@01`L70P001`L01`0700L00P021`0400L00087
0P021`8000@700L00`L020071`0700L00PL01@071`L000@700@01`L70P081`001`L00`071`021`03
00L700870P000`L000031`<00`L200031`0000870P041`<000L700L700L000<70`021`0400L01`80
0`L3008710000`L01`0400<70`021`@000@700L70`021`0400L01`8000<700000P031`<00PL01@07
00L000<70`031`8000<700000`L300<700D01`0700021`<00`L400071`001`0700021`<00PL00`07
000300870`031`@000<700L010021`<00`L200041`0700870`031`0300L0008700<01`000P041`80
0PL200031`0000<70`031`8000<7000010L00`071`021`0300L700H700061`8010L00`071`021`05
00L01`0010L00`071`021`0500L01`000PL200@70`000`L01`021`8010L01@071`L0008700<01`00
10L010071`L3008700<01`L00`031`<00PL01P07000700<700D01`L700021`0300L000870P041`<0
0PL00`071`0200@700<01`L00PL01@0700L000@700<01`L00PL2008700<01`L00`041`800PL00`07
00021`0500L71`000`L01P07000700870`031`<00PL00`071`0300<700<01`L00PL00`0700021`05
00L71`0010L200<700<01`000P041`800PL01@0700L000@700<01`L00PL01@0700L000@700<01`L0
0PL200L700071`0300L7008700<01`L00PL200031`0000<70`031`8000H7000700L200<70`001`L0
1`L01`000`L3008700@01`070P031`<00PL200051`0700L010031`0500L000L00P0010L000021`<0
0PL0100700L200031`0000800`L3008700D01`0700031`<00`L200031`0000<70`031`0500L01`00
0PL300<710001`L000L01`000PL300870`0010L000L200031`07008710001@L01`0700800PL300<7
0P0010L01`021`<00`L00`0700021`0300L000800`L200031`07008000<700000`L300<70P000`L0
00041`0300L7008700<01`L01PL000L70P031`0300L70?l00P021`0400L71`8020L000L700<01`00
0PL010071`L200<70`021`0300L700<00`L2008700<01`000`031`800`L00`0700021`0300L70080
10L3008700<01`000P031`<00`L500<70P041`800PL00`071`0200@70P021`0300L000<00`L30087
00<01`000PL00`071`0300<70`021`0600L700L00PL300<7100010L01`L200@70P021`0300L70080
10L200<71@031`<00`L300041`071`<010L2008700H01`L01`031`800`L400041`071`800`L30087
00<01`L00`031`800`L01P071`0700P700071`0600L700L00PL00`0700031`<00PL00`071`030087
0P001@L01`0700@00`L200<70P0010L01`021`8010L300870`000`L01`021`<00`L300061`071`07
0P031`<000@700L70P041`0600L01`070P000`L01`021`800`L200041`0700870`031`<00PL01007
00L200<70P031`0:00L000L01`0700@70P021`0300L000800`L200061`071`070`031`<00`L00`07
000200870`041`800PL0100700L200<70P031`@000D700L01`0200870`021`0300L700<00`L00`07
00021`0300L0008700<01`L01PL000L700@01`L70P0010L01`L2008700P01`L01`07008700D01`07
00021`@000<700000PL200051`071`000`L200031`0700800`L01@071`0700800PL200031`0000<0
0PL200051`001`000PL300041`001`<000<700L00P021`800PL400031`00008710000`L000031`80
00@700L70P000`L000021`0400L000<70P000`L0000200870P000`L0000200870P021`8000<700L0
0`0010L000L3008700D01`001`0200871@000`L000021`8000D700L700031`8000<700L00P031`05
00L700L00P021`8000<700000P021`0500L01`000PL01@0700L0008700<01`L00P021`0400L000<7
00<01`L01PL000L700<01`L00PL200<700<01`000P031nd00`L300031`0700870P041`0300L700H7
00071`0300L700870P031`0300L0008010L00`071`021`0500L01`000PL300<70`0010L01`L300@7
0P021`0600L700L00PL300<7100010L01`L300<70P031`0300L000<00`L2008700H01`001`021`<0
0`L300871@041`800`L500<70P041`D00PL300<70`021`0600L000L00PL200<710000`L01`021`80
0`L3008700<01`000`031`<00PL00`0700021`0300L7008010L3008700<01`000P031`<00PL01@07
00L000@700<01`L00PL300031`0700870P041`0300L700H700071`800PL200041`071`800PL20087
0`031`0300L7008000H700001`021`D000D700L700031`8000L700L01`07008000@700070P021`80
0PL200031`0000800PL200041`071`800PL2008710000`L000021`8000H700001`021`<00PL20087
00@01`L70P0010L01`L200031`00008700@01`000`L00`071`0200870`021`0300L0008000<70000
0PL200031`0000800PL200870P021`0400L0008710000`L000021`800PL200041`001`8000L700L0
1`0700800`L01@071`0700D00PL00`07000200031`00008700@01`L70`021`800PL2008700@01`00
0PL200P700071`0600L000L00PL00`0700031`@000D700L01`0200<70`0010L01`L300870`031`@0
00@700L70`031`<00PL00`07000200@70`021`<000@700L70`041`<000<700L00`041`<000@700L7
0`021`<00`L400041`071`<00`L3008700<01`000`031`<00PL3008700<01`000P041`<000<700L0
0`041`<00PL00`07000200870`041`<000@700L70`031`<00PL00`07000300<70`021`<00PL00`07
000200<70P001@L01`0700@00`L3008700H01`001`081`001`L01P07000700<70P031`0600L000L0
0PL00`0700031`800PL00`071`0300<70P031`@000@700L70`031`800`L00`07000200@70P031`<0
00@700L70`041`<000@700L70P041`800PL00`071`0300870`031`@000@700L70`031`<00PL00`07
000300<70`021`<00PL00`071`0200@70P021`0300L0008010L3008700<01`000P031`8010L30003
1`0700870P031`<00PL00`07000300<70P031`<00PL00`071`0200<700<01`000PL01P07000700<7
0P031`0600L000L020L000L70P021ol02P021`8020L000L700<01`L00PL00`071`021`<000<700L0
0PL300<700<01`000P021`@00PL300031`0700@00`L400031`0700@00PL0100700021`8000@70000
0PL3008710021`<000<700000PL300871P021`@00PL300870P000`L000031`@00PL200031`000087
10031`8000<700000PL3008710021`H00PL300870P0010L000021`@00PL300870`000`L000021`80
00@700L710000`L01`0400<710000`L01`03008710021`<000<700L00PL300<700<01`000P041`03
00L7008700<01`L01PL000`70P031`0300L0008010L200<70`000`L01`021`800`L300041`071`<0
10L2008700<01`000`031`800`L01P07000700870`031`800`L01P07000700<70P021`0600L000L0
0`L200<70`021`0300L0008010L200<700D01`0700031`8010L300041`071`<00`L200<700H01`00
1`021`800`L01P07000700<70P031`<00PL01P07000700<70P031`@000@700L70P041`<00PL00`07
000200<70P031`0300L000800`L200@70`000`L01`021`803@L000`700<01`000PL00`071`0200<7
10021`<000@700L70`031`0300L7008000<700000P031`@000D700001`0200870`031`@000@700L0
0PL00`071`04008700<01`000`021`@000<7000010021`<00PL2008700<01`0010031`@00PL20003
1`00008710031`D000@700L70P021`<00PL600031`0000800PL400041`071`@00PL01`071`0700L0
10031`<00PL200051`0000L010031`@000<700000PL010071`L3008700<01`000P021`@00`L20087
00H01`L01`0=1`0030L01P071`0700<70P001@L01`0700@00PL200071`0000L01`0200<70`021`80
00D700001`0400<710000`L000021`800PL300<71@0010L000L2008710000`L01`0400870P001@L0
000700@00`L300870P001@L0000700@00`L400051`0000L00P021`<00`L400051`0000L00P021`@0
00D700L01`0200870P0010L000L500<70`021`800PL200031`0000800`L400051`0000L00P021`<0
0`L200031`0700<000<700000PL400051`0700L00P031`0300L0008700<01`L02`L000`700<01`L0
o`02008700<01`L02`L000`700@01`L70P031`@000<700L00P000`L01`021`800PL0100700L20087
0P0010L01`L400051`0700L00P031`8000D700L01`0300<70`031`8000<700000`L200<710000`L0
1`0400<70P021`<000<700000PL4008710001@L01`0700800`L200051`0700L010021`@00PL20004
1`0000870P031`@000<700L010031`800`L200031`0000<70`031`<000D700L01`0200<70P001@L0
1`0700@00PL0100700021`8000@700L00PL200<700L01`001`0700@00`L200<700<01`L02`L000`7
00<01`L00PL2008700<01`L01@021`800PL0100700L200<700<01`000P021`0500L000L010021`<0
00<700000`L4000:1`071`0700L01`800`L01@071`07008000D700001`0500051`0700L00P000`L0
1`0200<700T01`001`0700L00P000`L0000200<70P000`L000031`@000P7000700L01`8000<700L0
0PL200031`07008000D700L01`0500051`0000L00P001@L01`L000<70P001PL01`07008700<01`00
0`031`8000@700000PL400051`001`000PL300031`0700870P0010L01`021`800PL5008700<01`L0
0P041`0300L700/7000<1`0300L700871@031`<00`L00`07000200870P041`<000<700L00PL200<7
0P031`0300L000<010L200870`021`0300L700<00`L30087100010L01`L3008700<01`L00`021`80
10L3008700<01`L00P031`8010L500@70P031`800PL00`071`0300@70P021`<00PL00`071`030087
00<01`000`021`<00`L3008700<01`L00`021`8010L400031`0700870P031`800`L00`07000200@7
0P021`<000<700L00PL300<71@041`0300L700/7000<1`0300L00?l00`000`L01`0<1`0030L01@07
1`07008000<700000PL01@0700L000870P001PL000L01`<000<700000PL200041`071`8000<700L0
0`000`L000031`0300L700<000@700L00PL5008700<01`L00P021`0500L000L00`001`L01`0700L0
0`021`<000D700001`02008700@01`000PL200031`0700<00PL01@071`L000870`000`L01`020087
0P0010L01`L200051`0000L00`021`<000L700L01`0700<000D7000700021`800PL00`071`050087
00@01`070`021`0400L71`8000L700001`0700800PL0100700021`8000L700001`07008000<70000
0PL01@0700L000870P001@L000L0008700<01`L02`L000`700@01`L70P031`<00PL01P071`0700<7
0P021`0300L000<00`L200<700<01`000PL00`07000200@7100010L01`L200<70`031`D00`L200<7
0`021`0300L700<00`L2008700<01`000`031`800`L00`0700021`0300L000<00`L400071`071`07
00031`800`L400041`071`800`L3008700<01`L00`031`800`L500<70`031`800PL00`07000300@7
0`001`L01`L01`000`L200<7100010L01`L200<700<01`000PL00`071`0300<70P031`0300L700/7
000<1`0300L7008700@01`L70`021`0400L71`800`L300031`0700@00`L200<70P0010L01`021`80
10L3008700D01`0700031`<00`L300041`071`<010L2008700<01`L00P031`8000D700L01`0400<7
0P031`8000@700L00PL300<70`021`0400L01`800`L200<710001@L01`0700800`L2008700<01`L0
0P041`<00PL00`07000200<70`031`0500L01`000PL300@70P021`0400L01`800`L200<710000`L0
1`0300<70P031`0300L700<00`L00`071`021`0300L700/7000<1`0300L700870P021`0600L000L0
10L01P071`L01`D000<700000PL200051`071`000`L200031`0700800`L200031`0700800PL20003
1`0000<00PL200041`001`8000<700000PL400031`0700@000@700000PL400031`00008700@01`00
0PL010071`L200031`0700800`L200031`0700800`L00`071`0200041`071`8000<700000P021`<0
00<700000P000`L01`0400870P0010L000L200031`0000871@000`L000021`8000<700L00P031`80
00<700L00P031`0500L700L00P021`8000<700000`000`L01`021`0300L7008700H01`001`021`80
10L00`071`0;1`0030Oo00P03@L0014700<01`000P031`8010L01@0700L000870`031`<000@700L7
0`041`800PL00`07000300<70P031`@000@700L70`031`800`L01P07000700870`021`@000@700L7
0`031`<00PL00`07000200@70P031`D00`L200@70`0010L01`L300<70`021`0300L000<00PL30087
00H01`001`031`800`L3008700<01`000`031`800`L400041`071`8010L3008700<01`000P031`<0
0PL01@0700L000@70P031`<000<700L04@L001470P021`0300L700870P031`0300L7008000<70000
0`021`0300L0008000D700L700031`8000D700L01`04008700@01`000PL200870P000`L000020087
0P0010L01`L200870P021`800`L200870P000`L00003008700D01`001`02008700@01`L70P0010L0
1`L5008700@01`000`L00`071`0200051`001`000PL500031`0000870P031`800PL200870P021`04
00L0008710000`L000021`800PL200041`071`@000D700L01`0200<700D01`L01`0300041`071`D0
00<700000PL010071`L200@700<01`L00P0B1`004@L010071`L200<70`021`0400L71`<000<700L0
10021`<00`L200041`07008710001@L000L0008700<01`000P041`<00PL5008700<01`0010L00`07
000300031`0000@70`000`L01`0400870`031`8000@700L00PL01@070007008000P700L700L01`80
0`L3008710000`L01`0300@70P000`L0000200031`0700<700<01`000PL500870`041`<000H700L7
00L200031`0000800PL0100700L200<70`021`@000<700L00`031`0300L700<00`L200<700<01`L0
40L001070P031`0300L0008700H01`001`031`800PL00`071`3;008700<01`L00P031`0600L000L0
0PL00`0700031`804@L0014700D01`L700021`0300L000870`031`<000D700L01`02008710021`80
00@700L00PL300<70`021`0300L000800`L200041`071`8000<700000PL00`0700041`0400L01`D0
10L300051`0700L00P021`0400L000870P0010L01`021`0300L000<70`021`0400L01`800PL20004
1`071`8000D700L01`0300@71@0010L000041`0300L000870P000`L000021`0400L000<70`001`L0
1`L01`000`L3008700@01`070P021`@00PL200051`0700L00`031`800`L00`0700021`0500L71`00
4PL001470P021`0400L71`8010L00`071`0200031`0000800`L300031`07008000<700L00PL20007
1`0700L01`02008700@01`000PL200041`0000870`031`0300L000870P021`800PL300870P021`80
00<700000P031`<00PL300031`0700870P0010L01`L200031`00008700@01`000`L00`0700020087
0`031`@000<700000PL200870`021`800PL2008700<01`000`L300870`000`L000021`8000@700L7
0P001`L01`0700L00P031`0700L000L01`0300<710000`L000021`0300L700870P031`0300L70080
4PL0014700D01`0700041`0300L700870`0010L01`L200@70`0010L01`L300@70P021`0600L700L0
0`L200<7100010L01`L300<70P031`0600L000L00`L010071`L400041`071`<00`L3008700<01`00
0P041`800`L01@0700L000<70P041`<000@700L70`031`<00PL00`07000300<700H01`L700L20003
1`0700870P031`<00PL00`07000300<70P031`0300L0008700<01`L00P041`<00PL00`07000200@7
0P021`0300L0008010L00`071`021`0500L01`004PL000h7o`0400l7000?1`0300L000<700<01`L0
0PL00`0700021`0300L7008000<700L00`021`0300L7008000@700L70P021`8000<700L00P031`05
00L700L00P021`8000<700000P031`8000<700000PL0100700021`8000L700L01`07008000D70000
1`0500031`00008710021`800PL200051`071`000`L01@071`0700800PL2008710021`8000<70000
0`001@L00007008000L700L01`0700800PL200041`071`8000<700000`L400031`0000870P001@L0
1`L000<70P000`L01`0200870P021`0400L0008700<01`L00`000`L01`02008700H01`L01`041`07
00L71`07000@1`0040L200<70P031`0300L700<00`L2008700H01`001`031`800`L400041`071`80
10L3008700<01`000P031`8010L01@0700L000<70P041`800PL00`071`0200<710000`L01`020003
1`0700870P031`@000@700L70`031`<00PL00`07000300<70P031`0700L000L01`0400<70P021`03
00L7008010L200<700D01`0700041`800`L300041`071`<010L2008700<01`000`031`800`L01P07
000700870P031`<00PL010071`L200<70P0A1`004@L01`071`L01`000PL00`071`0300<70P021`03
00L700<00`L3008700H01`001`021`8010L3008700<01`000P031`<00`L200031`0000<70P041`80
0PL00`071`0200@70P021`0300L000<00`L3008700H01`001`021`<00`L3008700H01`001`021`<0
0`L400041`071`8010L2008700<01`L00P041`800`L200031`0000<70`031`<000@700L70`041`80
0PL01P07000700870`031`<00PL00`071`0200<70`021`0600L700L00`L00`071`0@1`004@L20087
00P01`L01`07008700T01`L700L01`000`L200870P0010L000L200071`0000L01`0200<700D01`L0
1`0300061`071`070`021`0500L71`000PL0100700021`8000L700L01`0700800PL400031`000087
0P021`0300L0008000@700070`001@L01`L000<700D01`L01`0300041`001`<000@700L70P021`80
00<700000P021`8000L700L01`0700800PL200051`071`000`L00`071`0300061`071`070`001@L0
1`L000<70P000`L01`0300041`001`8000<700000PL200<700D01`0700031`0800L700L01`021`03
00L700804PL001870P000`L01`021nd00`L01007000C1`004`L300@700<01`L00PL01@0700L000<7
00<01`L00PL300031`0700870P041`800PL01P071`0700<70P031`<00PL00`071`0300<70`021`06
00L000L00`L01P071`L01`8000@700L70P041`<00PL00`071`0200@70P031`0500L01`000`L200@7
0P021`0300L700<010L2008700H01`001`031`0600L71`070P0010L01`L300<70`021`0300L700<0
0`L200<700<01`000PL00`071`0200@70P031`0300L0008010L02@071`L01`0700041`0300L70087
0`0D1`0050L200@70P031`8000<700000`L200<70`001PL01`L01`800PL400051`0700L00P021`@0
0PL01`071`0700L010031`0500L700L00P021`800PL300870`001PL000L01`800`L3008700@01`07
0P021`@00PL200031`00008710021`8000@700L00PL300<70P000`L01`0200041`0000870`021`80
0PL200051`071`000`L400041`07008700<01`L010021`8000D700L01`0400870P001PL01`L01`<0
0`L200<70P000`L000031`8010L201D7000E1`800`L00`0700021`0500L71`000`L0100700L20087
0P0010L01`L400031`0700@00`L01`07000700L00`031`@00PL00`071`0200<70P041`0800L01`07
00L200<70P021`<000<700000PL0100700021`@000<700L00P000`L01`021`0700L000L01`040087
0P0010L01`L200041`0000870P031`8000P700L01`0700@70P031`800PL00`071`0400<70`000`L0
1`0200031`07008710000`L01`04008700@01`000PL200041`0700<700D01`L700021`0300L000<7
0P0F1`005@L3008700<01`L00`031`800PL00`071`0300<70P031`0600L000L00PL200@70`021`03
00L0008010L200<70`000`L01`021`8010L2008700<01`L00P041`800PL00`07000300<70P031`06
00L000L00PL300<70`021`0600L000L00`L200<7100010L01`L200@70P021`0300L7008010L200<7
00<01`000P031`8010L300041`071`<010L2008700H01`001`031`800`L3008700<01`L00P031`<0
0PL00`071`0301H7000E1`0600L000L00PL300<700H01`0700O=00061`0700L00`L3008700H01`00
1`0F1`005@L00`071`0300051`071`000`L00`071`04008700<01`L00P001@L01`L000<70P000`L0
1`0300031`00008700<01`000`L200061`0000L00PL00`071`0200081`071`0700L20087100010L0
00L3008710000`L000021`0500L000L00P031`8000@700L70P000`L000021`0400L000<70P001@L0
00L000870P000`L0000200870`0010L000L400870P0010L01`021`0400L0008700D01`L01`030003
1`0000<700<01`000PL200071`0000L01`0200<700D01`L01`02008700<01`L010021`0500L71`00
0PL00`070002008700<01`L050L001D700@01`L70`031`800PL010071`L200<70`0010L01`L300@7
0P021`0300L000<00`L200<700H01`001`021`<00`L200<700H01`L01`031`800PL01P07000700<7
0P031`<00PL00`07000200@70P031`0500L01`000`L200@70`0010L01`L300<70P031`0600L000L0
0PL200<700<01`000PL010071`L200<70`021`0600L000L00`L200<7100010L01`L200@70`021`03
00L000800`L200<700<01`L00P031`<00`L00`071`0D1`005@L00`071`021`800`L01@0700L00087
0`031`<000@700L70`041`800PL00`070003008700<01`000`L400041`071`<00`L200<700@01`07
0P021`<00PL400041`071`<00`L300871@041`<00PL200031`0000870`041`D00PL300<70`021`03
00L000<00PL300870P0010L01`031`800`L3008700<01`000`031`0300L00087100010L01`L200@7
0`021`0300L000800`L3008700D01`0700031`8010L00`071`0D1`005@L200870`031`0300L70080
00D700001`3=00051`0000L00P021`0400L71`<00PL201H7000E1`0800L000L01`021`0400L71`<0
00L700L700L000<70P031`@000@700L70`031`800`L00`07000200@70P031`<000@700L70`041`<0
00<700L00`041`<000@700L70`021`<00`L400041`071`<00`L3008700<01`000`031`<00PL30087
00<01`000P041`<000<700L00`041`<00PL00`07000200<70P041`<000<700L00PL200<70`021`03
00L000<00`L200<700<01`000PL00`07000200<700L01`L01`07008000<700L05@L001D700H01`00
1`021`0300L000<70P021`0400L71`800`L200<7100010L01`L200@70P031`0300L0008010L200<7
0`0010L01`L300@70`000`L01`0300@70P021`0300L700<00PL300<7100010L01`L300<70`021`03
00L000<00`L300870`021`0300L7008010L300031`0700<010L3008700<01`000P031`8010L30003
1`0700870P041`800PL00`07000300<70P031`800`L00`071`0200<700<01`000PL01P07000701H7
000E1`800PL200<70P021`8000@700L00PL00`0700021`@00PL200051`0000L010021`8000@700L7
0`000`L01`021`8000D700L700021`8000@700070P031`0300L700@000<700000PL200061`0700L0
0PL01@07000700800PL200051`0000L00P0010L000L200041`001`<000<700000PL200051`001`00
0PL01P0700L01`800PL200031`0000800PL010071`L200041`001`800PL01@071`0700800`L00`07
0002008700@01`000PL400051`0000L00P021`@00PL00`0700021`0400L01`800PL200<70P021`80
5PL001D700<01`L00PL00`071`021`0500L01`000PL200041`071`<000<700L010031`@000<700L0
0P001PL01`L01`800PL200041`0700870`031`<00PL300031`0000<70P021`H00PL300<70`021`D0
0`L400871@021`@00`L500870`031`<00PL600870P031`8000@700000PL300<70`021`0400L01`80
0PL200061`071`070P000`L01`0400<710000`L01`03008700@01`000PL01@0700L000@700<01`L0
0PL00`071`0D1`006PO[01/7000L1`0800L700L01`031`800`L00`071`0200031`0000800`L40003
1`0000870P021`<00`L200061`0700L00PL00`071`0200061`071`0710001`L0000700L01P021`<0
0PL2008700<01`0010031`@00PL200031`00008710031`D000@700L70P021`<00PL600031`0700<0
00<700000P001PL01`L01`800PL02@071`0700L01`0200<70`021`800PL200031`0000800`L40003
1`00008700@01`L70P031`0500L01`000PL00`071`0K1`007@L300870P021`8000<700L00P031`<0
0PL200051`0000L00`041`0500L000L00P021`0400L71`<00`L5008700@01`000PL400041`071`<0
0PL200051`0700L010031`<00PL200051`0000L010031`@000D700001`0200870`031`@000D700L0
1`0200870`021`0300L000<00PL200041`071`D00`L300<700<01`L00P001@L000L000@70`001@L0
000700800PL300<70P000`L01`0200870P021`<07PL001d70`031`0500L01`000PL00`0700031`80
0`L400041`071`8010L3008700<01`000P041`0300L700870`000`L01`021`8010L2008700<01`L0
0P041`800PL01P07000700<70P031`0600L000L00PL300<70`021`0600L000L00`L200<700H01`00
1`021`8010L2008700<01`L00P041`800`L00`07000200@700<01`L00PL300041`071`<010L20087
00<01`000`031`800`L00`0700021`0500L01`000`L301h7000L1`0400L700<70P021`0400L01`80
0PL200041`071`@000D700L01`0200<70`021`0300L000800`L300<70P000`L000031`800`L40003
1`0700@00`L200870`000`L000021`@00PL400051`0700L00P031`8000D700L01`04008710021`80
00@700000PL200<710000`L01`0400<70P031`8000<700000`L300<70`0010L01`L300<70P001@L0
1`0700@00PL0100700021`8000@700L00PL200<700@01`L07@L001/700@01`L7h@031`0300L701X7
000J1`0300L700871@021`8010L300031`0700870P031`800`L00`07000300<70P031`<00PL00`07
1`0300<70`021`0600L000L00PL3008700H01`L01`021`8010L3008700<01`L00P041`0300L70087
1@041`0300L700870P021`0300L700<010L2008700<01`000PL00`071`03008700H01`001`021`<0
0`L3008700<01`L00`031`800`L400031`0700870P031`800`L00`07000200@70P021`D010L00`07
1`0I1`006`L01P071`L01`<00PL200@70`0010L01`L300<70P031`0300L000<00`L200<70`021`03
00L000<00`L30087100010L01`L3008700@01`070P0010L000041`<00PL00`07000200<70`031`D0
0`L300<70`0010L01`L300@70`001`L000L01`000PL3008700<01`000`021`<00`L400041`071`<0
0`L200<710000`L01`021`800`L3008700<01`000P041`800PL300031`07008700<01`L06PL001`7
00<01`L00P001PL000L01`800`L00`071`0200041`001`8000<700L00P021`800`L01@071`070080
0PL01@071`0700<00PL01@071`L0008700@01`000PL200071`0700L01`0200<70`000`L000021`80
0PL00`07000200091`001`0700L0008700D01`L700021`0600L01`070P001PL0000700870P021`80
00@700000`L200071`0700L01`0200870P001@L01`L000<700<01`L00`001@L01`L000870P001@L0
1`L000<70P021`8000<700L00P0010L000L2008700@01`L70P000`L01`0200031`00008700<01`L0
6`L001d700<01`000`L2008700<01`00c00010L01`L200<700<01`007PL001h700<01`L00PL20087
00H01`L01`031`800`L200041`0700870P041`<00PL00`07000200<70P041`0500L01`000PL300@7
0P021`0300L700800`L200051`0700L00P000`L01`021`800`L200041`0700870`031`<00PL01007
00L200<70P031`0900L000L01`0700800`L2008700<01`L00P041`<00PL01@0700L000@70P031`<0
00@700L70`041`800PL0100700L200<70P031`0300L0008700<01`L00P041`0300L701d7000O1`0<
00L71`0700L01`070P031`0300L0008700@01`L70P0010L01`041`0500L700L00P021`0300L700@0
0`L200041`001`8000<700000PL200071`0700L01`0200041`00008710000`L000021`@00PL01007
1`L200051`071`000`L01@071`0700800`L00`071`0400870P000`L0000200870`002PL000L01`07
00L200870P0010L000L200031`0000<710021`0300L7008000D700L700041`0400L01`800`L01P07
1`0700<70P0020L01`0700L00`L00`071`0N1`0080L010071`021`<00`L01@071`L000870`041`80
0PL200870P031`800`L400041`07008700@01`L70`021`0600L000L00PL3008700H01`001`031`80
0`L01`07000700L00`041`800`L200031`0000<70P041`<000<700L00P000`L01`021`800`L01P07
000700870`021`0600L000L00PL300<700L01`L01`0700@00`L200<70P021`800PL200@70`021`05
00L71`000`L3008700@01`L08@L0024700<01`000`L00`071`021`800PL00`071`0300@70P021`06
00L000L00`L200<70`021`0300L700<00`L200<700H01`001`021`800`L400041`071`<00`L30087
00<01`000P041`800`L01@0700L000<70P041`<000@700L70`031`<00PL00`07000300<70P021`06
00L000L00`L200<70`021`0300L700<00`L200<700H01`001`021`8010L3008700<01`L00P041`07
00L71`07000R1`008PL20087d`021`808`L002<700L01`0700L0008700<01`L00`031`8000@700L0
0PL300870P001PL01`L01`<00`L200041`071`D00PL00`0700041`0400L01`D010L300031`0700@0
0PL00`0700031`8000@700L00PL00`0700031`0300L0008700@01`070P031`0300L0008710000`L0
1`0300@71@0010L01`041`0300L000871@021`0400L000<70`001PL01`L01`800PL3008700@01`07
0P031`<00PL02P071`0700L01`0T1`008`L2008700H01`L01`031`0300L7008700<01`000PL01@07
1`L000@70P031`0300L0008010L200<70`000`L01`021`8010L2008700<01`000P041`800PL00`07
1`0300<70P031`0300L0008700@01`L70P031`800`L01P071`0700<70P031`<00PL00`071`0200@7
0`0010L01`L200@70P031`0300L000800`L200@70`000`L01`021`8010L01@071`L0008700<01`00
10L01`071`L01`000PL00`071`0202@7000S1`<000<700L00PL200870`031`8000@700L00PL300<7
0P031`0300L0008010L200<71@021`0300L000@700@01`071@041`<000<700L010021`0300L000<7
0P0010L01`021`0300L000<700<01`000PL0100700L200<700<01`000PL400031`0700<010L50004
1`0700@700<01`000PL500<70P041`<000<700L00PL200<70`021`0400L01`800`L300870P031`03
00L0008090L002<700<01`000P041`0700L01`0700021`0400L71`8000L700L01`07008000@700L7
0P021`800PL200031`0700800PL200041`071`800PL200870`021`800PL200031`0000<00PL30087
0P021`0400L71`8000@700L70P000`L000021`0400L000<700<01`L00P021`<00PL500031`000087
0P021`<00PL200870P021`0400L000870P000`L01`0200870P021`800PL02`07000700L01`070080
0`L02P071`0700L01`041`<000<700L08`L001l7h@0P1`0080L010071`031`800`L01@0700L00087
0`041`800PL0100700L200<70P031`0700L000L01`0400<70`021`0600L000L00PL3008700H01`00
1`031`800`L3008700<01`000P041`800`L200031`0000<70P041`<000@700L70`031`800`L01P07
000700870`021`0600L000L00PL300<710000`L01`0200031`0700870P031`8000@700L00PL200@7
0`021`0500L01`000`L200<700@01`L08@L0024700<01`000`L300D70P001@L01`L000H700@01`00
0`L01P071`0700<70P000`L00003008700<01`L00P0010L000L200870P001`L01`0700L00P0010L0
00021`@000<700000PL0100700021`0400L71`8000D700L700031`0500L700L00P031`0300L70080
00@700L70P000`L0000200870`002PL000L01`0700L200870P0010L000L2008700<01`L01@000`L0
00031`0300L0008700@01`L70P000`L01`051`0500L700L00P051`<00`L00`07000R1`008PL200<7
00@01`001@L200<70P061`8010L300870P021`0400L71`<00`L300041`071`<010L2008700<01`L0
0P031`8000D700L01`0400<70P031`8000@700L00PL300<70`021`0400L01`800`L200<710001@L0
1`0700800`L2008700<01`L00P041`<00PL00`07000200<70`031`0300L700800PL300@70P061`80
0`L200D70P000`L01`021`808`L002<70P021`0300L7008010L200<700<01`001@NU00D700<01`00
0`L200@70P021`0300L7008090L002@70P000`L01`021`800PL010071`021`0400L700D70P031`07
00L700L01`0300871@021`0300L700800PL0100700021`8000L700L01`0700800`L300051`0000L0
0P021`0400L000870P001PL01`07008700D01`L700021`0600L01`070P021`8000@700L70P001@L0
000700<00`L200071`0700L01`0200870P0010L01`L2008700<01`L01@021`<000@700L00PL01007
1`L200D700@01`L00PL010071`021`800`L01007000U1`009@L300@70`041`0300L000<700<01`L0
0PL0100700L200<70`021`@000<700L010031`<00PL400041`071`<00PL0100700L200031`000080
0`L3008700D01`0700031`<00`L200031`0000<70`031`0500L01`000PL300<710001`L000L01`00
0PL3008700<01`000`021`<00`L400031`0700@00PL300<70P0010L01`041`0700L71`0700041`<0
10L302H7000V1`801@L00`071`041`8010L01@071`L0008700<01`0010L010071`L3008700<01`L0
0`031`<00PL01P07000700<700D01`L700021`0300L000870P041`<00PL00`071`0200@700<01`L0
0PL01@0700L000@700<01`L00PL2008700<01`L00`041`800PL00`0700021`0500L71`000`L01P07
000700870`031`<00PL00`071`0300<700<01`L00PL00`0700021`0500L71`0010L200H700<01`L0
0`L202L7000W1`801@L00`071`041`0300L700<700L01`L01`0700800`L3008710000`L01`0400<7
00D01`001`0200041`0000870`021`0400L01`8000<700000P031`<00PL01@0700L000<70`031`80
00<700000`L300<700D01`0700021`<00`L400071`001`0700021`<00PL300041`001`8000<700L0
0PL400031`0700@00PL300<70P0010L01`021`0300L700<700<01`L010L00`071`031`80:0L002L7
d@0X1`00:@L200D700<01`L00PL00`0700051`8010L3008700<01`000P031`<00`L300031`070087
0P041`800PL00`071`0200@70P021`0300L000<00`L200<700<01`000PL00`071`0300<70`021`06
00L700L00`L200<7100010L01`L200@70P021`0300L7008010L200<700<01`000P031`<00`L30004
1`071`<010L200D700<01`0010L00`071`031`80:PL002X70P051`0500L71`000PL00`071`021`80
10L300870`000`L01`021`<00`L300061`071`070P031`<000@700L70P041`0600L01`0710031`80
0`L200041`0700870`031`<00PL0100700L200<70P031`@000H700L01`041`800PL00`07000200<7
0P001PL01`L01`<00`L300<700<01`000P021`<010L200@700@01`L00`L00`071`031`80:`L002/7
0P051`0400L700<700D01`L01`0200<700D01`L01`0200870P000`L00003008700<01`L00P0010L0
1`L300041`001`<000<700L00P021`800PL400031`00008700@01`000PL010071`L200051`071`00
0`L01@071`0700800`L00`071`0200041`071`8000<700000P021`800PL200031`0700<000@70007
0`021`0400L0008700<01`L01@000`L000021`8000D700L700031`8000D700L700031`0400L700D7
0P0/1`00;0L200D700<01`0010L2008700@01`070P031`800`L01`07000700L010031`800`L01P07
000700870`021`0600L000L00`L200<70`021`0300L0008010L200<70P000`L000031`8010L30004
1`071`<00`L200<700H01`001`021`<00PL01P07000700<70P031`@000<700L00P000`L01`021`80
0`L200041`0700870P041`0300L000D70P0]1`00;@L200D70P041j/010L200D700<01`L0;@L002l7
00<01`L00`L01@071`L0008700H01`0700L200@70P021`800PL200051`071`000PL200041`071`80
0PL2008710000`L000021`8000H700001`021`0500L000L00P021`0400L71`8000@700L70P000`L0
00021`0400L000<700<01`L00P001@L000L0008700<01`000P000`L000021`8000<700000P021`80
0PL2008700@01`000PL01@071`0700800PL200870P041`8000H700L01`021`0500L71`001@L00`07
1`0^1`00<0L00`071`021`8000<700L00`L300<700<01`L00PL00`07000200@70P031`<000@700L7
0`041`<000<700L00`041`<000@700L70`021`<00`L400071`071`0700031`0300L0008700<01`00
0`031`<00PL3008700<01`000P041`<000<700L00`041`<00PL00`07000200<70P041`<000<700L0
0`L010071`L300@710041`0300L702l7000`1`800`L0100700051`0300L700870P031`0300L00080
10L200<70`0010L01`L300@70`0010L01`L200@70P021`0300L700<00PL300<710000`L01`021`80
0`L200<700<01`000`031`800`L3008700<01`L00P041`800PL00`07000200@70`021`0300L00080
0`L200@70`000`L01`021`8010L00`071`031`8000<700L00PL20347000a1`800PL00`071`0200<7
Y@031`800PL00`071`020387000b1`8000<700L00PL200<700<01`000PL01P071`0700<70P0010L0
1`021`0300L000<70`021`<00PL00`071`0300871P021`<00`L300871@031`8000@700L70P000`L0
00021`0400L000<71@021`<00`L300871P021`<00PL00`071`0300870`031`0300L0008700@01`07
0P031`0300L0008700H01`L01`031`800`L01007000c1`00<`L300@70P021`0600L700L00`L200<7
00<01`000PL0100700L200<70P031`0600L000L00`L2008700H01`001`031`0300L700870`021`03
00L0008010L200<700D01`0700031`8010L300041`071`<010L01P071`L01`8000@700L70P031`06
00L000L00`L200<70P0010L01`021`0300L000<70P031`0300L0008700<01`L00P041`<0=0L003@7
0P051`8000<700L00PL2008700<01`000`L200031`0700800`L00`071`0200051`071`000PL30087
00D01`001`0600870`021`800PL00`07000400@70`021`8000<700000PL300@71@0010L01`L20087
0`021`H000D7000700021`<00PL01@071`0700800PL010071`L200031`0700800`L00`0700021`80
0`L0100700051`80=@L003D70P051`<010L00`0700031`0400L700<70P051`<00`L00`0700031`80
00<700L00PL400870P001@L01`0700@00`L300870P021`8000<700000P031`@000<700000PL20087
0`031`@000D700L01`02008710031`0400L000<700<01`000`L300D70P031`0400L700<700<01`00
10L300D70P0f1`00=@Ne03H7000g1`801@L200<700<01`0010L3008700@01`000`L200031`0700@7
00<01`L00PL300<710031`800PL300031`00008710021`0700L000L01`0400<710000`L01`020004
1`071`@00PL200041`0000870P031`@00`L300@700<01`L00`L0100700031`8000@700L70`041`03
00L000<70P051`80>0L003P70P041`<000<700L00PL010071`021`0300L0008700@01`070P031`03
00L700870P021`8000@700070P001@L00007008000<700L00P031`0900L000L01`0700800PL40087
0P000`L000021`@00PL200051`0700L00P000`L01`021`8000<700L00P001@L00007008000@70007
0P021`8010L010071`L200041`07008700<01`000PL010071`031`0300L0008010L203T7000i1`80
0`L0100700051`800`L200<700<01`L00P051`0600L71`070P0010L01`L3008700H01`001`021`80
10L3008700<01`L00P041`800`L500<70P041`800PL00`071`0300@70P021`0600L000L00PL30087
00H01`001`031`0300L700<70P021`0400L71`800`L200D70P000`L01`021`80>PL003X7Z`0k1`00
>`L010071`041`0300L700<710021`0500L01`000PL00`071`041`0300L000<70P000`L01`021`03
00L000<70`021`800PL2008700H01`0700L200061`0700L00PL01@071`L0008700<01`000P002@L0
00L01`0700021`800PL200870P041`0300L000<700@01`000PL200031`0700D700P01`L01`070087
10051`0300L7008700@01`L0?0L003`700<01`001@L00`071`031`<00`L300@700<01`L010L200@7
0P051`8010L2008700<01`000`031`<00PL00`0700021`0300L700<00`L3008700H01`L01`021`<0
0`L400041`071`8010L200D70P041`801PL00`071`021`<00`L300D700<01`L00`L00`07000m1`00
?@L200H700H01`L700L200@700<01`L010L00`071`021`0300L000@70P061`0400L71`8000D700L0
1`0200031`0700<700@01`L70P0010L01`021`<00`L3008700@01`070P031`0300L7008700T01`00
1`0700L00P031`0300L700@70P041`0300L000@700<01`L010L00`071`021`8000<700L00PL00`07
1`041`80?PL003h700<01`L01@L00`07002>00031`0700H700<01`L0?@L004L700<01`L010L20004
1`0700H70P031`0600L000L00PL00`071`021`0300L0008700@01`L70P031`0300L0008700<01`00
0P041`800`L200031`0000<70P041`<000<700L00P000`L01`021`800`L01P071`0700@700D01`L0
1`0200031`0700870P061`0400L01`801PL00`071`161`00B0L00`071`031`8000D700L700051`80
0`L01P07000700870P031`0600L700L00PL300<70P031`0300L0008010L200<700D01`0700031`80
10L300031`0700870P031`<00PL00`0700021`0400L71`800PL01P07000700<70P051`0500L700L0
0P051`0300L704L700191`0500L71`000PL200<700D01`L700021`0300L700800PL200<70P021`04
00L71`8000<700000`021`0300L000870P021`0400L71`8000@700L70P000`L000021`0400L000<7
00<01`L00P021`0300L000871@000`L000031`0300L700800`L200870P021`0400L700870P031`80
0PL01@071`L004X7001:1`0300L000@700<01`L00PL300@700<01`0010L00`071`021`8000<700L0
0`L300031`0700@00PL00`0700031`8000@700L00PL00`0700031`0300L0008700@01`070P031`03
00L0008710000`L01`0300@700@01`0010L00`071`021`0300L000@70`041`0300L7008700<01`00
B`L004/700<01`L00`Mm00D700<01`L0BPL005<700D01`L01`0200D700<01`L00PL00`0700041`80
10L300051`0700L00P021`0300L000<70P0010L01`021`0300L000<700<01`000PL0100700L200<7
00<01`000PL200051`0700L00`041`8010L00`0700041`0300L700<70P001@L01`L005@7001D1`80
0`L200D700D01`L700021`0300L700870P021`8000<700000P031`<00`L010071`031`8000<700L0
20L0100700031`0400L700<70`031`@000<700000PL200@700@01`L00`L00`071`031`800`L205D7
001D1`8010L200D700@01`L00`L010071`L400041`071`8010L300@70`041`802`L200@70`041`<0
10L2008700<01`000`031`0500L71`000PL00`071`031`8010L205D7001C1`0400L700@70P051`03
00L000@700D01`L01`0200041`071`<00`L0100700031`<010L200/70P041`<00`L200031`070087
0`021`0600L000L00PL00`071`021`0300L000D70P041`0400L705@7001B1g/0D`L005d70P051`03
00L700@70P031`<00PL01P07000700<70P031`8000@700L00PL00`071`051`0700L700L01`0200<7
0P031`0600L000L00PL300<70P061`0300L700<70P1N1`00GPL200@70P051`8010L2008700<01`L0
0`031`800`L00`0700021`0500L71`001@L01@071`L0008700<01`000`L200<70`021`0300L70080
10L200D70P041`80G`L005l70P031`0300L000<700@01`000PL400031`0700870P021`0400L70087
0P0010L01`041`0500L71`0010L0100700L2008700@01`L00PL200<700<01`000`021`8000<700L0
0PL00`0700031`80H0L00607G`1Q1`00HPL00`0700031`0500L71`000PL00`0700021`8010L200H7
0P041`0300L700@700<01`L010L00`071`021`801PL200@70P021`0300L0008700D01`L700031`03
00L006<7001S1`801`L010071`L200<70P031`0300L000@700<01`0010L00`071`031`0300L000D7
00<01`L00PL00`0700041`0300L000<70P031`800`L00`071`051`80I0L006@700<01`L01@L00`07
1`021`0300L700<700@01`L00PL010071`071`0300L7008700D01`L700041`0300L700D700@01`L0
0PL010071`051`0300L7008700<01`L01@L00`071`1S1`00K0L00`071`091`0300L000<70P081`05
00L71`001@L01@071`L000P70P031`0300L000/700<01`L0J`L006`7A`1]1`00NPL010071`021`03
00L700L700<01`L01`L00`071`071`0400L7008700<01`L0N@L007/70P041`0300L700D700<01`L0
2@L00`071`051`0300L700870P1l1`00N`L200D700<01`L00`L00`071`0;1`0300L700<700<01`L0
0`L207`7001j1`0400L700D700D01`L7000?1`0500L71`001@L010071`1k1`00N@L]07X700251`03
00L7014700<01`L0Q0L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-10.3946, -10.3946, 0.0724361, \
0.0724361}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell["Diffraction Pattern", "Subtitle",
  Background->RGBColor[1, 0, 1]],

Cell["Formulae for the diffraction pattern.", "Text",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(In\ my\ \(notes : \ 
          e\_k\%\[VerticalSeparator]\) = \ \((e\_k\%y, \ \(-e\_k\%x\))\), 
    e\_j\%\(\('\)\(\[VerticalSeparator]\)\) = \ \(\((\(-e\_j\%y\), \ 
              e\_j\%x)\) . \ 
            In\ the\ paper\ the\ notation\ was\ changed\ to\ b\_jl = \ \(e\_k\
\%\[VerticalSeparator] . 
            e\_l = \(epk[k] . 
                e[l]\ and\ b\_kl = \ \
\(e\_j\%\(\('\)\(\[VerticalSeparator]\)\) . e\_l = 
              epj[j] . e[l]\)\)\)\)\)], "DisplayFormula"],

Cell[BoxData[{
    \(epk[
        k_] := {\(e[
            k]\)[\([2]\)], \(-\(e[k]\)[\([1]\)]\)}\), "\[IndentingNewLine]", 
    \(epj[j_] := {\(-\(e[j]\)[\([2]\)]\), \(e[j]\)[\([1]\)]}\)}], "Input",
  CellLabel->"In[16]:="],

Cell[CellGroupData[{

Cell["Basis of the reciprocal space. Formula  (21), Acta Cryst.", "Text"],

Cell[BoxData[
    \(U[j_, \ k_]\  := \ 
      a[\([j, k]\)]\ e[j]\  + \ \[Sum]\+\(l = 1\)\%5 
            If[\((l != j)\) && \((l != k)\), \((\ epk[k] . e[l])\)\ e[l], 
            0]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(\(\(\ \)\(V[j_, \ k_]\  := \ 
      a[\([j, k]\)]\ e[k]\  + \ \[Sum]\+\(l = 1\)\%5 
            If[\((l != j)\) && \((l != k)\), \((\ epj[j] . e[l])\)\ e[l], 
            0]\)\)\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(q1[j_, \ 
        k_]\  := \ \(2\ \[Pi]\ \((U[j, k] . V[j, k])\)\ V[j, k]\  - \ \((V[j, \
k] . V[j, k])\)\ U[j, k]\)\/\(\((U[j, k] . U[j, k])\)\ \((V[j, k] . V[j, \
k])\)\  - \ \((U[j, k] . V[j, k])\)\^2\)\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(q2[j_, \ 
        k_]\  := \ \(2\ \[Pi]\ \((U[j, k] . V[j, k])\)\ U[j, k]\  - \ \((U[j, \
k] . U[j, k])\)\ V[j, k]\)\/\(\((U[j, k] . U[j, k])\)\ \((V[j, k] . V[j, \
k])\)\  - \ \((U[j, k] . V[j, k])\)\^2\)\)], "Input",
  CellLabel->"In[21]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reciprocal lattice. Formula (20), Acta Cryst.", "Text"],

Cell[BoxData[
    \(Q[j_, \ k_, \ 
        g_]\  := \ \((a[\([j, k]\)]\ m\  + \ \[Sum]\+\(l = 1\)\%5 
                  If[\((l != j)\) && \((l != k)\), \((\ 
                      epk[k] . e[l])\)\ g[\([l]\)], 0])\)\ q1[j, 
            k]\  + \ \(\((a[\([j, k]\)]\ n\  + \ \[Sum]\+\(l = 1\)\%5 
                  If[\((l != j)\) && \((l != k)\), \((\ 
                      epj[j] . e[l])\)\ g[\([l]\)], 0])\)\(\ \)\(q2[j, 
            k]\)\(\ \)\)\)], "Input",
  CellLabel->"In[22]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
AL Returns the lattice coorresponding to (j,k,g) with m and n \
running between -Np to Np\
\>", "Text"],

Cell[BoxData[
    \(\(RL[j_, \ k_, \ g_, \ Np_]\  := \ \ Flatten[
          Table[N[Q[j, \ k, \ g]] /. {m \[Rule] x, n \[Rule] y}, {x, \(-Np\), 
              Np}, {y, \(-Np\), Np}], 1];\)\)], "Input",
  CellLabel->"In[23]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basis of the reciprocal of the average lattice", "Text",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(basis21\  = \ FullSimplify[{q1[2, 1]\ , q2[2, 1]\ }]\)], "Input",
  CellLabel->"In[201]:="],

Cell[BoxData[
    \({{4\/5\ \@\(1 - 2\/\@5\)\ \[Pi], \(-\(1\/25\)\)\ \((\(-5\) + \@5)\)\ \
\((4 + \((\(-3\) + \@5)\)\ \[Pi])\)}, {2\/5\ \@\(2 - 2\/\@5\), 
        2\/25\ \((\(-5\) + 3\ \@5)\)\ \((\(-1\) + 2\ \[Pi])\)}}\)], "Output",
  CellLabel->"Out[201]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(basis31\  = \ FullSimplify[{q1[3, 1]\ , q2[3, 1]\ }]\)], "Input",
  CellLabel->"In[202]:="],

Cell[BoxData[
    \({{\(-\(4\/5\)\)\ \@\(1 + 2\/\@5\)\ \[Pi], \(-\(1\/25\)\)\ \((5 + \@5)\)\
\ \((\(-4\) + \((3 + \@5)\)\ \[Pi])\)}, {2\/5\ \@\(2 + 2\/\@5\), \(-\(2\/25\)\
\)\ \((5 + 3\ \@5)\)\ \((\(-1\) + 2\ \[Pi])\)}}\)], "Output",
  CellLabel->"Out[202]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(basis32\  = \ FullSimplify[{q1[3, 2]\ , q2[3, 2]\ }]\)], "Input",
  CellLabel->"In[203]:="],

Cell[BoxData[
    \({{\(-\(2\/5\)\)\ \((\@\(2 - 2\/\@5\) - \@\(10 - 22\/\@5\)\ \[Pi])\), \
\(-\(1\/25\)\)\ \((\(-5\) + \@5)\)\ \((\(-1\) + \@5 + 
              2\ \[Pi])\)}, {\(-\(2\/5\)\)\ \@\(4 - 8\/\@5\)\ \((\(-1\) + \
\[Pi])\), \(-\(4\/25\)\)\ \((\(-\@5\) + \((\(-5\) + 
                    2\ \@5)\)\ \[Pi])\)}}\)], "Output",
  CellLabel->"Out[203]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(basis41\  = \ FullSimplify[{q1[4, 1], q2[4, 1]}]\)], "Input",
  CellLabel->"In[204]:="],

Cell[BoxData[
    \({{4\/5\ \@\(1 + 2\/\@5\)\ \[Pi], \(-\(1\/25\)\)\ \((5 + \@5)\)\ \((\(-4\
\) + \((3 + \@5)\)\ \[Pi])\)}, {\(-\(2\/5\)\)\ \@\(2 + 2\/\@5\), \(-\(2\/25\)\
\)\ \((5 + 3\ \@5)\)\ \((\(-1\) + 2\ \[Pi])\)}}\)], "Output",
  CellLabel->"Out[204]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(basis42\  = FullSimplify[{q1[4, 2], q2[4, 2]}]\)], "Input",
  CellLabel->"In[205]:="],

Cell[BoxData[
    \({{4\/5\ \@\(1 + 2\/\@5\)\ \((\(-1\) + \[Pi])\), \(-\(4\/25\)\)\ \
\((\(-\@5\) + \((5 + 
                    2\ \@5)\)\ \[Pi])\)}, {\(-\(2\/5\)\)\ \((\@\(2 + 2\/\@5\) \
- \@\(10 + 22\/\@5\)\ \[Pi])\), 
        1\/25\ \((5 + \@5)\)\ \((1 + \@5 - 2\ \[Pi])\)}}\)], "Output",
  CellLabel->"Out[205]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(basis43\  = \ FullSimplify[{q1[4, 3], q2[4, 3]}]\)], "Input",
  CellLabel->"In[206]:="],

Cell[BoxData[
    \({{\(-\(2\/5\)\)\ \@\(1 - 2\/\@5\)\ \((2 + \((\(-1\) + \@5)\)\ \[Pi])\), \
\(-\(\(2\ \((2 + \[Pi] - \@5\ \[Pi])\)\)\/\(5\ \@5\)\)\)}, {\(-\(2\/5\)\)\ \@\
\(1 - 2\/\@5\)\ \((2 + \((\(-1\) + \@5)\)\ \[Pi])\), \(2\ \((2 + \[Pi] - \@5\ \
\[Pi])\)\)\/\(5\ \@5\)}}\)], "Output",
  CellLabel->"Out[206]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(basis51\  = \ FullSimplify[{q1[5, 1], q2[5, 1]}]\)], "Input",
  CellLabel->"In[207]:="],

Cell[BoxData[
    \({{\(-\(4\/5\)\)\ \@\(1 - 2\/\@5\)\ \[Pi], \(-\(1\/25\)\)\ \((\(-5\) + \
\@5)\)\ \((4 + \((\(-3\) + \@5)\)\ \[Pi])\)}, {\(-\(2\/5\)\)\ \@\(2 - \
2\/\@5\), 2\/25\ \((\(-5\) + 3\ \@5)\)\ \((\(-1\) + 2\ \[Pi])\)}}\)], "Output",\

  CellLabel->"Out[207]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(basis52\  = FullSimplify[{q1[5, 2], q2[5, 2]}]\)], "Input",
  CellLabel->"In[208]:="],

Cell[BoxData[
    \({{2\/5\ \@\(1 + 2\/\@5\)\ \((\(-2\) + \[Pi] + \@5\ \[Pi])\), \(2\ \((2 \
+ \[Pi] + \@5\ \[Pi])\)\)\/\(5\ \@5\)}, {2\/5\ \@\(1 + 2\/\@5\)\ \((\(-2\) + \
\[Pi] + \@5\ \[Pi])\), \(-\(\(2\ \((2 + \[Pi] + \@5\ \[Pi])\)\)\/\(5\ \@5\)\)\
\)}}\)], "Output",
  CellLabel->"Out[208]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(basis53\  = \ FullSimplify[{q1[5, 3], q2[5, 3]}]\)], "Input",
  CellLabel->"In[209]:="],

Cell[BoxData[
    \({{\(-\(2\/5\)\)\ \((\@\(2 + 2\/\@5\) - \@\(10 + 22\/\@5\)\ \[Pi])\), \
\(-\(1\/25\)\)\ \((5 + \@5)\)\ \((1 + \@5 - 
              2\ \[Pi])\)}, {4\/5\ \@\(1 + 2\/\@5\)\ \((\(-1\) + \[Pi])\), 
        4\/25\ \((\(-\@5\) + \((5 + 2\ \@5)\)\ \[Pi])\)}}\)], "Output",
  CellLabel->"Out[209]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(basis54\  = \ FullSimplify[{q1[5, 4], q2[5, 4]}]\)], "Input",
  CellLabel->"In[210]:="],

Cell[BoxData[
    \({{\(-\(2\/5\)\)\ \@\(4 - 8\/\@5\)\ \((\(-1\) + \[Pi])\), 
        4\/25\ \((\(-\@5\) + \((\(-5\) + 
                    2\ \@5)\)\ \[Pi])\)}, {\(-\(2\/5\)\)\ \((\@\(2 - 2\/\@5\) \
- \@\(10 - 22\/\@5\)\ \[Pi])\), 
        1\/25\ \((\(-5\) + \@5)\)\ \((\(-1\) + \@5 + 
              2\ \[Pi])\)}}\)], "Output",
  CellLabel->"Out[210]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Append[basis21, {0, 0}], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-6\), 6}, {\(-6\), 6}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[230]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-6)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-4)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-2)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(2)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(4)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(6)] 1 .4875 0 1 Mshowa
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-4)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-2)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(2)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(4)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.56805 .51474 Mdot
.53505 .56017 Mdot
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[230]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00R7oo0`00UGoo0028Ool01000Oomoo`00U7oo0028Ool01000Oomoo`001Goo0P00
SGoo0022Ool40002Ool30006Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`03001oogoo08ao
o`00RGoo0`001Goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool008Yoo`<000Aoo`03001oogoo08aoo`00Rgoo00<007oo
Ool00goo00<007ooOol0S7oo0028Ool50004Ool2002=Ool0089oo`@0009oo`04001oogoo0005Ool0
0`00Oomoo`2<Ool008Uoo`03001oo`0000Eoo`03001oogoo08aoo`00RWoo0P001Goo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00R7oo10001Goo00<007ooOol0S7oo0028Ool00`00Oomoo`06
Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`8008eoo`00PWoo100017oo00<007ooOol017oo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0029Ool20006Ool00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`001goo0`00;Goo0`00:Goo1000:Woo00<0
07ooOol0:Goo1000;7oo0`00:Woo0`000goo0007Ool01000Oomoo`00;Goo00<007ooOol0:7oo00<0
07ooOol0:goo00<007ooOol0:Goo00<007ooOol0;Woo00<007ooOol0:Goo00@007ooOol0009oo`00
1goo00@007ooOol002Yoo`D002Yoo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yoo`D0
02Yoo`04001oogoo0002Ool00003Ool000000080009oo`<002Eoo`@0009oo`04001oogoo000TOol4
0004Ool00`00Oomoo`0YOol00`00Oomoo`0[Ool00`00Oomoo`0YOol01000Oomoo`00:goo0`000goo
0008Ool00`00Oomoo`0[Ool00`00Ool0000ZOol01000Oomoo`00:Woo00<007ooOol0:Goo00@007oo
Ool002]oo`03001oo`0002aoo`03001oogoo009oo`0027oo0`00;7oo0P00:goo0P00:7oo1@00:goo
0P00;Goo0P00;7oo0`000Woo002=Ool7002<Ool008aoo`T008]oo`00Rgoo2`00RWoo002:Ool=0029
Ool008Yoo`d000Yoo`D007Yoo`001Wooo`0060000goo0006Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool=0005Ool00`00Oomoo`0:000:Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`01Ool000Ioo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo
02Eoo`d000Moo`/001Ioo`03001oogoo02]oo`03001oogoo02aoo`03001oogoo005oo`00Rgoo2`00
1goo3@00MWoo002<Ool90008Ool=001fOol008eoo`L000Uoo`d007Ioo`00SWoo1@002Woo3@00MWoo
002AOol00`00Oomoo`09Ool=001fOol0095oo`03001oogoo00Yoo`/007Moo`00TGoo00<007ooOol0
2goo2@00N7oo002AOol00`00Oomoo`0<Ool7001iOol0095oo`03001oogoo00Aoo`D000Aoo`D007Yo
o`00TGoo0P0017oo1`00PWoo002AOol00`00Oomoo`02Ool90021Ool0095oo`04001oogooOol;0020
Ool0095oo`03001oogoo00d007moo`00TGoo00<007ooOol03@00Ogoo002AOol00`00Oomoo`0=001o
Ool0095oo`03001oogoo00d007moo`00TGoo00<007ooOol03@00Ogoo002AOol01000Oomoogoo2`00
P7oo002AOol00`00Oomoo`02Ool90021Ool0095oo`03001oogoo00=oo`L0089oo`00TGoo0P001Goo
1@00Pgoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00R7oo10001Goo00<007ooOol0
S7oo0028Ool00`00Oomoo`06Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`8008eoo`00RWoo
00<007ooOol017oo00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0029Ool2
0006Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol2002=Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00
SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002:Ool30004Ool00`00Oomoo`2<Ool0
08]oo`03001oogoo00=oo`03001oogoo08aoo`00R7oo1@0017oo0P00SGoo0028Ool01000Oomoo`00
1Goo00<007ooOol0S7oo0029Ool00`00Ool00005Ool00`00Oomoo`2<Ool008Yoo`8000Eoo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol2002=Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol2002=Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo0028Ool30006Ool00`00Oomoo`2<Ool008Qoo`04001oogoo0005Ool00`00Oomoo`2<
Ool008Qoo`04001oogoo0005Ool2002=Ool008Qoo`<009Eoo`00RGoo00<007ooOol0U7oo0029Ool3
002DOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.25906, -6.19431, 0.0431659, \
0.0431659}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[230]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Append[basis31, {0, 0}], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-6\), 6}, {\(-6\), 6}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[231]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-6)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-4)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-2)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(2)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(4)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(6)] 1 .4875 0 1 Mshowa
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-4)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-2)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(2)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(4)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.21173 .19971 Mdot
.55671 .08762 Mdot
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[231]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00R7oo0`00UGoo0028Ool01000Oomoo`00U7oo0028Ool01000Oomoo`001Goo0P00
SGoo0022Ool40002Ool30006Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`03001oogoo08ao
o`00RGoo0`001Goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`0:Ool5001mOol0095o
o`03001oogoo00Uoo`L007aoo`00TGoo00<007ooOol027oo2@00Ngoo002AOol00`00Oomoo`07Ool;
001jOol0095oo`8000Moo`d007Uoo`00TGoo00<007ooOol01Woo3@00NGoo002AOol00`00Oomoo`06
Ool=001iOol0095oo`03001oogoo00Ioo`d007Uoo`00TGoo00<007ooOol01Woo3@00NGoo002AOol0
0`00Oomoo`07Ool;001jOol0095oo`03001oogoo00Qoo`T007]oo`00TGoo00<007ooOol02Goo1`00
O7oo002AOol00`00Oomoo`0:Ool5001mOol0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool008Yoo`<000Aoo`03001o
ogoo08aoo`00Rgoo00<007ooOol00goo00<007ooOol0S7oo0028Ool50004Ool2002=Ool0089oo`@0
009oo`04001oogoo0005Ool00`00Oomoo`2<Ool008Uoo`03001oo`0000Eoo`03001oogoo08aoo`00
RWoo0P001Goo00<007ooOol0S7oo000nOol5001>Ool00`00Oomoo`2<Ool003eoo`L004eoo`03001o
ogoo08aoo`00?7oo2@00C7oo00<007ooOol0S7oo000kOol;001;Ool00`00Oomoo`2<Ool003Yoo`d0
04Yoo`03001oogoo08aoo`00>Woo3@00BWoo00<007ooOol0S7oo000jOol=001:Ool00`00Oomoo`2<
Ool003Yoo`d004Yoo`03001oogoo08aoo`00>Woo3@00BWoo0P00SGoo000kOol;001;Ool00`00Oomo
o`2<Ool003aoo`T004aoo`03001oogoo08aoo`00?Goo1`00CGoo00<007ooOol0S7oo000nOol5001>
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
R7oo10001Goo00<007ooOol0S7oo0028Ool00`00Oomoo`06Ool00`00Oomoo`2<Ool008Uoo`03001o
ogoo00Eoo`8008eoo`00PWoo100017oo00<007ooOol017oo00<007ooOol0S7oo0028Ool01000Oomo
o`001Goo00<007ooOol0S7oo0029Ool20006Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`8008eoo`001goo0`00;Goo0`00:Goo1000:Woo00<007ooOol0:Goo1000;7oo0`00:Woo0`00
0goo0007Ool01000Oomoo`00;Goo00<007ooOol0:7oo00<007ooOol0:goo00<007ooOol0:Goo00<0
07ooOol0;Woo00<007ooOol0:Goo00@007ooOol0009oo`001goo00@007ooOol002Yoo`D002Yoo`03
001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yoo`D002Yoo`04001oogoo0002Ool00003Ool0
00000080009oo`<002Eoo`@0009oo`04001oogoo000TOol40004Ool00`00Oomoo`0YOol00`00Oomo
o`0[Ool00`00Oomoo`0YOol01000Oomoo`00:goo0`000goo0008Ool00`00Oomoo`0[Ool00`00Ool0
000ZOol01000Oomoo`00:Woo00<007ooOol0:Goo00@007ooOol002]oo`03001oo`0002aoo`03001o
ogoo009oo`0027oo0`00;7oo0P00:goo0P00:7oo1@00:goo0P00;Goo0P00;7oo0`000Woo002=Ool7
002<Ool008aoo`T008]oo`00Rgoo2`00RWoo002:Ool=0029Ool008Yoo`d008Uoo`001Wooo`006000
0goo0006Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02Ool=0005Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`01
Ool000Ioo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo02Eoo`d002Qoo`03001oogoo02]o
o`03001oogoo02aoo`03001oogoo005oo`00Rgoo2`00RWoo002<Ool9002;Ool008eoo`L008aoo`00
SWoo1@00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`80
08eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool008Qoo`@000Eoo`03001oogoo08aoo`00R7oo00<007ooOol01Woo
00<007ooOol0S7oo0029Ool00`00Oomoo`05Ool2002=Ool008Yoo`03001oogoo00Aoo`03001oogoo
08aoo`00R7oo00@007ooOol000Eoo`03001oogoo08aoo`00RGoo0P001Woo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00RWoo0`0017oo00<007ooOol0S7oo002;Ool00`00Oomoo`03Ool00`00
Oomoo`2<Ool008Qoo`D000Aoo`8008eoo`00R7oo00@007ooOol000Eoo`03001oogoo08aoo`00RGoo
00<007oo00001Goo00<007ooOol0S7oo002:Ool20005Ool00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00R7oo0`001Woo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0028Ool01000Oomoo`001Goo
0P00SGoo0028Ool3002EOol008Uoo`03001oogoo09Aoo`00RGoo0`00U7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.25906, -6.19431, 0.0431659, \
0.0431659}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[231]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Append[basis32, {0, 0}], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-6\), 6}, {\(-6\), 6}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[232]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-6)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-4)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-2)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(2)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(4)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(6)] 1 .4875 0 1 Mshowa
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-4)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-2)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(2)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(4)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.50701 .56928 Mdot
.45361 .55193 Mdot
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[232]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00R7oo0`00UGoo0028Ool01000Oomoo`00U7oo0028Ool01000Oomoo`001Goo0P00
SGoo0022Ool40002Ool30006Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`03001oogoo08ao
o`00RGoo0`001Goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool008Yoo`<000Aoo`03001oogoo08aoo`00Rgoo00<007oo
Ool00goo00<007ooOol0S7oo0028Ool50004Ool2002=Ool0089oo`@0009oo`04001oogoo0005Ool0
0`00Oomoo`2<Ool008Uoo`03001oo`0000Eoo`03001oogoo08aoo`00RWoo0P001Goo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00R7oo10001Goo00<007ooOol0S7oo0028Ool00`00Oomoo`06
Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`8008eoo`00PWoo100017oo00<007ooOol017oo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0029Ool20006Ool00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`001goo0`00;Goo0`00:Goo1000:Woo00<0
07ooOol0:Goo1000;7oo0`00:Woo0`000goo0007Ool01000Oomoo`00;Goo00<007ooOol0:7oo00<0
07ooOol0:goo00<007ooOol0:Goo00<007ooOol0;Woo00<007ooOol0:Goo00@007ooOol0009oo`00
1goo00@007ooOol002Yoo`D002Yoo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yoo`D0
02Yoo`04001oogoo0002Ool00003Ool000000080009oo`<002Eoo`@0009oo`04001oogoo000TOol4
0004Ool00`00Oomoo`0YOol00`00Oomoo`0[Ool00`00Oomoo`0YOol01000Oomoo`00:goo0`000goo
0008Ool00`00Oomoo`0[Ool00`00Ool0000ZOol01000Oomoo`00:Woo00<007ooOol0:Goo00@007oo
Ool002]oo`03001oo`0002aoo`03001oogoo009oo`0027oo0`00;7oo0P00:goo0P00:7oo1@00:goo
0P00;Goo0P00;7oo0`000Woo002=Ool7002<Ool008aoo`T008]oo`00Rgoo2`00RWoo002:Ool=0029
Ool008Yoo`d008Uoo`001Wooo`0060000goo0006Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02Ool=0005
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`01Ool000Ioo`03001oogoo02]oo`03001oogoo02]oo`03001o
ogoo02Eoo`d002Qoo`03001oogoo02]oo`03001oogoo02aoo`03001oogoo005oo`00Rgoo2`00RWoo
002<Ool9002;Ool008eoo`L008aoo`00SWoo1@00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00PGoo1@002goo00<007ooOol0S7oo0020Ool7000:Ool00`00Oomoo`2<Ool007moo`T0
00Uoo`03001oogoo08aoo`00OWoo2`0027oo0P00SGoo001mOol=0007Ool00`00Oomoo`2<Ool007eo
o`d000Ioo`D008]oo`00OGoo3@001Goo1`00RWoo001mOol=0004Ool90029Ool007eoo`d000=oo`/0
08Qoo`00OWoo2`000goo3@00Qgoo001oOol90004Ool=0027Ool0081oo`L000Eoo`d008Moo`00PGoo
1@001Woo3@00Qgoo002<Ool=0027Ool008eoo`/008Qoo`00SWoo2@00RGoo002?Ool7002:Ool0091o
o`D008]oo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool008Qoo`@000Eo
o`03001oogoo08aoo`00R7oo00<007ooOol01Woo00<007ooOol0S7oo0029Ool00`00Oomoo`05Ool2
002=Ool008Yoo`03001oogoo00Aoo`03001oogoo08aoo`00R7oo00@007ooOol000Eoo`03001oogoo
08aoo`00RGoo0P001Woo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00RWoo0`0017oo00<0
07ooOol0S7oo002;Ool00`00Oomoo`03Ool00`00Oomoo`2<Ool008Qoo`D000Aoo`8008eoo`00R7oo
00@007ooOol000Eoo`03001oogoo08aoo`00RGoo00<007oo00001Goo00<007ooOol0S7oo002:Ool2
0005Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00R7oo0`001Woo00<007ooOol0S7oo0028Ool01000Oomoo`001Goo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo0P00SGoo0028Ool3002EOol008Uoo`03001oogoo
09Aoo`00RGoo0`00U7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.25906, -6.19431, 0.0431659, \
0.0431659}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[232]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Append[basis41, {0, 0}], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-6\), 6}, {\(-6\), 6}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[233]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-6)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-4)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-2)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(2)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(4)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(6)] 1 .4875 0 1 Mshowa
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-4)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-2)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(2)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(4)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.78827 .19971 Mdot
.44329 .08762 Mdot
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[233]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00R7oo0`00UGoo0028Ool01000Oomoo`00U7oo0028Ool01000Oomoo`001Goo0P00
SGoo0022Ool40002Ool30006Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`03001oogoo08ao
o`00RGoo0`001Goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo001nOol5000>Ool00`00Oomoo`2<Ool007eo
o`L000eoo`03001oogoo08aoo`00O7oo2@0037oo00<007ooOol0S7oo001kOol;000;Ool00`00Oomo
o`2<Ool007Yoo`d000Yoo`8008eoo`00NWoo3@002Woo00<007ooOol0S7oo001jOol=000:Ool00`00
Oomoo`2<Ool007Yoo`d000Yoo`03001oogoo08aoo`00NWoo3@002Woo00<007ooOol0S7oo001kOol;
000;Ool00`00Oomoo`2<Ool007aoo`T000aoo`03001oogoo08aoo`00OGoo1`003Goo00<007ooOol0
S7oo001nOol5000>Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool008Yoo`<000Aoo`03001o
ogoo08aoo`00Rgoo00<007ooOol00goo00<007ooOol0S7oo0028Ool50004Ool2002=Ool0089oo`@0
009oo`04001oogoo0005Ool00`00Oomoo`2<Ool008Uoo`03001oo`0000Eoo`03001oogoo08aoo`00
RWoo0P001Goo00<007ooOol0S7oo002AOol00`00Oomoo`1:Ool5000mOol0095oo`03001oogoo04Uo
o`L003aoo`00TGoo00<007ooOol0B7oo2@00>goo002AOol00`00Oomoo`17Ool;000jOol0095oo`03
001oogoo04Ioo`d003Uoo`00TGoo00<007ooOol0AWoo3@00>Goo002AOol00`00Oomoo`16Ool=000i
Ool0095oo`03001oogoo04Ioo`d003Uoo`00TGoo0P00Agoo3@00>Goo002AOol00`00Oomoo`17Ool;
000jOol0095oo`03001oogoo04Qoo`T003]oo`00TGoo00<007ooOol0BGoo1`00?7oo002AOol00`00
Oomoo`1:Ool5000mOol0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
R7oo10001Goo00<007ooOol0S7oo0028Ool00`00Oomoo`06Ool00`00Oomoo`2<Ool008Uoo`03001o
ogoo00Eoo`8008eoo`00PWoo100017oo00<007ooOol017oo00<007ooOol0S7oo0028Ool01000Oomo
o`001Goo00<007ooOol0S7oo0029Ool20006Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`8008eoo`001goo0`00;Goo0`00:Goo1000:Woo00<007ooOol0:Goo1000;7oo0`00:Woo0`00
0goo0007Ool01000Oomoo`00;Goo00<007ooOol0:7oo00<007ooOol0:goo00<007ooOol0:Goo00<0
07ooOol0;Woo00<007ooOol0:Goo00@007ooOol0009oo`001goo00@007ooOol002Yoo`D002Yoo`03
001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yoo`D002Yoo`04001oogoo0002Ool00003Ool0
00000080009oo`<002Eoo`@0009oo`04001oogoo000TOol40004Ool00`00Oomoo`0YOol00`00Oomo
o`0[Ool00`00Oomoo`0YOol01000Oomoo`00:goo0`000goo0008Ool00`00Oomoo`0[Ool00`00Ool0
000ZOol01000Oomoo`00:Woo00<007ooOol0:Goo00@007ooOol002]oo`03001oo`0002aoo`03001o
ogoo009oo`0027oo0`00;7oo0P00:goo0P00:7oo1@00:goo0P00;Goo0P00;7oo0`000Woo002=Ool7
002<Ool008aoo`T008]oo`00Rgoo2`00RWoo002:Ool=0029Ool008Yoo`d008Uoo`001Wooo`006000
0goo0006Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02Ool=0005Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`01
Ool000Ioo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo02Eoo`d002Qoo`03001oogoo02]o
o`03001oogoo02aoo`03001oogoo005oo`00Rgoo2`00RWoo002<Ool9002;Ool008eoo`L008aoo`00
SWoo1@00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`80
08eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool008Qoo`@000Eoo`03001oogoo08aoo`00R7oo00<007ooOol01Woo
00<007ooOol0S7oo0029Ool00`00Oomoo`05Ool2002=Ool008Yoo`03001oogoo00Aoo`03001oogoo
08aoo`00R7oo00@007ooOol000Eoo`03001oogoo08aoo`00RGoo0P001Woo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00RWoo0`0017oo00<007ooOol0S7oo002;Ool00`00Oomoo`03Ool00`00
Oomoo`2<Ool008Qoo`D000Aoo`8008eoo`00R7oo00@007ooOol000Eoo`03001oogoo08aoo`00RGoo
00<007oo00001Goo00<007ooOol0S7oo002:Ool20005Ool00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00R7oo0`001Woo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0028Ool01000Oomoo`001Goo
0P00SGoo0028Ool3002EOol008Uoo`03001oogoo09Aoo`00RGoo0`00U7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.25906, -6.19431, 0.0431659, \
0.0431659}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[233]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Append[basis42, {0, 0}], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-6\), 6}, {\(-6\), 6}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[234]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-6)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-4)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-2)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(2)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(4)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(6)] 1 .4875 0 1 Mshowa
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-4)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-2)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(2)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(4)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.69651 .13305 Mdot
.90972 .4265 Mdot
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[234]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00R7oo0`00UGoo0028Ool01000Oomoo`00U7oo0028Ool01000Oomoo`001Goo0P00
SGoo0022Ool40002Ool30006Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`03001oogoo08ao
o`00RGoo0`001Goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`0aOol5001FOol0095oo`03001oogoo031oo`L005Eoo`00TGoo00<007ooOol0;goo2@00E7oo
002AOol00`00Oomoo`0^Ool;001COol0095oo`8002ioo`d0059oo`00TGoo00<007ooOol0;Goo3@00
DWoo002AOol00`00Oomoo`0]Ool=001BOol0095oo`03001oogoo02eoo`d0059oo`00TGoo00<007oo
Ool0;Goo3@00DWoo002AOol00`00Oomoo`0^Ool;001COol0095oo`03001oogoo02moo`T005Aoo`00
TGoo00<007ooOol0<7oo1`00EGoo002AOol00`00Oomoo`0aOol5001FOol008Yoo`<000Aoo`03001o
ogoo08aoo`00Rgoo00<007ooOol00goo00<007ooOol0S7oo0028Ool50004Ool2002=Ool0089oo`@0
009oo`04001oogoo0005Ool00`00Oomoo`2<Ool008Uoo`03001oo`0000Eoo`03001oogoo08aoo`00
RWoo0P001Goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00R7oo10001Goo00<007ooOol0
S7oo0028Ool00`00Oomoo`06Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`8008eoo`00PWoo
100017oo00<007ooOol017oo00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo
0029Ool20006Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0K7oo1@006goo002AOol00`00Oomoo`1[Ool7000JOol0095oo`03001oogoo06Yoo`T001Uoo`00
TGoo0P00JWoo2`0067oo002AOol00`00Oomoo`1XOol=000GOol0095oo`03001oogoo06Qoo`d001Mo
o`00TGoo00<007ooOol0J7oo3@005goo002AOol00`00Oomoo`1XOol=000GOol0095oo`03001oogoo
06Qoo`d001Moo`00TGoo00<007ooOol0JGoo2`0067oo002AOol00`00Oomoo`1ZOol9000IOol0095o
o`03001oogoo06]oo`L001Yoo`00TGoo00<007ooOol0K7oo1@006goo002AOol00`00Oomoo`2<Ool0
095oo`8008eoo`001goo0`00;Goo0`00:Goo1000:Woo00<007ooOol0:Goo1000;7oo0`00:Woo0`00
0goo0007Ool01000Oomoo`00;Goo00<007ooOol0:7oo00<007ooOol0:goo00<007ooOol0:Goo00<0
07ooOol0;Woo00<007ooOol0:Goo00@007ooOol0009oo`001goo00@007ooOol002Yoo`D002Yoo`03
001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yoo`D002Yoo`04001oogoo0002Ool00003Ool0
00000080009oo`<002Eoo`@0009oo`04001oogoo000TOol40004Ool00`00Oomoo`0YOol00`00Oomo
o`0[Ool00`00Oomoo`0YOol01000Oomoo`00:goo0`000goo0008Ool00`00Oomoo`0[Ool00`00Ool0
000ZOol01000Oomoo`00:Woo00<007ooOol0:Goo00@007ooOol002]oo`03001oo`0002aoo`03001o
ogoo009oo`0027oo0`00;7oo0P00:goo0P00:7oo1@00:goo0P00;Goo0P00;7oo0`000Woo002=Ool7
002<Ool008aoo`T008]oo`00Rgoo2`00RWoo002:Ool=0029Ool008Yoo`d008Uoo`001Wooo`006000
0goo0006Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02Ool=0005Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`01
Ool000Ioo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo02Eoo`d002Qoo`03001oogoo02]o
o`03001oogoo02aoo`03001oogoo005oo`00Rgoo2`00RWoo002<Ool9002;Ool008eoo`L008aoo`00
SWoo1@00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`80
08eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool008Qoo`@000Eoo`03001oogoo08aoo`00R7oo00<007ooOol01Woo
00<007ooOol0S7oo0029Ool00`00Oomoo`05Ool2002=Ool008Yoo`03001oogoo00Aoo`03001oogoo
08aoo`00R7oo00@007ooOol000Eoo`03001oogoo08aoo`00RGoo0P001Woo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00RWoo0`0017oo00<007ooOol0S7oo002;Ool00`00Oomoo`03Ool00`00
Oomoo`2<Ool008Qoo`D000Aoo`8008eoo`00R7oo00@007ooOol000Eoo`03001oogoo08aoo`00RGoo
00<007oo00001Goo00<007ooOol0S7oo002:Ool20005Ool00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00R7oo0`001Woo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0028Ool01000Oomoo`001Goo
0P00SGoo0028Ool3002EOol008Uoo`03001oogoo09Aoo`00RGoo0`00U7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.25906, -6.19431, 0.0431659, \
0.0431659}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[234]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Append[basis43, {0, 0}], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-6\), 6}, {\(-6\), 6}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[235]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-6)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-4)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-2)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(2)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(4)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(6)] 1 .4875 0 1 Mshowa
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-4)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-2)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(2)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(4)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.43628 .52807 Mdot
.43628 .47193 Mdot
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[235]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00R7oo0`00UGoo0028Ool01000Oomoo`00U7oo0028Ool01000Oomoo`001Goo0P00
SGoo0022Ool40002Ool30006Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`03001oogoo08ao
o`00RGoo0`001Goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool008Yoo`<000Aoo`03001oogoo08aoo`00Rgoo00<007oo
Ool00goo00<007ooOol0S7oo0028Ool50004Ool2002=Ool0089oo`@0009oo`04001oogoo0005Ool0
0`00Oomoo`2<Ool008Uoo`03001oo`0000Eoo`03001oogoo08aoo`00RWoo0P001Goo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00R7oo10001Goo00<007ooOol0S7oo0028Ool00`00Oomoo`06
Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`8008eoo`00PWoo100017oo00<007ooOol017oo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0029Ool20006Ool00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo001lOol5000@Ool00`00Oomoo`2<Ool007]oo`L000moo`8008eoo`001goo0`00;Goo0`00
:Goo10004goo2@003Woo00<007ooOol0:Goo1000;7oo0`00:Woo0`000goo0007Ool01000Oomoo`00
;Goo00<007ooOol0:7oo00<007ooOol04goo2`003Goo00<007ooOol0:Goo00<007ooOol0;Woo00<0
07ooOol0:Goo00@007ooOol0009oo`001goo00@007ooOol002Yoo`D002Yoo`03001oogoo015oo`d0
00aoo`03001oogoo02Yoo`03001oogoo02Yoo`D002Yoo`04001oogoo0002Ool00003Ool000000080
009oo`<002Eoo`@0009oo`04001oogoo000TOol40004Ool00`00Oomoo`0@Ool=000<Ool00`00Oomo
o`0[Ool00`00Oomoo`0YOol01000Oomoo`00:goo0`000goo0008Ool00`00Oomoo`0[Ool00`00Ool0
000ZOol01000Oomoo`004Goo3@0037oo00<007ooOol0:Goo00@007ooOol002]oo`03001oo`0002ao
o`03001oogoo009oo`0027oo0`00;7oo0P00:goo0P004Woo3@002Goo1@00:goo0P00;Goo0P00;7oo
0`000Woo001hOol=0008Ool7002<Ool007Uoo`/000Qoo`T008]oo`00NWoo2@0027oo2`00RWoo001k
Ool70008Ool=0029Ool007aoo`D000Uoo`d008Uoo`001Wooo`0060000goo0006Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`02Ool=0005Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`01Ool000Ioo`03001oogoo02]o
o`03001oogoo02]oo`03001oogoo01Moo`D000Uoo`d002Qoo`03001oogoo02]oo`03001oogoo02ao
o`03001oogoo005oo`00Ngoo1`002Goo2`00RWoo001jOol90009Ool9002;Ool007Uoo`/000Uoo`L0
08aoo`00N7oo3@002Goo1@00SGoo001hOol=000<Ool00`00Oomoo`2<Ool007Qoo`d000aoo`03001o
ogoo08aoo`00N7oo3@0037oo00<007ooOol0S7oo001hOol=000<Ool00`00Oomoo`2<Ool007Uoo`/0
00eoo`03001oogoo08aoo`00NWoo2@003Woo0P00SGoo001kOol7000?Ool00`00Oomoo`2<Ool007ao
o`D0011oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`80
08eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool008Qoo`@000Eoo`03001oogoo08aoo`00R7oo00<007ooOol01Woo
00<007ooOol0S7oo0029Ool00`00Oomoo`05Ool2002=Ool008Yoo`03001oogoo00Aoo`03001oogoo
08aoo`00R7oo00@007ooOol000Eoo`03001oogoo08aoo`00RGoo0P001Woo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00RWoo0`0017oo00<007ooOol0S7oo002;Ool00`00Oomoo`03Ool00`00
Oomoo`2<Ool008Qoo`D000Aoo`8008eoo`00R7oo00@007ooOol000Eoo`03001oogoo08aoo`00RGoo
00<007oo00001Goo00<007ooOol0S7oo002:Ool20005Ool00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00R7oo0`001Woo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0028Ool01000Oomoo`001Goo
0P00SGoo0028Ool3002EOol008Uoo`03001oogoo09Aoo`00RGoo0`00U7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.25906, -6.19431, 0.0431659, \
0.0431659}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[235]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Append[basis51, {0, 0}], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-6\), 6}, {\(-6\), 6}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[236]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-6)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-4)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-2)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(2)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(4)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(6)] 1 .4875 0 1 Mshowa
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-4)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-2)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(2)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(4)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.43195 .51474 Mdot
.46495 .56017 Mdot
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[236]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00R7oo0`00UGoo0028Ool01000Oomoo`00U7oo0028Ool01000Oomoo`001Goo0P00
SGoo0022Ool40002Ool30006Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`03001oogoo08ao
o`00RGoo0`001Goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool008Yoo`<000Aoo`03001oogoo08aoo`00Rgoo00<007oo
Ool00goo00<007ooOol0S7oo0028Ool50004Ool2002=Ool0089oo`@0009oo`04001oogoo0005Ool0
0`00Oomoo`2<Ool008Uoo`03001oo`0000Eoo`03001oogoo08aoo`00RWoo0P001Goo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00R7oo10001Goo00<007ooOol0S7oo0028Ool00`00Oomoo`06
Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`8008eoo`00PWoo100017oo00<007ooOol017oo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0029Ool20006Ool00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`001goo0`00;Goo0`00:Goo1000:Woo00<0
07ooOol0:Goo1000;7oo0`00:Woo0`000goo0007Ool01000Oomoo`00;Goo00<007ooOol0:7oo00<0
07ooOol0:goo00<007ooOol0:Goo00<007ooOol0;Woo00<007ooOol0:Goo00@007ooOol0009oo`00
1goo00@007ooOol002Yoo`D002Yoo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yoo`D0
02Yoo`04001oogoo0002Ool00003Ool000000080009oo`<002Eoo`@0009oo`04001oogoo000TOol4
0004Ool00`00Oomoo`0YOol00`00Oomoo`0[Ool00`00Oomoo`0YOol01000Oomoo`00:goo0`000goo
0008Ool00`00Oomoo`0[Ool00`00Ool0000ZOol01000Oomoo`00:Woo00<007ooOol0:Goo00@007oo
Ool002]oo`03001oo`0002aoo`03001oogoo009oo`0027oo0`00;7oo0P00:goo0P00:7oo1@00:goo
0P00;Goo0P00;7oo0`000Woo002=Ool7002<Ool008aoo`T008]oo`00Rgoo2`00RWoo002:Ool=0029
Ool007]oo`D000Yoo`d008Uoo`001Wooo`0060000goo0006Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool90003Ool00`00Oomoo`02Ool=0005
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`01Ool000Ioo`03001oogoo02]oo`03001oogoo02]oo`03001o
ogoo01=oo`/000Moo`d002Qoo`03001oogoo02]oo`03001oogoo02aoo`03001oogoo005oo`00Mgoo
3@001goo2`00RWoo001gOol=0008Ool9002;Ool007Moo`d000Uoo`L008aoo`00Mgoo3@002Woo1@00
SGoo001gOol=000=Ool00`00Oomoo`2<Ool007Qoo`/000ioo`03001oogoo08aoo`00NGoo2@003goo
00<007ooOol0S7oo001jOol7000@Ool00`00Oomoo`2<Ool007]oo`D000Aoo`D000Qoo`03001oogoo
08aoo`00Pgoo1`001goo0P00SGoo0022Ool90006Ool00`00Oomoo`2<Ool0085oo`/000Eoo`03001o
ogoo08aoo`00P7oo3@0017oo00<007ooOol0S7oo0020Ool=0004Ool00`00Oomoo`2<Ool0081oo`d0
00Aoo`03001oogoo08aoo`00P7oo3@0017oo00<007ooOol0S7oo0020Ool=0004Ool00`00Oomoo`2<
Ool0085oo`/000Eoo`03001oogoo08aoo`00PWoo2@001Woo00<007ooOol0S7oo0023Ool70007Ool0
0`00Oomoo`2<Ool008Aoo`D000Qoo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool008Qoo`@000Eoo`03001oogoo08aoo`00R7oo00<007ooOol01Woo00<007ooOol0S7oo0029Ool0
0`00Oomoo`05Ool2002=Ool008Yoo`03001oogoo00Aoo`03001oogoo08aoo`00R7oo00@007ooOol0
00Eoo`03001oogoo08aoo`00RGoo0P001Woo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
RWoo0`0017oo00<007ooOol0S7oo002;Ool00`00Oomoo`03Ool00`00Oomoo`2<Ool008Qoo`D000Ao
o`8008eoo`00R7oo00@007ooOol000Eoo`03001oogoo08aoo`00RGoo00<007oo00001Goo00<007oo
Ool0S7oo002:Ool20005Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00R7oo0`001Woo00<007ooOol0S7oo0028Ool0
1000Oomoo`001Goo00<007ooOol0S7oo0028Ool01000Oomoo`001Goo0P00SGoo0028Ool3002EOol0
08Uoo`03001oogoo09Aoo`00RGoo0`00U7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.25906, -6.19431, 0.0431659, \
0.0431659}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[236]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Append[basis52, {0, 0}], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-6\), 6}, {\(-6\), 6}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[237]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-6)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-4)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-2)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(2)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(4)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(6)] 1 .4875 0 1 Mshowa
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-4)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-2)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(2)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(4)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.87467 .68137 Mdot
.87467 .31863 Mdot
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[237]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00R7oo0`00UGoo0028Ool01000Oomoo`00U7oo0028Ool01000Oomoo`001Goo0P00
SGoo0022Ool40002Ool30006Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`03001oogoo08ao
o`00RGoo0`001Goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool008Yoo`<000Aoo`03001oogoo08aoo`00Rgoo00<007oo
Ool00goo00<007ooOol0S7oo0028Ool50004Ool2002=Ool0089oo`@0009oo`04001oogoo0005Ool0
0`00Oomoo`2<Ool008Uoo`03001oo`0000Eoo`03001oogoo08aoo`00RWoo0P001Goo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`1ROol5000UOol0095oo`03001oogoo065oo`L002Aoo`00TGoo00<0
07ooOol0H7oo2@008goo002AOol00`00Oomoo`1OOol;000ROol0095oo`03001oogoo05ioo`d0025o
o`00TGoo00<007ooOol0GWoo3@008Goo002AOol00`00Oomoo`1NOol=000QOol0095oo`03001oogoo
05ioo`d0025oo`00R7oo10001Goo00<007ooOol0GWoo3@008Goo0028Ool00`00Oomoo`06Ool00`00
Oomoo`1OOol;000ROol008Uoo`03001oogoo00Eoo`80065oo`T002=oo`00PWoo100017oo00<007oo
Ool017oo00<007ooOol0HGoo1`0097oo0028Ool01000Oomoo`001Goo00<007ooOol0HWoo1@009Goo
0029Ool20006Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`001goo0`00
;Goo0`00:Goo1000:Woo00<007ooOol0:Goo1000;7oo0`00:Woo0`000goo0007Ool01000Oomoo`00
;Goo00<007ooOol0:7oo00<007ooOol0:goo00<007ooOol0:Goo00<007ooOol0;Woo00<007ooOol0
:Goo00@007ooOol0009oo`001goo00@007ooOol002Yoo`D002Yoo`03001oogoo02Yoo`03001oogoo
02Yoo`03001oogoo02Yoo`D002Yoo`04001oogoo0002Ool00003Ool000000080009oo`<002Eoo`@0
009oo`04001oogoo000TOol40004Ool00`00Oomoo`0YOol00`00Oomoo`0[Ool00`00Oomoo`0YOol0
1000Oomoo`00:goo0`000goo0008Ool00`00Oomoo`0[Ool00`00Ool0000ZOol01000Oomoo`00:Woo
00<007ooOol0:Goo00@007ooOol002]oo`03001oo`0002aoo`03001oogoo009oo`0027oo0`00;7oo
0P00:goo0P00:7oo1@00:goo0P00;Goo0P00;7oo0`000Woo002=Ool7002<Ool008aoo`T008]oo`00
Rgoo2`00RWoo002:Ool=0029Ool008Yoo`d008Uoo`001Wooo`0060000goo0006Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`02Ool=0005Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`01Ool000Ioo`03001oogoo02]o
o`03001oogoo02]oo`03001oogoo02Eoo`d002Qoo`03001oogoo02]oo`03001oogoo02aoo`03001o
ogoo005oo`00Rgoo2`00RWoo002<Ool9002;Ool008eoo`L008aoo`00SWoo1@00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool008Qoo`@000Eoo`03001oogoo08aoo`00R7oo00<007ooOol01Woo00<007ooOol0HWoo1@009Goo
0029Ool00`00Oomoo`05Ool2001ROol7000TOol008Yoo`03001oogoo00Aoo`03001oogoo061oo`T0
02=oo`00R7oo00@007ooOol000Eoo`03001oogoo05moo`/0029oo`00RGoo0P001Woo00<007ooOol0
GWoo3@008Goo002AOol00`00Oomoo`1NOol=000QOol0095oo`03001oogoo05ioo`d0025oo`00TGoo
00<007ooOol0GWoo3@008Goo002AOol00`00Oomoo`1NOol=000QOol0095oo`03001oogoo05moo`/0
029oo`00TGoo00<007ooOol0H7oo2@008goo002AOol00`00Oomoo`1QOol7000TOol0095oo`03001o
ogoo069oo`D002Eoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00RWoo0`0017oo00<007ooOol0S7oo002;Ool00`00Oomoo`03Ool00`00
Oomoo`2<Ool008Qoo`D000Aoo`8008eoo`00R7oo00@007ooOol000Eoo`03001oogoo08aoo`00RGoo
00<007oo00001Goo00<007ooOol0S7oo002:Ool20005Ool00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00R7oo0`001Woo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0028Ool01000Oomoo`001Goo
0P00SGoo0028Ool3002EOol008Uoo`03001oogoo09Aoo`00RGoo0`00U7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.25906, -6.19431, 0.0431659, \
0.0431659}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[237]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Append[basis53, {0, 0}], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-6\), 6}, {\(-6\), 6}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[238]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-6)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-4)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-2)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(2)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(4)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(6)] 1 .4875 0 1 Mshowa
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-4)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-2)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(2)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(4)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.90972 .5735 Mdot
.69651 .86695 Mdot
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[238]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00R7oo0`00UGoo0028Ool01000Oomoo`00U7oo0028Ool01000Oomoo`001Goo0P00
SGoo0022Ool40002Ool30006Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`03001oogoo08ao
o`00RGoo0`001Goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool008Yoo`<000Aoo`03001oogoo08aoo`00Rgoo00<007oo
Ool00goo00<007ooOol0S7oo0028Ool50004Ool2002=Ool0089oo`@0009oo`04001oogoo0005Ool0
0`00Oomoo`2<Ool008Uoo`03001oo`0000Eoo`03001oogoo08aoo`00RWoo0P001Goo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00R7oo10001Goo00<007ooOol0S7oo0028Ool00`00Oomoo`06
Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`8008eoo`00PWoo100017oo00<007ooOol017oo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0029Ool20006Ool00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`001goo0`00;Goo0`00:Goo1000:Woo00<0
07ooOol0:Goo1000;7oo0`00:Woo0`000goo0007Ool01000Oomoo`00;Goo00<007ooOol0:7oo00<0
07ooOol0:goo00<007ooOol0:Goo00<007ooOol0;Woo00<007ooOol0:Goo00@007ooOol0009oo`00
1goo00@007ooOol002Yoo`D002Yoo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02Yoo`D0
02Yoo`04001oogoo0002Ool00003Ool000000080009oo`<002Eoo`@0009oo`04001oogoo000TOol4
0004Ool00`00Oomoo`0YOol00`00Oomoo`0[Ool00`00Oomoo`0YOol01000Oomoo`00:goo0`000goo
0008Ool00`00Oomoo`0[Ool00`00Ool0000ZOol01000Oomoo`00:Woo00<007ooOol0:Goo00@007oo
Ool002]oo`03001oo`0002aoo`03001oogoo009oo`0027oo0`00;7oo0P00:goo0P00:7oo1@00:goo
0P00;Goo0P00;7oo0`000Woo002=Ool7002<Ool008aoo`T008]oo`00Rgoo2`00RWoo002:Ool=0029
Ool008Yoo`d008Uoo`001Wooo`0060000goo0006Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02Ool=0005
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`01Ool000Ioo`03001oogoo02]oo`03001oogoo02]oo`03001o
ogoo02Eoo`d002Qoo`03001oogoo02]oo`03001oogoo02aoo`03001oogoo005oo`00Rgoo2`00RWoo
002<Ool9002;Ool008eoo`L008aoo`00SWoo1@00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0K7oo
1@006goo002AOol00`00Oomoo`1[Ool7000JOol0095oo`03001oogoo06Yoo`T001Uoo`00TGoo00<0
07ooOol0JGoo2`0067oo002AOol00`00Oomoo`1XOol=000GOol0095oo`03001oogoo06Qoo`d001Mo
o`00TGoo00<007ooOol0J7oo3@005goo002AOol00`00Oomoo`1XOol=000GOol0095oo`8006Uoo`d0
01Moo`00TGoo00<007ooOol0JGoo2`0067oo002AOol00`00Oomoo`1ZOol9000IOol0095oo`03001o
ogoo06]oo`L001Yoo`00TGoo00<007ooOol0K7oo1@006goo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool008Qoo`@000Eoo`03001oogoo08aoo`00R7oo00<007ooOol01Woo00<007ooOol0S7oo0029Ool0
0`00Oomoo`05Ool2002=Ool008Yoo`03001oogoo00Aoo`03001oogoo08aoo`00R7oo00@007ooOol0
00Eoo`03001oogoo08aoo`00RGoo0P001Woo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
RWoo0`0017oo00<007ooOol0S7oo002;Ool00`00Oomoo`03Ool00`00Oomoo`2<Ool008Qoo`D000Ao
o`8008eoo`00R7oo00@007ooOol000Eoo`03001oogoo08aoo`00RGoo00<007oo00001Goo00<007oo
Ool0S7oo002:Ool20005Ool00`00Oomoo`0aOol5001FOol0095oo`03001oogoo031oo`L005Eoo`00
TGoo00<007ooOol0;goo2@00E7oo002AOol00`00Oomoo`0^Ool;001COol0095oo`03001oogoo02eo
o`d0059oo`00TGoo00<007ooOol0;Goo3@00DWoo002AOol00`00Oomoo`0]Ool=001BOol0095oo`03
001oogoo02eoo`d0059oo`00TGoo0P00;Woo3@00DWoo002AOol00`00Oomoo`0^Ool;001COol0095o
o`03001oogoo02moo`T005Aoo`00TGoo00<007ooOol0<7oo1`00EGoo002AOol00`00Oomoo`0aOol5
001FOol0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00R7oo0`001Woo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0028Ool01000Oomoo`001Goo
0P00SGoo0028Ool3002EOol008Uoo`03001oogoo09Aoo`00RGoo0`00U7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.25906, -6.19431, 0.0431659, \
0.0431659}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[238]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[Append[basis54, {0, 0}], Axes \[Rule] True, 
      Prolog \[Rule] PointSize[0.05], 
      PlotRange \[Rule] \ {{\(-6\), 6}, {\(-6\), 6}}, 
      AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[239]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[0 .4875 -6 -9 ]
[0 .4875 6 0 ]
[.16667 .4875 -6 -9 ]
[.16667 .4875 6 0 ]
[.33333 .4875 -6 -9 ]
[.33333 .4875 6 0 ]
[.66667 .4875 -3 -9 ]
[.66667 .4875 3 0 ]
[.83333 .4875 -3 -9 ]
[.83333 .4875 3 0 ]
[1 .4875 -3 -9 ]
[1 .4875 3 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .16667 -12 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -12 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .5 m
0 .50625 L
s
[(-6)] 0 .4875 0 1 Mshowa
.16667 .5 m
.16667 .50625 L
s
[(-4)] .16667 .4875 0 1 Mshowa
.33333 .5 m
.33333 .50625 L
s
[(-2)] .33333 .4875 0 1 Mshowa
.66667 .5 m
.66667 .50625 L
s
[(2)] .66667 .4875 0 1 Mshowa
.83333 .5 m
.83333 .50625 L
s
[(4)] .83333 .4875 0 1 Mshowa
1 .5 m
1 .50625 L
s
[(6)] 1 .4875 0 1 Mshowa
.125 Mabswid
.04167 .5 m
.04167 .50375 L
s
.08333 .5 m
.08333 .50375 L
s
.125 .5 m
.125 .50375 L
s
.20833 .5 m
.20833 .50375 L
s
.25 .5 m
.25 .50375 L
s
.29167 .5 m
.29167 .50375 L
s
.375 .5 m
.375 .50375 L
s
.41667 .5 m
.41667 .50375 L
s
.45833 .5 m
.45833 .50375 L
s
.54167 .5 m
.54167 .50375 L
s
.58333 .5 m
.58333 .50375 L
s
.625 .5 m
.625 .50375 L
s
.70833 .5 m
.70833 .50375 L
s
.75 .5 m
.75 .50375 L
s
.79167 .5 m
.79167 .50375 L
s
.875 .5 m
.875 .50375 L
s
.91667 .5 m
.91667 .50375 L
s
.95833 .5 m
.95833 .50375 L
s
.25 Mabswid
0 .5 m
1 .5 L
s
.5 0 m
.50625 0 L
s
[(-6)] .4875 0 1 0 Mshowa
.5 .16667 m
.50625 .16667 L
s
[(-4)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(-2)] .4875 .33333 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(2)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(4)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.125 Mabswid
.5 .04167 m
.50375 .04167 L
s
.5 .08333 m
.50375 .08333 L
s
.5 .125 m
.50375 .125 L
s
.5 .20833 m
.50375 .20833 L
s
.5 .25 m
.50375 .25 L
s
.5 .29167 m
.50375 .29167 L
s
.5 .375 m
.50375 .375 L
s
.5 .41667 m
.50375 .41667 L
s
.5 .45833 m
.50375 .45833 L
s
.5 .54167 m
.50375 .54167 L
s
.5 .58333 m
.50375 .58333 L
s
.5 .625 m
.50375 .625 L
s
.5 .70833 m
.50375 .70833 L
s
.5 .75 m
.50375 .75 L
s
.5 .79167 m
.50375 .79167 L
s
.5 .875 m
.50375 .875 L
s
.5 .91667 m
.50375 .91667 L
s
.5 .95833 m
.50375 .95833 L
s
.25 Mabswid
.5 0 m
.5 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.05 w
.45361 .44807 Mdot
.50701 .43072 Mdot
.5 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[239]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00R7oo0`00UGoo0028Ool01000Oomoo`00U7oo0028Ool01000Oomoo`001Goo0P00
SGoo0022Ool40002Ool30006Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`03001oogoo08ao
o`00RGoo0`001Goo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool008Yoo`<000Aoo`03001oogoo08aoo`00Rgoo00<007oo
Ool00goo00<007ooOol0S7oo0028Ool50004Ool2002=Ool0089oo`@0009oo`04001oogoo0005Ool0
0`00Oomoo`2<Ool008Uoo`03001oo`0000Eoo`03001oogoo08aoo`00RWoo0P001Goo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00R7oo10001Goo00<007ooOol0S7oo0028Ool00`00Oomoo`06
Ool00`00Oomoo`2<Ool008Uoo`03001oogoo00Eoo`8008eoo`00PWoo100017oo00<007ooOol017oo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo00<007ooOol0S7oo0029Ool20006Ool00`00Oomo
o`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002@Ool5002;Ool0
08moo`L008Yoo`00SWoo2@00RGoo002=Ool;0028Ool008aoo`d008Moo`00PGoo1@001Woo3@00Qgoo
0020Ool70005Ool=0027Ool007moo`T000Aoo`d008Moo`00OWoo2`000goo3@00Qgoo001mOol=0003
Ool;0028Ool007eoo`d000Aoo`T008Uoo`00OGoo3@001Goo1`00RWoo001mOol=0006Ool5002;Ool0
07eoo`d000Moo`8008eoo`001goo0`00;Goo0`00:Goo10005goo2`0027oo00<007ooOol0:Goo1000
;7oo0`00:Woo0`000goo0007Ool01000Oomoo`00;Goo00<007ooOol0:7oo00<007ooOol06Goo2@00
2Goo00<007ooOol0:Goo00<007ooOol0;Woo00<007ooOol0:Goo00@007ooOol0009oo`001goo00@0
07ooOol002Yoo`D002Yoo`03001oogoo01Uoo`L000Yoo`03001oogoo02Yoo`03001oogoo02Yoo`D0
02Yoo`04001oogoo0002Ool00003Ool000000080009oo`<002Eoo`@0009oo`04001oogoo000TOol4
0004Ool00`00Oomoo`0IOol5000;Ool00`00Oomoo`0[Ool00`00Oomoo`0YOol01000Oomoo`00:goo
0`000goo0008Ool00`00Oomoo`0[Ool00`00Ool0000ZOol01000Oomoo`00:Woo00<007ooOol0:Goo
00@007ooOol002]oo`03001oo`0002aoo`03001oogoo009oo`0027oo0`00;7oo0P00:goo0P00:7oo
1@00:goo0P00;Goo0P00;7oo0`000Woo002=Ool7002<Ool008aoo`T008]oo`00Rgoo2`00RWoo002:
Ool=0029Ool008Yoo`d008Uoo`001Wooo`0060000goo0006Ool00`00Oomoo`08Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool=0005Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`01Ool000Ioo`03001oogoo02]oo`03001oogoo02]o
o`03001oogoo02Eoo`d002Qoo`03001oogoo02]oo`03001oogoo02aoo`03001oogoo005oo`00Rgoo
2`00RWoo002<Ool9002;Ool008eoo`L008aoo`00SWoo1@00SGoo002AOol00`00Oomoo`2<Ool0095o
o`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002A
Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomo
o`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001o
ogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00
TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007oo
Ool0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool008Qoo`@000Eo
o`03001oogoo08aoo`00R7oo00<007ooOol01Woo00<007ooOol0S7oo0029Ool00`00Oomoo`05Ool2
002=Ool008Yoo`03001oogoo00Aoo`03001oogoo08aoo`00R7oo00@007ooOol000Eoo`03001oogoo
08aoo`00RGoo0P001Woo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`8008eoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo
08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo
00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00RWoo0`0017oo00<0
07ooOol0S7oo002;Ool00`00Oomoo`03Ool00`00Oomoo`2<Ool008Qoo`D000Aoo`8008eoo`00R7oo
00@007ooOol000Eoo`03001oogoo08aoo`00RGoo00<007oo00001Goo00<007ooOol0S7oo002:Ool2
0005Ool00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00
Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0
095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<0
07ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo
002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo0P00SGoo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03
001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08ao
o`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<Ool0095oo`8008eoo`00TGoo00<007ooOol0
S7oo002AOol00`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol0
0`00Oomoo`2<Ool0095oo`03001oogoo08aoo`00TGoo00<007ooOol0S7oo002AOol00`00Oomoo`2<
Ool0095oo`03001oogoo08aoo`00R7oo0`001Woo00<007ooOol0S7oo0028Ool01000Oomoo`001Goo
00<007ooOol0S7oo0028Ool01000Oomoo`001Goo0P00SGoo0028Ool3002EOol008Uoo`03001oogoo
09Aoo`00RGoo0`00U7oo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.25906, -6.19431, 0.0431659, \
0.0431659}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[239]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculations", "Subsection"],

Cell["Reciprocal lattice", "Subsubsection"],

Cell[CellGroupData[{

Cell["g and Range for the average lattice g=(0,0,0,0)", "Text"],

Cell[BoxData[{
    \(\(Np\  = 5;\)\), "\[IndentingNewLine]", 
    \(\(g = {g1, g2, g3, g4, g5};\)\)}], "Input",
  CellLabel->"In[24]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Partial reciprocal lattice", "Text"],

Cell[BoxData[{
    \(\(RL021 = RL[2, \ 1, \ g, \ Np];\)\), "\[IndentingNewLine]", 
    \(\(RL031 = RL[3, \ 1, \ g, \ Np];\)\), "\[IndentingNewLine]", 
    \(\(RL032 = RL[3, \ 2, \ g, \ Np];\)\), "\[IndentingNewLine]", 
    \(\(RL041 = RL[4, \ 1, \ g, \ Np];\)\), "\[IndentingNewLine]", 
    \(\(RL042 = RL[4, \ 2, \ g, \ Np];\)\), "\[IndentingNewLine]", 
    \(\(RL043 = RL[4, \ 3, \ g, \ Np];\)\), "\[IndentingNewLine]", 
    \(\(RL051 = RL[5, \ 1, \ g, \ Np];\)\), "\[IndentingNewLine]", 
    \(\(RL052 = RL[5, \ 2, \ g, \ Np];\)\), "\[IndentingNewLine]", 
    \(\(RL053 = RL[5, \ 3, \ g, \ Np];\)\), "\[IndentingNewLine]", 
    \(\(RL054 = RL[5, \ 4, \ g, \ Np];\)\)}], "Input",
  CellLabel->"In[26]:="]
}, Open  ]],

Cell[BoxData[
    \(\(RL0 = 
        Chop[Join[RL021, RL031, RL032, RL041, RL042, RL043, \ RL051, \ 
            RL052, \ RL053, \ RL054]];\)\)], "Input",
  CellLabel->"In[36]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dispalying results ", "Subsection"],

Cell[BoxData[
    \(gLattice[x1_, \ x2_, \ x3_, \ x4_, \ x5_\ ]\  := \ 
      N[\ RL0\  /. \ {g1\  \[Rule] \ x1, \ g2\  \[Rule] \ x2, \ 
            g3\  \[Rule] \ x3, \ g4\  \[Rule] \ x4, \ 
            g5\  \[Rule] \ x5}]\)], "Input",
  CellLabel->"In[62]:="],

Cell["With  g=(0,0,0,0)", "InlineFormula"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gl0\  = 
      ListPlot[SphericalCut[gLattice[0, 0, 0, 0, 0], 2.5], 
        Axes \[Rule] False, PlotStyle \[Rule] AbsolutePointSize[7], 
        PlotRange\ \  \[Rule] \ {{\(-2.75\), 2.75}, {\(-2.75\), 2.75}}, 
        AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[63]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.181818 0.5 0.181818 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
7 Mabswid
.91938 .37267 Mdot
.84665 .24782 Mdot
.92362 .59177 Mdot
.8509 .46692 Mdot
.77817 .34208 Mdot
.70544 .21723 Mdot
.63272 .09239 Mdot
.85514 .68602 Mdot
.78242 .56118 Mdot
.70969 .43633 Mdot
.63696 .31149 Mdot
.56423 .18664 Mdot
.49151 .0618 Mdot
.78666 .78028 Mdot
.71394 .65543 Mdot
.64121 .53059 Mdot
.56848 .40574 Mdot
.49575 .2809 Mdot
.42303 .15606 Mdot
.71818 .87453 Mdot
.64545 .74969 Mdot
.57273 .62484 Mdot
.5 .5 Mdot
.42727 .37516 Mdot
.35455 .25031 Mdot
.28182 .12547 Mdot
.57697 .84394 Mdot
.50425 .7191 Mdot
.43152 .59426 Mdot
.35879 .46941 Mdot
.28606 .34457 Mdot
.21334 .21972 Mdot
.50849 .9382 Mdot
.43577 .81336 Mdot
.36304 .68851 Mdot
.29031 .56367 Mdot
.21758 .43882 Mdot
.14486 .31398 Mdot
.36728 .90761 Mdot
.29456 .78277 Mdot
.22183 .65792 Mdot
.1491 .53308 Mdot
.07638 .40823 Mdot
.15335 .75218 Mdot
.08062 .62733 Mdot
.5 .5 Mdot
.7507 .8595 Mdot
.84696 .75176 Mdot
.54363 .93125 Mdot
.63989 .8235 Mdot
.73615 .71575 Mdot
.83241 .60801 Mdot
.92867 .50026 Mdot
.43283 .89525 Mdot
.52909 .7875 Mdot
.62535 .67975 Mdot
.72161 .572 Mdot
.81787 .46426 Mdot
.91413 .35651 Mdot
.32202 .85924 Mdot
.41828 .7515 Mdot
.51454 .64375 Mdot
.6108 .536 Mdot
.70706 .42826 Mdot
.80332 .32051 Mdot
.21122 .82324 Mdot
.30748 .71549 Mdot
.40374 .60775 Mdot
.5 .5 Mdot
.59626 .39225 Mdot
.69252 .28451 Mdot
.78878 .17676 Mdot
.19668 .67949 Mdot
.29294 .57174 Mdot
.3892 .464 Mdot
.48546 .35625 Mdot
.58172 .2485 Mdot
.67798 .14076 Mdot
.08587 .64349 Mdot
.18213 .53574 Mdot
.27839 .428 Mdot
.37465 .32025 Mdot
.47091 .2125 Mdot
.56717 .10475 Mdot
.07133 .49974 Mdot
.16759 .39199 Mdot
.26385 .28425 Mdot
.36011 .1765 Mdot
.45637 .06875 Mdot
.15304 .24824 Mdot
.2493 .1405 Mdot
.5 .5 Mdot
.5 .5 Mdot
.23556 .84952 Mdot
.36778 .90777 Mdot
.10334 .67476 Mdot
.23556 .73301 Mdot
.36778 .79127 Mdot
.5 .84952 Mdot
.63222 .90777 Mdot
.10334 .55825 Mdot
.23556 .61651 Mdot
.36778 .67476 Mdot
.5 .73301 Mdot
.63222 .79127 Mdot
.76444 .84952 Mdot
.10334 .44175 Mdot
.23556 .5 Mdot
.36778 .55825 Mdot
.5 .61651 Mdot
.63222 .67476 Mdot
.76444 .73301 Mdot
.10334 .32524 Mdot
.23556 .38349 Mdot
.36778 .44175 Mdot
.5 .5 Mdot
.63222 .55825 Mdot
.76444 .61651 Mdot
.89666 .67476 Mdot
.23556 .26699 Mdot
.36778 .32524 Mdot
.5 .38349 Mdot
.63222 .44175 Mdot
.76444 .5 Mdot
.89666 .55825 Mdot
.23556 .15048 Mdot
.36778 .20873 Mdot
.5 .26699 Mdot
.63222 .32524 Mdot
.76444 .38349 Mdot
.89666 .44175 Mdot
.36778 .09223 Mdot
.5 .15048 Mdot
.63222 .20873 Mdot
.76444 .26699 Mdot
.89666 .32524 Mdot
.63222 .09223 Mdot
.76444 .15048 Mdot
.91938 .62733 Mdot
.84665 .75218 Mdot
.92362 .40823 Mdot
.8509 .53308 Mdot
.77817 .65792 Mdot
.70544 .78277 Mdot
.63272 .90761 Mdot
.85514 .31398 Mdot
.78242 .43882 Mdot
.70969 .56367 Mdot
.63696 .68851 Mdot
.56423 .81336 Mdot
.49151 .9382 Mdot
.78666 .21972 Mdot
.71394 .34457 Mdot
.64121 .46941 Mdot
.56848 .59426 Mdot
.49575 .7191 Mdot
.42303 .84394 Mdot
.71818 .12547 Mdot
.64545 .25031 Mdot
.57273 .37516 Mdot
.5 .5 Mdot
.42727 .62484 Mdot
.35455 .74969 Mdot
.28182 .87453 Mdot
.57697 .15606 Mdot
.50425 .2809 Mdot
.43152 .40574 Mdot
.35879 .53059 Mdot
.28606 .65543 Mdot
.21334 .78028 Mdot
.50849 .0618 Mdot
.43577 .18664 Mdot
.36304 .31149 Mdot
.29031 .43633 Mdot
.21758 .56118 Mdot
.14486 .68602 Mdot
.36728 .09239 Mdot
.29456 .21723 Mdot
.22183 .34208 Mdot
.1491 .46692 Mdot
.07638 .59177 Mdot
.15335 .24782 Mdot
.08062 .37267 Mdot
.5 .5 Mdot
.5 .5 Mdot
.08587 .35651 Mdot
.07133 .50026 Mdot
.21122 .17676 Mdot
.19668 .32051 Mdot
.18213 .46426 Mdot
.16759 .60801 Mdot
.15304 .75176 Mdot
.32202 .14076 Mdot
.30748 .28451 Mdot
.29294 .42826 Mdot
.27839 .572 Mdot
.26385 .71575 Mdot
.2493 .8595 Mdot
.43283 .10475 Mdot
.41828 .2485 Mdot
.40374 .39225 Mdot
.3892 .536 Mdot
.37465 .67975 Mdot
.36011 .8235 Mdot
.54363 .06875 Mdot
.52909 .2125 Mdot
.51454 .35625 Mdot
.5 .5 Mdot
.48546 .64375 Mdot
.47091 .7875 Mdot
.45637 .93125 Mdot
.63989 .1765 Mdot
.62535 .32025 Mdot
.6108 .464 Mdot
.59626 .60775 Mdot
.58172 .7515 Mdot
.56717 .89525 Mdot
.7507 .1405 Mdot
.73615 .28425 Mdot
.72161 .428 Mdot
.70706 .57174 Mdot
.69252 .71549 Mdot
.67798 .85924 Mdot
.84696 .24824 Mdot
.83241 .39199 Mdot
.81787 .53574 Mdot
.80332 .67949 Mdot
.78878 .82324 Mdot
.92867 .49974 Mdot
.91413 .64349 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[63]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00S7oo0`0000Aoo`00
000008eoo`00Rgoo2@00S7oo0021Ool30006Ool;0006Ool30022Ool0081oo`D000Eoo`/000Eoo`D0
085oo`00Ogoo1`0017oo2`0017oo1`00P7oo001oOol70005Ool90005Ool70020Ool007moo`L000Io
o`<00004Ool000000006Ool70020Ool0081oo`D001Eoo`D0085oo`00PGoo0`005goo0`00PWoo001X
Ool30019Ool3001YOol006Moo`D004Moo`D006Qoo`00IWoo1`00AGoo1`00Igoo001VOol70015Ool7
001WOol006Ioo`L000ioo`<002=oo`<000ioo`L006Moo`00Igoo1@003Woo1@008Goo1@003Woo1@00
J7oo001XOol3000>Ool7000OOol7000>Ool3001YOol007Uoo`L001moo`L007Yoo`00NGoo1`007goo
1`00NWoo001jOol5000QOol5001kOol004moo`<002Uoo`<002=oo`<002Uoo`<0051oo`00CWoo1@00
NGoo1@00Cgoo001=Ool7001gOol7001>Ool004eoo`L007Moo`L004ioo`00AWoo0`0017oo1`001goo
0`00Hgoo0`001goo1`0017oo0`00Agoo0015Ool50004Ool50007Ool5001QOol50007Ool50004Ool5
0016Ool004Aoo`L000Aoo`<000Moo`L005moo`L000Moo`<000Aoo`L004Eoo`00@Woo2@003Woo1`00
;Woo0`00;Woo1`003Woo2@00@goo0011Ool:000>Ool7000HOol3000BOol5000BOol3000HOol7000>
Ool:0012Ool0041oo`X0011oo`D001Qoo`D0011oo`L0011oo`D001Qoo`D0011oo`X0045oo`00@7oo
2@004Woo0`0067oo1`003goo1`003goo1`0067oo0`004Woo2@00@Goo0010Ool7000_Ool7000?Ool7
000?Ool7000_Ool70011Ool0045oo`D0031oo`L0011oo`D0011oo`L0031oo`D0049oo`00@Woo0`00
<Woo1@004Woo0`004Woo1@00<Woo0`00@goo000kOol3000XOol3000?Ool3000YOol3000?Ool3000X
Ool3000lOol003Yoo`D002Ioo`D004]oo`D002Ioo`D003]oo`00>Goo1`0097oo1`00BGoo1`0097oo
1`00>Woo000iOol7000TOol7000AOol3000QOol3000AOol7000TOol7000jOol003Uoo`L002Aoo`L0
011oo`D001moo`D0011oo`L002Aoo`L003Yoo`00>Woo1@009Woo1@0047oo1`007Goo1`0047oo1@00
9Woo1@00>goo000kOol3000XOol3000AOol7000MOol7000AOol3000XOol3000lOol007Yoo`L001eo
o`L007]oo`00Ngoo1@007goo1@00O7oo001XOol3000AOol3000QOol3000AOol3001YOol006Moo`D0
01Yoo`<000eoo`<001Yoo`D006Qoo`00IWoo1`0067oo1@002goo1@0067oo1`00Igoo001COol3000@
Ool7000GOol70009Ool7000GOol7000@Ool3001DOol003aoo`<001=oo`D000moo`L001Moo`L000Uo
o`L001Moo`L000moo`D001=oo`<003eoo`00>goo1@004Goo1`003goo1@0067oo1`002Goo1`0067oo
1@003goo1`004Goo1@00?7oo000jOol7000@Ool7000@Ool3000JOol5000;Ool5000JOol3000@Ool7
000@Ool7000kOol003Yoo`L0011oo`L002ioo`<000eoo`<002ioo`L0011oo`L003]oo`00>Woo1`00
4Goo1@00LGoo1@004Goo1`00>goo000kOol5000COol3001cOol3000COol5000lOol003aoo`<00:5o
o`<003eoo`00ogoo8Goo000ZOol4000fOol3000@Ool3000[Ool3000@Ool3000fOol4000[Ool002Uo
o`H003Aoo`D000ioo`D002Uoo`D000ioo`D003Aoo`H002Yoo`00:7oo2000<Woo1`0037oo1`009goo
1`0037oo1`00<Woo2000:Goo000XOol8000bOol7000<Ool7000WOol7000<Ool7000bOol8000YOol0
02Qoo`P0039oo`L000aoo`L002Moo`L000aoo`L0039oo`P002Uoo`00:Goo1P004goo0`007Woo1@00
3Woo1@004goo0`004goo1@003Woo1@007Woo0`004goo1P00:Woo000ZOol4000COol5000NOol3000@
Ool3000COol5000COol3000@Ool3000NOol5000COol4000[Ool0041oo`L004Eoo`L004Eoo`L0045o
o`00@7oo1`00AGoo1`00AGoo1`00@Goo0010Ool70015Ool70015Ool70011Ool0045oo`D000Aoo`<0
00Yoo`<0039oo`L0039oo`<000Yoo`<000Aoo`D0049oo`00@Woo0`0017oo1@0027oo1@00<7oo2@00
<7oo1@0027oo1@0017oo0`00@goo0018Ool70006Ool7000_Ool9000_Ool70006Ool70019Ool004Qo
o`L000Ioo`L002moo`T002moo`L000Ioo`L004Uoo`00B7oo1`001Woo1`00<7oo1`00<7oo1`001Woo
1`00BGoo0019Ool50008Ool5000bOol5000bOol50008Ool5001:Ool004Yoo`<000Yoo`<006]oo`<0
00Yoo`<004]oo`00ogoo8Goo001WOol3001;Ool3001XOol002Qoo`<003]oo`D004Uoo`D003]oo`<0
02Uoo`009goo1@002goo0`00:goo2000AGoo2000:goo0`002goo1@00:7oo000VOol70009Ool5000Z
Ool90013Ool9000ZOol50009Ool7000WOol001aoo`<000Moo`L000Qoo`L002Uoo`X0045oo`X002Uo
o`L000Qoo`L000Moo`<001eoo`006goo1@001Woo1`0027oo1`00:Woo2@00@Goo2@00:Woo1`0027oo
1`001Woo1@0077oo000JOol70006Ool50009Ool7000ZOol90011Ool9000ZOol70009Ool50006Ool7
000KOol001Yoo`L000Moo`<000]oo`D002]oo`P004=oo`P002]oo`D000]oo`<000Moo`L001]oo`00
6Woo1`005Woo0`00;7oo1`00AGoo1`00;7oo0`005Woo1`006goo000KOol5000NOol3000@Ool3000C
Ool50017Ool5000COol3000@Ool3000NOol5000LOol001aoo`<001ioo`D000ioo`D001=oo`<004Uo
o`<001=oo`D000ioo`D001ioo`<001eoo`00?7oo1`0037oo1`00Lgoo1`0037oo1`00?Goo000lOol7
000<Ool7001cOol7000<Ool7000mOol001Moo`<0029oo`L000aoo`L003Aoo`<000Eoo`<003Aoo`L0
00aoo`L0029oo`<001Qoo`005Woo1@008Woo1@003Woo1@00=7oo1@000goo1@00=7oo1@003Woo1@00
8Woo1@005goo000EOol7000ROol3000@Ool3000dOol700000goo00000005000dOol3000@Ool3000R
Ool7000FOol001Eoo`L006aoo`L00003Ool0000000D006aoo`L001Ioo`005Goo1`00K7oo1`0000=o
o`0000001@00K7oo1`005Woo000EOol6001NOol3000=Ool50003Ool5000=Ool3001NOol6000FOol0
01Aoo`L005eoo`D000eoo`<000Eoo`<000eoo`D005eoo`L001Eoo`0057oo1`00G7oo1`008goo1`00
G7oo1`005Goo000DOol7000WOol3000bOol7000@Ool3000@Ool7000bOol3000WOol7000EOol001Eo
o`D002Moo`D0035oo`L000moo`D000moo`L0035oo`D002Moo`D001Ioo`005Woo0`005Woo0`003Woo
1`00:goo0`000goo1@003goo1`003goo1@000goo0`00:goo1`003Woo0`005Woo0`005goo000^Ool5
000=Ool7000ZOol50003Ool3000@Ool7000@Ool30003Ool5000ZOol7000=Ool5000_Ool002eoo`L0
00aoo`L002Uoo`L001Eoo`L001Eoo`L002Uoo`L000aoo`L002ioo`00;Goo1`003Goo1@00:Woo1`00
5Woo1@005Woo1`00:Woo1@003Goo1`00;Woo000]Ool7000>Ool3000[Ool70003Ool3000AOol3000A
Ool30003Ool7000[Ool3000>Ool7000^Ool001Aoo`<001Moo`D003ioo`D000=oo`D002=oo`D000=o
o`D003ioo`D001Moo`<001Eoo`004goo1@005goo0`00@7oo0`000goo1`008Goo1`000goo0`00@7oo
0`005goo1@0057oo000BOol7001OOol7000QOol7001OOol7000COol0019oo`L005moo`L0025oo`L0
05moo`L001=oo`004Woo1`00H7oo1@008goo1@00H7oo1`004goo000COol5000fOol30002Ool3000T
Ool3000UOol3000TOol30002Ool3000fOol5000DOol001Aoo`<003Ioo`X0075oo`X003Ioo`<001Eo
o`00C7oo3000Kgoo3000CGoo000mOol3000<Ool<001_Ool<000<Ool3000nOol001aoo`<001eoo`D0
00]oo``0011oo`<004Uoo`<0011oo``000]oo`D001eoo`<001eoo`006goo1@006goo1`002goo2P00
47oo1@00Agoo1@0047oo2P002goo1`006goo1@0077oo000JOol7000JOol7000<Ool9000?Ool70015
Ool7000?Ool9000<Ool7000JOol7000KOol001Yoo`L001Yoo`L000ioo`L000moo`L004Eoo`L000mo
o`L000ioo`L001Yoo`L001]oo`006Woo1`006goo1@0047oo1@0047oo1`00AGoo1`0047oo1@0047oo
1@006goo1`006goo000KOol5000MOol3000BOol3000BOol50017Ool5000BOol3000BOol3000MOol5
000LOol001aoo`<004Uoo`<004Uoo`<004Uoo`<001eoo`00<goo0`00>7oo0`00?Goo0`00>7oo0`00
=7oo000YOol30006Ool5000^Ool30005Ool5000kOol50005Ool3000^Ool50006Ool3000ZOol002Qo
o`D000Aoo`L002aoo`D000=oo`L003Uoo`L000=oo`D002aoo`L000Aoo`D002Uoo`009goo1`000goo
1`00:goo1`000Woo1`00>Goo1`000Woo1`00:goo1`000goo1`00:7oo000WOol70003Ool7000[Ool7
0002Ool7000iOol70002Ool7000[Ool70003Ool7000XOol002Moo`L000Aoo`D002aoo`L000=oo`D0
03]oo`D000=oo`L002aoo`D000Aoo`L002Qoo`00:7oo1@001Woo0`00;Woo1@001Goo0`00?Goo0`00
1Goo1@00;Woo0`001Woo1@00:Goo000YOol3000iOol3001?Ool3000iOol3000ZOol00?moob5oo`00
ogoo8Goo000COol3000/Ool30019Ool30019Ool3000/Ool3000DOol0019oo`D002Yoo`D004Moo`D0
04Moo`D002Yoo`D001=oo`004Goo1`00:7oo1`00AGoo1`00AGoo1`00:7oo1`004Woo000AOol7000X
Ool70015Ool70015Ool7000XOol7000BOol0015oo`L002Qoo`L004Eoo`L004Eoo`L002Qoo`L0019o
o`004Woo1@00:Woo1@00Agoo1@00Agoo1@00:Woo1@004goo000COol3000/Ool30019Ool30019Ool3
000/Ool3000DOol00?moob5oo`00ogoo8Goo000YOol3000iOol3001?Ool3000iOol3000ZOol002Qo
o`D000Ioo`<002ioo`D000Eoo`<003eoo`<000Eoo`D002ioo`<000Ioo`D002Uoo`009goo1`0017oo
1@00;7oo1`000goo1@00>goo1@000goo1`00;7oo1@0017oo1`00:7oo000WOol70003Ool7000[Ool7
0002Ool7000iOol70002Ool7000[Ool70003Ool7000XOol002Moo`L000=oo`L002]oo`L0009oo`L0
03Uoo`L0009oo`L002]oo`L000=oo`L002Qoo`00:7oo1@0017oo1`00;7oo1@000goo1`00>Goo1`00
0goo1@00;7oo1`0017oo1@00:Goo000YOol30006Ool5000^Ool30005Ool5000kOol50005Ool3000^
Ool50006Ool3000ZOol003=oo`<003Qoo`<003eoo`<003Qoo`<003Aoo`0077oo0`00BGoo0`00BGoo
0`00BGoo0`007Goo000KOol5000MOol3000BOol3000BOol50017Ool5000BOol3000BOol3000MOol5
000LOol001Yoo`L001]oo`D0011oo`D0011oo`L004Eoo`L0011oo`D0011oo`D001]oo`L001]oo`00
6Woo1`006Woo1`003Woo1`003goo1`00AGoo1`003goo1`003Woo1`006Woo1`006goo000JOol7000J
Ool7000<Ool9000?Ool70015Ool7000?Ool9000<Ool7000JOol7000KOol001]oo`D001]oo`L000]o
o`X0011oo`D004Moo`D0011oo`X000]oo`L001]oo`D001aoo`0077oo0`007Goo1@002goo300047oo
0`00BGoo0`0047oo30002goo1@007Goo0`007Goo000mOol3000<Ool<001_Ool<000<Ool3000nOol0
04aoo``006moo``004eoo`0057oo0`00=Woo2P00LGoo2P00=Woo0`005Goo000COol5000fOol30002
Ool3000TOol3000UOol3000TOol30002Ool3000fOol5000DOol0019oo`L0061oo`D002=oo`D0061o
o`L001=oo`004Woo1`00Ggoo1`008Goo1`00Ggoo1`004goo000BOol7001OOol7000QOol7001OOol7
000COol001=oo`D001Moo`<0041oo`<000=oo`L0025oo`L000=oo`<0041oo`<001Moo`D001Aoo`00
57oo0`005goo1@00?Woo1@000goo1@008goo1@000goo1@00?Woo1@005goo0`005Goo000]Ool7000>
Ool3000[Ool70003Ool3000AOol3000AOol30003Ool7000[Ool3000>Ool7000^Ool002eoo`L000eo
o`D002Yoo`L001Ioo`D001Ioo`L002Yoo`D000eoo`L002ioo`00;Goo1`0037oo1`00:Goo1`005Goo
1`005Goo1`00:Goo1`0037oo1`00;Woo000^Ool5000=Ool7000ZOol50003Ool3000@Ool7000@Ool3
0003Ool5000ZOol7000=Ool5000_Ool001Ioo`<001Ioo`<000ioo`L002]oo`<000=oo`D000moo`L0
00moo`D000=oo`<002]oo`L000ioo`<001Ioo`<001Moo`005Goo1@009goo1@00<Goo1`003goo1@00
3goo1`00<Goo1@009goo1@005Woo000DOol7000WOol3000bOol7000@Ool3000@Ool7000bOol3000W
Ool7000EOol001Aoo`L005aoo`L002=oo`L005aoo`L001Eoo`0057oo1`00GGoo1@003Goo0`001Goo
0`003Goo1@00GGoo1`005Goo000EOol6001NOol3000=Ool50003Ool5000=Ool3001NOol6000FOol0
01Eoo`L006aoo`L00003Ool0000000D006aoo`L001Ioo`005Goo1`00K7oo1`0000=oo`0000001@00
K7oo1`005Woo000EOol7000ROol3000@Ool3000dOol700000goo00000005000dOol3000@Ool3000R
Ool7000FOol001Ioo`D0029oo`D000ioo`D003Aoo`D000=oo`D003Aoo`D000ioo`D0029oo`D001Mo
o`005goo0`008Woo1`0037oo1`00=7oo0`001Goo0`00=7oo1`0037oo1`008Woo0`0067oo000lOol7
000<Ool7001cOol7000<Ool7000mOol003aoo`L000aoo`L007=oo`L000aoo`L003eoo`0077oo0`00
7Woo1@003Woo1@004goo0`00BGoo0`004goo1@003Woo1@007Woo0`007Goo000KOol5000NOol3000@
Ool3000COol50017Ool5000COol3000@Ool3000NOol5000LOol001Yoo`L001Ioo`<002aoo`L004Eo
o`L002aoo`<001Ioo`L001]oo`006Woo1`001goo0`002goo1@00:goo2000@goo2000:goo1@002goo
0`001goo1`006goo000JOol70006Ool50009Ool7000ZOol90011Ool9000ZOol70009Ool50006Ool7
000KOol001]oo`D000Ioo`L000Qoo`L002Yoo`T0045oo`T002Yoo`L000Qoo`L000Ioo`D001aoo`00
77oo0`001goo1`0027oo1`00:Goo2P00@Goo2P00:Goo1`0027oo1`001goo0`007Goo000VOol70009
Ool5000ZOol90013Ool9000ZOol50009Ool7000WOol002Moo`D000]oo`<002]oo`P004Eoo`P002]o
o`<000]oo`D002Qoo`00:7oo0`00>goo1@00BGoo1@00>goo0`00:Goo001WOol3001;Ool3001XOol0
0?moob5oo`00BWoo0`002Woo0`00Jgoo0`002Woo0`00Bgoo0019Ool50008Ool5000bOol5000bOol5
0008Ool5001:Ool004Qoo`L000Ioo`L0031oo`L0031oo`L000Ioo`L004Uoo`00B7oo1`001Woo1`00
;goo2@00;goo1`001Woo1`00BGoo0018Ool70006Ool7000_Ool9000_Ool70006Ool70019Ool0049o
o`<000Aoo`D000Qoo`D0031oo`T0031oo`D000Qoo`D000Aoo`<004=oo`00@Goo1@0017oo0`002Woo
0`00<Woo1`00<Woo0`002Woo0`0017oo1@00@Woo0010Ool70015Ool70015Ool70011Ool0041oo`L0
04Eoo`L004Eoo`L0045oo`00@7oo1`00AGoo1`00AGoo1`00@Goo000ZOol4000COol5000NOol3000@
Ool3000COol5000COol3000@Ool3000NOol5000COol4000[Ool002Uoo`H001=oo`<001ioo`D000io
o`D001=oo`<001=oo`D000ioo`D001ioo`<001=oo`H002Yoo`00:7oo2000<Woo1`0037oo1`009goo
1`0037oo1`00<Woo2000:Goo000XOol8000bOol7000<Ool7000WOol7000<Ool7000bOol8000YOol0
02Qoo`P0039oo`L000aoo`L002Moo`L000aoo`L0039oo`P002Uoo`00:Goo1P00=7oo1@003Woo1@00
:Goo1@003Woo1@00=7oo1P00:Woo000ZOol4000fOol3000@Ool3000[Ool3000@Ool3000fOol4000[
Ool00?moob5oo`00?7oo0`00XGoo0`00?Goo000kOol5000COol3001cOol3000COol5000lOol003Yo
o`L0015oo`D0075oo`D0015oo`L003]oo`00>Woo1`0047oo1`00;Woo0`003Goo0`00;Woo1`0047oo
1`00>goo000jOol7000@Ool7000@Ool3000JOol5000;Ool5000JOol3000@Ool7000@Ool7000kOol0
03]oo`D0015oo`L000moo`D001Qoo`L000Uoo`L001Qoo`D000moo`L0015oo`D003aoo`00?7oo0`00
4goo1@003goo1`005goo1`002Goo1`005goo1`003goo1@004goo0`00?Goo001COol3000@Ool7000G
Ool70009Ool7000GOol7000@Ool3001DOol006Ioo`L001Qoo`D000]oo`D001Qoo`L006Moo`00Igoo
1@006Woo0`003Goo0`006Woo1@00J7oo001XOol3000AOol3000QOol3000AOol3001YOol007]oo`D0
01moo`D007aoo`00NWoo1`007Goo1`00Ngoo000kOol3000XOol3000AOol7000MOol7000AOol3000X
Ool3000lOol003Yoo`D002Ioo`D0011oo`L001eoo`L0011oo`D002Ioo`D003]oo`00>Goo1`0097oo
1`0047oo1@007goo1@0047oo1`0097oo1`00>Woo000iOol7000TOol7000AOol3000QOol3000AOol7
000TOol7000jOol003Uoo`L002Aoo`L004Uoo`L002Aoo`L003Yoo`00>Woo1@009Woo1@00Bgoo1@00
9Woo1@00>goo000kOol3000XOol3000?Ool3000YOol3000?Ool3000XOol3000lOol0049oo`<0039o
o`D0019oo`<0019oo`D0039oo`<004=oo`00@Goo1@00<7oo1`0047oo1@0047oo1`00<7oo1@00@Woo
0010Ool7000_Ool7000?Ool7000?Ool7000_Ool70011Ool0041oo`T0019oo`<001Qoo`L000moo`L0
00moo`L001Qoo`<0019oo`T0045oo`00@7oo2P0047oo1@0067oo1@0047oo1`0047oo1@0067oo1@00
47oo2P00@Goo0011Ool:000>Ool7000HOol3000BOol5000BOol3000HOol7000>Ool:0012Ool0049o
o`T000ioo`L002ioo`<002ioo`L000ioo`T004=oo`00A7oo1`0017oo0`001goo1`00Ggoo1`001goo
0`0017oo1`00AGoo0015Ool50004Ool50007Ool5001QOol50007Ool50004Ool50016Ool004Ioo`<0
00Aoo`L000Moo`<006=oo`<000Moo`L000Aoo`<004Moo`00CGoo1`00Mgoo1`00CWoo001=Ool7001g
Ool7001>Ool004ioo`D007Uoo`D004moo`00Cgoo0`00:Goo0`008goo0`00:Goo0`00D7oo001jOol5
000QOol5001kOol007Uoo`L001moo`L007Yoo`00NGoo1`007goo1`00NWoo001XOol3000>Ool7000O
Ool7000>Ool3001YOol006Moo`D000ioo`D0025oo`D000ioo`D006Qoo`00IWoo1`003Woo0`008goo
0`003Woo1`00Igoo001VOol70015Ool7001WOol006Ioo`L004Eoo`L006Moo`00Igoo1@00Agoo1@00
J7oo001XOol30019Ool3001YOol0085oo`<001Moo`<0089oo`00P7oo1@005Goo1@00PGoo001oOol7
0006Ool3000017oo000000001Woo1`00P7oo001oOol70005Ool90005Ool70020Ool007moo`L000Ao
o`/000Aoo`L0081oo`00P7oo1@001Goo2`001Goo1@00PGoo0021Ool30006Ool;0006Ool30022Ool0
08]oo`T008aoo`00S7oo0`0000Aoo`00000008eoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.75003, -2.75003, 0.019164, \
0.019164}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[63]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\</usr/people/joseluis/Docs/Papers/Average/gl0.eps\>", \ 
      gl0]\)], "Input"],

Cell[BoxData[
    \("/usr/people/joseluis/Docs/Papers/Average/gl0.eps"\)], "Output"]
}, Open  ]],

Cell["With  g=(1,0,1,0,1)", "InlineFormula"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gl1\  = 
      ListPlot[SphericalCut[gLattice[1, 1, 1, 1, 1], 2.5], 
        Axes \[Rule] False, PlotStyle \[Rule] AbsolutePointSize[4.0], 
        PlotRange\ \  \[Rule] \ {{\(-2.75\), 2.75}, {\(-2.75\), 2.75}}, 
        AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[64]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.181818 0.5 0.181818 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
4 Mabswid
.91938 .37267 Mdot
.84665 .24782 Mdot
.92362 .59177 Mdot
.8509 .46692 Mdot
.77817 .34208 Mdot
.70544 .21723 Mdot
.63272 .09239 Mdot
.85514 .68602 Mdot
.78242 .56118 Mdot
.70969 .43633 Mdot
.63696 .31149 Mdot
.56423 .18664 Mdot
.49151 .0618 Mdot
.78666 .78028 Mdot
.71394 .65543 Mdot
.64121 .53059 Mdot
.56848 .40574 Mdot
.49575 .2809 Mdot
.42303 .15606 Mdot
.71818 .87453 Mdot
.64545 .74969 Mdot
.57273 .62484 Mdot
.5 .5 Mdot
.42727 .37516 Mdot
.35455 .25031 Mdot
.28182 .12547 Mdot
.57697 .84394 Mdot
.50425 .7191 Mdot
.43152 .59426 Mdot
.35879 .46941 Mdot
.28606 .34457 Mdot
.21334 .21972 Mdot
.50849 .9382 Mdot
.43577 .81336 Mdot
.36304 .68851 Mdot
.29031 .56367 Mdot
.21758 .43882 Mdot
.14486 .31398 Mdot
.36728 .90761 Mdot
.29456 .78277 Mdot
.22183 .65792 Mdot
.1491 .53308 Mdot
.07638 .40823 Mdot
.15335 .75218 Mdot
.08062 .62733 Mdot
.5 .5 Mdot
.7507 .8595 Mdot
.84696 .75176 Mdot
.54363 .93125 Mdot
.63989 .8235 Mdot
.73615 .71575 Mdot
.83241 .60801 Mdot
.92867 .50026 Mdot
.43283 .89525 Mdot
.52909 .7875 Mdot
.62535 .67975 Mdot
.72161 .572 Mdot
.81787 .46426 Mdot
.91413 .35651 Mdot
.32202 .85924 Mdot
.41828 .7515 Mdot
.51454 .64375 Mdot
.6108 .536 Mdot
.70706 .42826 Mdot
.80332 .32051 Mdot
.21122 .82324 Mdot
.30748 .71549 Mdot
.40374 .60775 Mdot
.5 .5 Mdot
.59626 .39225 Mdot
.69252 .28451 Mdot
.78878 .17676 Mdot
.19668 .67949 Mdot
.29294 .57174 Mdot
.3892 .464 Mdot
.48546 .35625 Mdot
.58172 .2485 Mdot
.67798 .14076 Mdot
.08587 .64349 Mdot
.18213 .53574 Mdot
.27839 .428 Mdot
.37465 .32025 Mdot
.47091 .2125 Mdot
.56717 .10475 Mdot
.07133 .49974 Mdot
.16759 .39199 Mdot
.26385 .28425 Mdot
.36011 .1765 Mdot
.45637 .06875 Mdot
.15304 .24824 Mdot
.2493 .1405 Mdot
.5 .5 Mdot
.5 .5 Mdot
.23556 .84952 Mdot
.36778 .90777 Mdot
.10334 .67476 Mdot
.23556 .73301 Mdot
.36778 .79127 Mdot
.5 .84952 Mdot
.63222 .90777 Mdot
.10334 .55825 Mdot
.23556 .61651 Mdot
.36778 .67476 Mdot
.5 .73301 Mdot
.63222 .79127 Mdot
.76444 .84952 Mdot
.10334 .44175 Mdot
.23556 .5 Mdot
.36778 .55825 Mdot
.5 .61651 Mdot
.63222 .67476 Mdot
.76444 .73301 Mdot
.10334 .32524 Mdot
.23556 .38349 Mdot
.36778 .44175 Mdot
.5 .5 Mdot
.63222 .55825 Mdot
.76444 .61651 Mdot
.89666 .67476 Mdot
.23556 .26699 Mdot
.36778 .32524 Mdot
.5 .38349 Mdot
.63222 .44175 Mdot
.76444 .5 Mdot
.89666 .55825 Mdot
.23556 .15048 Mdot
.36778 .20873 Mdot
.5 .26699 Mdot
.63222 .32524 Mdot
.76444 .38349 Mdot
.89666 .44175 Mdot
.36778 .09223 Mdot
.5 .15048 Mdot
.63222 .20873 Mdot
.76444 .26699 Mdot
.89666 .32524 Mdot
.63222 .09223 Mdot
.76444 .15048 Mdot
.91938 .62733 Mdot
.84665 .75218 Mdot
.92362 .40823 Mdot
.8509 .53308 Mdot
.77817 .65792 Mdot
.70544 .78277 Mdot
.63272 .90761 Mdot
.85514 .31398 Mdot
.78242 .43882 Mdot
.70969 .56367 Mdot
.63696 .68851 Mdot
.56423 .81336 Mdot
.49151 .9382 Mdot
.78666 .21972 Mdot
.71394 .34457 Mdot
.64121 .46941 Mdot
.56848 .59426 Mdot
.49575 .7191 Mdot
.42303 .84394 Mdot
.71818 .12547 Mdot
.64545 .25031 Mdot
.57273 .37516 Mdot
.5 .5 Mdot
.42727 .62484 Mdot
.35455 .74969 Mdot
.28182 .87453 Mdot
.57697 .15606 Mdot
.50425 .2809 Mdot
.43152 .40574 Mdot
.35879 .53059 Mdot
.28606 .65543 Mdot
.21334 .78028 Mdot
.50849 .0618 Mdot
.43577 .18664 Mdot
.36304 .31149 Mdot
.29031 .43633 Mdot
.21758 .56118 Mdot
.14486 .68602 Mdot
.36728 .09239 Mdot
.29456 .21723 Mdot
.22183 .34208 Mdot
.1491 .46692 Mdot
.07638 .59177 Mdot
.15335 .24782 Mdot
.08062 .37267 Mdot
.5 .5 Mdot
.5 .5 Mdot
.08587 .35651 Mdot
.07133 .50026 Mdot
.21122 .17676 Mdot
.19668 .32051 Mdot
.18213 .46426 Mdot
.16759 .60801 Mdot
.15304 .75176 Mdot
.32202 .14076 Mdot
.30748 .28451 Mdot
.29294 .42826 Mdot
.27839 .572 Mdot
.26385 .71575 Mdot
.2493 .8595 Mdot
.43283 .10475 Mdot
.41828 .2485 Mdot
.40374 .39225 Mdot
.3892 .536 Mdot
.37465 .67975 Mdot
.36011 .8235 Mdot
.54363 .06875 Mdot
.52909 .2125 Mdot
.51454 .35625 Mdot
.5 .5 Mdot
.48546 .64375 Mdot
.47091 .7875 Mdot
.45637 .93125 Mdot
.63989 .1765 Mdot
.62535 .32025 Mdot
.6108 .464 Mdot
.59626 .60775 Mdot
.58172 .7515 Mdot
.56717 .89525 Mdot
.7507 .1405 Mdot
.73615 .28425 Mdot
.72161 .428 Mdot
.70706 .57174 Mdot
.69252 .71549 Mdot
.67798 .85924 Mdot
.84696 .24824 Mdot
.83241 .39199 Mdot
.81787 .53574 Mdot
.80332 .67949 Mdot
.78878 .82324 Mdot
.92867 .49974 Mdot
.91413 .64349 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[64]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool008aoo`8000=oo`8008eoo`00Rgoo100000=oo`0000000P00S7oo0022Ool20007Ool400000goo
000000020007Ool20023Ool0085oo`@000Moo`8000=oo`8000Moo`@0089oo`00PGoo10005Goo1000
PWoo0022Ool2000GOol20023Ool00?moob5oo`00ogoo8Goo001YOol20019Ool2001ZOol006Qoo`@0
04Moo`@006Uoo`00Igoo1@00Agoo1@00J7oo001WOol40019Ool4001XOol006Qoo`80015oo`8002Eo
o`80015oo`8006Uoo`00NWoo10008goo1000Ngoo001jOol4000SOol4001kOol007]oo`8002Eoo`80
07aoo`00ogoo8Goo003oOolQOol0051oo`8007]oo`80055oo`00Cgoo1000NGoo1000D7oo001?Ool4
001iOol4001@Ool0051oo`8007]oo`80055oo`00Agoo0P004Woo0P00IGoo0P004Woo0P00B7oo0016
Ool4000@Ool4001SOol4000@Ool40017Ool004Ioo`@0011oo`@006=oo`@0011oo`@004Moo`00@goo
0P000Woo0P004Woo0P00<Woo0P00<Goo0P004Woo0P000Woo0P00A7oo0012Ool40018Ool40017Ool4
0013Ool0049oo`@0039oo`8001Aoo`@001=oo`80039oo`@004=oo`00@goo0P00<Woo100057oo0P00
4goo1000<Woo0P00A7oo001gOol4000YOol4001hOol007Qoo`8002]oo`8007Uoo`00ogoo8Goo003o
OolQOol003aoo`8002Qoo`8004moo`8002Qoo`8003eoo`00>goo10009Woo1000CGoo10009Woo1000
?7oo000kOol4000VOol4001=Ool4000VOol4000lOol003aoo`8002Qoo`8001Aoo`8002=oo`8001Ao
o`8002Qoo`8003eoo`00Ngoo10008Goo1000O7oo001kOol4000QOol4001lOol007aoo`8002=oo`80
07eoo`00ogoo8Goo003oOolQOol006Uoo`8004Uoo`8006Yoo`00J7oo10006Woo0P003goo0P006Woo
1000JGoo001DOol2000BOol4000IOol4000=Ool4000IOol4000BOol2001EOol003aoo`8001Eoo`@0
019oo`8001Yoo`@000eoo`@001Yoo`80019oo`@001Eoo`8003eoo`00>goo100057oo1000;goo0P00
3goo0P00;goo100057oo1000?7oo000kOol4000EOol2001cOol2000EOol4000lOol003aoo`800:=o
o`8003eoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000[Ool2001:Ool2000]Ool2001:
Ool2000/Ool002Yoo`@003Moo`8000moo`@002]oo`@000moo`8003Moo`@002]oo`00:Woo1000=Woo
10003Woo1000:goo10003Woo1000=Woo1000:goo000[Ool2000gOol4000?Ool2000]Ool2000?Ool4
000gOol2000/Ool006Eoo`80055oo`8006Ioo`00ogoo8Goo0013Ool2001:Ool20019Ool20014Ool0
049oo`@004Qoo`@004Moo`@004=oo`00@Woo1000B7oo1000Agoo1000@goo0013Ool2001:Ool20019
Ool20014Ool008eoo`800003Ool0000008ioo`00Bgoo0P002Woo0P00<goo1`00<goo0P002Woo0P00
C7oo001:Ool40008Ool4000bOol7000bOol40008Ool4001;Ool004Yoo`@000Qoo`@003=oo`800003
Ool0000003=oo`@000Qoo`@004]oo`00Bgoo0P002Woo0P00KGoo0P002Woo0P00C7oo003oOolQOol0
0?moob5oo`00ogoo8Goo001WOol2001=Ool2001XOol002Uoo`8003]oo`@004]oo`@003]oo`8002Yo
o`00:7oo1000>Woo1000Bgoo1000>Woo1000:Goo000XOol4000;Ool2000^Ool20002Ool20015Ool2
0002Ool2000^Ool2000;Ool4000YOol001eoo`8000Yoo`8000]oo`@002moo`D004=oo`D002moo`@0
00]oo`8000Yoo`8001ioo`0077oo10005Woo1000;Woo1P00@goo1P00;Woo10005Woo10007Goo000L
Ool4000GOol2000_Ool50015Ool5000_Ool2000GOol4000MOol001eoo`8004Yoo`8004Uoo`8004Yo
o`8001ioo`00ogoo8Goo000oOol2002MOol20010Ool003ioo`@000moo`8007Uoo`8000moo`@003mo
o`00?Woo10003Woo1000Mgoo10003Woo1000?goo000oOol2000?Ool4001gOol4000?Ool20010Ool0
01Qoo`8003Moo`8003Moo`8000Moo`8003Moo`8003Moo`8001Uoo`005goo1000KWoo10001Goo1000
KWoo100067oo000GOol4001^Ool40005Ool4001^Ool4000HOol001Qoo`80071oo`8000Moo`80071o
o`8001Uoo`00ogoo8Goo000FOol2003_Ool2000GOol001Eoo`@0065oo`8002Moo`80065oo`@001Io
o`005Goo1000H7oo10009Goo1000H7oo10005Woo000FOol2000[Ool2000dOol4000BOol2000AOol4
000dOol2000[Ool2000GOol0049oo`@003Aoo`80019oo`@0015oo`8003Aoo`@004=oo`00;goo0P00
4Goo1000B7oo1000Agoo10004Goo0P00<7oo000^Ool4000AOol2000^Ool2000JOol2000IOol2000^
Ool2000AOol4000_Ool002ioo`@0041oo`@003=oo`@0041oo`@002moo`00;goo0P00@Goo1000<goo
1000@Goo0P00<7oo001cOol20006Ool2000UOol20006Ool2001dOol001Eoo`8006=oo`@002=oo`@0
06=oo`8001Ioo`0057oo1000HWoo10008goo1000HWoo10005Goo000DOol4001SOol2000UOol2001S
Ool4000EOol001Eoo`800?5oo`8001Ioo`00ogoo8Goo003oOolQOol004moo`80009oo`8007Eoo`80
009oo`80051oo`00CWoo2000Lgoo2000Cgoo001>Ool8001cOol8001?Ool003eoo`80011oo`H007Eo
o`H0011oo`8003ioo`007Goo0P007Goo10004Goo100057oo0P00BGoo0P0057oo10004Goo10007Goo
0P007Woo000LOol4000LOol4000BOol2000DOol40017Ool4000DOol2000BOol4000LOol4000MOol0
01aoo`@001eoo`8002Uoo`@004Moo`@002Uoo`8001eoo`@001eoo`007Goo0P00BWoo0P00BGoo0P00
BWoo0P007Woo003oOolQOol00?moob5oo`00<goo0P00>Woo0P00?Goo0P00>Woo0P00=7oo000ZOol2
0006Ool4000hOol4000kOol4000hOol40006Ool2000[Ool002Uoo`@000Eoo`@0031oo`8000Ioo`@0
03]oo`@000Ioo`80031oo`@000Eoo`@002Yoo`00:Goo10001Woo0P00<7oo10001Woo0P00?Goo0P00
1Woo1000<7oo0P001Woo1000:Woo000ZOol2000iOol4001=Ool4000iOol2000[Ool006Ioo`8004mo
o`8006Moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000COol2000^Ool2001:Ool20019
Ool2000^Ool2000DOol0019oo`@002aoo`@004Qoo`@004Moo`@002aoo`@001=oo`004Woo1000;7oo
1000B7oo1000Agoo1000;7oo10004goo000BOol4000]Ool2001:Ool20019Ool2000]Ool4000COol0
01=oo`800?Eoo`8001Aoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001VOol2001?Ool2
001WOol002Yoo`8003Uoo`@004eoo`@003Uoo`8002]oo`00:Goo10001Woo0P00<7oo10001Woo0P00
?Goo0P001Woo1000<7oo0P001Woo1000:Woo000YOol40005Ool4000`Ool20006Ool4000kOol40006
Ool2000`Ool40005Ool4000ZOol002Yoo`8000Ioo`@003Qoo`@003]oo`@003Qoo`@000Ioo`8002]o
o`00<goo0P00>Woo0P00?Goo0P00>Woo0P00=7oo003oOolQOol00?moob5oo`007Goo0P00BWoo0P00
BGoo0P00BWoo0P007Woo000LOol4000MOol2000YOol40017Ool4000YOol2000MOol4000MOol001ao
o`@001aoo`@0019oo`8001Aoo`@004Moo`@001Aoo`80019oo`@001aoo`@001eoo`007Goo0P007Goo
10004Goo100057oo0P00BGoo0P0057oo10004Goo10007Goo0P007Woo000mOol2000@Ool6001eOol6
000@Ool2000nOol004ioo`P007=oo`P004moo`00CWoo2000Lgoo2000Cgoo001?Ool20002Ool2001e
Ool20002Ool2001@Ool00?moob5oo`00ogoo8Goo000EOol2003aOol2000FOol001Aoo`@006=oo`80
02Eoo`8006=oo`@001Eoo`0057oo1000HWoo10008goo1000HWoo10005Goo000EOol2001SOol4000S
Ool4001SOol2000FOol002moo`80049oo`8000Ioo`8002Eoo`8000Ioo`80049oo`80031oo`00;Woo
1000@7oo1000<goo1000@7oo1000;goo000^Ool40010Ool4000cOol40010Ool4000_Ool002moo`80
019oo`8002ioo`8001Yoo`8001Uoo`8002ioo`80019oo`80031oo`00@Woo1000B7oo1000Agoo1000
@goo0012Ool4000dOol2000BOol4000AOol2000dOol40013Ool001Ioo`8002]oo`8003Aoo`@0019o
o`80015oo`@003Aoo`8002]oo`8001Moo`005Goo1000H7oo10009Goo1000H7oo10005Woo000EOol4
001QOol2000WOol2001QOol4000FOol001Ioo`800>moo`8001Moo`00ogoo8Goo000HOol2001`Ool2
0007Ool2001`Ool2000IOol001Moo`@006ioo`@000Eoo`@006ioo`@001Qoo`005goo1000KWoo1000
1Goo1000KWoo100067oo000HOol2000gOol2000gOol20007Ool2000gOol2000gOol2000IOol003mo
o`8000moo`@007Moo`@000moo`80041oo`00?Woo10003Woo1000Mgoo10003Woo1000?goo000nOol4
000?Ool2001iOol2000?Ool4000oOol003moo`8009eoo`80041oo`00ogoo8Goo000MOol2001:Ool2
0019Ool2001:Ool2000NOol001aoo`@001Moo`8002moo`D004Eoo`D002moo`8001Moo`@001eoo`00
77oo10005Woo1000;Woo1P00@goo1P00;Woo10005Woo10007Goo000MOol2000:Ool2000;Ool4000_
Ool50013Ool5000_Ool4000;Ool2000:Ool2000NOol002Qoo`@000]oo`8002ioo`80009oo`8004Eo
o`80009oo`8002ioo`8000]oo`@002Uoo`00:7oo1000>Woo1000Bgoo1000>Woo1000:Goo000YOol2
000kOol4001;Ool4000kOol2000ZOol006Moo`8004eoo`8006Qoo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00Bgoo0P002Woo0P00KGoo0P002Woo0P00C7oo001:Ool40008Ool4000cOol200000goo0000
000cOol40008Ool4001;Ool004Yoo`@000Qoo`@0039oo`L0039oo`@000Qoo`@004]oo`00Bgoo0P00
2Woo0P00<goo1`00<goo0P002Woo0P00C7oo002=Ool200000goo0000002>Ool004=oo`8004Yoo`80
04Uoo`8004Aoo`00@Woo1000B7oo1000Agoo1000@goo0012Ool40018Ool40017Ool40013Ool004=o
o`8004Yoo`8004Uoo`8004Aoo`00ogoo8Goo001UOol2001AOol2001VOol002]oo`8003Moo`@000mo
o`8002eoo`8000moo`@003Moo`8002aoo`00:Woo1000=Woo10003Woo1000:goo10003Woo1000=Woo
1000:goo000ZOol4000gOol2000?Ool4000[Ool4000?Ool2000gOol4000[Ool002]oo`8004Yoo`80
02eoo`8004Yoo`8002aoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000lOol2002SOol2
000mOol003]oo`@001Eoo`8007=oo`8001Eoo`@003aoo`00>goo100057oo1000;goo0P003goo0P00
;goo100057oo1000?7oo000lOol2000EOol4000BOol2000JOol4000=Ool4000JOol2000BOol4000E
Ool2000mOol005Aoo`80019oo`@001Uoo`@000eoo`@001Uoo`@0019oo`8005Eoo`00J7oo10006Woo
0P003goo0P006Woo1000JGoo001YOol20019Ool2001ZOol00?moob5oo`00ogoo8Goo001lOol2000S
Ool2001mOol007]oo`@0025oo`@007aoo`00Ngoo10008Goo1000O7oo000lOol2000XOol2000DOol2
000SOol2000DOol2000XOol2000mOol003]oo`@002Ioo`@004eoo`@002Ioo`@003aoo`00>goo1000
9Woo1000CGoo10009Woo1000?7oo000lOol2000XOol2001?Ool2000XOol2000mOol00?moob5oo`00
ogoo8Goo001hOol2000[Ool2001iOol007Moo`@002Uoo`@007Qoo`00@goo0P00<Woo100057oo0P00
4goo1000<Woo0P00A7oo0012Ool4000bOol2000DOol4000COol2000bOol40013Ool0049oo`@004Qo
o`@004Moo`@004=oo`00@goo0P000Woo0P004Woo0P00<Woo0P00<Goo0P004Woo0P000Woo0P00A7oo
0016Ool4000@Ool4001SOol4000@Ool40017Ool004Ioo`@0011oo`@006=oo`@0011oo`@004Moo`00
Agoo0P004Woo0P00IGoo0P004Woo0P00B7oo001@Ool2001kOol2001AOol004moo`@007Uoo`@0051o
o`00Cgoo1000NGoo1000D7oo001@Ool2001kOol2001AOol00?moob5oo`00ogoo8Goo001kOol2000U
Ool2001lOol007Yoo`@002=oo`@007]oo`00NWoo10008goo1000Ngoo001XOol2000AOol2000UOol2
000AOol2001YOol006Moo`@004Uoo`@006Qoo`00Igoo1@00Agoo1@00J7oo001XOol40017Ool4001Y
Ool006Uoo`8004Uoo`8006Yoo`00ogoo8Goo003oOolQOol0089oo`8001Moo`8008=oo`00PGoo1000
5Goo1000PWoo0021Ool40007Ool20003Ool20007Ool40022Ool0089oo`8000Moo`@00003Ool00000
008000Moo`8008=oo`00Rgoo100000=oo`0000000P00S7oo002<Ool20003Ool2002=Ool00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.75003, -2.75003, 0.019164, \
0.019164}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[gl0, gl1]\)], "Input",
  CellLabel->"In[65]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.181818 0.5 0.181818 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
7 Mabswid
.91938 .37267 Mdot
.84665 .24782 Mdot
.92362 .59177 Mdot
.8509 .46692 Mdot
.77817 .34208 Mdot
.70544 .21723 Mdot
.63272 .09239 Mdot
.85514 .68602 Mdot
.78242 .56118 Mdot
.70969 .43633 Mdot
.63696 .31149 Mdot
.56423 .18664 Mdot
.49151 .0618 Mdot
.78666 .78028 Mdot
.71394 .65543 Mdot
.64121 .53059 Mdot
.56848 .40574 Mdot
.49575 .2809 Mdot
.42303 .15606 Mdot
.71818 .87453 Mdot
.64545 .74969 Mdot
.57273 .62484 Mdot
.5 .5 Mdot
.42727 .37516 Mdot
.35455 .25031 Mdot
.28182 .12547 Mdot
.57697 .84394 Mdot
.50425 .7191 Mdot
.43152 .59426 Mdot
.35879 .46941 Mdot
.28606 .34457 Mdot
.21334 .21972 Mdot
.50849 .9382 Mdot
.43577 .81336 Mdot
.36304 .68851 Mdot
.29031 .56367 Mdot
.21758 .43882 Mdot
.14486 .31398 Mdot
.36728 .90761 Mdot
.29456 .78277 Mdot
.22183 .65792 Mdot
.1491 .53308 Mdot
.07638 .40823 Mdot
.15335 .75218 Mdot
.08062 .62733 Mdot
.5 .5 Mdot
.7507 .8595 Mdot
.84696 .75176 Mdot
.54363 .93125 Mdot
.63989 .8235 Mdot
.73615 .71575 Mdot
.83241 .60801 Mdot
.92867 .50026 Mdot
.43283 .89525 Mdot
.52909 .7875 Mdot
.62535 .67975 Mdot
.72161 .572 Mdot
.81787 .46426 Mdot
.91413 .35651 Mdot
.32202 .85924 Mdot
.41828 .7515 Mdot
.51454 .64375 Mdot
.6108 .536 Mdot
.70706 .42826 Mdot
.80332 .32051 Mdot
.21122 .82324 Mdot
.30748 .71549 Mdot
.40374 .60775 Mdot
.5 .5 Mdot
.59626 .39225 Mdot
.69252 .28451 Mdot
.78878 .17676 Mdot
.19668 .67949 Mdot
.29294 .57174 Mdot
.3892 .464 Mdot
.48546 .35625 Mdot
.58172 .2485 Mdot
.67798 .14076 Mdot
.08587 .64349 Mdot
.18213 .53574 Mdot
.27839 .428 Mdot
.37465 .32025 Mdot
.47091 .2125 Mdot
.56717 .10475 Mdot
.07133 .49974 Mdot
.16759 .39199 Mdot
.26385 .28425 Mdot
.36011 .1765 Mdot
.45637 .06875 Mdot
.15304 .24824 Mdot
.2493 .1405 Mdot
.5 .5 Mdot
.5 .5 Mdot
.23556 .84952 Mdot
.36778 .90777 Mdot
.10334 .67476 Mdot
.23556 .73301 Mdot
.36778 .79127 Mdot
.5 .84952 Mdot
.63222 .90777 Mdot
.10334 .55825 Mdot
.23556 .61651 Mdot
.36778 .67476 Mdot
.5 .73301 Mdot
.63222 .79127 Mdot
.76444 .84952 Mdot
.10334 .44175 Mdot
.23556 .5 Mdot
.36778 .55825 Mdot
.5 .61651 Mdot
.63222 .67476 Mdot
.76444 .73301 Mdot
.10334 .32524 Mdot
.23556 .38349 Mdot
.36778 .44175 Mdot
.5 .5 Mdot
.63222 .55825 Mdot
.76444 .61651 Mdot
.89666 .67476 Mdot
.23556 .26699 Mdot
.36778 .32524 Mdot
.5 .38349 Mdot
.63222 .44175 Mdot
.76444 .5 Mdot
.89666 .55825 Mdot
.23556 .15048 Mdot
.36778 .20873 Mdot
.5 .26699 Mdot
.63222 .32524 Mdot
.76444 .38349 Mdot
.89666 .44175 Mdot
.36778 .09223 Mdot
.5 .15048 Mdot
.63222 .20873 Mdot
.76444 .26699 Mdot
.89666 .32524 Mdot
.63222 .09223 Mdot
.76444 .15048 Mdot
.91938 .62733 Mdot
.84665 .75218 Mdot
.92362 .40823 Mdot
.8509 .53308 Mdot
.77817 .65792 Mdot
.70544 .78277 Mdot
.63272 .90761 Mdot
.85514 .31398 Mdot
.78242 .43882 Mdot
.70969 .56367 Mdot
.63696 .68851 Mdot
.56423 .81336 Mdot
.49151 .9382 Mdot
.78666 .21972 Mdot
.71394 .34457 Mdot
.64121 .46941 Mdot
.56848 .59426 Mdot
.49575 .7191 Mdot
.42303 .84394 Mdot
.71818 .12547 Mdot
.64545 .25031 Mdot
.57273 .37516 Mdot
.5 .5 Mdot
.42727 .62484 Mdot
.35455 .74969 Mdot
.28182 .87453 Mdot
.57697 .15606 Mdot
.50425 .2809 Mdot
.43152 .40574 Mdot
.35879 .53059 Mdot
.28606 .65543 Mdot
.21334 .78028 Mdot
.50849 .0618 Mdot
.43577 .18664 Mdot
.36304 .31149 Mdot
.29031 .43633 Mdot
.21758 .56118 Mdot
.14486 .68602 Mdot
.36728 .09239 Mdot
.29456 .21723 Mdot
.22183 .34208 Mdot
.1491 .46692 Mdot
.07638 .59177 Mdot
.15335 .24782 Mdot
.08062 .37267 Mdot
.5 .5 Mdot
.5 .5 Mdot
.08587 .35651 Mdot
.07133 .50026 Mdot
.21122 .17676 Mdot
.19668 .32051 Mdot
.18213 .46426 Mdot
.16759 .60801 Mdot
.15304 .75176 Mdot
.32202 .14076 Mdot
.30748 .28451 Mdot
.29294 .42826 Mdot
.27839 .572 Mdot
.26385 .71575 Mdot
.2493 .8595 Mdot
.43283 .10475 Mdot
.41828 .2485 Mdot
.40374 .39225 Mdot
.3892 .536 Mdot
.37465 .67975 Mdot
.36011 .8235 Mdot
.54363 .06875 Mdot
.52909 .2125 Mdot
.51454 .35625 Mdot
.5 .5 Mdot
.48546 .64375 Mdot
.47091 .7875 Mdot
.45637 .93125 Mdot
.63989 .1765 Mdot
.62535 .32025 Mdot
.6108 .464 Mdot
.59626 .60775 Mdot
.58172 .7515 Mdot
.56717 .89525 Mdot
.7507 .1405 Mdot
.73615 .28425 Mdot
.72161 .428 Mdot
.70706 .57174 Mdot
.69252 .71549 Mdot
.67798 .85924 Mdot
.84696 .24824 Mdot
.83241 .39199 Mdot
.81787 .53574 Mdot
.80332 .67949 Mdot
.78878 .82324 Mdot
.92867 .49974 Mdot
.91413 .64349 Mdot
4 Mabswid
.91938 .37267 Mdot
.84665 .24782 Mdot
.92362 .59177 Mdot
.8509 .46692 Mdot
.77817 .34208 Mdot
.70544 .21723 Mdot
.63272 .09239 Mdot
.85514 .68602 Mdot
.78242 .56118 Mdot
.70969 .43633 Mdot
.63696 .31149 Mdot
.56423 .18664 Mdot
.49151 .0618 Mdot
.78666 .78028 Mdot
.71394 .65543 Mdot
.64121 .53059 Mdot
.56848 .40574 Mdot
.49575 .2809 Mdot
.42303 .15606 Mdot
.71818 .87453 Mdot
.64545 .74969 Mdot
.57273 .62484 Mdot
.5 .5 Mdot
.42727 .37516 Mdot
.35455 .25031 Mdot
.28182 .12547 Mdot
.57697 .84394 Mdot
.50425 .7191 Mdot
.43152 .59426 Mdot
.35879 .46941 Mdot
.28606 .34457 Mdot
.21334 .21972 Mdot
.50849 .9382 Mdot
.43577 .81336 Mdot
.36304 .68851 Mdot
.29031 .56367 Mdot
.21758 .43882 Mdot
.14486 .31398 Mdot
.36728 .90761 Mdot
.29456 .78277 Mdot
.22183 .65792 Mdot
.1491 .53308 Mdot
.07638 .40823 Mdot
.15335 .75218 Mdot
.08062 .62733 Mdot
.5 .5 Mdot
.7507 .8595 Mdot
.84696 .75176 Mdot
.54363 .93125 Mdot
.63989 .8235 Mdot
.73615 .71575 Mdot
.83241 .60801 Mdot
.92867 .50026 Mdot
.43283 .89525 Mdot
.52909 .7875 Mdot
.62535 .67975 Mdot
.72161 .572 Mdot
.81787 .46426 Mdot
.91413 .35651 Mdot
.32202 .85924 Mdot
.41828 .7515 Mdot
.51454 .64375 Mdot
.6108 .536 Mdot
.70706 .42826 Mdot
.80332 .32051 Mdot
.21122 .82324 Mdot
.30748 .71549 Mdot
.40374 .60775 Mdot
.5 .5 Mdot
.59626 .39225 Mdot
.69252 .28451 Mdot
.78878 .17676 Mdot
.19668 .67949 Mdot
.29294 .57174 Mdot
.3892 .464 Mdot
.48546 .35625 Mdot
.58172 .2485 Mdot
.67798 .14076 Mdot
.08587 .64349 Mdot
.18213 .53574 Mdot
.27839 .428 Mdot
.37465 .32025 Mdot
.47091 .2125 Mdot
.56717 .10475 Mdot
.07133 .49974 Mdot
.16759 .39199 Mdot
.26385 .28425 Mdot
.36011 .1765 Mdot
.45637 .06875 Mdot
.15304 .24824 Mdot
.2493 .1405 Mdot
.5 .5 Mdot
.5 .5 Mdot
.23556 .84952 Mdot
.36778 .90777 Mdot
.10334 .67476 Mdot
.23556 .73301 Mdot
.36778 .79127 Mdot
.5 .84952 Mdot
.63222 .90777 Mdot
.10334 .55825 Mdot
.23556 .61651 Mdot
.36778 .67476 Mdot
.5 .73301 Mdot
.63222 .79127 Mdot
.76444 .84952 Mdot
.10334 .44175 Mdot
.23556 .5 Mdot
.36778 .55825 Mdot
.5 .61651 Mdot
.63222 .67476 Mdot
.76444 .73301 Mdot
.10334 .32524 Mdot
.23556 .38349 Mdot
.36778 .44175 Mdot
.5 .5 Mdot
.63222 .55825 Mdot
.76444 .61651 Mdot
.89666 .67476 Mdot
.23556 .26699 Mdot
.36778 .32524 Mdot
.5 .38349 Mdot
.63222 .44175 Mdot
.76444 .5 Mdot
.89666 .55825 Mdot
.23556 .15048 Mdot
.36778 .20873 Mdot
.5 .26699 Mdot
.63222 .32524 Mdot
.76444 .38349 Mdot
.89666 .44175 Mdot
.36778 .09223 Mdot
.5 .15048 Mdot
.63222 .20873 Mdot
.76444 .26699 Mdot
.89666 .32524 Mdot
.63222 .09223 Mdot
.76444 .15048 Mdot
.91938 .62733 Mdot
.84665 .75218 Mdot
.92362 .40823 Mdot
.8509 .53308 Mdot
.77817 .65792 Mdot
.70544 .78277 Mdot
.63272 .90761 Mdot
.85514 .31398 Mdot
.78242 .43882 Mdot
.70969 .56367 Mdot
.63696 .68851 Mdot
.56423 .81336 Mdot
.49151 .9382 Mdot
.78666 .21972 Mdot
.71394 .34457 Mdot
.64121 .46941 Mdot
.56848 .59426 Mdot
.49575 .7191 Mdot
.42303 .84394 Mdot
.71818 .12547 Mdot
.64545 .25031 Mdot
.57273 .37516 Mdot
.5 .5 Mdot
.42727 .62484 Mdot
.35455 .74969 Mdot
.28182 .87453 Mdot
.57697 .15606 Mdot
.50425 .2809 Mdot
.43152 .40574 Mdot
.35879 .53059 Mdot
.28606 .65543 Mdot
.21334 .78028 Mdot
.50849 .0618 Mdot
.43577 .18664 Mdot
.36304 .31149 Mdot
.29031 .43633 Mdot
.21758 .56118 Mdot
.14486 .68602 Mdot
.36728 .09239 Mdot
.29456 .21723 Mdot
.22183 .34208 Mdot
.1491 .46692 Mdot
.07638 .59177 Mdot
.15335 .24782 Mdot
.08062 .37267 Mdot
.5 .5 Mdot
.5 .5 Mdot
.08587 .35651 Mdot
.07133 .50026 Mdot
.21122 .17676 Mdot
.19668 .32051 Mdot
.18213 .46426 Mdot
.16759 .60801 Mdot
.15304 .75176 Mdot
.32202 .14076 Mdot
.30748 .28451 Mdot
.29294 .42826 Mdot
.27839 .572 Mdot
.26385 .71575 Mdot
.2493 .8595 Mdot
.43283 .10475 Mdot
.41828 .2485 Mdot
.40374 .39225 Mdot
.3892 .536 Mdot
.37465 .67975 Mdot
.36011 .8235 Mdot
.54363 .06875 Mdot
.52909 .2125 Mdot
.51454 .35625 Mdot
.5 .5 Mdot
.48546 .64375 Mdot
.47091 .7875 Mdot
.45637 .93125 Mdot
.63989 .1765 Mdot
.62535 .32025 Mdot
.6108 .464 Mdot
.59626 .60775 Mdot
.58172 .7515 Mdot
.56717 .89525 Mdot
.7507 .1405 Mdot
.73615 .28425 Mdot
.72161 .428 Mdot
.70706 .57174 Mdot
.69252 .71549 Mdot
.67798 .85924 Mdot
.84696 .24824 Mdot
.83241 .39199 Mdot
.81787 .53574 Mdot
.80332 .67949 Mdot
.78878 .82324 Mdot
.92867 .49974 Mdot
.91413 .64349 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[65]:=",
  ImageSize->{288, 288},
  ImageMargins->{{40, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00S7oo0`0000Aoo`00
000008eoo`00Rgoo2@00S7oo0021Ool30006Ool;0006Ool30022Ool0081oo`D000Eoo`/000Eoo`D0
085oo`00Ogoo1`0017oo2`0017oo1`00P7oo001oOol70005Ool90005Ool70020Ool007moo`L000Io
o`<00004Ool000000006Ool70020Ool0081oo`D001Eoo`D0085oo`00PGoo0`005goo0`00PWoo001X
Ool30019Ool3001YOol006Moo`D004Moo`D006Qoo`00IWoo1`00AGoo1`00Igoo001VOol70015Ool7
001WOol006Ioo`L000ioo`<002=oo`<000ioo`L006Moo`00Igoo1@003Woo1@008Goo1@003Woo1@00
J7oo001XOol3000>Ool7000OOol7000>Ool3001YOol007Uoo`L001moo`L007Yoo`00NGoo1`007goo
1`00NWoo001jOol5000QOol5001kOol004moo`<002Uoo`<002=oo`<002Uoo`<0051oo`00CWoo1@00
NGoo1@00Cgoo001=Ool7001gOol7001>Ool004eoo`L007Moo`L004ioo`00AWoo0`0017oo1`001goo
0`00Hgoo0`001goo1`0017oo0`00Agoo0015Ool50004Ool50007Ool5001QOol50007Ool50004Ool5
0016Ool004Aoo`L000Aoo`<000Moo`L005moo`L000Moo`<000Aoo`L004Eoo`00@Woo2@003Woo1`00
;Woo0`00;Woo1`003Woo2@00@goo0011Ool:000>Ool7000HOol3000BOol5000BOol3000HOol7000>
Ool:0012Ool0041oo`X0011oo`D001Qoo`D0011oo`L0011oo`D001Qoo`D0011oo`X0045oo`00@7oo
2@004Woo0`0067oo1`003goo1`003goo1`0067oo0`004Woo2@00@Goo0010Ool7000_Ool7000?Ool7
000?Ool7000_Ool70011Ool0045oo`D0031oo`L0011oo`D0011oo`L0031oo`D0049oo`00@Woo0`00
<Woo1@004Woo0`004Woo1@00<Woo0`00@goo000kOol3000XOol3000?Ool3000YOol3000?Ool3000X
Ool3000lOol003Yoo`D002Ioo`D004]oo`D002Ioo`D003]oo`00>Goo1`0097oo1`00BGoo1`0097oo
1`00>Woo000iOol7000TOol7000AOol3000QOol3000AOol7000TOol7000jOol003Uoo`L002Aoo`L0
011oo`D001moo`D0011oo`L002Aoo`L003Yoo`00>Woo1@009Woo1@0047oo1`007Goo1`0047oo1@00
9Woo1@00>goo000kOol3000XOol3000AOol7000MOol7000AOol3000XOol3000lOol007Yoo`L001eo
o`L007]oo`00Ngoo1@007goo1@00O7oo001XOol3000AOol3000QOol3000AOol3001YOol006Moo`D0
01Yoo`<000eoo`<001Yoo`D006Qoo`00IWoo1`0067oo1@002goo1@0067oo1`00Igoo001COol3000@
Ool7000GOol70009Ool7000GOol7000@Ool3001DOol003aoo`<001=oo`D000moo`L001Moo`L000Uo
o`L001Moo`L000moo`D001=oo`<003eoo`00>goo1@004Goo1`003goo1@0067oo1`002Goo1`0067oo
1@003goo1`004Goo1@00?7oo000jOol7000@Ool7000@Ool3000JOol5000;Ool5000JOol3000@Ool7
000@Ool7000kOol003Yoo`L0011oo`L002ioo`<000eoo`<002ioo`L0011oo`L003]oo`00>Woo1`00
4Goo1@00LGoo1@004Goo1`00>goo000kOol5000COol3001cOol3000COol5000lOol003aoo`<00:5o
o`<003eoo`00ogoo8Goo000ZOol4000fOol3000@Ool3000[Ool3000@Ool3000fOol4000[Ool002Uo
o`H003Aoo`D000ioo`D002Uoo`D000ioo`D003Aoo`H002Yoo`00:7oo2000<Woo1`0037oo1`009goo
1`0037oo1`00<Woo2000:Goo000XOol8000bOol7000<Ool7000WOol7000<Ool7000bOol8000YOol0
02Qoo`P0039oo`L000aoo`L002Moo`L000aoo`L0039oo`P002Uoo`00:Goo1P004goo0`007Woo1@00
3Woo1@004goo0`004goo1@003Woo1@007Woo0`004goo1P00:Woo000ZOol4000COol5000NOol3000@
Ool3000COol5000COol3000@Ool3000NOol5000COol4000[Ool0041oo`L004Eoo`L004Eoo`L0045o
o`00@7oo1`00AGoo1`00AGoo1`00@Goo0010Ool70015Ool70015Ool70011Ool0045oo`D000Aoo`<0
00Yoo`<0039oo`L0039oo`<000Yoo`<000Aoo`D0049oo`00@Woo0`0017oo1@0027oo1@00<7oo2@00
<7oo1@0027oo1@0017oo0`00@goo0018Ool70006Ool7000_Ool9000_Ool70006Ool70019Ool004Qo
o`L000Ioo`L002moo`T002moo`L000Ioo`L004Uoo`00B7oo1`001Woo1`00<7oo1`00<7oo1`001Woo
1`00BGoo0019Ool50008Ool5000bOol5000bOol50008Ool5001:Ool004Yoo`<000Yoo`<006]oo`<0
00Yoo`<004]oo`00ogoo8Goo001WOol3001;Ool3001XOol002Qoo`<003]oo`D004Uoo`D003]oo`<0
02Uoo`009goo1@002goo0`00:goo2000AGoo2000:goo0`002goo1@00:7oo000VOol70009Ool5000Z
Ool90013Ool9000ZOol50009Ool7000WOol001aoo`<000Moo`L000Qoo`L002Uoo`X0045oo`X002Uo
o`L000Qoo`L000Moo`<001eoo`006goo1@001Woo1`0027oo1`00:Woo2@00@Goo2@00:Woo1`0027oo
1`001Woo1@0077oo000JOol70006Ool50009Ool7000ZOol90011Ool9000ZOol70009Ool50006Ool7
000KOol001Yoo`L000Moo`<000]oo`D002]oo`P004=oo`P002]oo`D000]oo`<000Moo`L001]oo`00
6Woo1`005Woo0`00;7oo1`00AGoo1`00;7oo0`005Woo1`006goo000KOol5000NOol3000@Ool3000C
Ool50017Ool5000COol3000@Ool3000NOol5000LOol001aoo`<001ioo`D000ioo`D001=oo`<004Uo
o`<001=oo`D000ioo`D001ioo`<001eoo`00?7oo1`0037oo1`00Lgoo1`0037oo1`00?Goo000lOol7
000<Ool7001cOol7000<Ool7000mOol001Moo`<0029oo`L000aoo`L003Aoo`<000Eoo`<003Aoo`L0
00aoo`L0029oo`<001Qoo`005Woo1@008Woo1@003Woo1@00=7oo1@000goo1@00=7oo1@003Woo1@00
8Woo1@005goo000EOol7000ROol3000@Ool3000dOol700000goo00000005000dOol3000@Ool3000R
Ool7000FOol001Eoo`L006aoo`L00003Ool0000000D006aoo`L001Ioo`005Goo1`00K7oo1`0000=o
o`0000001@00K7oo1`005Woo000EOol6001NOol3000=Ool50003Ool5000=Ool3001NOol6000FOol0
01Aoo`L005eoo`D000eoo`<000Eoo`<000eoo`D005eoo`L001Eoo`0057oo1`00G7oo1`008goo1`00
G7oo1`005Goo000DOol7000WOol3000bOol7000@Ool3000@Ool7000bOol3000WOol7000EOol001Eo
o`D002Moo`D0035oo`L000moo`D000moo`L0035oo`D002Moo`D001Ioo`005Woo0`005Woo0`003Woo
1`00:goo0`000goo1@003goo1`003goo1@000goo0`00:goo1`003Woo0`005Woo0`005goo000^Ool5
000=Ool7000ZOol50003Ool3000@Ool7000@Ool30003Ool5000ZOol7000=Ool5000_Ool002eoo`L0
00aoo`L002Uoo`L001Eoo`L001Eoo`L002Uoo`L000aoo`L002ioo`00;Goo1`003Goo1@00:Woo1`00
5Woo1@005Woo1`00:Woo1@003Goo1`00;Woo000]Ool7000>Ool3000[Ool70003Ool3000AOol3000A
Ool30003Ool7000[Ool3000>Ool7000^Ool001Aoo`<001Moo`D003ioo`D000=oo`D002=oo`D000=o
o`D003ioo`D001Moo`<001Eoo`004goo1@005goo0`00@7oo0`000goo1`008Goo1`000goo0`00@7oo
0`005goo1@0057oo000BOol7001OOol7000QOol7001OOol7000COol0019oo`L005moo`L0025oo`L0
05moo`L001=oo`004Woo1`00H7oo1@008goo1@00H7oo1`004goo000COol5000fOol30002Ool3000T
Ool3000UOol3000TOol30002Ool3000fOol5000DOol001Aoo`<003Ioo`X0075oo`X003Ioo`<001Eo
o`00C7oo3000Kgoo3000CGoo000mOol3000<Ool<001_Ool<000<Ool3000nOol001aoo`<001eoo`D0
00]oo``0011oo`<004Uoo`<0011oo``000]oo`D001eoo`<001eoo`006goo1@006goo1`002goo2P00
47oo1@00Agoo1@0047oo2P002goo1`006goo1@0077oo000JOol7000JOol7000<Ool9000?Ool70015
Ool7000?Ool9000<Ool7000JOol7000KOol001Yoo`L001Yoo`L000ioo`L000moo`L004Eoo`L000mo
o`L000ioo`L001Yoo`L001]oo`006Woo1`006goo1@0047oo1@0047oo1`00AGoo1`0047oo1@0047oo
1@006goo1`006goo000KOol5000MOol3000BOol3000BOol50017Ool5000BOol3000BOol3000MOol5
000LOol001aoo`<004Uoo`<004Uoo`<004Uoo`<001eoo`00<goo0`00>7oo0`00?Goo0`00>7oo0`00
=7oo000YOol30006Ool5000^Ool30005Ool5000kOol50005Ool3000^Ool50006Ool3000ZOol002Qo
o`D000Aoo`L002aoo`D000=oo`L003Uoo`L000=oo`D002aoo`L000Aoo`D002Uoo`009goo1`000goo
1`00:goo1`000Woo1`00>Goo1`000Woo1`00:goo1`000goo1`00:7oo000WOol70003Ool7000[Ool7
0002Ool7000iOol70002Ool7000[Ool70003Ool7000XOol002Moo`L000Aoo`D002aoo`L000=oo`D0
03]oo`D000=oo`L002aoo`D000Aoo`L002Qoo`00:7oo1@001Woo0`00;Woo1@001Goo0`00?Goo0`00
1Goo1@00;Woo0`001Woo1@00:Goo000YOol3000iOol3001?Ool3000iOol3000ZOol00?moob5oo`00
ogoo8Goo000COol3000/Ool30019Ool30019Ool3000/Ool3000DOol0019oo`D002Yoo`D004Moo`D0
04Moo`D002Yoo`D001=oo`004Goo1`00:7oo1`00AGoo1`00AGoo1`00:7oo1`004Woo000AOol7000X
Ool70015Ool70015Ool7000XOol7000BOol0015oo`L002Qoo`L004Eoo`L004Eoo`L002Qoo`L0019o
o`004Woo1@00:Woo1@00Agoo1@00Agoo1@00:Woo1@004goo000COol3000/Ool30019Ool30019Ool3
000/Ool3000DOol00?moob5oo`00ogoo8Goo000YOol3000iOol3001?Ool3000iOol3000ZOol002Qo
o`D000Ioo`<002ioo`D000Eoo`<003eoo`<000Eoo`D002ioo`<000Ioo`D002Uoo`009goo1`0017oo
1@00;7oo1`000goo1@00>goo1@000goo1`00;7oo1@0017oo1`00:7oo000WOol70003Ool7000[Ool7
0002Ool7000iOol70002Ool7000[Ool70003Ool7000XOol002Moo`L000=oo`L002]oo`L0009oo`L0
03Uoo`L0009oo`L002]oo`L000=oo`L002Qoo`00:7oo1@0017oo1`00;7oo1@000goo1`00>Goo1`00
0goo1@00;7oo1`0017oo1@00:Goo000YOol30006Ool5000^Ool30005Ool5000kOol50005Ool3000^
Ool50006Ool3000ZOol003=oo`<003Qoo`<003eoo`<003Qoo`<003Aoo`0077oo0`00BGoo0`00BGoo
0`00BGoo0`007Goo000KOol5000MOol3000BOol3000BOol50017Ool5000BOol3000BOol3000MOol5
000LOol001Yoo`L001]oo`D0011oo`D0011oo`L004Eoo`L0011oo`D0011oo`D001]oo`L001]oo`00
6Woo1`006Woo1`003Woo1`003goo1`00AGoo1`003goo1`003Woo1`006Woo1`006goo000JOol7000J
Ool7000<Ool9000?Ool70015Ool7000?Ool9000<Ool7000JOol7000KOol001]oo`D001]oo`L000]o
o`X0011oo`D004Moo`D0011oo`X000]oo`L001]oo`D001aoo`0077oo0`007Goo1@002goo300047oo
0`00BGoo0`0047oo30002goo1@007Goo0`007Goo000mOol3000<Ool<001_Ool<000<Ool3000nOol0
04aoo``006moo``004eoo`0057oo0`00=Woo2P00LGoo2P00=Woo0`005Goo000COol5000fOol30002
Ool3000TOol3000UOol3000TOol30002Ool3000fOol5000DOol0019oo`L0061oo`D002=oo`D0061o
o`L001=oo`004Woo1`00Ggoo1`008Goo1`00Ggoo1`004goo000BOol7001OOol7000QOol7001OOol7
000COol001=oo`D001Moo`<0041oo`<000=oo`L0025oo`L000=oo`<0041oo`<001Moo`D001Aoo`00
57oo0`005goo1@00?Woo1@000goo1@008goo1@000goo1@00?Woo1@005goo0`005Goo000]Ool7000>
Ool3000[Ool70003Ool3000AOol3000AOol30003Ool7000[Ool3000>Ool7000^Ool002eoo`L000eo
o`D002Yoo`L001Ioo`D001Ioo`L002Yoo`D000eoo`L002ioo`00;Goo1`0037oo1`00:Goo1`005Goo
1`005Goo1`00:Goo1`0037oo1`00;Woo000^Ool5000=Ool7000ZOol50003Ool3000@Ool7000@Ool3
0003Ool5000ZOol7000=Ool5000_Ool001Ioo`<001Ioo`<000ioo`L002]oo`<000=oo`D000moo`L0
00moo`D000=oo`<002]oo`L000ioo`<001Ioo`<001Moo`005Goo1@009goo1@00<Goo1`003goo1@00
3goo1`00<Goo1@009goo1@005Woo000DOol7000WOol3000bOol7000@Ool3000@Ool7000bOol3000W
Ool7000EOol001Aoo`L005aoo`L002=oo`L005aoo`L001Eoo`0057oo1`00GGoo1@003Goo0`001Goo
0`003Goo1@00GGoo1`005Goo000EOol6001NOol3000=Ool50003Ool5000=Ool3001NOol6000FOol0
01Eoo`L006aoo`L00003Ool0000000D006aoo`L001Ioo`005Goo1`00K7oo1`0000=oo`0000001@00
K7oo1`005Woo000EOol7000ROol3000@Ool3000dOol700000goo00000005000dOol3000@Ool3000R
Ool7000FOol001Ioo`D0029oo`D000ioo`D003Aoo`D000=oo`D003Aoo`D000ioo`D0029oo`D001Mo
o`005goo0`008Woo1`0037oo1`00=7oo0`001Goo0`00=7oo1`0037oo1`008Woo0`0067oo000lOol7
000<Ool7001cOol7000<Ool7000mOol003aoo`L000aoo`L007=oo`L000aoo`L003eoo`0077oo0`00
7Woo1@003Woo1@004goo0`00BGoo0`004goo1@003Woo1@007Woo0`007Goo000KOol5000NOol3000@
Ool3000COol50017Ool5000COol3000@Ool3000NOol5000LOol001Yoo`L001Ioo`<002aoo`L004Eo
o`L002aoo`<001Ioo`L001]oo`006Woo1`001goo0`002goo1@00:goo2000@goo2000:goo1@002goo
0`001goo1`006goo000JOol70006Ool50009Ool7000ZOol90011Ool9000ZOol70009Ool50006Ool7
000KOol001]oo`D000Ioo`L000Qoo`L002Yoo`T0045oo`T002Yoo`L000Qoo`L000Ioo`D001aoo`00
77oo0`001goo1`0027oo1`00:Goo2P00@Goo2P00:Goo1`0027oo1`001goo0`007Goo000VOol70009
Ool5000ZOol90013Ool9000ZOol50009Ool7000WOol002Moo`D000]oo`<002]oo`P004Eoo`P002]o
o`<000]oo`D002Qoo`00:7oo0`00>goo1@00BGoo1@00>goo0`00:Goo001WOol3001;Ool3001XOol0
0?moob5oo`00BWoo0`002Woo0`00Jgoo0`002Woo0`00Bgoo0019Ool50008Ool5000bOol5000bOol5
0008Ool5001:Ool004Qoo`L000Ioo`L0031oo`L0031oo`L000Ioo`L004Uoo`00B7oo1`001Woo1`00
;goo2@00;goo1`001Woo1`00BGoo0018Ool70006Ool7000_Ool9000_Ool70006Ool70019Ool0049o
o`<000Aoo`D000Qoo`D0031oo`T0031oo`D000Qoo`D000Aoo`<004=oo`00@Goo1@0017oo0`002Woo
0`00<Woo1`00<Woo0`002Woo0`0017oo1@00@Woo0010Ool70015Ool70015Ool70011Ool0041oo`L0
04Eoo`L004Eoo`L0045oo`00@7oo1`00AGoo1`00AGoo1`00@Goo000ZOol4000COol5000NOol3000@
Ool3000COol5000COol3000@Ool3000NOol5000COol4000[Ool002Uoo`H001=oo`<001ioo`D000io
o`D001=oo`<001=oo`D000ioo`D001ioo`<001=oo`H002Yoo`00:7oo2000<Woo1`0037oo1`009goo
1`0037oo1`00<Woo2000:Goo000XOol8000bOol7000<Ool7000WOol7000<Ool7000bOol8000YOol0
02Qoo`P0039oo`L000aoo`L002Moo`L000aoo`L0039oo`P002Uoo`00:Goo1P00=7oo1@003Woo1@00
:Goo1@003Woo1@00=7oo1P00:Woo000ZOol4000fOol3000@Ool3000[Ool3000@Ool3000fOol4000[
Ool00?moob5oo`00?7oo0`00XGoo0`00?Goo000kOol5000COol3001cOol3000COol5000lOol003Yo
o`L0015oo`D0075oo`D0015oo`L003]oo`00>Woo1`0047oo1`00;Woo0`003Goo0`00;Woo1`0047oo
1`00>goo000jOol7000@Ool7000@Ool3000JOol5000;Ool5000JOol3000@Ool7000@Ool7000kOol0
03]oo`D0015oo`L000moo`D001Qoo`L000Uoo`L001Qoo`D000moo`L0015oo`D003aoo`00?7oo0`00
4goo1@003goo1`005goo1`002Goo1`005goo1`003goo1@004goo0`00?Goo001COol3000@Ool7000G
Ool70009Ool7000GOol7000@Ool3001DOol006Ioo`L001Qoo`D000]oo`D001Qoo`L006Moo`00Igoo
1@006Woo0`003Goo0`006Woo1@00J7oo001XOol3000AOol3000QOol3000AOol3001YOol007]oo`D0
01moo`D007aoo`00NWoo1`007Goo1`00Ngoo000kOol3000XOol3000AOol7000MOol7000AOol3000X
Ool3000lOol003Yoo`D002Ioo`D0011oo`L001eoo`L0011oo`D002Ioo`D003]oo`00>Goo1`0097oo
1`0047oo1@007goo1@0047oo1`0097oo1`00>Woo000iOol7000TOol7000AOol3000QOol3000AOol7
000TOol7000jOol003Uoo`L002Aoo`L004Uoo`L002Aoo`L003Yoo`00>Woo1@009Woo1@00Bgoo1@00
9Woo1@00>goo000kOol3000XOol3000?Ool3000YOol3000?Ool3000XOol3000lOol0049oo`<0039o
o`D0019oo`<0019oo`D0039oo`<004=oo`00@Goo1@00<7oo1`0047oo1@0047oo1`00<7oo1@00@Woo
0010Ool7000_Ool7000?Ool7000?Ool7000_Ool70011Ool0041oo`T0019oo`<001Qoo`L000moo`L0
00moo`L001Qoo`<0019oo`T0045oo`00@7oo2P0047oo1@0067oo1@0047oo1`0047oo1@0067oo1@00
47oo2P00@Goo0011Ool:000>Ool7000HOol3000BOol5000BOol3000HOol7000>Ool:0012Ool0049o
o`T000ioo`L002ioo`<002ioo`L000ioo`T004=oo`00A7oo1`0017oo0`001goo1`00Ggoo1`001goo
0`0017oo1`00AGoo0015Ool50004Ool50007Ool5001QOol50007Ool50004Ool50016Ool004Ioo`<0
00Aoo`L000Moo`<006=oo`<000Moo`L000Aoo`<004Moo`00CGoo1`00Mgoo1`00CWoo001=Ool7001g
Ool7001>Ool004ioo`D007Uoo`D004moo`00Cgoo0`00:Goo0`008goo0`00:Goo0`00D7oo001jOol5
000QOol5001kOol007Uoo`L001moo`L007Yoo`00NGoo1`007goo1`00NWoo001XOol3000>Ool7000O
Ool7000>Ool3001YOol006Moo`D000ioo`D0025oo`D000ioo`D006Qoo`00IWoo1`003Woo0`008goo
0`003Woo1`00Igoo001VOol70015Ool7001WOol006Ioo`L004Eoo`L006Moo`00Igoo1@00Agoo1@00
J7oo001XOol30019Ool3001YOol0085oo`<001Moo`<0089oo`00P7oo1@005Goo1@00PGoo001oOol7
0006Ool3000017oo000000001Woo1`00P7oo001oOol70005Ool90005Ool70020Ool007moo`L000Ao
o`/000Aoo`L0081oo`00P7oo1@001Goo2`001Goo1@00PGoo0021Ool30006Ool;0006Ool30022Ool0
08]oo`T008aoo`00S7oo0`0000Aoo`00000008eoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.75003, -2.75003, 0.019164, \
0.019164}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[65]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\</usr/people/joseluis/Docs/Papers/Average/gl01.eps\>", \ \
%]\)], "Input"],

Cell[BoxData[
    \("/usr/people/joseluis/Docs/Papers/Average/gl01.eps"\)], "Output"]
}, Open  ]],

Cell["With  g=(2,2,2,2,2)", "InlineFormula"],

Cell[CellGroupData[{

Cell[BoxData[
    \(gl2\  = 
      ListPlot[SphericalCut[gLattice[4, 4, 4, 4, 4], 2.5], 
        Axes \[Rule] False, PlotStyle \[Rule] AbsolutePointSize[4.0], 
        PlotRange\ \  \[Rule] \ {{\(-2.75\), 2.75}, {\(-2.75\), 2.75}}, 
        AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[69]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.181818 0.5 0.181818 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
4 Mabswid
.92362 .59177 Mdot
.8509 .46692 Mdot
.85514 .68602 Mdot
.78242 .56118 Mdot
.70969 .43633 Mdot
.78666 .78028 Mdot
.71394 .65543 Mdot
.64121 .53059 Mdot
.56848 .40574 Mdot
.71818 .87453 Mdot
.64545 .74969 Mdot
.57273 .62484 Mdot
.5 .5 Mdot
.42727 .37516 Mdot
.57697 .84394 Mdot
.50425 .7191 Mdot
.43152 .59426 Mdot
.35879 .46941 Mdot
.28606 .34457 Mdot
.5 .5 Mdot
.54363 .93125 Mdot
.63989 .8235 Mdot
.43283 .89525 Mdot
.52909 .7875 Mdot
.62535 .67975 Mdot
.32202 .85924 Mdot
.41828 .7515 Mdot
.51454 .64375 Mdot
.6108 .536 Mdot
.21122 .82324 Mdot
.30748 .71549 Mdot
.40374 .60775 Mdot
.5 .5 Mdot
.59626 .39225 Mdot
.19668 .67949 Mdot
.29294 .57174 Mdot
.3892 .464 Mdot
.48546 .35625 Mdot
.58172 .2485 Mdot
.5 .5 Mdot
.5 .5 Mdot
.10334 .67476 Mdot
.23556 .73301 Mdot
.10334 .55825 Mdot
.23556 .61651 Mdot
.36778 .67476 Mdot
.10334 .44175 Mdot
.23556 .5 Mdot
.36778 .55825 Mdot
.5 .61651 Mdot
.10334 .32524 Mdot
.23556 .38349 Mdot
.36778 .44175 Mdot
.5 .5 Mdot
.63222 .55825 Mdot
.23556 .26699 Mdot
.36778 .32524 Mdot
.5 .38349 Mdot
.63222 .44175 Mdot
.76444 .5 Mdot
.92362 .40823 Mdot
.8509 .53308 Mdot
.85514 .31398 Mdot
.78242 .43882 Mdot
.70969 .56367 Mdot
.78666 .21972 Mdot
.71394 .34457 Mdot
.64121 .46941 Mdot
.56848 .59426 Mdot
.71818 .12547 Mdot
.64545 .25031 Mdot
.57273 .37516 Mdot
.5 .5 Mdot
.42727 .62484 Mdot
.57697 .15606 Mdot
.50425 .2809 Mdot
.43152 .40574 Mdot
.35879 .53059 Mdot
.28606 .65543 Mdot
.5 .5 Mdot
.5 .5 Mdot
.21122 .17676 Mdot
.19668 .32051 Mdot
.32202 .14076 Mdot
.30748 .28451 Mdot
.29294 .42826 Mdot
.43283 .10475 Mdot
.41828 .2485 Mdot
.40374 .39225 Mdot
.3892 .536 Mdot
.54363 .06875 Mdot
.52909 .2125 Mdot
.51454 .35625 Mdot
.5 .5 Mdot
.48546 .64375 Mdot
.63989 .1765 Mdot
.62535 .32025 Mdot
.6108 .464 Mdot
.59626 .60775 Mdot
.58172 .7515 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[69]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002KOol20023Ool009Yoo`@0089oo`00VWoo1000PWoo002KOol20023
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol007]oo`800:=o
o`00NWoo1000XWoo001jOol4002ROol007]oo`800:=oo`00ogoo8Goo003oOolQOol00<eoo`80055o
o`00c7oo1000D7oo003<Ool4001@Ool00<eoo`80055oo`00Fgoo0P00`goo001JOol40032Ool005Yo
o`@00<9oo`00Fgoo0P00`goo003oOolQOol00:Eoo`8007Uoo`00Y7oo1000N7oo002TOol4001hOol0
0:Eoo`8007Uoo`00ogoo8Goo003oOolQOol003aoo`8007Uoo`8006Moo`00>goo1000Mgoo1000IWoo
000kOol4001gOol4001VOol003aoo`8007Uoo`8006Moo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00Ugoo0P00Qgoo002FOol40026Ool009Ioo`@004Moo`8003eo
o`00Ugoo0P00Agoo1000?7oo003POol4000lOol00>5oo`8003eoo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo001gOol2000]Ool2001hOol007Ioo`@002]oo`@000moo`8006Ioo`00MWoo1000
:goo10003Woo1000IGoo001gOol2000]Ool2000?Ool4001UOol00;Qoo`8006Ioo`00ogoo8Goo0013
Ool2003KOol0049oo`@00=Yoo`00@Woo1000fWoo0013Ool2003KOol0091oo`8008ioo`00Egoo0P00
=Woo1000SGoo001FOol4000eOol4002=Ool005Ioo`@003Ioo`8008ioo`00Egoo0P00agoo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?Aoo`8002Yoo`00lgoo1000:Goo000gOol2001iOol2
000oOol4000YOol001eoo`8001Moo`@002moo`8004Ioo`@003moo`8002Yoo`0077oo10005Woo1000
;Woo1000AGoo1000Jgoo000LOol4000GOol2000_Ool40016Ool2001/Ool001eoo`8004Yoo`800;Eo
o`00ogoo8Goo003oOolQOol0055oo`8007Uoo`80059oo`00D7oo1000Mgoo1000DGoo001@Ool4001g
Ool4001AOol0055oo`8003Moo`8000Moo`8003Moo`80059oo`00RGoo10001Goo1000RWoo0029Ool4
0005Ool4002:Ool008Yoo`8000Moo`8008]oo`00ogoo8Goo003oOolQOol007Yoo`8002Moo`8007]o
o`00NGoo10009Goo1000NWoo0013Ool2000dOol4000BOol2000AOol4001jOol0049oo`@003Aoo`80
019oo`@0015oo`8007]oo`00@Woo1000B7oo1000SWoo0013Ool2000^Ool2000JOol2000IOol2001d
Ool0079oo`@003=oo`@007=oo`00LWoo1000<goo1000Lgoo001cOol20006Ool2000UOol20006Ool2
001dOol007Yoo`@002=oo`@006=oo`8001Ioo`00NWoo10008goo1000HWoo10005Goo001kOol2000U
Ool2001SOol4000EOol00?moo`Uoo`8001Ioo`00ogoo8Goo003oOolQOol005=oo`800<]oo`00DWoo
1000bWoo001BOol4001eOol2001COol005=oo`8007Eoo`@0019oo`8003ioo`007Goo0P00BWoo0P00
BGoo0P0057oo10004Goo1000?Goo000LOol40018Ool40017Ool4000DOol2000BOol4000mOol001ao
o`@004Qoo`@004Moo`@002Uoo`8003ioo`007Goo0P00BWoo0P00BGoo0P00JWoo003oOolQOol00?mo
ob5oo`00Kgoo0P00?Goo0P00L7oo001^Ool4000kOol40012Ool2000[Ool006Ioo`8000Ioo`@003]o
o`@000Ioo`8003Uoo`@002Yoo`00IGoo10001Woo0P00?Goo0P001Woo1000>7oo1000:Woo001UOol4
001=Ool4000iOol2000[Ool006Ioo`8004moo`8006Moo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo0013Ool2001:Ool20019Ool20014Ool0049oo`@004Qoo`@004Moo`@004=oo`00@Woo1000
B7oo1000Agoo1000@goo0013Ool2001:Ool20019Ool20014Ool00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo001VOol2001?Ool2001WOol006Eoo`@004eoo`@003Uoo`8002]oo`00
IGoo10001Woo0P00?Goo0P001Woo1000>7oo1000:Woo001VOol20006Ool4000kOol40006Ool2000i
Ool4000ZOol006ioo`@003]oo`@0049oo`8002]oo`00Kgoo0P00?Goo0P00L7oo003oOolQOol00?mo
ob5oo`007Goo0P00BWoo0P00BGoo0P00JWoo000LOol40018Ool40017Ool4000YOol2000nOol001ao
o`@004Qoo`@004Moo`@001Aoo`80019oo`@003eoo`007Goo0P00BWoo0P00BGoo0P0057oo10004Goo
1000?Goo001COol2001eOol4000BOol2000nOol0059oo`@007Eoo`8005=oo`00DWoo1000bWoo001C
Ool2003;Ool00?moob5oo`00ogoo8Goo003oOol9Ool2000FOol007]oo`8002Eoo`8006=oo`@001Eo
o`00NWoo10008goo1000HWoo10005Goo001jOol4000SOol4001SOol2000FOol007=oo`8000Ioo`80
02Eoo`8000Ioo`8007Aoo`00LWoo1000<goo1000Lgoo001bOol4000cOol4001cOol004=oo`8002io
o`8001Yoo`8001Uoo`8007Aoo`00@Woo1000B7oo1000SWoo0012Ool4000dOol2000BOol4000AOol2
001kOol004=oo`8003Aoo`@0019oo`80015oo`@007Yoo`00NGoo10009Goo1000NWoo001jOol2000W
Ool2001kOol00?moob5oo`00ogoo8Goo002:Ool20007Ool2002;Ool008Uoo`@000Eoo`@008Yoo`00
RGoo10001Goo1000RWoo001AOol2000gOol20007Ool2000gOol2001BOol0051oo`@007Moo`@0055o
o`00D7oo1000Mgoo1000DGoo001AOol2001iOol2001BOol00?moob5oo`00ogoo8Goo000MOol2001:
Ool2002eOol001aoo`@001Moo`8002moo`@004Ioo`8006aoo`0077oo10005Woo1000;Woo1000AGoo
1000Jgoo000MOol2000GOol4000_Ool20016Ool4000oOol2000ZOol003Moo`8007Uoo`8003moo`@0
02Uoo`00lgoo1000:Goo003dOol2000ZOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
Egoo0P00agoo001FOol4000fOol2002>Ool005Ioo`@003Eoo`@008eoo`00Egoo0P00=Woo1000SGoo
002@Ool2002>Ool004=oo`800=]oo`00@Woo1000fWoo0012Ool4003JOol004=oo`800=]oo`00ogoo
8Goo002hOol2001VOol007Moo`8002eoo`8000moo`@006Eoo`00MWoo1000:goo10003Woo1000IGoo
001fOol4000[Ool4000?Ool2001VOol007Moo`8002eoo`8007Qoo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003QOol2000mOol00>1oo`@003aoo`00Ugoo0P00Agoo1000?7oo002FOol40017
Ool2000mOol009Ioo`@008Ioo`00Ugoo0P00Qgoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000lOol2001iOol2001WOol003]oo`@007Moo`@006Ioo`00>goo1000
Mgoo1000IWoo000lOol2001iOol2001WOol00?moob5oo`00ogoo8Goo002UOol2001iOol00:Aoo`@0
07Qoo`00Y7oo1000N7oo002UOol2001iOol00?moob5oo`00Fgoo0P00`goo001JOol40032Ool005Yo
o`@00<9oo`00Fgoo0P00`goo003=Ool2001AOol00<aoo`@0051oo`00c7oo1000D7oo003=Ool2001A
Ool00?moob5oo`00ogoo8Goo001kOol2002SOol007Yoo`@00:9oo`00NWoo1000XWoo001kOol2002S
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol009]oo`8008=o
o`00VWoo1000PWoo002JOol40022Ool009]oo`8008=oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.75003, -2.75003, 0.019164, \
0.019164}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[69]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[gl0, \ gl1, \ gl2]\)], "Input",
  CellLabel->"In[70]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.181818 0.5 0.181818 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
7 Mabswid
.91938 .37267 Mdot
.84665 .24782 Mdot
.92362 .59177 Mdot
.8509 .46692 Mdot
.77817 .34208 Mdot
.70544 .21723 Mdot
.63272 .09239 Mdot
.85514 .68602 Mdot
.78242 .56118 Mdot
.70969 .43633 Mdot
.63696 .31149 Mdot
.56423 .18664 Mdot
.49151 .0618 Mdot
.78666 .78028 Mdot
.71394 .65543 Mdot
.64121 .53059 Mdot
.56848 .40574 Mdot
.49575 .2809 Mdot
.42303 .15606 Mdot
.71818 .87453 Mdot
.64545 .74969 Mdot
.57273 .62484 Mdot
.5 .5 Mdot
.42727 .37516 Mdot
.35455 .25031 Mdot
.28182 .12547 Mdot
.57697 .84394 Mdot
.50425 .7191 Mdot
.43152 .59426 Mdot
.35879 .46941 Mdot
.28606 .34457 Mdot
.21334 .21972 Mdot
.50849 .9382 Mdot
.43577 .81336 Mdot
.36304 .68851 Mdot
.29031 .56367 Mdot
.21758 .43882 Mdot
.14486 .31398 Mdot
.36728 .90761 Mdot
.29456 .78277 Mdot
.22183 .65792 Mdot
.1491 .53308 Mdot
.07638 .40823 Mdot
.15335 .75218 Mdot
.08062 .62733 Mdot
.5 .5 Mdot
.7507 .8595 Mdot
.84696 .75176 Mdot
.54363 .93125 Mdot
.63989 .8235 Mdot
.73615 .71575 Mdot
.83241 .60801 Mdot
.92867 .50026 Mdot
.43283 .89525 Mdot
.52909 .7875 Mdot
.62535 .67975 Mdot
.72161 .572 Mdot
.81787 .46426 Mdot
.91413 .35651 Mdot
.32202 .85924 Mdot
.41828 .7515 Mdot
.51454 .64375 Mdot
.6108 .536 Mdot
.70706 .42826 Mdot
.80332 .32051 Mdot
.21122 .82324 Mdot
.30748 .71549 Mdot
.40374 .60775 Mdot
.5 .5 Mdot
.59626 .39225 Mdot
.69252 .28451 Mdot
.78878 .17676 Mdot
.19668 .67949 Mdot
.29294 .57174 Mdot
.3892 .464 Mdot
.48546 .35625 Mdot
.58172 .2485 Mdot
.67798 .14076 Mdot
.08587 .64349 Mdot
.18213 .53574 Mdot
.27839 .428 Mdot
.37465 .32025 Mdot
.47091 .2125 Mdot
.56717 .10475 Mdot
.07133 .49974 Mdot
.16759 .39199 Mdot
.26385 .28425 Mdot
.36011 .1765 Mdot
.45637 .06875 Mdot
.15304 .24824 Mdot
.2493 .1405 Mdot
.5 .5 Mdot
.5 .5 Mdot
.23556 .84952 Mdot
.36778 .90777 Mdot
.10334 .67476 Mdot
.23556 .73301 Mdot
.36778 .79127 Mdot
.5 .84952 Mdot
.63222 .90777 Mdot
.10334 .55825 Mdot
.23556 .61651 Mdot
.36778 .67476 Mdot
.5 .73301 Mdot
.63222 .79127 Mdot
.76444 .84952 Mdot
.10334 .44175 Mdot
.23556 .5 Mdot
.36778 .55825 Mdot
.5 .61651 Mdot
.63222 .67476 Mdot
.76444 .73301 Mdot
.10334 .32524 Mdot
.23556 .38349 Mdot
.36778 .44175 Mdot
.5 .5 Mdot
.63222 .55825 Mdot
.76444 .61651 Mdot
.89666 .67476 Mdot
.23556 .26699 Mdot
.36778 .32524 Mdot
.5 .38349 Mdot
.63222 .44175 Mdot
.76444 .5 Mdot
.89666 .55825 Mdot
.23556 .15048 Mdot
.36778 .20873 Mdot
.5 .26699 Mdot
.63222 .32524 Mdot
.76444 .38349 Mdot
.89666 .44175 Mdot
.36778 .09223 Mdot
.5 .15048 Mdot
.63222 .20873 Mdot
.76444 .26699 Mdot
.89666 .32524 Mdot
.63222 .09223 Mdot
.76444 .15048 Mdot
.91938 .62733 Mdot
.84665 .75218 Mdot
.92362 .40823 Mdot
.8509 .53308 Mdot
.77817 .65792 Mdot
.70544 .78277 Mdot
.63272 .90761 Mdot
.85514 .31398 Mdot
.78242 .43882 Mdot
.70969 .56367 Mdot
.63696 .68851 Mdot
.56423 .81336 Mdot
.49151 .9382 Mdot
.78666 .21972 Mdot
.71394 .34457 Mdot
.64121 .46941 Mdot
.56848 .59426 Mdot
.49575 .7191 Mdot
.42303 .84394 Mdot
.71818 .12547 Mdot
.64545 .25031 Mdot
.57273 .37516 Mdot
.5 .5 Mdot
.42727 .62484 Mdot
.35455 .74969 Mdot
.28182 .87453 Mdot
.57697 .15606 Mdot
.50425 .2809 Mdot
.43152 .40574 Mdot
.35879 .53059 Mdot
.28606 .65543 Mdot
.21334 .78028 Mdot
.50849 .0618 Mdot
.43577 .18664 Mdot
.36304 .31149 Mdot
.29031 .43633 Mdot
.21758 .56118 Mdot
.14486 .68602 Mdot
.36728 .09239 Mdot
.29456 .21723 Mdot
.22183 .34208 Mdot
.1491 .46692 Mdot
.07638 .59177 Mdot
.15335 .24782 Mdot
.08062 .37267 Mdot
.5 .5 Mdot
.5 .5 Mdot
.08587 .35651 Mdot
.07133 .50026 Mdot
.21122 .17676 Mdot
.19668 .32051 Mdot
.18213 .46426 Mdot
.16759 .60801 Mdot
.15304 .75176 Mdot
.32202 .14076 Mdot
.30748 .28451 Mdot
.29294 .42826 Mdot
.27839 .572 Mdot
.26385 .71575 Mdot
.2493 .8595 Mdot
.43283 .10475 Mdot
.41828 .2485 Mdot
.40374 .39225 Mdot
.3892 .536 Mdot
.37465 .67975 Mdot
.36011 .8235 Mdot
.54363 .06875 Mdot
.52909 .2125 Mdot
.51454 .35625 Mdot
.5 .5 Mdot
.48546 .64375 Mdot
.47091 .7875 Mdot
.45637 .93125 Mdot
.63989 .1765 Mdot
.62535 .32025 Mdot
.6108 .464 Mdot
.59626 .60775 Mdot
.58172 .7515 Mdot
.56717 .89525 Mdot
.7507 .1405 Mdot
.73615 .28425 Mdot
.72161 .428 Mdot
.70706 .57174 Mdot
.69252 .71549 Mdot
.67798 .85924 Mdot
.84696 .24824 Mdot
.83241 .39199 Mdot
.81787 .53574 Mdot
.80332 .67949 Mdot
.78878 .82324 Mdot
.92867 .49974 Mdot
.91413 .64349 Mdot
4 Mabswid
.91938 .37267 Mdot
.84665 .24782 Mdot
.92362 .59177 Mdot
.8509 .46692 Mdot
.77817 .34208 Mdot
.70544 .21723 Mdot
.63272 .09239 Mdot
.85514 .68602 Mdot
.78242 .56118 Mdot
.70969 .43633 Mdot
.63696 .31149 Mdot
.56423 .18664 Mdot
.49151 .0618 Mdot
.78666 .78028 Mdot
.71394 .65543 Mdot
.64121 .53059 Mdot
.56848 .40574 Mdot
.49575 .2809 Mdot
.42303 .15606 Mdot
.71818 .87453 Mdot
.64545 .74969 Mdot
.57273 .62484 Mdot
.5 .5 Mdot
.42727 .37516 Mdot
.35455 .25031 Mdot
.28182 .12547 Mdot
.57697 .84394 Mdot
.50425 .7191 Mdot
.43152 .59426 Mdot
.35879 .46941 Mdot
.28606 .34457 Mdot
.21334 .21972 Mdot
.50849 .9382 Mdot
.43577 .81336 Mdot
.36304 .68851 Mdot
.29031 .56367 Mdot
.21758 .43882 Mdot
.14486 .31398 Mdot
.36728 .90761 Mdot
.29456 .78277 Mdot
.22183 .65792 Mdot
.1491 .53308 Mdot
.07638 .40823 Mdot
.15335 .75218 Mdot
.08062 .62733 Mdot
.5 .5 Mdot
.7507 .8595 Mdot
.84696 .75176 Mdot
.54363 .93125 Mdot
.63989 .8235 Mdot
.73615 .71575 Mdot
.83241 .60801 Mdot
.92867 .50026 Mdot
.43283 .89525 Mdot
.52909 .7875 Mdot
.62535 .67975 Mdot
.72161 .572 Mdot
.81787 .46426 Mdot
.91413 .35651 Mdot
.32202 .85924 Mdot
.41828 .7515 Mdot
.51454 .64375 Mdot
.6108 .536 Mdot
.70706 .42826 Mdot
.80332 .32051 Mdot
.21122 .82324 Mdot
.30748 .71549 Mdot
.40374 .60775 Mdot
.5 .5 Mdot
.59626 .39225 Mdot
.69252 .28451 Mdot
.78878 .17676 Mdot
.19668 .67949 Mdot
.29294 .57174 Mdot
.3892 .464 Mdot
.48546 .35625 Mdot
.58172 .2485 Mdot
.67798 .14076 Mdot
.08587 .64349 Mdot
.18213 .53574 Mdot
.27839 .428 Mdot
.37465 .32025 Mdot
.47091 .2125 Mdot
.56717 .10475 Mdot
.07133 .49974 Mdot
.16759 .39199 Mdot
.26385 .28425 Mdot
.36011 .1765 Mdot
.45637 .06875 Mdot
.15304 .24824 Mdot
.2493 .1405 Mdot
.5 .5 Mdot
.5 .5 Mdot
.23556 .84952 Mdot
.36778 .90777 Mdot
.10334 .67476 Mdot
.23556 .73301 Mdot
.36778 .79127 Mdot
.5 .84952 Mdot
.63222 .90777 Mdot
.10334 .55825 Mdot
.23556 .61651 Mdot
.36778 .67476 Mdot
.5 .73301 Mdot
.63222 .79127 Mdot
.76444 .84952 Mdot
.10334 .44175 Mdot
.23556 .5 Mdot
.36778 .55825 Mdot
.5 .61651 Mdot
.63222 .67476 Mdot
.76444 .73301 Mdot
.10334 .32524 Mdot
.23556 .38349 Mdot
.36778 .44175 Mdot
.5 .5 Mdot
.63222 .55825 Mdot
.76444 .61651 Mdot
.89666 .67476 Mdot
.23556 .26699 Mdot
.36778 .32524 Mdot
.5 .38349 Mdot
.63222 .44175 Mdot
.76444 .5 Mdot
.89666 .55825 Mdot
.23556 .15048 Mdot
.36778 .20873 Mdot
.5 .26699 Mdot
.63222 .32524 Mdot
.76444 .38349 Mdot
.89666 .44175 Mdot
.36778 .09223 Mdot
.5 .15048 Mdot
.63222 .20873 Mdot
.76444 .26699 Mdot
.89666 .32524 Mdot
.63222 .09223 Mdot
.76444 .15048 Mdot
.91938 .62733 Mdot
.84665 .75218 Mdot
.92362 .40823 Mdot
.8509 .53308 Mdot
.77817 .65792 Mdot
.70544 .78277 Mdot
.63272 .90761 Mdot
.85514 .31398 Mdot
.78242 .43882 Mdot
.70969 .56367 Mdot
.63696 .68851 Mdot
.56423 .81336 Mdot
.49151 .9382 Mdot
.78666 .21972 Mdot
.71394 .34457 Mdot
.64121 .46941 Mdot
.56848 .59426 Mdot
.49575 .7191 Mdot
.42303 .84394 Mdot
.71818 .12547 Mdot
.64545 .25031 Mdot
.57273 .37516 Mdot
.5 .5 Mdot
.42727 .62484 Mdot
.35455 .74969 Mdot
.28182 .87453 Mdot
.57697 .15606 Mdot
.50425 .2809 Mdot
.43152 .40574 Mdot
.35879 .53059 Mdot
.28606 .65543 Mdot
.21334 .78028 Mdot
.50849 .0618 Mdot
.43577 .18664 Mdot
.36304 .31149 Mdot
.29031 .43633 Mdot
.21758 .56118 Mdot
.14486 .68602 Mdot
.36728 .09239 Mdot
.29456 .21723 Mdot
.22183 .34208 Mdot
.1491 .46692 Mdot
.07638 .59177 Mdot
.15335 .24782 Mdot
.08062 .37267 Mdot
.5 .5 Mdot
.5 .5 Mdot
.08587 .35651 Mdot
.07133 .50026 Mdot
.21122 .17676 Mdot
.19668 .32051 Mdot
.18213 .46426 Mdot
.16759 .60801 Mdot
.15304 .75176 Mdot
.32202 .14076 Mdot
.30748 .28451 Mdot
.29294 .42826 Mdot
.27839 .572 Mdot
.26385 .71575 Mdot
.2493 .8595 Mdot
.43283 .10475 Mdot
.41828 .2485 Mdot
.40374 .39225 Mdot
.3892 .536 Mdot
.37465 .67975 Mdot
.36011 .8235 Mdot
.54363 .06875 Mdot
.52909 .2125 Mdot
.51454 .35625 Mdot
.5 .5 Mdot
.48546 .64375 Mdot
.47091 .7875 Mdot
.45637 .93125 Mdot
.63989 .1765 Mdot
.62535 .32025 Mdot
.6108 .464 Mdot
.59626 .60775 Mdot
.58172 .7515 Mdot
.56717 .89525 Mdot
.7507 .1405 Mdot
.73615 .28425 Mdot
.72161 .428 Mdot
.70706 .57174 Mdot
.69252 .71549 Mdot
.67798 .85924 Mdot
.84696 .24824 Mdot
.83241 .39199 Mdot
.81787 .53574 Mdot
.80332 .67949 Mdot
.78878 .82324 Mdot
.92867 .49974 Mdot
.91413 .64349 Mdot
.92362 .59177 Mdot
.8509 .46692 Mdot
.85514 .68602 Mdot
.78242 .56118 Mdot
.70969 .43633 Mdot
.78666 .78028 Mdot
.71394 .65543 Mdot
.64121 .53059 Mdot
.56848 .40574 Mdot
.71818 .87453 Mdot
.64545 .74969 Mdot
.57273 .62484 Mdot
.5 .5 Mdot
.42727 .37516 Mdot
.57697 .84394 Mdot
.50425 .7191 Mdot
.43152 .59426 Mdot
.35879 .46941 Mdot
.28606 .34457 Mdot
.5 .5 Mdot
.54363 .93125 Mdot
.63989 .8235 Mdot
.43283 .89525 Mdot
.52909 .7875 Mdot
.62535 .67975 Mdot
.32202 .85924 Mdot
.41828 .7515 Mdot
.51454 .64375 Mdot
.6108 .536 Mdot
.21122 .82324 Mdot
.30748 .71549 Mdot
.40374 .60775 Mdot
.5 .5 Mdot
.59626 .39225 Mdot
.19668 .67949 Mdot
.29294 .57174 Mdot
.3892 .464 Mdot
.48546 .35625 Mdot
.58172 .2485 Mdot
.5 .5 Mdot
.5 .5 Mdot
.10334 .67476 Mdot
.23556 .73301 Mdot
.10334 .55825 Mdot
.23556 .61651 Mdot
.36778 .67476 Mdot
.10334 .44175 Mdot
.23556 .5 Mdot
.36778 .55825 Mdot
.5 .61651 Mdot
.10334 .32524 Mdot
.23556 .38349 Mdot
.36778 .44175 Mdot
.5 .5 Mdot
.63222 .55825 Mdot
.23556 .26699 Mdot
.36778 .32524 Mdot
.5 .38349 Mdot
.63222 .44175 Mdot
.76444 .5 Mdot
.92362 .40823 Mdot
.8509 .53308 Mdot
.85514 .31398 Mdot
.78242 .43882 Mdot
.70969 .56367 Mdot
.78666 .21972 Mdot
.71394 .34457 Mdot
.64121 .46941 Mdot
.56848 .59426 Mdot
.71818 .12547 Mdot
.64545 .25031 Mdot
.57273 .37516 Mdot
.5 .5 Mdot
.42727 .62484 Mdot
.57697 .15606 Mdot
.50425 .2809 Mdot
.43152 .40574 Mdot
.35879 .53059 Mdot
.28606 .65543 Mdot
.5 .5 Mdot
.5 .5 Mdot
.21122 .17676 Mdot
.19668 .32051 Mdot
.32202 .14076 Mdot
.30748 .28451 Mdot
.29294 .42826 Mdot
.43283 .10475 Mdot
.41828 .2485 Mdot
.40374 .39225 Mdot
.3892 .536 Mdot
.54363 .06875 Mdot
.52909 .2125 Mdot
.51454 .35625 Mdot
.5 .5 Mdot
.48546 .64375 Mdot
.63989 .1765 Mdot
.62535 .32025 Mdot
.6108 .464 Mdot
.59626 .60775 Mdot
.58172 .7515 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[70]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00S7oo0`0000Aoo`00
000008eoo`00Rgoo2@00S7oo0021Ool30006Ool;0006Ool30022Ool0081oo`D000Eoo`/000Eoo`D0
085oo`00Ogoo1`0017oo2`0017oo1`00P7oo001oOol70005Ool90005Ool70020Ool007moo`L000Io
o`<00004Ool000000006Ool70020Ool0081oo`D001Eoo`D0085oo`00PGoo0`005goo0`00PWoo001X
Ool30019Ool3001YOol006Moo`D004Moo`D006Qoo`00IWoo1`00AGoo1`00Igoo001VOol70015Ool7
001WOol006Ioo`L000ioo`<002=oo`<000ioo`L006Moo`00Igoo1@003Woo1@008Goo1@003Woo1@00
J7oo001XOol3000>Ool7000OOol7000>Ool3001YOol007Uoo`L001moo`L007Yoo`00NGoo1`007goo
1`00NWoo001jOol5000QOol5001kOol004moo`<002Uoo`<002=oo`<002Uoo`<0051oo`00CWoo1@00
NGoo1@00Cgoo001=Ool7001gOol7001>Ool004eoo`L007Moo`L004ioo`00AWoo0`0017oo1`001goo
0`00Hgoo0`001goo1`0017oo0`00Agoo0015Ool50004Ool50007Ool5001QOol50007Ool50004Ool5
0016Ool004Aoo`L000Aoo`<000Moo`L005moo`L000Moo`<000Aoo`L004Eoo`00@Woo2@003Woo1`00
;Woo0`00;Woo1`003Woo2@00@goo0011Ool:000>Ool7000HOol3000BOol5000BOol3000HOol7000>
Ool:0012Ool0041oo`X0011oo`D001Qoo`D0011oo`L0011oo`D001Qoo`D0011oo`X0045oo`00@7oo
2@004Woo0`0067oo1`003goo1`003goo1`0067oo0`004Woo2@00@Goo0010Ool7000_Ool7000?Ool7
000?Ool7000_Ool70011Ool0045oo`D0031oo`L0011oo`D0011oo`L0031oo`D0049oo`00@Woo0`00
<Woo1@004Woo0`004Woo1@00<Woo0`00@goo000kOol3000XOol3000?Ool3000YOol3000?Ool3000X
Ool3000lOol003Yoo`D002Ioo`D004]oo`D002Ioo`D003]oo`00>Goo1`0097oo1`00BGoo1`0097oo
1`00>Woo000iOol7000TOol7000AOol3000QOol3000AOol7000TOol7000jOol003Uoo`L002Aoo`L0
011oo`D001moo`D0011oo`L002Aoo`L003Yoo`00>Woo1@009Woo1@0047oo1`007Goo1`0047oo1@00
9Woo1@00>goo000kOol3000XOol3000AOol7000MOol7000AOol3000XOol3000lOol007Yoo`L001eo
o`L007]oo`00Ngoo1@007goo1@00O7oo001XOol3000AOol3000QOol3000AOol3001YOol006Moo`D0
01Yoo`<000eoo`<001Yoo`D006Qoo`00IWoo1`0067oo1@002goo1@0067oo1`00Igoo001COol3000@
Ool7000GOol70009Ool7000GOol7000@Ool3001DOol003aoo`<001=oo`D000moo`L001Moo`L000Uo
o`L001Moo`L000moo`D001=oo`<003eoo`00>goo1@004Goo1`003goo1@0067oo1`002Goo1`0067oo
1@003goo1`004Goo1@00?7oo000jOol7000@Ool7000@Ool3000JOol5000;Ool5000JOol3000@Ool7
000@Ool7000kOol003Yoo`L0011oo`L002ioo`<000eoo`<002ioo`L0011oo`L003]oo`00>Woo1`00
4Goo1@00LGoo1@004Goo1`00>goo000kOol5000COol3001cOol3000COol5000lOol003aoo`<00:5o
o`<003eoo`00ogoo8Goo000ZOol4000fOol3000@Ool3000[Ool3000@Ool3000fOol4000[Ool002Uo
o`H003Aoo`D000ioo`D002Uoo`D000ioo`D003Aoo`H002Yoo`00:7oo2000<Woo1`0037oo1`009goo
1`0037oo1`00<Woo2000:Goo000XOol8000bOol7000<Ool7000WOol7000<Ool7000bOol8000YOol0
02Qoo`P0039oo`L000aoo`L002Moo`L000aoo`L0039oo`P002Uoo`00:Goo1P004goo0`007Woo1@00
3Woo1@004goo0`004goo1@003Woo1@007Woo0`004goo1P00:Woo000ZOol4000COol5000NOol3000@
Ool3000COol5000COol3000@Ool3000NOol5000COol4000[Ool0041oo`L004Eoo`L004Eoo`L0045o
o`00@7oo1`00AGoo1`00AGoo1`00@Goo0010Ool70015Ool70015Ool70011Ool0045oo`D000Aoo`<0
00Yoo`<0039oo`L0039oo`<000Yoo`<000Aoo`D0049oo`00@Woo0`0017oo1@0027oo1@00<7oo2@00
<7oo1@0027oo1@0017oo0`00@goo0018Ool70006Ool7000_Ool9000_Ool70006Ool70019Ool004Qo
o`L000Ioo`L002moo`T002moo`L000Ioo`L004Uoo`00B7oo1`001Woo1`00<7oo1`00<7oo1`001Woo
1`00BGoo0019Ool50008Ool5000bOol5000bOol50008Ool5001:Ool004Yoo`<000Yoo`<006]oo`<0
00Yoo`<004]oo`00ogoo8Goo001WOol3001;Ool3001XOol002Qoo`<003]oo`D004Uoo`D003]oo`<0
02Uoo`009goo1@002goo0`00:goo2000AGoo2000:goo0`002goo1@00:7oo000VOol70009Ool5000Z
Ool90013Ool9000ZOol50009Ool7000WOol001aoo`<000Moo`L000Qoo`L002Uoo`X0045oo`X002Uo
o`L000Qoo`L000Moo`<001eoo`006goo1@001Woo1`0027oo1`00:Woo2@00@Goo2@00:Woo1`0027oo
1`001Woo1@0077oo000JOol70006Ool50009Ool7000ZOol90011Ool9000ZOol70009Ool50006Ool7
000KOol001Yoo`L000Moo`<000]oo`D002]oo`P004=oo`P002]oo`D000]oo`<000Moo`L001]oo`00
6Woo1`005Woo0`00;7oo1`00AGoo1`00;7oo0`005Woo1`006goo000KOol5000NOol3000@Ool3000C
Ool50017Ool5000COol3000@Ool3000NOol5000LOol001aoo`<001ioo`D000ioo`D001=oo`<004Uo
o`<001=oo`D000ioo`D001ioo`<001eoo`00?7oo1`0037oo1`00Lgoo1`0037oo1`00?Goo000lOol7
000<Ool7001cOol7000<Ool7000mOol001Moo`<0029oo`L000aoo`L003Aoo`<000Eoo`<003Aoo`L0
00aoo`L0029oo`<001Qoo`005Woo1@008Woo1@003Woo1@00=7oo1@000goo1@00=7oo1@003Woo1@00
8Woo1@005goo000EOol7000ROol3000@Ool3000dOol700000goo00000005000dOol3000@Ool3000R
Ool7000FOol001Eoo`L006aoo`L00003Ool0000000D006aoo`L001Ioo`005Goo1`00K7oo1`0000=o
o`0000001@00K7oo1`005Woo000EOol6001NOol3000=Ool50003Ool5000=Ool3001NOol6000FOol0
01Aoo`L005eoo`D000eoo`<000Eoo`<000eoo`D005eoo`L001Eoo`0057oo1`00G7oo1`008goo1`00
G7oo1`005Goo000DOol7000WOol3000bOol7000@Ool3000@Ool7000bOol3000WOol7000EOol001Eo
o`D002Moo`D0035oo`L000moo`D000moo`L0035oo`D002Moo`D001Ioo`005Woo0`005Woo0`003Woo
1`00:goo0`000goo1@003goo1`003goo1@000goo0`00:goo1`003Woo0`005Woo0`005goo000^Ool5
000=Ool7000ZOol50003Ool3000@Ool7000@Ool30003Ool5000ZOol7000=Ool5000_Ool002eoo`L0
00aoo`L002Uoo`L001Eoo`L001Eoo`L002Uoo`L000aoo`L002ioo`00;Goo1`003Goo1@00:Woo1`00
5Woo1@005Woo1`00:Woo1@003Goo1`00;Woo000]Ool7000>Ool3000[Ool70003Ool3000AOol3000A
Ool30003Ool7000[Ool3000>Ool7000^Ool001Aoo`<001Moo`D003ioo`D000=oo`D002=oo`D000=o
o`D003ioo`D001Moo`<001Eoo`004goo1@005goo0`00@7oo0`000goo1`008Goo1`000goo0`00@7oo
0`005goo1@0057oo000BOol7001OOol7000QOol7001OOol7000COol0019oo`L005moo`L0025oo`L0
05moo`L001=oo`004Woo1`00H7oo1@008goo1@00H7oo1`004goo000COol5000fOol30002Ool3000T
Ool3000UOol3000TOol30002Ool3000fOol5000DOol001Aoo`<003Ioo`X0075oo`X003Ioo`<001Eo
o`00C7oo3000Kgoo3000CGoo000mOol3000<Ool<001_Ool<000<Ool3000nOol001aoo`<001eoo`D0
00]oo``0011oo`<004Uoo`<0011oo``000]oo`D001eoo`<001eoo`006goo1@006goo1`002goo2P00
47oo1@00Agoo1@0047oo2P002goo1`006goo1@0077oo000JOol7000JOol7000<Ool9000?Ool70015
Ool7000?Ool9000<Ool7000JOol7000KOol001Yoo`L001Yoo`L000ioo`L000moo`L004Eoo`L000mo
o`L000ioo`L001Yoo`L001]oo`006Woo1`006goo1@0047oo1@0047oo1`00AGoo1`0047oo1@0047oo
1@006goo1`006goo000KOol5000MOol3000BOol3000BOol50017Ool5000BOol3000BOol3000MOol5
000LOol001aoo`<004Uoo`<004Uoo`<004Uoo`<001eoo`00<goo0`00>7oo0`00?Goo0`00>7oo0`00
=7oo000YOol30006Ool5000^Ool30005Ool5000kOol50005Ool3000^Ool50006Ool3000ZOol002Qo
o`D000Aoo`L002aoo`D000=oo`L003Uoo`L000=oo`D002aoo`L000Aoo`D002Uoo`009goo1`000goo
1`00:goo1`000Woo1`00>Goo1`000Woo1`00:goo1`000goo1`00:7oo000WOol70003Ool7000[Ool7
0002Ool7000iOol70002Ool7000[Ool70003Ool7000XOol002Moo`L000Aoo`D002aoo`L000=oo`D0
03]oo`D000=oo`L002aoo`D000Aoo`L002Qoo`00:7oo1@001Woo0`00;Woo1@001Goo0`00?Goo0`00
1Goo1@00;Woo0`001Woo1@00:Goo000YOol3000iOol3001?Ool3000iOol3000ZOol00?moob5oo`00
ogoo8Goo000COol3000/Ool30019Ool30019Ool3000/Ool3000DOol0019oo`D002Yoo`D004Moo`D0
04Moo`D002Yoo`D001=oo`004Goo1`00:7oo1`00AGoo1`00AGoo1`00:7oo1`004Woo000AOol7000X
Ool70015Ool70015Ool7000XOol7000BOol0015oo`L002Qoo`L004Eoo`L004Eoo`L002Qoo`L0019o
o`004Woo1@00:Woo1@00Agoo1@00Agoo1@00:Woo1@004goo000COol3000/Ool30019Ool30019Ool3
000/Ool3000DOol00?moob5oo`00ogoo8Goo000YOol3000iOol3001?Ool3000iOol3000ZOol002Qo
o`D000Ioo`<002ioo`D000Eoo`<003eoo`<000Eoo`D002ioo`<000Ioo`D002Uoo`009goo1`0017oo
1@00;7oo1`000goo1@00>goo1@000goo1`00;7oo1@0017oo1`00:7oo000WOol70003Ool7000[Ool7
0002Ool7000iOol70002Ool7000[Ool70003Ool7000XOol002Moo`L000=oo`L002]oo`L0009oo`L0
03Uoo`L0009oo`L002]oo`L000=oo`L002Qoo`00:7oo1@0017oo1`00;7oo1@000goo1`00>Goo1`00
0goo1@00;7oo1`0017oo1@00:Goo000YOol30006Ool5000^Ool30005Ool5000kOol50005Ool3000^
Ool50006Ool3000ZOol003=oo`<003Qoo`<003eoo`<003Qoo`<003Aoo`0077oo0`00BGoo0`00BGoo
0`00BGoo0`007Goo000KOol5000MOol3000BOol3000BOol50017Ool5000BOol3000BOol3000MOol5
000LOol001Yoo`L001]oo`D0011oo`D0011oo`L004Eoo`L0011oo`D0011oo`D001]oo`L001]oo`00
6Woo1`006Woo1`003Woo1`003goo1`00AGoo1`003goo1`003Woo1`006Woo1`006goo000JOol7000J
Ool7000<Ool9000?Ool70015Ool7000?Ool9000<Ool7000JOol7000KOol001]oo`D001]oo`L000]o
o`X0011oo`D004Moo`D0011oo`X000]oo`L001]oo`D001aoo`0077oo0`007Goo1@002goo300047oo
0`00BGoo0`0047oo30002goo1@007Goo0`007Goo000mOol3000<Ool<001_Ool<000<Ool3000nOol0
04aoo``006moo``004eoo`0057oo0`00=Woo2P00LGoo2P00=Woo0`005Goo000COol5000fOol30002
Ool3000TOol3000UOol3000TOol30002Ool3000fOol5000DOol0019oo`L0061oo`D002=oo`D0061o
o`L001=oo`004Woo1`00Ggoo1`008Goo1`00Ggoo1`004goo000BOol7001OOol7000QOol7001OOol7
000COol001=oo`D001Moo`<0041oo`<000=oo`L0025oo`L000=oo`<0041oo`<001Moo`D001Aoo`00
57oo0`005goo1@00?Woo1@000goo1@008goo1@000goo1@00?Woo1@005goo0`005Goo000]Ool7000>
Ool3000[Ool70003Ool3000AOol3000AOol30003Ool7000[Ool3000>Ool7000^Ool002eoo`L000eo
o`D002Yoo`L001Ioo`D001Ioo`L002Yoo`D000eoo`L002ioo`00;Goo1`0037oo1`00:Goo1`005Goo
1`005Goo1`00:Goo1`0037oo1`00;Woo000^Ool5000=Ool7000ZOol50003Ool3000@Ool7000@Ool3
0003Ool5000ZOol7000=Ool5000_Ool001Ioo`<001Ioo`<000ioo`L002]oo`<000=oo`D000moo`L0
00moo`D000=oo`<002]oo`L000ioo`<001Ioo`<001Moo`005Goo1@009goo1@00<Goo1`003goo1@00
3goo1`00<Goo1@009goo1@005Woo000DOol7000WOol3000bOol7000@Ool3000@Ool7000bOol3000W
Ool7000EOol001Aoo`L005aoo`L002=oo`L005aoo`L001Eoo`0057oo1`00GGoo1@003Goo0`001Goo
0`003Goo1@00GGoo1`005Goo000EOol6001NOol3000=Ool50003Ool5000=Ool3001NOol6000FOol0
01Eoo`L006aoo`L00003Ool0000000D006aoo`L001Ioo`005Goo1`00K7oo1`0000=oo`0000001@00
K7oo1`005Woo000EOol7000ROol3000@Ool3000dOol700000goo00000005000dOol3000@Ool3000R
Ool7000FOol001Ioo`D0029oo`D000ioo`D003Aoo`D000=oo`D003Aoo`D000ioo`D0029oo`D001Mo
o`005goo0`008Woo1`0037oo1`00=7oo0`001Goo0`00=7oo1`0037oo1`008Woo0`0067oo000lOol7
000<Ool7001cOol7000<Ool7000mOol003aoo`L000aoo`L007=oo`L000aoo`L003eoo`0077oo0`00
7Woo1@003Woo1@004goo0`00BGoo0`004goo1@003Woo1@007Woo0`007Goo000KOol5000NOol3000@
Ool3000COol50017Ool5000COol3000@Ool3000NOol5000LOol001Yoo`L001Ioo`<002aoo`L004Eo
o`L002aoo`<001Ioo`L001]oo`006Woo1`001goo0`002goo1@00:goo2000@goo2000:goo1@002goo
0`001goo1`006goo000JOol70006Ool50009Ool7000ZOol90011Ool9000ZOol70009Ool50006Ool7
000KOol001]oo`D000Ioo`L000Qoo`L002Yoo`T0045oo`T002Yoo`L000Qoo`L000Ioo`D001aoo`00
77oo0`001goo1`0027oo1`00:Goo2P00@Goo2P00:Goo1`0027oo1`001goo0`007Goo000VOol70009
Ool5000ZOol90013Ool9000ZOol50009Ool7000WOol002Moo`D000]oo`<002]oo`P004Eoo`P002]o
o`<000]oo`D002Qoo`00:7oo0`00>goo1@00BGoo1@00>goo0`00:Goo001WOol3001;Ool3001XOol0
0?moob5oo`00BWoo0`002Woo0`00Jgoo0`002Woo0`00Bgoo0019Ool50008Ool5000bOol5000bOol5
0008Ool5001:Ool004Qoo`L000Ioo`L0031oo`L0031oo`L000Ioo`L004Uoo`00B7oo1`001Woo1`00
;goo2@00;goo1`001Woo1`00BGoo0018Ool70006Ool7000_Ool9000_Ool70006Ool70019Ool0049o
o`<000Aoo`D000Qoo`D0031oo`T0031oo`D000Qoo`D000Aoo`<004=oo`00@Goo1@0017oo0`002Woo
0`00<Woo1`00<Woo0`002Woo0`0017oo1@00@Woo0010Ool70015Ool70015Ool70011Ool0041oo`L0
04Eoo`L004Eoo`L0045oo`00@7oo1`00AGoo1`00AGoo1`00@Goo000ZOol4000COol5000NOol3000@
Ool3000COol5000COol3000@Ool3000NOol5000COol4000[Ool002Uoo`H001=oo`<001ioo`D000io
o`D001=oo`<001=oo`D000ioo`D001ioo`<001=oo`H002Yoo`00:7oo2000<Woo1`0037oo1`009goo
1`0037oo1`00<Woo2000:Goo000XOol8000bOol7000<Ool7000WOol7000<Ool7000bOol8000YOol0
02Qoo`P0039oo`L000aoo`L002Moo`L000aoo`L0039oo`P002Uoo`00:Goo1P00=7oo1@003Woo1@00
:Goo1@003Woo1@00=7oo1P00:Woo000ZOol4000fOol3000@Ool3000[Ool3000@Ool3000fOol4000[
Ool00?moob5oo`00?7oo0`00XGoo0`00?Goo000kOol5000COol3001cOol3000COol5000lOol003Yo
o`L0015oo`D0075oo`D0015oo`L003]oo`00>Woo1`0047oo1`00;Woo0`003Goo0`00;Woo1`0047oo
1`00>goo000jOol7000@Ool7000@Ool3000JOol5000;Ool5000JOol3000@Ool7000@Ool7000kOol0
03]oo`D0015oo`L000moo`D001Qoo`L000Uoo`L001Qoo`D000moo`L0015oo`D003aoo`00?7oo0`00
4goo1@003goo1`005goo1`002Goo1`005goo1`003goo1@004goo0`00?Goo001COol3000@Ool7000G
Ool70009Ool7000GOol7000@Ool3001DOol006Ioo`L001Qoo`D000]oo`D001Qoo`L006Moo`00Igoo
1@006Woo0`003Goo0`006Woo1@00J7oo001XOol3000AOol3000QOol3000AOol3001YOol007]oo`D0
01moo`D007aoo`00NWoo1`007Goo1`00Ngoo000kOol3000XOol3000AOol7000MOol7000AOol3000X
Ool3000lOol003Yoo`D002Ioo`D0011oo`L001eoo`L0011oo`D002Ioo`D003]oo`00>Goo1`0097oo
1`0047oo1@007goo1@0047oo1`0097oo1`00>Woo000iOol7000TOol7000AOol3000QOol3000AOol7
000TOol7000jOol003Uoo`L002Aoo`L004Uoo`L002Aoo`L003Yoo`00>Woo1@009Woo1@00Bgoo1@00
9Woo1@00>goo000kOol3000XOol3000?Ool3000YOol3000?Ool3000XOol3000lOol0049oo`<0039o
o`D0019oo`<0019oo`D0039oo`<004=oo`00@Goo1@00<7oo1`0047oo1@0047oo1`00<7oo1@00@Woo
0010Ool7000_Ool7000?Ool7000?Ool7000_Ool70011Ool0041oo`T0019oo`<001Qoo`L000moo`L0
00moo`L001Qoo`<0019oo`T0045oo`00@7oo2P0047oo1@0067oo1@0047oo1`0047oo1@0067oo1@00
47oo2P00@Goo0011Ool:000>Ool7000HOol3000BOol5000BOol3000HOol7000>Ool:0012Ool0049o
o`T000ioo`L002ioo`<002ioo`L000ioo`T004=oo`00A7oo1`0017oo0`001goo1`00Ggoo1`001goo
0`0017oo1`00AGoo0015Ool50004Ool50007Ool5001QOol50007Ool50004Ool50016Ool004Ioo`<0
00Aoo`L000Moo`<006=oo`<000Moo`L000Aoo`<004Moo`00CGoo1`00Mgoo1`00CWoo001=Ool7001g
Ool7001>Ool004ioo`D007Uoo`D004moo`00Cgoo0`00:Goo0`008goo0`00:Goo0`00D7oo001jOol5
000QOol5001kOol007Uoo`L001moo`L007Yoo`00NGoo1`007goo1`00NWoo001XOol3000>Ool7000O
Ool7000>Ool3001YOol006Moo`D000ioo`D0025oo`D000ioo`D006Qoo`00IWoo1`003Woo0`008goo
0`003Woo1`00Igoo001VOol70015Ool7001WOol006Ioo`L004Eoo`L006Moo`00Igoo1@00Agoo1@00
J7oo001XOol30019Ool3001YOol0085oo`<001Moo`<0089oo`00P7oo1@005Goo1@00PGoo001oOol7
0006Ool3000017oo000000001Woo1`00P7oo001oOol70005Ool90005Ool70020Ool007moo`L000Ao
o`/000Aoo`L0081oo`00P7oo1@001Goo2`001Goo1@00PGoo0021Ool30006Ool;0006Ool30022Ool0
08]oo`T008aoo`00S7oo0`0000Aoo`00000008eoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-2.75003, -2.75003, 0.019164, \
0.019164}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\</usr/people/joseluis/Docs/Papers/Average/gl012.eps\>", %]\)], \
"Input"],

Cell[BoxData[
    \("/usr/people/joseluis/Docs/Papers/Average/gl012.eps"\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculating intensities", "Subsection",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["Formula (22). Acta Cryst.", "Text"],

Cell[BoxData[
    \(Ints[j_, k_, \ q_, \ g_]\  := \ 
      Abs[\((1\  + \ Exp[\(-\[ImaginaryI]\)\ q . \ e[j]]\  + \ Exp[\(-\
\[ImaginaryI]\)\ q . e[k]]\  + \ Exp[\(-\[ImaginaryI]\)\ q . \((e[j]\  + \ \
e[k])\)])\)\ /\ 4]\^2\ Product[
          If[\((l \[NotEqual] j)\) && \((l \[NotEqual] 
                  k)\), \(4\ Sin[q . e[l]\ /\ 2]\^2\)\/\((2\ \[Pi]\ \
g[\([l]\)]\  + \ q . e[l])\)\^2, 1], \ {l, 5}]\)], "Input",
  CellLabel->"In[72]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(In\ the\ case\ of\ the\ average\ lattice\ \((g\_l = 
          0)\)\ the\ indetermination\ Sin[0]\/0\ is\ replaced\ by\ 1\)], \
"DisplayFormula"],

Cell[BoxData[
    \(Ints[j_, k_, \ q_, \ g_]\  := \ 
      Abs[\((1\  + \ Exp[\(-\[ImaginaryI]\)\ q . \ e[j]]\  + \ Exp[\(-\
\[ImaginaryI]\)\ q . e[k]]\  + \ Exp[\(-\[ImaginaryI]\)\ q . \((e[j]\  + \ \
e[k])\)])\)\ /\ 4]\^2\ Product[
          If[\((l \[NotEqual] j)\) && \((l \[NotEqual] k)\), 
            If[q . e[l]\  < \ 0.0000001, 
              1\ , \(4\ Sin[q . e[l]\ /\ 2]\^2\)\/\((2\ \[Pi]\ g[\([l]\)]\  + \
\ q . e[l])\)\^2], 1], \ {l, 5}]\)], "Input",
  CellLabel->"In[330]:="]
}, Open  ]],

Cell["For the average lattice, g = (0,0,0,0):", "Text"],

Cell[BoxData[{
    \(\(g\  = \ {0, 0, 0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(gValues\  = \ {g1\  \[Rule] \ g[\([1]\)], \ 
          g2\  \[Rule] \ g[\([2]\)], \ g3\  \[Rule] \ g[\([3]\)], \ 
          g4\  \[Rule] \ g[\([4]\)], \ 
          g5\  \[Rule] \ g[\([5]\)]};\)\)}], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[{
    \(\(sRL21 = \ 
        SphericalCut[RL021\ \  /. \ gValues, 5];\)\), "\[IndentingNewLine]", 
    \(\(sRL31 = \ 
        SphericalCut[RL031\ \  /. \ gValues, 5];\)\), "\[IndentingNewLine]", 
    \(\(sRL32 = \ 
        SphericalCut[RL032\ \  /. \ gValues, 5];\)\), "\[IndentingNewLine]", 
    \(\(sRL41 = \ 
        SphericalCut[RL041\ \  /. \ gValues, 5];\)\), "\[IndentingNewLine]", 
    \(\(sRL42 = \ 
        SphericalCut[RL042\ \  /. \ gValues, 5];\)\), "\[IndentingNewLine]", 
    \(\(sRL43 = \ 
        SphericalCut[RL043\ \  /. \ gValues, 5];\)\), "\[IndentingNewLine]", 
    \(\(sRL51 = \ 
        SphericalCut[RL051\ \  /. \ gValues, 5];\)\), "\[IndentingNewLine]", 
    \(\(sRL52 = \ 
        SphericalCut[RL052\ \  /. \ gValues, 5];\)\), "\[IndentingNewLine]", 
    \(\(sRL53 = \ 
        SphericalCut[RL053\ \  /. \ gValues, 5];\)\), "\[IndentingNewLine]", 
    \(\(sRL54 = \ SphericalCut[RL054\ \  /. \ gValues, 5];\)\)}], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(\(sRL0\  = \ 
        Join[sRL21, sRL31, sRL32, sRL41, sRL42, sRL43, \ sRL51, \ sRL52, \ 
          sRL53, \ sRL54];\)\)], "Input",
  CellLabel->"In[343]:="],

Cell[BoxData[{
    \(\(I21\  = \ 
        Table[Ints[2, 1, \ sRL21[\([s]\)], \ g], \ {s, \ 
            Length[sRL21]}];\)\), "\[IndentingNewLine]", 
    \(\(I31\  = \ 
        Table[Ints[3, 1, \ sRL31[\([s]\)], \ g], \ {s, \ 
            Length[sRL31]}];\)\), "\[IndentingNewLine]", 
    \(\(I32\  = \ 
        Table[Ints[3, 2, \ sRL32[\([s]\)], \ g], \ {s, \ 
            Length[sRL32]}];\)\), "\[IndentingNewLine]", 
    \(\(I41\  = \ 
        Table[Ints[4, 1, \ sRL41[\([s]\)], \ g], \ {s, \ 
            Length[sRL41]}];\)\), "\[IndentingNewLine]", 
    \(\(I42\  = \ 
        Table[Ints[4, 2, \ sRL42[\([s]\)], \ g], \ {s, \ 
            Length[sRL42]}];\)\), "\[IndentingNewLine]", 
    \(\(I43\  = \ 
        Table[Ints[4, 3, \ sRL43[\([s]\)], \ g], \ {s, \ 
            Length[sRL43]}];\)\), "\[IndentingNewLine]", 
    \(\(I51\  = \ 
        Table[Ints[5, 1, \ sRL51[\([s]\)], \ g], \ {s, \ 
            Length[sRL51]}];\)\), "\[IndentingNewLine]", 
    \(\(I52\  = \ 
        Table[Ints[5, 2, \ sRL52[\([s]\)], \ g], \ {s, \ 
            Length[sRL52]}];\)\), "\[IndentingNewLine]", 
    \(\(I53\  = \ 
        Table[Ints[5, 3, \ sRL53[\([s]\)], \ g], \ {s, \ 
            Length[sRL53]}];\)\), "\[IndentingNewLine]", 
    \(\(I54\  = \ 
        Table[Ints[5, 4, \ sRL54[\([s]\)], \ g], \ {s, \ 
            Length[sRL54]}];\)\)}], "Input",
  CellLabel->"In[344]:="],

Cell[BoxData[
    \(\(Intensities\  = \ 
        Chop[Join[I21, \ I31, \ I32, \ I41, \ I42, \ I43, \ I51, \ I52, \ 
            I53, \ I54]];\)\)], "Input",
  CellLabel->"In[354]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dPatt\  = DrawPattern[sRL0, Intensities*0.1, \ 0.5]\)], "Input",
  CellLabel->"In[472]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.04293 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499981 0.106605 0.521466 0.106605 [
[ 0 0 0 0 ]
[ 1 1.04293 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.04293 L
0 1.04293 L
closepath
clip
newpath
.5 g
.95659 .68434 m
.95659 .68434 .0001 0 365.73 arc
F
.91395 .61114 m
.91395 .61114 .0004 0 365.73 arc
F
.87131 .53794 m
.87131 .53794 .00019 0 365.73 arc
F
.82867 .46474 m
.82867 .46474 1e-005 0 365.73 arc
F
.78603 .39154 m
.78603 .39154 .00038 0 365.73 arc
F
.74338 .31834 m
.74338 .31834 .00076 0 365.73 arc
F
.70074 .24514 m
.70074 .24514 .00055 0 365.73 arc
F
.91644 .73961 m
.91644 .73961 0 0 365.73 arc
F
.8738 .66641 m
.8738 .66641 5e-005 0 365.73 arc
F
.83116 .59321 m
.83116 .59321 0 0 365.73 arc
F
.78852 .52001 m
.78852 .52001 .00039 0 365.73 arc
F
.74587 .44681 m
.74587 .44681 .00149 0 365.73 arc
F
.70323 .37361 m
.70323 .37361 .00228 0 365.73 arc
F
.66059 .30041 m
.66059 .30041 .00179 0 365.73 arc
F
.61795 .22721 m
.61795 .22721 .00058 0 365.73 arc
F
.87629 .79487 m
.87629 .79487 1e-005 0 365.73 arc
F
.83365 .72167 m
.83365 .72167 0 0 365.73 arc
F
.79101 .64847 m
.79101 .64847 .00013 0 365.73 arc
F
.74836 .57527 m
.74836 .57527 .00113 0 365.73 arc
F
.70572 .50207 m
.70572 .50207 .00314 0 365.73 arc
F
.66308 .42887 m
.66308 .42887 .00466 0 365.73 arc
F
.62044 .35567 m
.62044 .35567 .00407 0 365.73 arc
F
.5778 .28247 m
.5778 .28247 .00183 0 365.73 arc
F
.53515 .20927 m
.53515 .20927 .00021 0 365.73 arc
F
.83614 .85013 m
.83614 .85013 0 0 365.73 arc
F
.7935 .77694 m
.7935 .77694 0 0 365.73 arc
F
.75085 .70374 m
.75085 .70374 .00023 0 365.73 arc
F
.70821 .63054 m
.70821 .63054 .00166 0 365.73 arc
F
.66557 .55734 m
.66557 .55734 .00459 0 365.73 arc
F
.62293 .48414 m
.62293 .48414 .0072 0 365.73 arc
F
.58029 .41094 m
.58029 .41094 .00703 0 365.73 arc
F
.53764 .33774 m
.53764 .33774 .00396 0 365.73 arc
F
.495 .26454 m
.495 .26454 .00093 0 365.73 arc
F
.45236 .19134 m
.45236 .19134 0 0 365.73 arc
F
.79599 .9054 m
.79599 .9054 .0001 0 365.73 arc
F
.75334 .8322 m
.75334 .8322 5e-005 0 365.73 arc
F
.7107 .759 m
.7107 .759 .00013 0 365.73 arc
F
.66806 .6858 m
.66806 .6858 .00166 0 365.73 arc
F
.62542 .6126 m
.62542 .6126 .00511 0 365.73 arc
F
.58278 .5394 m
.58278 .5394 .00877 0 365.73 arc
F
.54013 .4662 m
.54013 .4662 .00962 0 365.73 arc
F
.49749 .393 m
.49749 .393 .00642 0 365.73 arc
F
.45485 .3198 m
.45485 .3198 .00218 0 365.73 arc
F
.41221 .2466 m
.41221 .2466 .00018 0 365.73 arc
F
.36956 .1734 m
.36956 .1734 5e-005 0 365.73 arc
F
.71319 .88746 m
.71319 .88746 .0004 0 365.73 arc
F
.67055 .81426 m
.67055 .81426 0 0 365.73 arc
F
.62791 .74107 m
.62791 .74107 .00113 0 365.73 arc
F
.58527 .66787 m
.58527 .66787 .00459 0 365.73 arc
F
.54262 .59467 m
.54262 .59467 .00877 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.45734 .44827 m
.45734 .44827 .0082 0 365.73 arc
F
.4147 .37507 m
.4147 .37507 .0035 0 365.73 arc
F
.37205 .30187 m
.37205 .30187 .0006 0 365.73 arc
F
.32941 .22867 m
.32941 .22867 0 0 365.73 arc
F
.28677 .15547 m
.28677 .15547 6e-005 0 365.73 arc
F
.6304 .86953 m
.6304 .86953 .00019 0 365.73 arc
F
.58775 .79633 m
.58775 .79633 .00039 0 365.73 arc
F
.54511 .72313 m
.54511 .72313 .00314 0 365.73 arc
F
.50247 .64993 m
.50247 .64993 .0072 0 365.73 arc
F
.45983 .57673 m
.45983 .57673 .00962 0 365.73 arc
F
.41719 .50353 m
.41719 .50353 .0082 0 365.73 arc
F
.37454 .43033 m
.37454 .43033 .00412 0 365.73 arc
F
.3319 .35713 m
.3319 .35713 .001 0 365.73 arc
F
.28926 .28393 m
.28926 .28393 5e-005 0 365.73 arc
F
.24662 .21073 m
.24662 .21073 1e-005 0 365.73 arc
F
.20398 .13753 m
.20398 .13753 1e-005 0 365.73 arc
F
.5476 .85159 m
.5476 .85159 1e-005 0 365.73 arc
F
.50496 .77839 m
.50496 .77839 .00149 0 365.73 arc
F
.46232 .7052 m
.46232 .7052 .00466 0 365.73 arc
F
.41968 .632 m
.41968 .632 .00703 0 365.73 arc
F
.37703 .5588 m
.37703 .5588 .00642 0 365.73 arc
F
.33439 .4856 m
.33439 .4856 .0035 0 365.73 arc
F
.29175 .4124 m
.29175 .4124 .001 0 365.73 arc
F
.24911 .3392 m
.24911 .3392 9e-005 0 365.73 arc
F
.20647 .266 m
.20647 .266 0 0 365.73 arc
F
.16382 .1928 m
.16382 .1928 0 0 365.73 arc
F
.46481 .83366 m
.46481 .83366 .00038 0 365.73 arc
F
.42217 .76046 m
.42217 .76046 .00228 0 365.73 arc
F
.37952 .68726 m
.37952 .68726 .00407 0 365.73 arc
F
.33688 .61406 m
.33688 .61406 .00396 0 365.73 arc
F
.29424 .54086 m
.29424 .54086 .00218 0 365.73 arc
F
.2516 .46766 m
.2516 .46766 .0006 0 365.73 arc
F
.20896 .39446 m
.20896 .39446 5e-005 0 365.73 arc
F
.16631 .32126 m
.16631 .32126 0 0 365.73 arc
F
.12367 .24806 m
.12367 .24806 0 0 365.73 arc
F
.38201 .81572 m
.38201 .81572 .00076 0 365.73 arc
F
.33937 .74252 m
.33937 .74252 .00179 0 365.73 arc
F
.29673 .66933 m
.29673 .66933 .00183 0 365.73 arc
F
.25409 .59613 m
.25409 .59613 .00093 0 365.73 arc
F
.21145 .52293 m
.21145 .52293 .00018 0 365.73 arc
F
.1688 .44973 m
.1688 .44973 0 0 365.73 arc
F
.12616 .37653 m
.12616 .37653 1e-005 0 365.73 arc
F
.08352 .30333 m
.08352 .30333 0 0 365.73 arc
F
.29922 .79779 m
.29922 .79779 .00055 0 365.73 arc
F
.25658 .72459 m
.25658 .72459 .00058 0 365.73 arc
F
.21394 .65139 m
.21394 .65139 .00021 0 365.73 arc
F
.17129 .57819 m
.17129 .57819 0 0 365.73 arc
F
.12865 .50499 m
.12865 .50499 5e-005 0 365.73 arc
F
.08601 .43179 m
.08601 .43179 6e-005 0 365.73 arc
F
.04337 .35859 m
.04337 .35859 1e-005 0 365.73 arc
F
.02382 .37995 m
.02382 .37995 1e-005 0 365.73 arc
F
.28322 .29567 m
.28322 .29567 .00114 0 365.73 arc
F
.24058 .60575 m
.24058 .60575 .00013 0 365.73 arc
F
.19794 .91583 m
.19794 .91583 5e-005 0 365.73 arc
F
.54262 .21139 m
.54262 .21139 .00114 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.45734 .83154 m
.45734 .83154 .00153 0 365.73 arc
F
.80202 .1271 m
.80202 .1271 1e-005 0 365.73 arc
F
.75938 .43718 m
.75938 .43718 .00013 0 365.73 arc
F
.71674 .74726 m
.71674 .74726 .00153 0 365.73 arc
F
.97614 .66298 m
.97614 .66298 5e-005 0 365.73 arc
F
.48618 1.00606 m
.48618 1.00606 .0001 0 365.73 arc
F
.54262 .94289 m
.54262 .94289 .0004 0 365.73 arc
F
.59906 .87971 m
.59906 .87971 .00019 0 365.73 arc
F
.6555 .81654 m
.6555 .81654 1e-005 0 365.73 arc
F
.71194 .75336 m
.71194 .75336 .00038 0 365.73 arc
F
.76838 .69019 m
.76838 .69019 .00076 0 365.73 arc
F
.82482 .62701 m
.82482 .62701 .00055 0 365.73 arc
F
.42121 .98495 m
.42121 .98495 0 0 365.73 arc
F
.47765 .92178 m
.47765 .92178 5e-005 0 365.73 arc
F
.53409 .8586 m
.53409 .8586 0 0 365.73 arc
F
.59053 .79543 m
.59053 .79543 .00039 0 365.73 arc
F
.64697 .73225 m
.64697 .73225 .00149 0 365.73 arc
F
.70341 .66908 m
.70341 .66908 .00228 0 365.73 arc
F
.75985 .6059 m
.75985 .6059 .00179 0 365.73 arc
F
.81629 .54273 m
.81629 .54273 .00058 0 365.73 arc
F
.35624 .96384 m
.35624 .96384 1e-005 0 365.73 arc
F
.41268 .90067 m
.41268 .90067 0 0 365.73 arc
F
.46912 .83749 m
.46912 .83749 .00013 0 365.73 arc
F
.52556 .77432 m
.52556 .77432 .00113 0 365.73 arc
F
.582 .71114 m
.582 .71114 .00314 0 365.73 arc
F
.63844 .64797 m
.63844 .64797 .00466 0 365.73 arc
F
.69488 .58479 m
.69488 .58479 .00407 0 365.73 arc
F
.75132 .52162 m
.75132 .52162 .00183 0 365.73 arc
F
.80776 .45844 m
.80776 .45844 .00021 0 365.73 arc
F
.29128 .94273 m
.29128 .94273 0 0 365.73 arc
F
.34772 .87956 m
.34772 .87956 0 0 365.73 arc
F
.40416 .81638 m
.40416 .81638 .00023 0 365.73 arc
F
.4606 .75321 m
.4606 .75321 .00166 0 365.73 arc
F
.51704 .69003 m
.51704 .69003 .00459 0 365.73 arc
F
.57348 .62686 m
.57348 .62686 .0072 0 365.73 arc
F
.62992 .56368 m
.62992 .56368 .00703 0 365.73 arc
F
.68636 .50051 m
.68636 .50051 .00396 0 365.73 arc
F
.7428 .43733 m
.7428 .43733 .00093 0 365.73 arc
F
.79924 .37416 m
.79924 .37416 0 0 365.73 arc
F
.22631 .92162 m
.22631 .92162 .0001 0 365.73 arc
F
.28275 .85845 m
.28275 .85845 5e-005 0 365.73 arc
F
.33919 .79527 m
.33919 .79527 .00013 0 365.73 arc
F
.39563 .7321 m
.39563 .7321 .00166 0 365.73 arc
F
.45207 .66892 m
.45207 .66892 .00511 0 365.73 arc
F
.50851 .60575 m
.50851 .60575 .00877 0 365.73 arc
F
.56495 .54257 m
.56495 .54257 .00962 0 365.73 arc
F
.62139 .4794 m
.62139 .4794 .00642 0 365.73 arc
F
.67783 .41622 m
.67783 .41622 .00218 0 365.73 arc
F
.73427 .35305 m
.73427 .35305 .00018 0 365.73 arc
F
.79071 .28987 m
.79071 .28987 5e-005 0 365.73 arc
F
.21778 .83734 m
.21778 .83734 .0004 0 365.73 arc
F
.27422 .77417 m
.27422 .77417 0 0 365.73 arc
F
.33066 .71099 m
.33066 .71099 .00113 0 365.73 arc
F
.3871 .64782 m
.3871 .64782 .00459 0 365.73 arc
F
.44354 .58464 m
.44354 .58464 .00877 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.55642 .45829 m
.55642 .45829 .0082 0 365.73 arc
F
.61286 .39512 m
.61286 .39512 .0035 0 365.73 arc
F
.6693 .33194 m
.6693 .33194 .0006 0 365.73 arc
F
.72574 .26877 m
.72574 .26877 0 0 365.73 arc
F
.78218 .20559 m
.78218 .20559 6e-005 0 365.73 arc
F
.20925 .75306 m
.20925 .75306 .00019 0 365.73 arc
F
.26569 .68988 m
.26569 .68988 .00039 0 365.73 arc
F
.32213 .62671 m
.32213 .62671 .00314 0 365.73 arc
F
.37857 .56353 m
.37857 .56353 .0072 0 365.73 arc
F
.43501 .50036 m
.43501 .50036 .00962 0 365.73 arc
F
.49145 .43718 m
.49145 .43718 .0082 0 365.73 arc
F
.54789 .37401 m
.54789 .37401 .00412 0 365.73 arc
F
.60433 .31083 m
.60433 .31083 .001 0 365.73 arc
F
.66077 .24766 m
.66077 .24766 5e-005 0 365.73 arc
F
.71721 .18448 m
.71721 .18448 1e-005 0 365.73 arc
F
.77365 .12131 m
.77365 .12131 1e-005 0 365.73 arc
F
.20073 .66877 m
.20073 .66877 1e-005 0 365.73 arc
F
.25717 .6056 m
.25717 .6056 .00149 0 365.73 arc
F
.31361 .54242 m
.31361 .54242 .00466 0 365.73 arc
F
.37005 .47925 m
.37005 .47925 .00703 0 365.73 arc
F
.42649 .41607 m
.42649 .41607 .00642 0 365.73 arc
F
.48293 .3529 m
.48293 .3529 .0035 0 365.73 arc
F
.53937 .28972 m
.53937 .28972 .001 0 365.73 arc
F
.59581 .22655 m
.59581 .22655 9e-005 0 365.73 arc
F
.65225 .16337 m
.65225 .16337 0 0 365.73 arc
F
.70869 .1002 m
.70869 .1002 0 0 365.73 arc
F
.1922 .58449 m
.1922 .58449 .00038 0 365.73 arc
F
.24864 .52131 m
.24864 .52131 .00228 0 365.73 arc
F
.30508 .45814 m
.30508 .45814 .00407 0 365.73 arc
F
.36152 .39496 m
.36152 .39496 .00396 0 365.73 arc
F
.41796 .33179 m
.41796 .33179 .00218 0 365.73 arc
F
.4744 .26861 m
.4744 .26861 .0006 0 365.73 arc
F
.53084 .20544 m
.53084 .20544 5e-005 0 365.73 arc
F
.58728 .14226 m
.58728 .14226 0 0 365.73 arc
F
.64372 .07909 m
.64372 .07909 0 0 365.73 arc
F
.18367 .5002 m
.18367 .5002 .00076 0 365.73 arc
F
.24011 .43703 m
.24011 .43703 .00179 0 365.73 arc
F
.29655 .37385 m
.29655 .37385 .00183 0 365.73 arc
F
.35299 .31068 m
.35299 .31068 .00093 0 365.73 arc
F
.40943 .2475 m
.40943 .2475 .00018 0 365.73 arc
F
.46587 .18433 m
.46587 .18433 0 0 365.73 arc
F
.52231 .12115 m
.52231 .12115 1e-005 0 365.73 arc
F
.57875 .05798 m
.57875 .05798 0 0 365.73 arc
F
.17514 .41592 m
.17514 .41592 .00055 0 365.73 arc
F
.23158 .35274 m
.23158 .35274 .00058 0 365.73 arc
F
.28802 .28957 m
.28802 .28957 .00021 0 365.73 arc
F
.34446 .22639 m
.34446 .22639 0 0 365.73 arc
F
.4009 .16322 m
.4009 .16322 5e-005 0 365.73 arc
F
.45734 .10004 m
.45734 .10004 6e-005 0 365.73 arc
F
.51378 .03687 m
.51378 .03687 1e-005 0 365.73 arc
F
.02382 .66298 m
.02382 .66298 1e-005 0 365.73 arc
F
.28322 .74726 m
.28322 .74726 .00114 0 365.73 arc
F
.24058 .43718 m
.24058 .43718 .00013 0 365.73 arc
F
.19794 .1271 m
.19794 .1271 5e-005 0 365.73 arc
F
.54262 .83154 m
.54262 .83154 .00114 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.45734 .21139 m
.45734 .21139 .00153 0 365.73 arc
F
.80202 .91583 m
.80202 .91583 1e-005 0 365.73 arc
F
.75938 .60575 m
.75938 .60575 .00013 0 365.73 arc
F
.71674 .29567 m
.71674 .29567 .00153 0 365.73 arc
F
.97614 .37995 m
.97614 .37995 5e-005 0 365.73 arc
F
.48742 .02488 m
.48742 .02488 1e-005 0 365.73 arc
F
.64774 .24554 m
.64774 .24554 .00114 0 365.73 arc
F
.33966 .30081 m
.33966 .30081 .00013 0 365.73 arc
F
.03158 .35607 m
.03158 .35607 5e-005 0 365.73 arc
F
.80806 .4662 m
.80806 .4662 .00114 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.1919 .57673 m
.1919 .57673 .00153 0 365.73 arc
F
.96838 .68686 m
.96838 .68686 1e-005 0 365.73 arc
F
.6603 .74212 m
.6603 .74212 .00013 0 365.73 arc
F
.35222 .79739 m
.35222 .79739 .00153 0 365.73 arc
F
.51254 1.01805 m
.51254 1.01805 5e-005 0 365.73 arc
F
.03484 .65809 m
.03484 .65809 .0001 0 365.73 arc
F
.11236 .69224 m
.11236 .69224 .0004 0 365.73 arc
F
.18989 .7264 m
.18989 .7264 .00019 0 365.73 arc
F
.26741 .76055 m
.26741 .76055 1e-005 0 365.73 arc
F
.34493 .79471 m
.34493 .79471 .00038 0 365.73 arc
F
.42246 .82887 m
.42246 .82887 .00076 0 365.73 arc
F
.49998 .86302 m
.49998 .86302 .00055 0 365.73 arc
F
.03484 .58978 m
.03484 .58978 0 0 365.73 arc
F
.11236 .62393 m
.11236 .62393 5e-005 0 365.73 arc
F
.18989 .65809 m
.18989 .65809 0 0 365.73 arc
F
.26741 .69224 m
.26741 .69224 .00039 0 365.73 arc
F
.34493 .7264 m
.34493 .7264 .00149 0 365.73 arc
F
.42246 .76055 m
.42246 .76055 .00228 0 365.73 arc
F
.49998 .79471 m
.49998 .79471 .00179 0 365.73 arc
F
.5775 .82887 m
.5775 .82887 .00058 0 365.73 arc
F
.03484 .52147 m
.03484 .52147 1e-005 0 365.73 arc
F
.11236 .55562 m
.11236 .55562 0 0 365.73 arc
F
.18989 .58978 m
.18989 .58978 .00013 0 365.73 arc
F
.26741 .62393 m
.26741 .62393 .00113 0 365.73 arc
F
.34493 .65809 m
.34493 .65809 .00314 0 365.73 arc
F
.42246 .69224 m
.42246 .69224 .00466 0 365.73 arc
F
.49998 .7264 m
.49998 .7264 .00407 0 365.73 arc
F
.5775 .76055 m
.5775 .76055 .00183 0 365.73 arc
F
.65503 .79471 m
.65503 .79471 .00021 0 365.73 arc
F
.03484 .45315 m
.03484 .45315 0 0 365.73 arc
F
.11236 .48731 m
.11236 .48731 0 0 365.73 arc
F
.18989 .52147 m
.18989 .52147 .00023 0 365.73 arc
F
.26741 .55562 m
.26741 .55562 .00166 0 365.73 arc
F
.34493 .58978 m
.34493 .58978 .00459 0 365.73 arc
F
.42246 .62393 m
.42246 .62393 .0072 0 365.73 arc
F
.49998 .65809 m
.49998 .65809 .00703 0 365.73 arc
F
.5775 .69224 m
.5775 .69224 .00396 0 365.73 arc
F
.65503 .7264 m
.65503 .7264 .00093 0 365.73 arc
F
.73255 .76055 m
.73255 .76055 0 0 365.73 arc
F
.03484 .38484 m
.03484 .38484 .0001 0 365.73 arc
F
.11236 .419 m
.11236 .419 5e-005 0 365.73 arc
F
.18989 .45315 m
.18989 .45315 .00013 0 365.73 arc
F
.26741 .48731 m
.26741 .48731 .00166 0 365.73 arc
F
.34493 .52147 m
.34493 .52147 .00511 0 365.73 arc
F
.42246 .55562 m
.42246 .55562 .00877 0 365.73 arc
F
.49998 .58978 m
.49998 .58978 .00962 0 365.73 arc
F
.5775 .62393 m
.5775 .62393 .00642 0 365.73 arc
F
.65503 .65809 m
.65503 .65809 .00218 0 365.73 arc
F
.73255 .69224 m
.73255 .69224 .00018 0 365.73 arc
F
.81008 .7264 m
.81008 .7264 5e-005 0 365.73 arc
F
.11236 .35069 m
.11236 .35069 .0004 0 365.73 arc
F
.18989 .38484 m
.18989 .38484 0 0 365.73 arc
F
.26741 .419 m
.26741 .419 .00113 0 365.73 arc
F
.34493 .45315 m
.34493 .45315 .00459 0 365.73 arc
F
.42246 .48731 m
.42246 .48731 .00877 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.5775 .55562 m
.5775 .55562 .0082 0 365.73 arc
F
.65503 .58978 m
.65503 .58978 .0035 0 365.73 arc
F
.73255 .62393 m
.73255 .62393 .0006 0 365.73 arc
F
.81008 .65809 m
.81008 .65809 0 0 365.73 arc
F
.8876 .69224 m
.8876 .69224 6e-005 0 365.73 arc
F
.18989 .31653 m
.18989 .31653 .00019 0 365.73 arc
F
.26741 .35069 m
.26741 .35069 .00039 0 365.73 arc
F
.34493 .38484 m
.34493 .38484 .00314 0 365.73 arc
F
.42246 .419 m
.42246 .419 .0072 0 365.73 arc
F
.49998 .45315 m
.49998 .45315 .00962 0 365.73 arc
F
.5775 .48731 m
.5775 .48731 .0082 0 365.73 arc
F
.65503 .52147 m
.65503 .52147 .00412 0 365.73 arc
F
.73255 .55562 m
.73255 .55562 .001 0 365.73 arc
F
.81008 .58978 m
.81008 .58978 5e-005 0 365.73 arc
F
.8876 .62393 m
.8876 .62393 1e-005 0 365.73 arc
F
.96512 .65809 m
.96512 .65809 1e-005 0 365.73 arc
F
.26741 .28238 m
.26741 .28238 1e-005 0 365.73 arc
F
.34493 .31653 m
.34493 .31653 .00149 0 365.73 arc
F
.42246 .35069 m
.42246 .35069 .00466 0 365.73 arc
F
.49998 .38484 m
.49998 .38484 .00703 0 365.73 arc
F
.5775 .419 m
.5775 .419 .00642 0 365.73 arc
F
.65503 .45315 m
.65503 .45315 .0035 0 365.73 arc
F
.73255 .48731 m
.73255 .48731 .001 0 365.73 arc
F
.81008 .52147 m
.81008 .52147 9e-005 0 365.73 arc
F
.8876 .55562 m
.8876 .55562 0 0 365.73 arc
F
.96512 .58978 m
.96512 .58978 0 0 365.73 arc
F
.34493 .24822 m
.34493 .24822 .00038 0 365.73 arc
F
.42246 .28238 m
.42246 .28238 .00228 0 365.73 arc
F
.49998 .31653 m
.49998 .31653 .00407 0 365.73 arc
F
.5775 .35069 m
.5775 .35069 .00396 0 365.73 arc
F
.65503 .38484 m
.65503 .38484 .00218 0 365.73 arc
F
.73255 .419 m
.73255 .419 .0006 0 365.73 arc
F
.81008 .45315 m
.81008 .45315 5e-005 0 365.73 arc
F
.8876 .48731 m
.8876 .48731 0 0 365.73 arc
F
.96512 .52147 m
.96512 .52147 0 0 365.73 arc
F
.42246 .21407 m
.42246 .21407 .00076 0 365.73 arc
F
.49998 .24822 m
.49998 .24822 .00179 0 365.73 arc
F
.5775 .28238 m
.5775 .28238 .00183 0 365.73 arc
F
.65503 .31653 m
.65503 .31653 .00093 0 365.73 arc
F
.73255 .35069 m
.73255 .35069 .00018 0 365.73 arc
F
.81008 .38484 m
.81008 .38484 0 0 365.73 arc
F
.8876 .419 m
.8876 .419 1e-005 0 365.73 arc
F
.96512 .45315 m
.96512 .45315 0 0 365.73 arc
F
.49998 .17991 m
.49998 .17991 .00055 0 365.73 arc
F
.5775 .21407 m
.5775 .21407 .00058 0 365.73 arc
F
.65503 .24822 m
.65503 .24822 .00021 0 365.73 arc
F
.73255 .28238 m
.73255 .28238 0 0 365.73 arc
F
.81008 .31653 m
.81008 .31653 5e-005 0 365.73 arc
F
.8876 .35069 m
.8876 .35069 6e-005 0 365.73 arc
F
.96512 .38484 m
.96512 .38484 1e-005 0 365.73 arc
F
.95659 .35859 m
.95659 .35859 .0001 0 365.73 arc
F
.91395 .43179 m
.91395 .43179 .0004 0 365.73 arc
F
.87131 .50499 m
.87131 .50499 .00019 0 365.73 arc
F
.82867 .57819 m
.82867 .57819 1e-005 0 365.73 arc
F
.78603 .65139 m
.78603 .65139 .00038 0 365.73 arc
F
.74338 .72459 m
.74338 .72459 .00076 0 365.73 arc
F
.70074 .79779 m
.70074 .79779 .00055 0 365.73 arc
F
.91644 .30333 m
.91644 .30333 0 0 365.73 arc
F
.8738 .37653 m
.8738 .37653 5e-005 0 365.73 arc
F
.83116 .44973 m
.83116 .44973 0 0 365.73 arc
F
.78852 .52293 m
.78852 .52293 .00039 0 365.73 arc
F
.74587 .59613 m
.74587 .59613 .00149 0 365.73 arc
F
.70323 .66933 m
.70323 .66933 .00228 0 365.73 arc
F
.66059 .74252 m
.66059 .74252 .00179 0 365.73 arc
F
.61795 .81572 m
.61795 .81572 .00058 0 365.73 arc
F
.87629 .24806 m
.87629 .24806 1e-005 0 365.73 arc
F
.83365 .32126 m
.83365 .32126 0 0 365.73 arc
F
.79101 .39446 m
.79101 .39446 .00013 0 365.73 arc
F
.74836 .46766 m
.74836 .46766 .00113 0 365.73 arc
F
.70572 .54086 m
.70572 .54086 .00314 0 365.73 arc
F
.66308 .61406 m
.66308 .61406 .00466 0 365.73 arc
F
.62044 .68726 m
.62044 .68726 .00407 0 365.73 arc
F
.5778 .76046 m
.5778 .76046 .00183 0 365.73 arc
F
.53515 .83366 m
.53515 .83366 .00021 0 365.73 arc
F
.83614 .1928 m
.83614 .1928 0 0 365.73 arc
F
.7935 .266 m
.7935 .266 0 0 365.73 arc
F
.75085 .3392 m
.75085 .3392 .00023 0 365.73 arc
F
.70821 .4124 m
.70821 .4124 .00166 0 365.73 arc
F
.66557 .4856 m
.66557 .4856 .00459 0 365.73 arc
F
.62293 .5588 m
.62293 .5588 .0072 0 365.73 arc
F
.58029 .632 m
.58029 .632 .00703 0 365.73 arc
F
.53764 .7052 m
.53764 .7052 .00396 0 365.73 arc
F
.495 .77839 m
.495 .77839 .00093 0 365.73 arc
F
.45236 .85159 m
.45236 .85159 0 0 365.73 arc
F
.79599 .13753 m
.79599 .13753 .0001 0 365.73 arc
F
.75334 .21073 m
.75334 .21073 5e-005 0 365.73 arc
F
.7107 .28393 m
.7107 .28393 .00013 0 365.73 arc
F
.66806 .35713 m
.66806 .35713 .00166 0 365.73 arc
F
.62542 .43033 m
.62542 .43033 .00511 0 365.73 arc
F
.58278 .50353 m
.58278 .50353 .00877 0 365.73 arc
F
.54013 .57673 m
.54013 .57673 .00962 0 365.73 arc
F
.49749 .64993 m
.49749 .64993 .00642 0 365.73 arc
F
.45485 .72313 m
.45485 .72313 .00218 0 365.73 arc
F
.41221 .79633 m
.41221 .79633 .00018 0 365.73 arc
F
.36956 .86953 m
.36956 .86953 5e-005 0 365.73 arc
F
.71319 .15547 m
.71319 .15547 .0004 0 365.73 arc
F
.67055 .22867 m
.67055 .22867 0 0 365.73 arc
F
.62791 .30187 m
.62791 .30187 .00113 0 365.73 arc
F
.58527 .37507 m
.58527 .37507 .00459 0 365.73 arc
F
.54262 .44827 m
.54262 .44827 .00877 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.45734 .59467 m
.45734 .59467 .0082 0 365.73 arc
F
.4147 .66787 m
.4147 .66787 .0035 0 365.73 arc
F
.37205 .74107 m
.37205 .74107 .0006 0 365.73 arc
F
.32941 .81426 m
.32941 .81426 0 0 365.73 arc
F
.28677 .88746 m
.28677 .88746 6e-005 0 365.73 arc
F
.6304 .1734 m
.6304 .1734 .00019 0 365.73 arc
F
.58775 .2466 m
.58775 .2466 .00039 0 365.73 arc
F
.54511 .3198 m
.54511 .3198 .00314 0 365.73 arc
F
.50247 .393 m
.50247 .393 .0072 0 365.73 arc
F
.45983 .4662 m
.45983 .4662 .00962 0 365.73 arc
F
.41719 .5394 m
.41719 .5394 .0082 0 365.73 arc
F
.37454 .6126 m
.37454 .6126 .00412 0 365.73 arc
F
.3319 .6858 m
.3319 .6858 .001 0 365.73 arc
F
.28926 .759 m
.28926 .759 5e-005 0 365.73 arc
F
.24662 .8322 m
.24662 .8322 1e-005 0 365.73 arc
F
.20398 .9054 m
.20398 .9054 1e-005 0 365.73 arc
F
.5476 .19134 m
.5476 .19134 1e-005 0 365.73 arc
F
.50496 .26454 m
.50496 .26454 .00149 0 365.73 arc
F
.46232 .33774 m
.46232 .33774 .00466 0 365.73 arc
F
.41968 .41094 m
.41968 .41094 .00703 0 365.73 arc
F
.37703 .48414 m
.37703 .48414 .00642 0 365.73 arc
F
.33439 .55734 m
.33439 .55734 .0035 0 365.73 arc
F
.29175 .63054 m
.29175 .63054 .001 0 365.73 arc
F
.24911 .70374 m
.24911 .70374 9e-005 0 365.73 arc
F
.20647 .77694 m
.20647 .77694 0 0 365.73 arc
F
.16382 .85013 m
.16382 .85013 0 0 365.73 arc
F
.46481 .20927 m
.46481 .20927 .00038 0 365.73 arc
F
.42217 .28247 m
.42217 .28247 .00228 0 365.73 arc
F
.37952 .35567 m
.37952 .35567 .00407 0 365.73 arc
F
.33688 .42887 m
.33688 .42887 .00396 0 365.73 arc
F
.29424 .50207 m
.29424 .50207 .00218 0 365.73 arc
F
.2516 .57527 m
.2516 .57527 .0006 0 365.73 arc
F
.20896 .64847 m
.20896 .64847 5e-005 0 365.73 arc
F
.16631 .72167 m
.16631 .72167 0 0 365.73 arc
F
.12367 .79487 m
.12367 .79487 0 0 365.73 arc
F
.38201 .22721 m
.38201 .22721 .00076 0 365.73 arc
F
.33937 .30041 m
.33937 .30041 .00179 0 365.73 arc
F
.29673 .37361 m
.29673 .37361 .00183 0 365.73 arc
F
.25409 .44681 m
.25409 .44681 .00093 0 365.73 arc
F
.21145 .52001 m
.21145 .52001 .00018 0 365.73 arc
F
.1688 .59321 m
.1688 .59321 0 0 365.73 arc
F
.12616 .66641 m
.12616 .66641 1e-005 0 365.73 arc
F
.08352 .73961 m
.08352 .73961 0 0 365.73 arc
F
.29922 .24514 m
.29922 .24514 .00055 0 365.73 arc
F
.25658 .31834 m
.25658 .31834 .00058 0 365.73 arc
F
.21394 .39154 m
.21394 .39154 .00021 0 365.73 arc
F
.17129 .46474 m
.17129 .46474 0 0 365.73 arc
F
.12865 .53794 m
.12865 .53794 5e-005 0 365.73 arc
F
.08601 .61114 m
.08601 .61114 6e-005 0 365.73 arc
F
.04337 .68434 m
.04337 .68434 1e-005 0 365.73 arc
F
.21826 .11234 m
.21826 .11234 1e-005 0 365.73 arc
F
.21826 .38509 m
.21826 .38509 .00114 0 365.73 arc
F
.49998 .24872 m
.49998 .24872 .00013 0 365.73 arc
F
.78171 .11234 m
.78171 .11234 5e-005 0 365.73 arc
F
.21826 .65784 m
.21826 .65784 .00114 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.78171 .38509 m
.78171 .38509 .00153 0 365.73 arc
F
.21826 .93059 m
.21826 .93059 1e-005 0 365.73 arc
F
.49998 .79422 m
.49998 .79422 .00013 0 365.73 arc
F
.78171 .65784 m
.78171 .65784 .00153 0 365.73 arc
F
.78171 .93059 m
.78171 .93059 5e-005 0 365.73 arc
F
.96838 .35607 m
.96838 .35607 1e-005 0 365.73 arc
F
.80806 .57673 m
.80806 .57673 .00114 0 365.73 arc
F
.6603 .30081 m
.6603 .30081 .00013 0 365.73 arc
F
.51254 .02488 m
.51254 .02488 5e-005 0 365.73 arc
F
.64774 .79739 m
.64774 .79739 .00114 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.35222 .24554 m
.35222 .24554 .00153 0 365.73 arc
F
.48742 1.01805 m
.48742 1.01805 1e-005 0 365.73 arc
F
.33966 .74212 m
.33966 .74212 .00013 0 365.73 arc
F
.1919 .4662 m
.1919 .4662 .00153 0 365.73 arc
F
.03158 .68686 m
.03158 .68686 5e-005 0 365.73 arc
F
.22631 .12131 m
.22631 .12131 .0001 0 365.73 arc
F
.21778 .20559 m
.21778 .20559 .0004 0 365.73 arc
F
.20925 .28987 m
.20925 .28987 .00019 0 365.73 arc
F
.20073 .37416 m
.20073 .37416 1e-005 0 365.73 arc
F
.1922 .45844 m
.1922 .45844 .00038 0 365.73 arc
F
.18367 .54273 m
.18367 .54273 .00076 0 365.73 arc
F
.17514 .62701 m
.17514 .62701 .00055 0 365.73 arc
F
.29128 .1002 m
.29128 .1002 0 0 365.73 arc
F
.28275 .18448 m
.28275 .18448 5e-005 0 365.73 arc
F
.27422 .26877 m
.27422 .26877 0 0 365.73 arc
F
.26569 .35305 m
.26569 .35305 .00039 0 365.73 arc
F
.25717 .43733 m
.25717 .43733 .00149 0 365.73 arc
F
.24864 .52162 m
.24864 .52162 .00228 0 365.73 arc
F
.24011 .6059 m
.24011 .6059 .00179 0 365.73 arc
F
.23158 .69019 m
.23158 .69019 .00058 0 365.73 arc
F
.35624 .07909 m
.35624 .07909 1e-005 0 365.73 arc
F
.34772 .16337 m
.34772 .16337 0 0 365.73 arc
F
.33919 .24766 m
.33919 .24766 .00013 0 365.73 arc
F
.33066 .33194 m
.33066 .33194 .00113 0 365.73 arc
F
.32213 .41622 m
.32213 .41622 .00314 0 365.73 arc
F
.31361 .50051 m
.31361 .50051 .00466 0 365.73 arc
F
.30508 .58479 m
.30508 .58479 .00407 0 365.73 arc
F
.29655 .66908 m
.29655 .66908 .00183 0 365.73 arc
F
.28802 .75336 m
.28802 .75336 .00021 0 365.73 arc
F
.42121 .05798 m
.42121 .05798 0 0 365.73 arc
F
.41268 .14226 m
.41268 .14226 0 0 365.73 arc
F
.40416 .22655 m
.40416 .22655 .00023 0 365.73 arc
F
.39563 .31083 m
.39563 .31083 .00166 0 365.73 arc
F
.3871 .39512 m
.3871 .39512 .00459 0 365.73 arc
F
.37857 .4794 m
.37857 .4794 .0072 0 365.73 arc
F
.37005 .56368 m
.37005 .56368 .00703 0 365.73 arc
F
.36152 .64797 m
.36152 .64797 .00396 0 365.73 arc
F
.35299 .73225 m
.35299 .73225 .00093 0 365.73 arc
F
.34446 .81654 m
.34446 .81654 0 0 365.73 arc
F
.48618 .03687 m
.48618 .03687 .0001 0 365.73 arc
F
.47765 .12115 m
.47765 .12115 5e-005 0 365.73 arc
F
.46912 .20544 m
.46912 .20544 .00013 0 365.73 arc
F
.4606 .28972 m
.4606 .28972 .00166 0 365.73 arc
F
.45207 .37401 m
.45207 .37401 .00511 0 365.73 arc
F
.44354 .45829 m
.44354 .45829 .00877 0 365.73 arc
F
.43501 .54257 m
.43501 .54257 .00962 0 365.73 arc
F
.42649 .62686 m
.42649 .62686 .00642 0 365.73 arc
F
.41796 .71114 m
.41796 .71114 .00218 0 365.73 arc
F
.40943 .79543 m
.40943 .79543 .00018 0 365.73 arc
F
.4009 .87971 m
.4009 .87971 5e-005 0 365.73 arc
F
.54262 .10004 m
.54262 .10004 .0004 0 365.73 arc
F
.53409 .18433 m
.53409 .18433 0 0 365.73 arc
F
.52556 .26861 m
.52556 .26861 .00113 0 365.73 arc
F
.51704 .3529 m
.51704 .3529 .00459 0 365.73 arc
F
.50851 .43718 m
.50851 .43718 .00877 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.49145 .60575 m
.49145 .60575 .0082 0 365.73 arc
F
.48293 .69003 m
.48293 .69003 .0035 0 365.73 arc
F
.4744 .77432 m
.4744 .77432 .0006 0 365.73 arc
F
.46587 .8586 m
.46587 .8586 0 0 365.73 arc
F
.45734 .94289 m
.45734 .94289 6e-005 0 365.73 arc
F
.59906 .16322 m
.59906 .16322 .00019 0 365.73 arc
F
.59053 .2475 m
.59053 .2475 .00039 0 365.73 arc
F
.582 .33179 m
.582 .33179 .00314 0 365.73 arc
F
.57348 .41607 m
.57348 .41607 .0072 0 365.73 arc
F
.56495 .50036 m
.56495 .50036 .00962 0 365.73 arc
F
.55642 .58464 m
.55642 .58464 .0082 0 365.73 arc
F
.54789 .66892 m
.54789 .66892 .00412 0 365.73 arc
F
.53937 .75321 m
.53937 .75321 .001 0 365.73 arc
F
.53084 .83749 m
.53084 .83749 5e-005 0 365.73 arc
F
.52231 .92178 m
.52231 .92178 1e-005 0 365.73 arc
F
.51378 1.00606 m
.51378 1.00606 1e-005 0 365.73 arc
F
.6555 .22639 m
.6555 .22639 1e-005 0 365.73 arc
F
.64697 .31068 m
.64697 .31068 .00149 0 365.73 arc
F
.63844 .39496 m
.63844 .39496 .00466 0 365.73 arc
F
.62992 .47925 m
.62992 .47925 .00703 0 365.73 arc
F
.62139 .56353 m
.62139 .56353 .00642 0 365.73 arc
F
.61286 .64782 m
.61286 .64782 .0035 0 365.73 arc
F
.60433 .7321 m
.60433 .7321 .001 0 365.73 arc
F
.59581 .81638 m
.59581 .81638 9e-005 0 365.73 arc
F
.58728 .90067 m
.58728 .90067 0 0 365.73 arc
F
.57875 .98495 m
.57875 .98495 0 0 365.73 arc
F
.71194 .28957 m
.71194 .28957 .00038 0 365.73 arc
F
.70341 .37385 m
.70341 .37385 .00228 0 365.73 arc
F
.69488 .45814 m
.69488 .45814 .00407 0 365.73 arc
F
.68636 .54242 m
.68636 .54242 .00396 0 365.73 arc
F
.67783 .62671 m
.67783 .62671 .00218 0 365.73 arc
F
.6693 .71099 m
.6693 .71099 .0006 0 365.73 arc
F
.66077 .79527 m
.66077 .79527 5e-005 0 365.73 arc
F
.65225 .87956 m
.65225 .87956 0 0 365.73 arc
F
.64372 .96384 m
.64372 .96384 0 0 365.73 arc
F
.76838 .35274 m
.76838 .35274 .00076 0 365.73 arc
F
.75985 .43703 m
.75985 .43703 .00179 0 365.73 arc
F
.75132 .52131 m
.75132 .52131 .00183 0 365.73 arc
F
.7428 .6056 m
.7428 .6056 .00093 0 365.73 arc
F
.73427 .68988 m
.73427 .68988 .00018 0 365.73 arc
F
.72574 .77417 m
.72574 .77417 0 0 365.73 arc
F
.71721 .85845 m
.71721 .85845 1e-005 0 365.73 arc
F
.70869 .94273 m
.70869 .94273 0 0 365.73 arc
F
.82482 .41592 m
.82482 .41592 .00055 0 365.73 arc
F
.81629 .5002 m
.81629 .5002 .00058 0 365.73 arc
F
.80776 .58449 m
.80776 .58449 .00021 0 365.73 arc
F
.79924 .66877 m
.79924 .66877 0 0 365.73 arc
F
.79071 .75306 m
.79071 .75306 5e-005 0 365.73 arc
F
.78218 .83734 m
.78218 .83734 6e-005 0 365.73 arc
F
.77365 .92162 m
.77365 .92162 1e-005 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[472]:=",
  ImageSize->{288, 300.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001;1000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002;Ool00cg_Oomoo`05Ool0
0cg_Oomoo`2:Ool00?moob5oo`00ogoo8Goo003oOolQOol008]oo`03?Nmoogoo00Eoo`03?Nmoogoo
08Yoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol007Qoo`03?Nmoogoo02]o
o`03?Nmoogoo07Moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol006Ioo`03
?Nmoogoo04moo`03?Nmoogoo06Eoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool005=oo`03?Nmoogoo02eoo`03?Nmoogoo01Eoo`03?Nmoogoo02eoo`03?Nmoogoo059oo`00ogoo
8Goo003oOolQOol003ioo`03?Nmoogoo09moo`03?Nmoogoo03eoo`00ogoo8Goo003oOolQOol0041o
o`03?Nmoogoo04Ioo`03?Nmoogoo00Uoo`03?Nmoogoo04Ioo`03?Nmoogoo03moo`00ogoo8Goo000h
Ool00cg_Oomoo`2[Ool00cg_Oomoo`0gOol00?moob5oo`00ogoo8Goo000jOol00cg_Oomoo`2WOol0
0cg_Oomoo`0iOol007Ioo`03?Nmoogoo02moo`03?Nmoogoo07Eoo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00DWoo00<mkgooOol0Mgoo00<mkgooOol0DGoo003oOolQOol006=oo`03?Nmoogoo00eoo`03
?Nmoogoo03Eoo`03?Nmoogoo00eoo`03?Nmoogoo069oo`00ogoo8Goo003oOolQOol006Yoo`03?Nmo
ogoo04Moo`03?Nmoogoo06Uoo`00ogoo8Goo002?Ool00cg_Oomoo`2>Ool0055oo`03?Nmoogoo035o
o`03?Nmoogoo015oo`03?Nmoogoo035oo`03?Nmoogoo051oo`00ogoo8Goo0021Ool00cg_Oomoo`0I
Ool00cg_Oomoo`20Ool002moo`03?Nmoogoo0;eoo`03?Nmoogoo02ioo`00ogoo8Goo003oOolQOol0
03ioo`03?Nmoogoo04Eoo`03?Nmoogoo00moo`03?Nmoogoo04Eoo`03?Nmoogoo03eoo`00QGoo00<m
kgooOol04Goo00<mkgooOol0Q7oo0016Ool00cg_Oomoo`0`Ool00cg_Oomoo`06Ool2?NlGOol2?Nl8
Ool00cg_Oomoo`0`Ool00cg_Oomoo`15Ool007Uoo`03?Nmoogoo02Uoo`03?Nmoogoo07Qoo`00ogoo
8Goo003oOolQOol0069oo`03?Nmoogoo00Qoo`03?Nmoogoo00=oo`8mkcEoo`8mk`Eoo`03?Nmoogoo
00Qoo`03?Nmoogoo065oo`00GWoo00<mkgooOol037oo00<mkgooOol0@Goo00<mkgooOol037oo00<m
kgooOol0GGoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol002=oo`03?Nmoogoo02moo`8m
k`Yoo`Dmk`moo`8mkaMoo`<mkaMoo`8mk`moo`Dmk`Yoo`8mkc5oo`03?Nmoogoo029oo`00HWoo00<m
kgooOol0:Woo00<mkgooOol0SWoo003oOolQOol00?moob5oo`00ogoo8Goo002=Ool2?Nl00goo?Nlm
k`2>Ool003]oo`03?Nmoogoo011oo`03?Nmoogoo03Ioo`8mk`eoo`8mkcQoo`03?Nmoogoo011oo`03
?Nmoogoo03Yoo`00UWoo00<mkgooOol0Qgoo003oOolQOol00?moob5oo`00C7oo00<mkgooOol0:Goo
0Sg_:goo0Sg_:goo00<mkgooOol0Bgoo001COol00cg_Oomoo`0ROol00cg_Oomoo`0ZOol00cg_Oomo
o`0SOol2?NmCOol003aoo`03?Nmoogoo01=oo`03?Nmoogoo02ioo`8mkaEoo`8mkc1oo`03?Nmoogoo
01=oo`03?Nmoogoo03]oo`00Pgoo00<mkgooOol057oo00<mkgooOol0Pgoo001@Ool2?NmkOol2?NmA
Ool0061oo`8mke]oo`8mkf5oo`005goo00<mkgooOol0Agoo00<mkgooOol01Woo00<mkgooOol0AWoo
00<ikSg_Ool01goo00<mkgooOol0Agoo00<mkgooOol05Woo003oOolQOol006Eoo`03?Nmoogoo00Uo
o`8mkcYoo`03?Nmoogoo00Uoo`8mkfEoo`00IGoo00<mkgooOol0AGoo00<mkgooOol0L7oo000fOol0
0cg_Oomoo`0@Ool00cg_Oomoo`0FOol2?NlZOol00cg_>Nioo`0ZOol2?NlHOol00cg_Oomoo`0@Ool0
0cg_Oomoo`0eOol002moo`03?Nmoogoo01Moo`03?Nmoogoo03Eoo`8mk`]oo`8mk`]oo`8mkcQoo`03
?Nmoogoo01Moo`03?Nmoogoo02ioo`00Vgoo0Sg_Pgoo003oOolQOol005ioo`8mkaMoo`8mkbeoo`8m
kaMoo`8mkemoo`00GWoo00<mkgooOol05Woo00<mkgooOol0;7oo00<mkgooOol05Woo00<mkgooOol0
GWoo0023Ool2?Nl00cW^Oomoo`0AOol00cW^?Nmoo`0kOol00cg_Oomoo`16Ool004Moo`03?Nmoogoo
03Uoo`8mkaAoo`8mkcaoo`03?Nmoogoo04Ioo`00ogoo8Goo001hOol2?NnVOol0021oo`03?Nmoogoo
01moo`03?Nmoogoo00Moo`03?Nmoogoo02Qoo`8mk`03>Nioogoo00eoo`03>Nhmkgoo00Moo`8mk`mo
o`03?NlikWoo02]oo`03?Nmoogoo00Moo`03?Nmoogoo01moo`03?Nmoogoo01moo`002Goo00<mkgoo
Ool0=Woo00<mkgooOol01goo00<mkgooOol077oo0Sg_2goo0Sg_3goo0Sg_27oo0Sg_3goo0Sg_2Woo
0Sg_87oo00<mkgooOol01goo00<mkgooOol0=Woo00<mkgooOol027oo000<Ool00cg_Oomoo`1?Ool2
?Nl<Ool00cg_Oomoo`12Ool00cg_Oomoo`0;Ool00cW^?Nmoo`1@Ool00cg_Oomoo`0;Ool00?moob5o
o`00ogoo8Goo003oOolQOol005Aoo`8mkbYoo`8mkaYoo`8mkb]oo`8mkeEoo`0097oo00<mkgooOol0
4Woo00<mkgooOol067oo00<mkgooOol07goo0Sg_27oo0cg_6Goo0Sg_27oo0cg_87oo00<mkgooOol0
6Goo00<mkgooOol04Woo00<mkgooOol08goo0006Ool00cg_Oomoo`1]Ool00cg_Oomoo`07Ool00cg_
>Nioo`0TOol00cg_Oomoo`1^Ool00cg_Oomoo`05Ool003ioo`03?Nmoogoo04eoo`<mkhmoo`002Goo
0Sg_:goo00<mkgooOol01Goo00<mkgooOol08Goo00<mkgooOol0:7oo0Sg_00<ikSg_Ool0:Goo00<i
kSg_Ool08Goo00<ikSg_Ool01Woo00<mkgooOol0:Goo00<mkgooOol02Goo000mOol00cg_Oomoo`1=
Ool4?Nm@Ool00cg_Oomoo`0lOol003]oo`03?Nmoocg_02Uoo`03?Nmoogoo00Aoo`8mkaaoo`03?Nli
kSg_008mk`03>Nioogoo029oo`8mkbUoo`<mkcaoo`00IWoo0Sg_1Goo0cg_7Goo13g_7Goo0Sg_1Woo
0Sg_J7oo001_Ool00cW^Oomoo`2^Ool00?moob5oo`00Mgoo0Sg_;7oo00<ikSg_?Nl0N7oo001fOol4
?NlZOol4?NmhOol0039oo`03?Nmoogoo01ioo`03>Nhmkgoo021oo`03?NlikSg_008mkbMoo`03?Nli
kSg_008mk`03>Nioogoo021oo`8mkb1oo`03?Nmoogoo035oo`0087oo00<mkgooOol03goo00<mkgoo
Ool05goo0Sg_3Goo0Sg_6Woo1Cg_9Woo1Cg_6Woo0cg_3Woo00<mkgooOol05goo00<mkgooOol03goo
00<mkgooOol07goo001gOol2?Nl00cW^?Nmoo`0WOol2?Nl00cW^?Nmoo`0ZOol00cg_Oomoo`1;Ool0
07Moo`<mkbYoo`<mkgUoo`00Ggoo00<ikSg_Ool0D7oo00<mkcW^Ool01goo0cg_HGoo000HOol00cg_
Oomoo`14Ool2?Nl9Ool2?NlOOol3?Nl2Ool3?NlOOol2?Nl9Ool2?Nm7Ool00cg_Oomoo`0GOol006]o
o`03?Nmoogoo01eoo`8mk`06>Nioogoo?NlikSg_7goo0Sg_K7oo0014Ool2?Nl3Ool2?NloOol:?Nm0
Ool2?Nl3Ool2?Nm5Ool0085oo`8mk`03>Nhmkgoo00Eoo`03>Nhmkcg_009oo`<mk`Moo`03?NlikSg_
08=oo`00B7oo0Sg_=goo13g_27oo13g_2Goo0cg_>7oo0Sg_BGoo000`Ool00cg_Oomoo`0EOol00cg_
Oomoo`0eOol00cg_>Nhmk`02?Nl8Ool013W^?Nlmkcg_27oo00DikSg_?NlmkcW^03Moo`03>Nioogoo
01Ioo`03?Nmoogoo02moo`002Woo00<mkgooOol0:Goo00<mkgooOol0:7oo0cg_6Goo23g_1goo1Sg_
1goo23g_6Goo0Sg_;7oo00<mkgooOol0:Goo00<mkgooOol02Goo001ROol00cg_Oomoo`0HOol2?Nl0
1CW^?Nmoogoo>Nh027oo0cg_00<ikSg_?Nl01goo0Sg_00HikSg_OolmkcW^?NlJOol00cW^Oomoo`1R
Ool003Moo`03?Nmoogoo01aoo`8mkbAoo`Dmk`03Oolmkcg_008mk`Moo`@mk`Qoo`TmkbAoo`8mkamo
o`03?Nmoogoo03Ioo`00Egoo00<mkgooOol08goo00DikSg_?Nlmkgoo00<mk`03>Nioogoo015oo`05
>Nhmkcg_?NlikP03?NlVOol00cg_Oomoo`1FOol0035oo`03?Nmoogoo009oo`8mka1oo`03?Nmoogoo
03Aoo`Lmka9oo`DmkcUoo`8mk`moo`8mk`Aoo`03?Nmoogoo031oo`00B7oo00<mkgooOol0=Woo0Sg_
00<ikSg_?Nl04Woo0cg_00<ikSg_Ool0>7oo00<mkgooOol0Agoo0021Ool4?NlCOol4?Nn4Ool006Qo
o`03?NlikSg_008mk`03>Nioogoo045oo`05>Nhmkcg_?NlikP1ZOol006Qoo`Hmkd9oo`HmkfYoo`00
J7oo0cg_00<ikSg_?Nl02Goo00@ikSg_?NlmkbUoo`<mk`Uoo`<mk`03>Nhmkcg_00Qoo`03?NlikWoo
05moo`0087oo00<mkgooOol0:Goo0Sg_4Goo00<mkgooOol027oo0cg_2Goo1Cg_:7oo1Cg_27oo13g_
2Woo0Sg_4Goo0Sg_:goo00<mkgooOol07goo001fOol3?Nl00cW^?Nmoo`0WOol2?Nl00cW^?Nlmk`09
Ool00cW^?Nlmk`1/Ool007Moo`Lmkb9oo`LmkgUoo`00FGoo0Sg_6goo00<mkcW^?Nl00Woo00<ikSg_
?Nl08Woo0cg_00HikWoo?NlmkcW^?NmgOol003Aoo`03?Nmoogoo01aoo`<mk`9oo`<mka]oo`<mk`03
Oolmkcg_00<mkb1oo`Dmk`03Oolmkcg_008mkaYoo`<mk`=oo`8mkamoo`03?Nmoogoo03=oo`0097oo
00<mkgooOol0;7oo00<mkgooOol00goo00<ikWooOol06Goo00DikSg_?NlmkcW^00<mk`03>Nhmkgoo
01moo`8mk`05>Nhmkcg_?NlikP03?NlKOol00cg_Oomoo`02Ool00cW^?Nmoo`0^Ool00cg_Oomoo`0S
Ool007Ioo`<mk`03Oolmkcg_008mkb9oo`@mk`03Oolmkcg_008mkgMoo`00ogoo8Goo002=Ool4?Nn?
Ool003aoo`03?Nmoogoo02=oo`8mkbUoo`04>Nhmkcg_?NmAOol00cg_Oomoo`0kOol000Yoo`03?Nmo
ogoo02Uoo`03?Nmoogoo00=oo`03?Nmoogoo00Moo`<mkaQoo`<mkbQoo`HmkbQoo`<mkaYoo`8mk`Uo
o`03?Nmoogoo00=oo`03?Nmoogoo02Uoo`03?Nmoogoo00Uoo`00HGoo0Sg_00<ikWooOol09Woo0cg_
00<ikSg_?Nl0:Goo00<ikWooOol0HWoo002=Ool4?Nn?Ool00:Eoo`04>Nhmkcg_?NmgOol007Ioo`<m
k`9oo`<mkb9oo`@mk`03Oolmkcg_008mkgMoo`0097oo00<mkgooOol0;7oo0cg_7goo0Sg_00DikSg_
?NmoocW^008mkb9oo`<mk`06>Nhmkcg_?NlikSg_87oo0cg_;Woo00<mkgooOol08goo000dOol00cg_
Oomoo`0LOol00cg_Oomoo`02Ool3?NlJOol:?NlPOol:?NlJOol3?Nl3Ool2?NlOOol00cg_Oomoo`0c
Ool005Uoo`03>Nioogoo01Yoo`<mk`06Oolmkcg_?NlikSg_87oo0Sg_00DikSg_?NmoocW^00<mka]o
o`03?Nmoogoo05Uoo`00Mgoo1cg_8Woo1cg_NGoo001gOol013W^?Nlmkcg_:Goo0cg_2Woo0Sg_00<i
kWooOol0JWoo000POol00cg_Oomoo`0YOol2?Nl@Ool2?Nl:Ool3?Nl9Ool5?NlXOol5?Nl8Ool4?Nl9
Ool3?NlAOol2?Nl[Ool00cg_Oomoo`0OOol005moo`03?Nmoogoo00Ioo`03?NlikSg_008mk`03>Nio
ogoo00Moo`8mk`03>Nhmkgoo02Qoo`03?NlikSg_00Uoo`03?NlikSg_008mk`03>Nioogoo00Ioo`03
?Nmoogoo05moo`00J7oo1Sg_@Woo1Sg_JWoo001XOol3?Nl00cW^?Nlmk`12Ool3?Nl00cW^?Nlmk`1Z
Ool0089oo`@mka=oo`@mkh=oo`00B7oo00<mkgooOol0=goo0cg_00<ikWooOol04Goo00@ikSg_?Nlm
kcUoo`8mkdQoo`00<Goo00<mkgooOol00Woo0Sg_AGoo2Cg_4Woo1Cg_>Goo00<mkgooOol03Woo0Sg_
17oo00<mkgooOol0<7oo001mOol2?Nl01CW^?Nlmkcg_>Nh00Sg_4Woo0cg_00HikSg_OolmkcW^?Nmo
Ool003Moo`03?Nmoogoo01aoo`8mkbAoo`Tmk`Qoo`@mk`Moo`@mk`03Oolmkcg_00<mkbAoo`8mkamo
o`03?Nmoogoo03Ioo`002Woo00<mkgooOol0:Goo00<mkgooOol07Goo0Sg_2Goo00<ikSg_?Nl067oo
00<mkcW^?Nl00Sg_2goo00<mkcW^?Nl00Sg_2Goo0cg_00DikSg_?NlmkcW^01Uoo`03?Nmoogoo00Qo
o`8mkb1oo`03?Nmoogoo02Uoo`03?Nmoogoo00Uoo`00<7oo00<mkgooOol0;goo00<mkgooOol067oo
23g_1goo1Sg_27oo1cg_6Woo00<mkgooOol0<7oo00<mkgooOol0;goo0018Ool2?NlfOol3?Nl00cW^
?Nmoo`07Ool2?Nl00cW^?Nmoo`07Ool2?Nl00cW^?Nlmk`0gOol2?Nm9Ool0085oo`@mkaAoo`DmkcMo
o`03?Nmoogoo04Qoo`00Pgoo00<mkgooOol01Goo0Sg_00HikWooOolmkcW^?Nl6Ool013W^?Nlmkcg_
Pgoo0014Ool2?Nl3Ool2?NloOol:?Nm0Ool2?Nl3Ool2?Nm5Ool008Yoo`03?NlikSg_008mk`05>Nhm
kcg_?NlikP1bOol00cg_Oomoo`0GOol001Qoo`03?Nmoogoo04Aoo`8mk`Uoo`8mkamoo`<mk`9oo`<m
kamoo`8mk`Qoo`<mkdMoo`03?Nmoogoo01Moo`00Ggoo0Sg_2Goo0Sg_AWoo0Sg_2Goo00<ikSg_Ool0
H7oo001gOol3?NlZOol3?NmiOol0021oo`03?Nmoogoo02Uoo`8mkbUoo`04>Nhmkcg_?NlXOol013W^
?Nlmkcg_:goo00<mkgooOol0:Goo00<mkgooOol07goo000bOol00cg_Oomoo`0VOol2?NlJOol5?NlV
Ool5?NlKOol00cg_Oomoo`0WOol00cg_Oomoo`0aOol005=oo`8mk`Ioo`8mkaUoo`<mk`03>Nhmkgoo
02Moo`8mk`03>Nhmkcg_029oo`8mkeAoo`00MWoo13g_:Woo13g_N7oo001fOol00cg_>Nhmk`0/Ool2
?NmiOol00?moob5oo`00ogoo8Goo000kOol00cg_Oomoo`0XOol2?Nl5Ool3?NlMOol4?NlMOol2?Nl5
Ool3?NlZOol2?NllOol003eoo`03?Nmoogoo02Ioo`03?NlikWoo00Eoo`03?NlikWoo01]oo`<mk`03
>Nhmkcg_01eoo`03>Nioogoo00Aoo`03?NlikWoo02Qoo`03?Nmoogoo03aoo`00SGoo13g_Sgoo0009
Ool2?Nl[Ool00cg_Oomoo`05Ool00cg_Oomoo`0QOol00cg_Oomoo`0XOol013W^?Nlmkcg_:Woo00<m
kgooOol08Goo0Sg_1goo00<mkgooOol0:Goo00<mkgooOol02Goo0006Ool00cg_Oomoo`1IOol00cg_
Oomoo`0YOol2?Nn8Ool00cg_Oomoo`05Ool002Aoo`03?Nmoogoo0==oo`03?Nmoogoo02=oo`00>Goo
00<mkgooOol067oo0Sg_87oo0Sg_27oo0cg_6Goo0Sg_27oo0cg_87oo0Sg_6Woo00<mkgooOol0>7oo
001DOol00cg_Oomoo`0OOol00cg_Oomoo`07Ool00cg_>Nioo`0IOol00cg_>Nioo`08Ool00cg_Oomo
o`0OOol00cW^Oomoo`1DOol00?moob5oo`00ogoo8Goo003oOolQOol000Uoo`04?Nmoogoo?NmAOol2
?Nl<Ool00cg_Oomoo`12Ool00cW^Oomoo`0;Ool2?NmAOol013g_Oomoocg_2Woo0012Ool00cg_Oomo
o`07Ool00cg_Oomoo`0MOol00cg_Oomoo`0JOol2?Nl8Ool2?NlLOol00cg_Oomoo`0NOol00cg_Oomo
o`07Ool00cg_Oomoo`11Ool0021oo`03?Nmoogoo02Uoo`03?Nmoogoo02Qoo`03>Nhmkcg_00moo`8m
k`Qoo`03>Nhmkgoo00ioo`8mkbaoo`03?Nmoogoo02Uoo`03?Nmoogoo01moo`00N7oo0Sg_:Woo0Sg_
NWoo003oOolQOol004Moo`03?Nmoogoo03Uoo`8mkaAoo`8mkcaoo`03?Nmoogoo04Ioo`00Pgoo00<i
kSg_?Nl04goo0Sg_QGoo001NOol2?NlGOol2?Nl;Ool00cg_Oomoo`0OOol00cg_Oomoo`0FOol2?NmO
Ool007Moo`03?Nmoogoo02aoo`03?Nmoogoo07Moo`00ogoo8Goo000_Ool00cg_Oomoo`2mOol00cg_
Oomoo`0^Ool004Uoo`03?Nmoogoo03Eoo`<mk`Yoo`8mk`]oo`8mkcQoo`03?Nmoogoo04Qoo`00=Woo
00<mkgooOol0:Goo0Sg_:Woo0Sg_:goo0Sg_:goo00<mkgooOol0=Goo001UOol00cg_Oomoo`09Ool2
?NljOol00cg_Oomoo`09Ool2?NmUOol006Eoo`03?Nmoogoo04Eoo`03?Nmoogoo071oo`005goo00<m
kgooOol0kGoo00<mkgooOol05Woo001POol2?Nl8Ool00cg_Oomoo`16Ool2?Nl8Ool2?NmQOol00?mo
ob5oo`00D7oo0Sg_Ngoo0Sg_DGoo000lOol00cg_Oomoo`0COol00cg_Oomoo`0^Ool2?NlEOol2?Nl`
Ool00cg_Oomoo`0COol00cg_Oomoo`0kOol008=oo`03?Nmoogoo01Aoo`03?Nmoogoo02moo`03?Nmo
ogoo055oo`00C7oo00<mkgooOol017oo00<mkgooOol08Woo0Sg_:goo0Sg_97oo0Sg_1Goo00<mkgoo
Ool0Bgoo001hOol00cg_Oomoo`0ZOol00cg_Oomoo`1hOol00?moob5oo`00ogoo8Goo001>Ool00cg_
Oomoo`0fOol2?Nl=Ool2?NlhOol00cg_Oomoo`1=Ool003]oo`03?Nmoogoo05Qoo`03?Nmoogoo04Yo
o`03?Nmoogoo03Yoo`00SGoo0Sg_00=oocg_?Nl0SWoo003oOolQOol00?moob5oo`00ogoo8Goo000S
Ool00cg_Oomoo`0kOol3?NlAOol00cg_Oomoo`0FOol3?NlHOol00cg_Oomoo`0?Ool3?NlmOol00cg_
Oomoo`0ROol005Eoo`8mk`eoo`8mk`moo`8mkc5oo`8mk`moo`8mk`eoo`8mkeIoo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo001NOol00cg_Oomoo`0<Ool00cg_Oomoo`03Ool2?NleOol2?Nl5
Ool00cg_Oomoo`0<Ool00cg_Oomoo`1MOol0069oo`03?Nmoogoo00Qoo`03?Nmoogoo00=oo`03>Nio
ogoo04Ioo`03?Nmoogoo065oo`00ogoo8Goo003oOolQOol007Uoo`03?Nmoogoo02Uoo`03?Nmoogoo
07Qoo`00AWoo00<mkgooOol0>Goo0Sg_00=oocg_Ool04Woo00@mkgoo?Nlmkc]oo`03?Nmoogoo04Eo
o`00?Woo00<mkgooOol0A7oo00<mkgooOol0F7oo00<mkgooOol0?Goo000nOol00cg_Oomoo`15Ool0
0cg_Oomoo`0?Ool00cg_Oomoo`15Ool00cg_Oomoo`0mOol00?moob5oo`00ogoo8Goo000_Ool00cg_
Oomoo`2mOol00cg_Oomoo`0^Ool0085oo`03?Nmoogoo01Uoo`03?Nmoogoo081oo`00ogoo8Goo001A
Ool00cg_Oomoo`0aOol00cg_Oomoo`0AOol00cg_Oomoo`0aOol00cg_Oomoo`1@Ool008moo`03?Nmo
ogoo08ioo`00ogoo8Goo001ZOol00cg_Oomoo`17Ool00cg_Oomoo`1YOol00?moob5oo`00ogoo8Goo
001SOol00cg_Oomoo`0=Ool00cg_Oomoo`0eOol00cg_Oomoo`0=Ool00cg_Oomoo`1ROol00?moob5o
o`00DWoo00<mkgooOol0Mgoo00<mkgooOol0DGoo003oOolQOol00?moob5oo`00ogoo8Goo001fOol0
0cg_Oomoo`0_Ool00cg_Oomoo`1eOol003Yoo`03?Nmoogoo0:Moo`03?Nmoogoo03Uoo`00ogoo8Goo
003oOolQOol003Qoo`03?Nmoogoo0:]oo`03?Nmoogoo03Moo`00ogoo8Goo0010Ool00cg_Oomoo`16
Ool00cg_Oomoo`09Ool00cg_Oomoo`16Ool00cg_Oomoo`0oOol00?moob5oo`00?Woo00<mkgooOol0
Wgoo00<mkgooOol0?Goo003oOolQOol00?moob5oo`00ogoo8Goo001COol00cg_Oomoo`0]Ool00cg_
Oomoo`0EOol00cg_Oomoo`0]Ool00cg_Oomoo`1BOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo001VOol00cg_Oomoo`1?Ool00cg_Oomoo`1UOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo001hOol00cg_Oomoo`0[Ool00cg_Oomoo`1gOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002;Ool00cg_Oomoo`05Ool00cg_Oomoo`2:Ool0
0?moob5oo`00ogoo8Goo002;Ool00cg_Oomoo`05Ool00cg_Oomoo`2:Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {299.313, 0}} -> {-4.69017, -4.89157, \
0.0326853, 0.0326853}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[472]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export["\</usr/people/joseluis/Docs/Papers/Average/averageDif.eps\>", \
%]\)], "Input"],

Cell[BoxData[
    \("/usr/people/joseluis/Docs/Papers/Average/averageDif.eps"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Laue lattice", "Section",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[{
    \(\(tol\  = \ 0.00000000001;\)\), "\[IndentingNewLine]", 
    \(\(Laue21\  = \ {};\)\), "\[IndentingNewLine]", 
    \(Do[If[
        Abs[sRL21[\([i]\)] . e[3]]\  < \ tol\  || \ 
          Abs[sRL21[\([i]\)] . e[4]]\  < \ tol\  || \ 
          Abs[sRL21[\([i]\)] . e[5]]\  < \ tol, 
        AppendTo[Laue21, sRL21[\([i]\)]]], {i, \ 
        Length[sRL21]}]\), "\[IndentingNewLine]", 
    \(\(Laue31\  = \ {};\)\), "\[IndentingNewLine]", 
    \(Do[If[
        Abs[sRL31[\([i]\)] . e[2]]\  < \ tol\  || \ 
          Abs[sRL31[\([i]\)] . e[4]]\  < \ tol\  || \ 
          Abs[sRL31[\([i]\)] . e[5]]\  < \ tol, \ \[IndentingNewLine]AppendTo[
          Laue31, sRL31[\([i]\)]]], {i, \ 
        Length[sRL31]}]\), "\[IndentingNewLine]", 
    \(\(Laue32\  = \ {};\)\), "\[IndentingNewLine]", 
    \(Do[If[
        Abs[sRL32[\([i]\)] . e[1]]\  < \ tol\  || \ 
          Abs[sRL32[\([i]\)] . e[4]]\  < \ tol\  || \ 
          Abs[sRL32[\([i]\)] . e[5]]\  < \ tol, 
        AppendTo[Laue32, sRL32[\([i]\)]]], {i, \ 
        Length[sRL32]}]\), "\[IndentingNewLine]", 
    \(\(Laue41\  = \ {};\)\), "\[IndentingNewLine]", 
    \(Do[If[
        Abs[sRL41[\([i]\)] . e[2]]\  < \ tol\  || \ 
          Abs[sRL41[\([i]\)] . e[3]]\  < \ tol\  || \ 
          Abs[sRL41[\([i]\)] . e[5]]\  < \ tol, \ 
        AppendTo[Laue41, sRL41[\([i]\)]]], {i, \ 
        Length[sRL41]}]\), "\[IndentingNewLine]", 
    \(\(Laue42\  = \ {};\)\), "\[IndentingNewLine]", 
    \(Do[If[
        Abs[sRL42[\([i]\)] . e[1]]\  < \ tol\  || \ 
          Abs[sRL42[\([i]\)] . e[3]]\  < \ tol\  || \ 
          Abs[sRL42[\([i]\)] . e[5]]\  < \ tol, \ 
        AppendTo[Laue42, sRL42[\([i]\)]]], {i, \ 
        Length[sRL42]}]\), "\[IndentingNewLine]", 
    \(\(Laue43\  = \ {};\)\), "\[IndentingNewLine]", 
    \(Do[If[
        Abs[sRL43[\([i]\)] . e[1]]\  < \ tol\  || \ 
          Abs[sRL43[\([i]\)] . e[2]]\  < \ tol\  || \ 
          Abs[sRL43[\([i]\)] . e[5]]\  < \ tol, \ 
        AppendTo[Laue43, sRL43[\([i]\)]]], {i, \ 
        Length[sRL43]}]\), "\[IndentingNewLine]", 
    \(\(Laue51\  = \ {};\)\), "\[IndentingNewLine]", 
    \(Do[If[
        Abs[sRL51[\([i]\)] . e[2]]\  < \ tol\  || \ 
          Abs[sRL51[\([i]\)] . e[3]]\  < \ tol\  || \ 
          Abs[sRL51[\([i]\)] . e[4]]\  < \ tol, \ 
        AppendTo[Laue51, sRL51[\([i]\)]]], {i, \ 
        Length[sRL51]}]\), "\[IndentingNewLine]", 
    \(\(Laue52\  = \ {};\)\), "\[IndentingNewLine]", 
    \(Do[If[
        Abs[sRL52[\([i]\)] . e[1]]\  < \ tol\  || \ 
          Abs[sRL52[\([i]\)] . e[3]]\  < \ tol\  || \ 
          Abs[sRL52[\([i]\)] . e[4]]\  < \ tol, \ 
        AppendTo[Laue52, sRL52[\([i]\)]]], {i, \ 
        Length[sRL52]}]\), "\[IndentingNewLine]", 
    \(\(Laue53\  = \ {};\)\), "\[IndentingNewLine]", 
    \(Do[If[
        Abs[sRL53[\([i]\)] . e[1]]\  < \ tol\  || \ 
          Abs[sRL53[\([i]\)] . e[2]]\  < \ tol\  || \ 
          Abs[sRL53[\([i]\)] . e[4]]\  < \ tol, \ 
        AppendTo[Laue53, sRL53[\([i]\)]]], {i, \ 
        Length[sRL53]}]\), "\[IndentingNewLine]", 
    \(\(Laue54\  = \ {};\)\), "\[IndentingNewLine]", 
    \(Do[If[
        Abs[sRL54[\([i]\)] . e[1]]\  < \ tol\  || \ 
          Abs[sRL54[\([i]\)] . e[2]]\  < \ tol\  || \ 
          Abs[sRL54[\([i]\)] . e[3]]\  < \ tol, \ 
        AppendTo[Laue54, sRL54[\([i]\)]]], {i, \ Length[sRL54]}]\)}], "Input",\

  CellLabel->"In[140]:="],

Cell[BoxData[
    \(\(myLaue\  = \ 
        Union[Laue21, \ Laue31, \ Laue32, \ Laue42, \ Laue42, \ Laue43, \ 
          Laue51, \ Laue52, \ Laue53, \ Laue54];\)\)], "Input",
  CellLabel->"In[161]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(grB\  = 
      DrawPattern[N[myLaue], Table[ .1, {i, Length[myLaue]}], \ 0]\)], "Input",\

  CellLabel->"In[162]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.04983 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15131 0.524914 0.15131 [
[ 0 0 0 0 ]
[ 1 1.04983 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.04983 L
0 1.04983 L
closepath
clip
newpath
0 g
.03894 .37511 m
.03894 .37511 .01513 0 365.73 arc
F
.03894 .67472 m
.03894 .67472 .01513 0 365.73 arc
F
.13115 .40507 m
.13115 .40507 .01513 0 365.73 arc
F
.13115 .64476 m
.13115 .64476 .01513 0 365.73 arc
F
.13182 .64454 m
.13182 .64454 .01513 0 365.73 arc
F
.21505 .13271 m
.21505 .13271 .01513 0 365.73 arc
F
.21505 .91711 m
.21505 .91711 .01513 0 365.73 arc
F
.22336 .43503 m
.22336 .43503 .01513 0 365.73 arc
F
.22336 .6148 m
.22336 .6148 .01513 0 365.73 arc
F
.27204 .21115 m
.27204 .21115 .01513 0 365.73 arc
F
.27204 .83867 m
.27204 .83867 .01513 0 365.73 arc
F
.27245 .21172 m
.27245 .21172 .01513 0 365.73 arc
F
.27245 .83811 m
.27245 .83811 .01513 0 365.73 arc
F
.31558 .46499 m
.31558 .46499 .01513 0 365.73 arc
F
.31558 .58484 m
.31558 .58484 .01513 0 365.73 arc
F
.32903 .28959 m
.32903 .28959 .01513 0 365.73 arc
F
.32903 .76023 m
.32903 .76023 .01513 0 365.73 arc
F
.38602 .36803 m
.38602 .36803 .01513 0 365.73 arc
F
.38602 .68179 m
.38602 .68179 .01513 0 365.73 arc
F
.40779 .49495 m
.40779 .49495 .01513 0 365.73 arc
F
.40779 .55487 m
.40779 .55487 .01513 0 365.73 arc
F
.44301 .44647 m
.44301 .44647 .01513 0 365.73 arc
F
.44301 .60335 m
.44301 .60335 .01513 0 365.73 arc
F
.5 .52491 m
.5 .52491 .01513 0 365.73 arc
F
.5 .04013 m
.5 .04013 .01513 0 365.73 arc
F
.5 .13708 m
.5 .13708 .01513 0 365.73 arc
F
.5 .13779 m
.5 .13779 .01513 0 365.73 arc
F
.5 .23404 m
.5 .23404 .01513 0 365.73 arc
F
.5 .331 m
.5 .331 .01513 0 365.73 arc
F
.5 .42796 m
.5 .42796 .01513 0 365.73 arc
F
.5 .62187 m
.5 .62187 .01513 0 365.73 arc
F
.5 .71883 m
.5 .71883 .01513 0 365.73 arc
F
.5 .81579 m
.5 .81579 .01513 0 365.73 arc
F
.5 .91204 m
.5 .91204 .01513 0 365.73 arc
F
.5 .91274 m
.5 .91274 .01513 0 365.73 arc
F
.5 1.0097 m
.5 1.0097 .01513 0 365.73 arc
F
.55699 .44647 m
.55699 .44647 .01513 0 365.73 arc
F
.55699 .60335 m
.55699 .60335 .01513 0 365.73 arc
F
.59221 .49495 m
.59221 .49495 .01513 0 365.73 arc
F
.59221 .55487 m
.59221 .55487 .01513 0 365.73 arc
F
.61398 .36803 m
.61398 .36803 .01513 0 365.73 arc
F
.61398 .68179 m
.61398 .68179 .01513 0 365.73 arc
F
.67097 .28959 m
.67097 .28959 .01513 0 365.73 arc
F
.67097 .76023 m
.67097 .76023 .01513 0 365.73 arc
F
.68442 .46499 m
.68442 .46499 .01513 0 365.73 arc
F
.68442 .58484 m
.68442 .58484 .01513 0 365.73 arc
F
.72755 .21172 m
.72755 .21172 .01513 0 365.73 arc
F
.72755 .83811 m
.72755 .83811 .01513 0 365.73 arc
F
.72796 .21115 m
.72796 .21115 .01513 0 365.73 arc
F
.72796 .83867 m
.72796 .83867 .01513 0 365.73 arc
F
.77664 .43503 m
.77664 .43503 .01513 0 365.73 arc
F
.77664 .6148 m
.77664 .6148 .01513 0 365.73 arc
F
.78495 .13271 m
.78495 .13271 .01513 0 365.73 arc
F
.78495 .91711 m
.78495 .91711 .01513 0 365.73 arc
F
.86818 .40528 m
.86818 .40528 .01513 0 365.73 arc
F
.86885 .40507 m
.86885 .40507 .01513 0 365.73 arc
F
.86885 .64476 m
.86885 .64476 .01513 0 365.73 arc
F
.96106 .37511 m
.96106 .37511 .01513 0 365.73 arc
F
.96106 .67472 m
.96106 .67472 .01513 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[162]:=",
  ImageSize->{288, 302.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001;PP10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;RLW9b40<?oo_hNZb/kMjT]OL@00?iFO_Ooo7W=cLda<C820P9F<W];>eU1;EK:_]Bl]<gmo
OiB;WMKBg2XX;H=kRhjYUM3KddiMD^GQY9no_m[ViUY]KFF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oO
ggN?Sl?Ei8EhU000O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2oO`2o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOlS3cdDnCFml
S[g3bcU0B]C>N7j0VLG6dD52Cf]]PW5VO]_Ggd8lBVIbVOoo0_oo1mWIhEiPLko0c3m0C1lO9FAJKk>i
c=;EhC<iC1TL9DaELeioI[C3]c11=20M9<:lbTIOC8RZVOl78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00?l78@L008h70`2?1`00S0L608h7002;1`P0S@L008/7202=1`00R`L808d7
002;1`P0S@L008`71`2=1`00S0L608h7002=1`@0S`L00?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l7
8@L00?l78@L00?l78@L00?l78@L003X71`2M1`H0?0L003T7201;1`D0C0L803/7000i1`P0B`L604/7
200k1`00>@L904T720191`T0>`L003T72@191`P0BPL803/7000i1`P0BPL804X7200k1`00>PL604/7
201;1`H0?0L003/7101=1`L0C0L303h7002<1`H0SPL008d7102?1`00o`LQ1`00o`LQ1`00o`LQ1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00C0L407l7
101=1`00B`L607`71`1<1`00BPL807X72@1;1`00BPL807X72@1;1`00B@L907X72@1;1`00B@L907X7
2@1;1`00BPL807/71`1<1`00BPL703/71@0l1`H0C@L004`70`0l1`L0?@L304h7002;1`P0S@L008/7
202=1`00R`L808d7002;1`P0S@L008`71P2>1`00S@L408l7003o1b47003o1b47003o1b47003o1b47
003o1b47003o1b47003o1b47003o1b47001K1`D0G@L505h7001J1`L0F`L705d7001J1`P0FPL805`7
001J1`P0FPL805`7001J1`P0FPL805`7001J1`P0FPL805`7001K1`H0G0L605d7001L1`@0GPL405h7
003o1b47003o1b47003o1b47003o1b47002<1`H0SPL008/7202=1`00R`L808d7002;1`P0S@L008/7
202=1`00R`L808d7002<1`H0SPL008d7102?1`00o`LQ1`00o`LQ1`00K@L403d7101^1`00J`L703/7
1P1]1`00JPL803X7201/1`0020L605`7200j1`P0G0L700T700071`P0F`L903P72@1K1`P02@L000L7
201K1`T0>@L805/720091`001PL905`71`0k1`L0F`L900P700071`P0G0L603`71P1L1`T020L000L7
201N1`<0?PL305l71`091`001`L70?l70`L600X700091`<0o`L71`<02`L002871@3?1`D09@L00287
1P3>1`H090L00247203<1`P08`L00247203;1`T08`L00247203<1`P08`L00247203<1`P08`L00287
1`3<1`P08`L002<71@1T1`H0I@L502@7002;1`P0IPL00`071`0T1`00?@L604P720191`H0?PL003`7
20171`P0A`L903d7000l1`P0A`L804L72@0m1`00>`L903P71@0:1`P02@L603P72@0m1`00?0L803L7
1`0:1`H02@L803L72@0m1`00?0L803L7200:1`@02PL903H7200n1`00?0L703L72@0H1`T0=`L603l7
000n1`<0>PL801P72@0i1`<0@0L005T70`0O1`P060L802070`1J1`00E`L601h71`0J1`H07`L605T7
001F1`P07`L301h70`0O1`P0F0L005H7201R1`P0F0L005H7201R1`P0F0L005H7201R1`P0F0L005L7
1`1S1`L0F0L005L71P1T1`H0F@L005P7101V1`@0FPL007871P0_1`H0L`L00747200]1`P0LPL00747
200]1`P0LPL007072@0/1`T0LPL007072@0/1`T0LPL007072@0/1`P0L`L007471`0^1`H0M0L007<7
0`0b1`<0M@L00?l78@L008`71P2>1`00R`L808d7002;1`P0S@L008/7202=1`00R`L808d7002<1`L0
S@L008`71P2>1`00S@L408l7001b1`D0<0L507@7001b1`H0;`L607<7001a1`P0;@L80787001`1`T0
;0L90787001`1`T0;0L90787001`1`T0;0L807<7001a1`P0;@L707<7001c1`D0<0L407@7003o1b47
001G1`H0I0L605T7001F1`P0HPL805P7001F1`P0HPL805P7001F1`P0HPL805P7001F1`P0HPL805P7
001F1`P07PL501/71P0N1`P0F0L005L71P0N1`L06@L801h71P1I1`00F0L401l7200H1`T07PL405X7
000n1`@0>0L901P72@0i1`@0?`L003d71P0h1`P060L903L71`0n1`00?0L803L7200;1`<02PL803L7
2@0m1`00>`L903L71`0:1`H02PL603P72@0m1`00?0L803T70`0;1`P02`L303T72@0m1`00?0L804L7
20171`P0?PL003`720171`P0B0L703h7000l1`L0B0L804P71P0o1`00?PL304/71`1:1`<0@0L00287
1`1S1`H0I0L602@7000Q1`P0I0L406@7200S1`008@L80<`7200S1`008@L90</7200S1`008@L90</7
200S1`008@L80<`7200S1`008PL60<h71P0T1`008`L40=070`0V1`00o`LQ1`0020L60?l70`L700T7
00071`P0o`L11`P02@L000L7201L1`L0>`L605`720091`001PL905/7200j1`P0F`L900P700071`P0
F`L803X7201K1`T020L000L7201K1`T0>0L905`71`091`001`L705`72@0i1`P0G0L600X700091`<0
G`L703/71`1N1`<02`L006/71P0l1`H0K@L006d70`0n1`<0K`L00?l78@L00?l78@L008`71@2?1`00
S0L608h7002;1`P0S@L008/7202=1`00R`L808d7002;1`P0S@L008`71`2=1`00S@L508h7002?1`80
S`L00?l78@L00?l78@L00?l78@L005/71@1M1`D0GPL005X71`1K1`L0G@L005X7201J1`P0G0L005X7
201J1`P0G0L005X7201J1`P0G0L005X7201J1`P0G0L005/71P1L1`H0G@L005`7101N1`@0GPL00?l7
8@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L008`71@2?1`00R`L708h7
002;1`P0S@L008/7202=1`00R`L808d7002;1`P0S@L004`7100l1`H0?@L404d7001;1`H0?0L403`7
1`1<1`00BPL807X72@1;1`00BPL807X72@1;1`00B@L907X72@1;1`00B@L907X72@1;1`00BPL807/7
1`1<1`00BPL707`71P1=1`00C0L308070`1>1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00S0L608h7000j1`H0
B`L804/71@0m1`00>PL704X7201;1`H0?0L003T7201:1`P0BPL803/7000i1`T0B@L804T72@0k1`00
>@L904T7201:1`P0>`L003T7201;1`H0B`L803/7000j1`L0C0L404d71`0k1`00>`L509l71@0l1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00
o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00o`LQ1`00S0L608h7
002;1`P0S@L008/7202=1`00R`L808d7002;1`P0S@L008`71`2=1`00S0L608h7002=1`@0S`L00?l7
8@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00?l78@L00001\
\>"],
  ImageRangeCache->{{{0, 287}, {301.312, 0}} -> {-3.30451, -3.46929, \
0.0230279, 0.0230279}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[162]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[dPatt, \ grB]\)], "Input",
  CellLabel->"In[473]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.04293 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.499981 0.106605 0.521466 0.106605 [
[ 0 0 0 0 ]
[ 1 1.04293 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.04293 L
0 1.04293 L
closepath
clip
newpath
.5 g
.95659 .68434 m
.95659 .68434 .0001 0 365.73 arc
F
.91395 .61114 m
.91395 .61114 .0004 0 365.73 arc
F
.87131 .53794 m
.87131 .53794 .00019 0 365.73 arc
F
.82867 .46474 m
.82867 .46474 1e-005 0 365.73 arc
F
.78603 .39154 m
.78603 .39154 .00038 0 365.73 arc
F
.74338 .31834 m
.74338 .31834 .00076 0 365.73 arc
F
.70074 .24514 m
.70074 .24514 .00055 0 365.73 arc
F
.91644 .73961 m
.91644 .73961 0 0 365.73 arc
F
.8738 .66641 m
.8738 .66641 5e-005 0 365.73 arc
F
.83116 .59321 m
.83116 .59321 0 0 365.73 arc
F
.78852 .52001 m
.78852 .52001 .00039 0 365.73 arc
F
.74587 .44681 m
.74587 .44681 .00149 0 365.73 arc
F
.70323 .37361 m
.70323 .37361 .00228 0 365.73 arc
F
.66059 .30041 m
.66059 .30041 .00179 0 365.73 arc
F
.61795 .22721 m
.61795 .22721 .00058 0 365.73 arc
F
.87629 .79487 m
.87629 .79487 1e-005 0 365.73 arc
F
.83365 .72167 m
.83365 .72167 0 0 365.73 arc
F
.79101 .64847 m
.79101 .64847 .00013 0 365.73 arc
F
.74836 .57527 m
.74836 .57527 .00113 0 365.73 arc
F
.70572 .50207 m
.70572 .50207 .00314 0 365.73 arc
F
.66308 .42887 m
.66308 .42887 .00466 0 365.73 arc
F
.62044 .35567 m
.62044 .35567 .00407 0 365.73 arc
F
.5778 .28247 m
.5778 .28247 .00183 0 365.73 arc
F
.53515 .20927 m
.53515 .20927 .00021 0 365.73 arc
F
.83614 .85013 m
.83614 .85013 0 0 365.73 arc
F
.7935 .77694 m
.7935 .77694 0 0 365.73 arc
F
.75085 .70374 m
.75085 .70374 .00023 0 365.73 arc
F
.70821 .63054 m
.70821 .63054 .00166 0 365.73 arc
F
.66557 .55734 m
.66557 .55734 .00459 0 365.73 arc
F
.62293 .48414 m
.62293 .48414 .0072 0 365.73 arc
F
.58029 .41094 m
.58029 .41094 .00703 0 365.73 arc
F
.53764 .33774 m
.53764 .33774 .00396 0 365.73 arc
F
.495 .26454 m
.495 .26454 .00093 0 365.73 arc
F
.45236 .19134 m
.45236 .19134 0 0 365.73 arc
F
.79599 .9054 m
.79599 .9054 .0001 0 365.73 arc
F
.75334 .8322 m
.75334 .8322 5e-005 0 365.73 arc
F
.7107 .759 m
.7107 .759 .00013 0 365.73 arc
F
.66806 .6858 m
.66806 .6858 .00166 0 365.73 arc
F
.62542 .6126 m
.62542 .6126 .00511 0 365.73 arc
F
.58278 .5394 m
.58278 .5394 .00877 0 365.73 arc
F
.54013 .4662 m
.54013 .4662 .00962 0 365.73 arc
F
.49749 .393 m
.49749 .393 .00642 0 365.73 arc
F
.45485 .3198 m
.45485 .3198 .00218 0 365.73 arc
F
.41221 .2466 m
.41221 .2466 .00018 0 365.73 arc
F
.36956 .1734 m
.36956 .1734 5e-005 0 365.73 arc
F
.71319 .88746 m
.71319 .88746 .0004 0 365.73 arc
F
.67055 .81426 m
.67055 .81426 0 0 365.73 arc
F
.62791 .74107 m
.62791 .74107 .00113 0 365.73 arc
F
.58527 .66787 m
.58527 .66787 .00459 0 365.73 arc
F
.54262 .59467 m
.54262 .59467 .00877 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.45734 .44827 m
.45734 .44827 .0082 0 365.73 arc
F
.4147 .37507 m
.4147 .37507 .0035 0 365.73 arc
F
.37205 .30187 m
.37205 .30187 .0006 0 365.73 arc
F
.32941 .22867 m
.32941 .22867 0 0 365.73 arc
F
.28677 .15547 m
.28677 .15547 6e-005 0 365.73 arc
F
.6304 .86953 m
.6304 .86953 .00019 0 365.73 arc
F
.58775 .79633 m
.58775 .79633 .00039 0 365.73 arc
F
.54511 .72313 m
.54511 .72313 .00314 0 365.73 arc
F
.50247 .64993 m
.50247 .64993 .0072 0 365.73 arc
F
.45983 .57673 m
.45983 .57673 .00962 0 365.73 arc
F
.41719 .50353 m
.41719 .50353 .0082 0 365.73 arc
F
.37454 .43033 m
.37454 .43033 .00412 0 365.73 arc
F
.3319 .35713 m
.3319 .35713 .001 0 365.73 arc
F
.28926 .28393 m
.28926 .28393 5e-005 0 365.73 arc
F
.24662 .21073 m
.24662 .21073 1e-005 0 365.73 arc
F
.20398 .13753 m
.20398 .13753 1e-005 0 365.73 arc
F
.5476 .85159 m
.5476 .85159 1e-005 0 365.73 arc
F
.50496 .77839 m
.50496 .77839 .00149 0 365.73 arc
F
.46232 .7052 m
.46232 .7052 .00466 0 365.73 arc
F
.41968 .632 m
.41968 .632 .00703 0 365.73 arc
F
.37703 .5588 m
.37703 .5588 .00642 0 365.73 arc
F
.33439 .4856 m
.33439 .4856 .0035 0 365.73 arc
F
.29175 .4124 m
.29175 .4124 .001 0 365.73 arc
F
.24911 .3392 m
.24911 .3392 9e-005 0 365.73 arc
F
.20647 .266 m
.20647 .266 0 0 365.73 arc
F
.16382 .1928 m
.16382 .1928 0 0 365.73 arc
F
.46481 .83366 m
.46481 .83366 .00038 0 365.73 arc
F
.42217 .76046 m
.42217 .76046 .00228 0 365.73 arc
F
.37952 .68726 m
.37952 .68726 .00407 0 365.73 arc
F
.33688 .61406 m
.33688 .61406 .00396 0 365.73 arc
F
.29424 .54086 m
.29424 .54086 .00218 0 365.73 arc
F
.2516 .46766 m
.2516 .46766 .0006 0 365.73 arc
F
.20896 .39446 m
.20896 .39446 5e-005 0 365.73 arc
F
.16631 .32126 m
.16631 .32126 0 0 365.73 arc
F
.12367 .24806 m
.12367 .24806 0 0 365.73 arc
F
.38201 .81572 m
.38201 .81572 .00076 0 365.73 arc
F
.33937 .74252 m
.33937 .74252 .00179 0 365.73 arc
F
.29673 .66933 m
.29673 .66933 .00183 0 365.73 arc
F
.25409 .59613 m
.25409 .59613 .00093 0 365.73 arc
F
.21145 .52293 m
.21145 .52293 .00018 0 365.73 arc
F
.1688 .44973 m
.1688 .44973 0 0 365.73 arc
F
.12616 .37653 m
.12616 .37653 1e-005 0 365.73 arc
F
.08352 .30333 m
.08352 .30333 0 0 365.73 arc
F
.29922 .79779 m
.29922 .79779 .00055 0 365.73 arc
F
.25658 .72459 m
.25658 .72459 .00058 0 365.73 arc
F
.21394 .65139 m
.21394 .65139 .00021 0 365.73 arc
F
.17129 .57819 m
.17129 .57819 0 0 365.73 arc
F
.12865 .50499 m
.12865 .50499 5e-005 0 365.73 arc
F
.08601 .43179 m
.08601 .43179 6e-005 0 365.73 arc
F
.04337 .35859 m
.04337 .35859 1e-005 0 365.73 arc
F
.02382 .37995 m
.02382 .37995 1e-005 0 365.73 arc
F
.28322 .29567 m
.28322 .29567 .00114 0 365.73 arc
F
.24058 .60575 m
.24058 .60575 .00013 0 365.73 arc
F
.19794 .91583 m
.19794 .91583 5e-005 0 365.73 arc
F
.54262 .21139 m
.54262 .21139 .00114 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.45734 .83154 m
.45734 .83154 .00153 0 365.73 arc
F
.80202 .1271 m
.80202 .1271 1e-005 0 365.73 arc
F
.75938 .43718 m
.75938 .43718 .00013 0 365.73 arc
F
.71674 .74726 m
.71674 .74726 .00153 0 365.73 arc
F
.97614 .66298 m
.97614 .66298 5e-005 0 365.73 arc
F
.48618 1.00606 m
.48618 1.00606 .0001 0 365.73 arc
F
.54262 .94289 m
.54262 .94289 .0004 0 365.73 arc
F
.59906 .87971 m
.59906 .87971 .00019 0 365.73 arc
F
.6555 .81654 m
.6555 .81654 1e-005 0 365.73 arc
F
.71194 .75336 m
.71194 .75336 .00038 0 365.73 arc
F
.76838 .69019 m
.76838 .69019 .00076 0 365.73 arc
F
.82482 .62701 m
.82482 .62701 .00055 0 365.73 arc
F
.42121 .98495 m
.42121 .98495 0 0 365.73 arc
F
.47765 .92178 m
.47765 .92178 5e-005 0 365.73 arc
F
.53409 .8586 m
.53409 .8586 0 0 365.73 arc
F
.59053 .79543 m
.59053 .79543 .00039 0 365.73 arc
F
.64697 .73225 m
.64697 .73225 .00149 0 365.73 arc
F
.70341 .66908 m
.70341 .66908 .00228 0 365.73 arc
F
.75985 .6059 m
.75985 .6059 .00179 0 365.73 arc
F
.81629 .54273 m
.81629 .54273 .00058 0 365.73 arc
F
.35624 .96384 m
.35624 .96384 1e-005 0 365.73 arc
F
.41268 .90067 m
.41268 .90067 0 0 365.73 arc
F
.46912 .83749 m
.46912 .83749 .00013 0 365.73 arc
F
.52556 .77432 m
.52556 .77432 .00113 0 365.73 arc
F
.582 .71114 m
.582 .71114 .00314 0 365.73 arc
F
.63844 .64797 m
.63844 .64797 .00466 0 365.73 arc
F
.69488 .58479 m
.69488 .58479 .00407 0 365.73 arc
F
.75132 .52162 m
.75132 .52162 .00183 0 365.73 arc
F
.80776 .45844 m
.80776 .45844 .00021 0 365.73 arc
F
.29128 .94273 m
.29128 .94273 0 0 365.73 arc
F
.34772 .87956 m
.34772 .87956 0 0 365.73 arc
F
.40416 .81638 m
.40416 .81638 .00023 0 365.73 arc
F
.4606 .75321 m
.4606 .75321 .00166 0 365.73 arc
F
.51704 .69003 m
.51704 .69003 .00459 0 365.73 arc
F
.57348 .62686 m
.57348 .62686 .0072 0 365.73 arc
F
.62992 .56368 m
.62992 .56368 .00703 0 365.73 arc
F
.68636 .50051 m
.68636 .50051 .00396 0 365.73 arc
F
.7428 .43733 m
.7428 .43733 .00093 0 365.73 arc
F
.79924 .37416 m
.79924 .37416 0 0 365.73 arc
F
.22631 .92162 m
.22631 .92162 .0001 0 365.73 arc
F
.28275 .85845 m
.28275 .85845 5e-005 0 365.73 arc
F
.33919 .79527 m
.33919 .79527 .00013 0 365.73 arc
F
.39563 .7321 m
.39563 .7321 .00166 0 365.73 arc
F
.45207 .66892 m
.45207 .66892 .00511 0 365.73 arc
F
.50851 .60575 m
.50851 .60575 .00877 0 365.73 arc
F
.56495 .54257 m
.56495 .54257 .00962 0 365.73 arc
F
.62139 .4794 m
.62139 .4794 .00642 0 365.73 arc
F
.67783 .41622 m
.67783 .41622 .00218 0 365.73 arc
F
.73427 .35305 m
.73427 .35305 .00018 0 365.73 arc
F
.79071 .28987 m
.79071 .28987 5e-005 0 365.73 arc
F
.21778 .83734 m
.21778 .83734 .0004 0 365.73 arc
F
.27422 .77417 m
.27422 .77417 0 0 365.73 arc
F
.33066 .71099 m
.33066 .71099 .00113 0 365.73 arc
F
.3871 .64782 m
.3871 .64782 .00459 0 365.73 arc
F
.44354 .58464 m
.44354 .58464 .00877 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.55642 .45829 m
.55642 .45829 .0082 0 365.73 arc
F
.61286 .39512 m
.61286 .39512 .0035 0 365.73 arc
F
.6693 .33194 m
.6693 .33194 .0006 0 365.73 arc
F
.72574 .26877 m
.72574 .26877 0 0 365.73 arc
F
.78218 .20559 m
.78218 .20559 6e-005 0 365.73 arc
F
.20925 .75306 m
.20925 .75306 .00019 0 365.73 arc
F
.26569 .68988 m
.26569 .68988 .00039 0 365.73 arc
F
.32213 .62671 m
.32213 .62671 .00314 0 365.73 arc
F
.37857 .56353 m
.37857 .56353 .0072 0 365.73 arc
F
.43501 .50036 m
.43501 .50036 .00962 0 365.73 arc
F
.49145 .43718 m
.49145 .43718 .0082 0 365.73 arc
F
.54789 .37401 m
.54789 .37401 .00412 0 365.73 arc
F
.60433 .31083 m
.60433 .31083 .001 0 365.73 arc
F
.66077 .24766 m
.66077 .24766 5e-005 0 365.73 arc
F
.71721 .18448 m
.71721 .18448 1e-005 0 365.73 arc
F
.77365 .12131 m
.77365 .12131 1e-005 0 365.73 arc
F
.20073 .66877 m
.20073 .66877 1e-005 0 365.73 arc
F
.25717 .6056 m
.25717 .6056 .00149 0 365.73 arc
F
.31361 .54242 m
.31361 .54242 .00466 0 365.73 arc
F
.37005 .47925 m
.37005 .47925 .00703 0 365.73 arc
F
.42649 .41607 m
.42649 .41607 .00642 0 365.73 arc
F
.48293 .3529 m
.48293 .3529 .0035 0 365.73 arc
F
.53937 .28972 m
.53937 .28972 .001 0 365.73 arc
F
.59581 .22655 m
.59581 .22655 9e-005 0 365.73 arc
F
.65225 .16337 m
.65225 .16337 0 0 365.73 arc
F
.70869 .1002 m
.70869 .1002 0 0 365.73 arc
F
.1922 .58449 m
.1922 .58449 .00038 0 365.73 arc
F
.24864 .52131 m
.24864 .52131 .00228 0 365.73 arc
F
.30508 .45814 m
.30508 .45814 .00407 0 365.73 arc
F
.36152 .39496 m
.36152 .39496 .00396 0 365.73 arc
F
.41796 .33179 m
.41796 .33179 .00218 0 365.73 arc
F
.4744 .26861 m
.4744 .26861 .0006 0 365.73 arc
F
.53084 .20544 m
.53084 .20544 5e-005 0 365.73 arc
F
.58728 .14226 m
.58728 .14226 0 0 365.73 arc
F
.64372 .07909 m
.64372 .07909 0 0 365.73 arc
F
.18367 .5002 m
.18367 .5002 .00076 0 365.73 arc
F
.24011 .43703 m
.24011 .43703 .00179 0 365.73 arc
F
.29655 .37385 m
.29655 .37385 .00183 0 365.73 arc
F
.35299 .31068 m
.35299 .31068 .00093 0 365.73 arc
F
.40943 .2475 m
.40943 .2475 .00018 0 365.73 arc
F
.46587 .18433 m
.46587 .18433 0 0 365.73 arc
F
.52231 .12115 m
.52231 .12115 1e-005 0 365.73 arc
F
.57875 .05798 m
.57875 .05798 0 0 365.73 arc
F
.17514 .41592 m
.17514 .41592 .00055 0 365.73 arc
F
.23158 .35274 m
.23158 .35274 .00058 0 365.73 arc
F
.28802 .28957 m
.28802 .28957 .00021 0 365.73 arc
F
.34446 .22639 m
.34446 .22639 0 0 365.73 arc
F
.4009 .16322 m
.4009 .16322 5e-005 0 365.73 arc
F
.45734 .10004 m
.45734 .10004 6e-005 0 365.73 arc
F
.51378 .03687 m
.51378 .03687 1e-005 0 365.73 arc
F
.02382 .66298 m
.02382 .66298 1e-005 0 365.73 arc
F
.28322 .74726 m
.28322 .74726 .00114 0 365.73 arc
F
.24058 .43718 m
.24058 .43718 .00013 0 365.73 arc
F
.19794 .1271 m
.19794 .1271 5e-005 0 365.73 arc
F
.54262 .83154 m
.54262 .83154 .00114 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.45734 .21139 m
.45734 .21139 .00153 0 365.73 arc
F
.80202 .91583 m
.80202 .91583 1e-005 0 365.73 arc
F
.75938 .60575 m
.75938 .60575 .00013 0 365.73 arc
F
.71674 .29567 m
.71674 .29567 .00153 0 365.73 arc
F
.97614 .37995 m
.97614 .37995 5e-005 0 365.73 arc
F
.48742 .02488 m
.48742 .02488 1e-005 0 365.73 arc
F
.64774 .24554 m
.64774 .24554 .00114 0 365.73 arc
F
.33966 .30081 m
.33966 .30081 .00013 0 365.73 arc
F
.03158 .35607 m
.03158 .35607 5e-005 0 365.73 arc
F
.80806 .4662 m
.80806 .4662 .00114 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.1919 .57673 m
.1919 .57673 .00153 0 365.73 arc
F
.96838 .68686 m
.96838 .68686 1e-005 0 365.73 arc
F
.6603 .74212 m
.6603 .74212 .00013 0 365.73 arc
F
.35222 .79739 m
.35222 .79739 .00153 0 365.73 arc
F
.51254 1.01805 m
.51254 1.01805 5e-005 0 365.73 arc
F
.03484 .65809 m
.03484 .65809 .0001 0 365.73 arc
F
.11236 .69224 m
.11236 .69224 .0004 0 365.73 arc
F
.18989 .7264 m
.18989 .7264 .00019 0 365.73 arc
F
.26741 .76055 m
.26741 .76055 1e-005 0 365.73 arc
F
.34493 .79471 m
.34493 .79471 .00038 0 365.73 arc
F
.42246 .82887 m
.42246 .82887 .00076 0 365.73 arc
F
.49998 .86302 m
.49998 .86302 .00055 0 365.73 arc
F
.03484 .58978 m
.03484 .58978 0 0 365.73 arc
F
.11236 .62393 m
.11236 .62393 5e-005 0 365.73 arc
F
.18989 .65809 m
.18989 .65809 0 0 365.73 arc
F
.26741 .69224 m
.26741 .69224 .00039 0 365.73 arc
F
.34493 .7264 m
.34493 .7264 .00149 0 365.73 arc
F
.42246 .76055 m
.42246 .76055 .00228 0 365.73 arc
F
.49998 .79471 m
.49998 .79471 .00179 0 365.73 arc
F
.5775 .82887 m
.5775 .82887 .00058 0 365.73 arc
F
.03484 .52147 m
.03484 .52147 1e-005 0 365.73 arc
F
.11236 .55562 m
.11236 .55562 0 0 365.73 arc
F
.18989 .58978 m
.18989 .58978 .00013 0 365.73 arc
F
.26741 .62393 m
.26741 .62393 .00113 0 365.73 arc
F
.34493 .65809 m
.34493 .65809 .00314 0 365.73 arc
F
.42246 .69224 m
.42246 .69224 .00466 0 365.73 arc
F
.49998 .7264 m
.49998 .7264 .00407 0 365.73 arc
F
.5775 .76055 m
.5775 .76055 .00183 0 365.73 arc
F
.65503 .79471 m
.65503 .79471 .00021 0 365.73 arc
F
.03484 .45315 m
.03484 .45315 0 0 365.73 arc
F
.11236 .48731 m
.11236 .48731 0 0 365.73 arc
F
.18989 .52147 m
.18989 .52147 .00023 0 365.73 arc
F
.26741 .55562 m
.26741 .55562 .00166 0 365.73 arc
F
.34493 .58978 m
.34493 .58978 .00459 0 365.73 arc
F
.42246 .62393 m
.42246 .62393 .0072 0 365.73 arc
F
.49998 .65809 m
.49998 .65809 .00703 0 365.73 arc
F
.5775 .69224 m
.5775 .69224 .00396 0 365.73 arc
F
.65503 .7264 m
.65503 .7264 .00093 0 365.73 arc
F
.73255 .76055 m
.73255 .76055 0 0 365.73 arc
F
.03484 .38484 m
.03484 .38484 .0001 0 365.73 arc
F
.11236 .419 m
.11236 .419 5e-005 0 365.73 arc
F
.18989 .45315 m
.18989 .45315 .00013 0 365.73 arc
F
.26741 .48731 m
.26741 .48731 .00166 0 365.73 arc
F
.34493 .52147 m
.34493 .52147 .00511 0 365.73 arc
F
.42246 .55562 m
.42246 .55562 .00877 0 365.73 arc
F
.49998 .58978 m
.49998 .58978 .00962 0 365.73 arc
F
.5775 .62393 m
.5775 .62393 .00642 0 365.73 arc
F
.65503 .65809 m
.65503 .65809 .00218 0 365.73 arc
F
.73255 .69224 m
.73255 .69224 .00018 0 365.73 arc
F
.81008 .7264 m
.81008 .7264 5e-005 0 365.73 arc
F
.11236 .35069 m
.11236 .35069 .0004 0 365.73 arc
F
.18989 .38484 m
.18989 .38484 0 0 365.73 arc
F
.26741 .419 m
.26741 .419 .00113 0 365.73 arc
F
.34493 .45315 m
.34493 .45315 .00459 0 365.73 arc
F
.42246 .48731 m
.42246 .48731 .00877 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.5775 .55562 m
.5775 .55562 .0082 0 365.73 arc
F
.65503 .58978 m
.65503 .58978 .0035 0 365.73 arc
F
.73255 .62393 m
.73255 .62393 .0006 0 365.73 arc
F
.81008 .65809 m
.81008 .65809 0 0 365.73 arc
F
.8876 .69224 m
.8876 .69224 6e-005 0 365.73 arc
F
.18989 .31653 m
.18989 .31653 .00019 0 365.73 arc
F
.26741 .35069 m
.26741 .35069 .00039 0 365.73 arc
F
.34493 .38484 m
.34493 .38484 .00314 0 365.73 arc
F
.42246 .419 m
.42246 .419 .0072 0 365.73 arc
F
.49998 .45315 m
.49998 .45315 .00962 0 365.73 arc
F
.5775 .48731 m
.5775 .48731 .0082 0 365.73 arc
F
.65503 .52147 m
.65503 .52147 .00412 0 365.73 arc
F
.73255 .55562 m
.73255 .55562 .001 0 365.73 arc
F
.81008 .58978 m
.81008 .58978 5e-005 0 365.73 arc
F
.8876 .62393 m
.8876 .62393 1e-005 0 365.73 arc
F
.96512 .65809 m
.96512 .65809 1e-005 0 365.73 arc
F
.26741 .28238 m
.26741 .28238 1e-005 0 365.73 arc
F
.34493 .31653 m
.34493 .31653 .00149 0 365.73 arc
F
.42246 .35069 m
.42246 .35069 .00466 0 365.73 arc
F
.49998 .38484 m
.49998 .38484 .00703 0 365.73 arc
F
.5775 .419 m
.5775 .419 .00642 0 365.73 arc
F
.65503 .45315 m
.65503 .45315 .0035 0 365.73 arc
F
.73255 .48731 m
.73255 .48731 .001 0 365.73 arc
F
.81008 .52147 m
.81008 .52147 9e-005 0 365.73 arc
F
.8876 .55562 m
.8876 .55562 0 0 365.73 arc
F
.96512 .58978 m
.96512 .58978 0 0 365.73 arc
F
.34493 .24822 m
.34493 .24822 .00038 0 365.73 arc
F
.42246 .28238 m
.42246 .28238 .00228 0 365.73 arc
F
.49998 .31653 m
.49998 .31653 .00407 0 365.73 arc
F
.5775 .35069 m
.5775 .35069 .00396 0 365.73 arc
F
.65503 .38484 m
.65503 .38484 .00218 0 365.73 arc
F
.73255 .419 m
.73255 .419 .0006 0 365.73 arc
F
.81008 .45315 m
.81008 .45315 5e-005 0 365.73 arc
F
.8876 .48731 m
.8876 .48731 0 0 365.73 arc
F
.96512 .52147 m
.96512 .52147 0 0 365.73 arc
F
.42246 .21407 m
.42246 .21407 .00076 0 365.73 arc
F
.49998 .24822 m
.49998 .24822 .00179 0 365.73 arc
F
.5775 .28238 m
.5775 .28238 .00183 0 365.73 arc
F
.65503 .31653 m
.65503 .31653 .00093 0 365.73 arc
F
.73255 .35069 m
.73255 .35069 .00018 0 365.73 arc
F
.81008 .38484 m
.81008 .38484 0 0 365.73 arc
F
.8876 .419 m
.8876 .419 1e-005 0 365.73 arc
F
.96512 .45315 m
.96512 .45315 0 0 365.73 arc
F
.49998 .17991 m
.49998 .17991 .00055 0 365.73 arc
F
.5775 .21407 m
.5775 .21407 .00058 0 365.73 arc
F
.65503 .24822 m
.65503 .24822 .00021 0 365.73 arc
F
.73255 .28238 m
.73255 .28238 0 0 365.73 arc
F
.81008 .31653 m
.81008 .31653 5e-005 0 365.73 arc
F
.8876 .35069 m
.8876 .35069 6e-005 0 365.73 arc
F
.96512 .38484 m
.96512 .38484 1e-005 0 365.73 arc
F
.95659 .35859 m
.95659 .35859 .0001 0 365.73 arc
F
.91395 .43179 m
.91395 .43179 .0004 0 365.73 arc
F
.87131 .50499 m
.87131 .50499 .00019 0 365.73 arc
F
.82867 .57819 m
.82867 .57819 1e-005 0 365.73 arc
F
.78603 .65139 m
.78603 .65139 .00038 0 365.73 arc
F
.74338 .72459 m
.74338 .72459 .00076 0 365.73 arc
F
.70074 .79779 m
.70074 .79779 .00055 0 365.73 arc
F
.91644 .30333 m
.91644 .30333 0 0 365.73 arc
F
.8738 .37653 m
.8738 .37653 5e-005 0 365.73 arc
F
.83116 .44973 m
.83116 .44973 0 0 365.73 arc
F
.78852 .52293 m
.78852 .52293 .00039 0 365.73 arc
F
.74587 .59613 m
.74587 .59613 .00149 0 365.73 arc
F
.70323 .66933 m
.70323 .66933 .00228 0 365.73 arc
F
.66059 .74252 m
.66059 .74252 .00179 0 365.73 arc
F
.61795 .81572 m
.61795 .81572 .00058 0 365.73 arc
F
.87629 .24806 m
.87629 .24806 1e-005 0 365.73 arc
F
.83365 .32126 m
.83365 .32126 0 0 365.73 arc
F
.79101 .39446 m
.79101 .39446 .00013 0 365.73 arc
F
.74836 .46766 m
.74836 .46766 .00113 0 365.73 arc
F
.70572 .54086 m
.70572 .54086 .00314 0 365.73 arc
F
.66308 .61406 m
.66308 .61406 .00466 0 365.73 arc
F
.62044 .68726 m
.62044 .68726 .00407 0 365.73 arc
F
.5778 .76046 m
.5778 .76046 .00183 0 365.73 arc
F
.53515 .83366 m
.53515 .83366 .00021 0 365.73 arc
F
.83614 .1928 m
.83614 .1928 0 0 365.73 arc
F
.7935 .266 m
.7935 .266 0 0 365.73 arc
F
.75085 .3392 m
.75085 .3392 .00023 0 365.73 arc
F
.70821 .4124 m
.70821 .4124 .00166 0 365.73 arc
F
.66557 .4856 m
.66557 .4856 .00459 0 365.73 arc
F
.62293 .5588 m
.62293 .5588 .0072 0 365.73 arc
F
.58029 .632 m
.58029 .632 .00703 0 365.73 arc
F
.53764 .7052 m
.53764 .7052 .00396 0 365.73 arc
F
.495 .77839 m
.495 .77839 .00093 0 365.73 arc
F
.45236 .85159 m
.45236 .85159 0 0 365.73 arc
F
.79599 .13753 m
.79599 .13753 .0001 0 365.73 arc
F
.75334 .21073 m
.75334 .21073 5e-005 0 365.73 arc
F
.7107 .28393 m
.7107 .28393 .00013 0 365.73 arc
F
.66806 .35713 m
.66806 .35713 .00166 0 365.73 arc
F
.62542 .43033 m
.62542 .43033 .00511 0 365.73 arc
F
.58278 .50353 m
.58278 .50353 .00877 0 365.73 arc
F
.54013 .57673 m
.54013 .57673 .00962 0 365.73 arc
F
.49749 .64993 m
.49749 .64993 .00642 0 365.73 arc
F
.45485 .72313 m
.45485 .72313 .00218 0 365.73 arc
F
.41221 .79633 m
.41221 .79633 .00018 0 365.73 arc
F
.36956 .86953 m
.36956 .86953 5e-005 0 365.73 arc
F
.71319 .15547 m
.71319 .15547 .0004 0 365.73 arc
F
.67055 .22867 m
.67055 .22867 0 0 365.73 arc
F
.62791 .30187 m
.62791 .30187 .00113 0 365.73 arc
F
.58527 .37507 m
.58527 .37507 .00459 0 365.73 arc
F
.54262 .44827 m
.54262 .44827 .00877 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.45734 .59467 m
.45734 .59467 .0082 0 365.73 arc
F
.4147 .66787 m
.4147 .66787 .0035 0 365.73 arc
F
.37205 .74107 m
.37205 .74107 .0006 0 365.73 arc
F
.32941 .81426 m
.32941 .81426 0 0 365.73 arc
F
.28677 .88746 m
.28677 .88746 6e-005 0 365.73 arc
F
.6304 .1734 m
.6304 .1734 .00019 0 365.73 arc
F
.58775 .2466 m
.58775 .2466 .00039 0 365.73 arc
F
.54511 .3198 m
.54511 .3198 .00314 0 365.73 arc
F
.50247 .393 m
.50247 .393 .0072 0 365.73 arc
F
.45983 .4662 m
.45983 .4662 .00962 0 365.73 arc
F
.41719 .5394 m
.41719 .5394 .0082 0 365.73 arc
F
.37454 .6126 m
.37454 .6126 .00412 0 365.73 arc
F
.3319 .6858 m
.3319 .6858 .001 0 365.73 arc
F
.28926 .759 m
.28926 .759 5e-005 0 365.73 arc
F
.24662 .8322 m
.24662 .8322 1e-005 0 365.73 arc
F
.20398 .9054 m
.20398 .9054 1e-005 0 365.73 arc
F
.5476 .19134 m
.5476 .19134 1e-005 0 365.73 arc
F
.50496 .26454 m
.50496 .26454 .00149 0 365.73 arc
F
.46232 .33774 m
.46232 .33774 .00466 0 365.73 arc
F
.41968 .41094 m
.41968 .41094 .00703 0 365.73 arc
F
.37703 .48414 m
.37703 .48414 .00642 0 365.73 arc
F
.33439 .55734 m
.33439 .55734 .0035 0 365.73 arc
F
.29175 .63054 m
.29175 .63054 .001 0 365.73 arc
F
.24911 .70374 m
.24911 .70374 9e-005 0 365.73 arc
F
.20647 .77694 m
.20647 .77694 0 0 365.73 arc
F
.16382 .85013 m
.16382 .85013 0 0 365.73 arc
F
.46481 .20927 m
.46481 .20927 .00038 0 365.73 arc
F
.42217 .28247 m
.42217 .28247 .00228 0 365.73 arc
F
.37952 .35567 m
.37952 .35567 .00407 0 365.73 arc
F
.33688 .42887 m
.33688 .42887 .00396 0 365.73 arc
F
.29424 .50207 m
.29424 .50207 .00218 0 365.73 arc
F
.2516 .57527 m
.2516 .57527 .0006 0 365.73 arc
F
.20896 .64847 m
.20896 .64847 5e-005 0 365.73 arc
F
.16631 .72167 m
.16631 .72167 0 0 365.73 arc
F
.12367 .79487 m
.12367 .79487 0 0 365.73 arc
F
.38201 .22721 m
.38201 .22721 .00076 0 365.73 arc
F
.33937 .30041 m
.33937 .30041 .00179 0 365.73 arc
F
.29673 .37361 m
.29673 .37361 .00183 0 365.73 arc
F
.25409 .44681 m
.25409 .44681 .00093 0 365.73 arc
F
.21145 .52001 m
.21145 .52001 .00018 0 365.73 arc
F
.1688 .59321 m
.1688 .59321 0 0 365.73 arc
F
.12616 .66641 m
.12616 .66641 1e-005 0 365.73 arc
F
.08352 .73961 m
.08352 .73961 0 0 365.73 arc
F
.29922 .24514 m
.29922 .24514 .00055 0 365.73 arc
F
.25658 .31834 m
.25658 .31834 .00058 0 365.73 arc
F
.21394 .39154 m
.21394 .39154 .00021 0 365.73 arc
F
.17129 .46474 m
.17129 .46474 0 0 365.73 arc
F
.12865 .53794 m
.12865 .53794 5e-005 0 365.73 arc
F
.08601 .61114 m
.08601 .61114 6e-005 0 365.73 arc
F
.04337 .68434 m
.04337 .68434 1e-005 0 365.73 arc
F
.21826 .11234 m
.21826 .11234 1e-005 0 365.73 arc
F
.21826 .38509 m
.21826 .38509 .00114 0 365.73 arc
F
.49998 .24872 m
.49998 .24872 .00013 0 365.73 arc
F
.78171 .11234 m
.78171 .11234 5e-005 0 365.73 arc
F
.21826 .65784 m
.21826 .65784 .00114 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.78171 .38509 m
.78171 .38509 .00153 0 365.73 arc
F
.21826 .93059 m
.21826 .93059 1e-005 0 365.73 arc
F
.49998 .79422 m
.49998 .79422 .00013 0 365.73 arc
F
.78171 .65784 m
.78171 .65784 .00153 0 365.73 arc
F
.78171 .93059 m
.78171 .93059 5e-005 0 365.73 arc
F
.96838 .35607 m
.96838 .35607 1e-005 0 365.73 arc
F
.80806 .57673 m
.80806 .57673 .00114 0 365.73 arc
F
.6603 .30081 m
.6603 .30081 .00013 0 365.73 arc
F
.51254 .02488 m
.51254 .02488 5e-005 0 365.73 arc
F
.64774 .79739 m
.64774 .79739 .00114 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.35222 .24554 m
.35222 .24554 .00153 0 365.73 arc
F
.48742 1.01805 m
.48742 1.01805 1e-005 0 365.73 arc
F
.33966 .74212 m
.33966 .74212 .00013 0 365.73 arc
F
.1919 .4662 m
.1919 .4662 .00153 0 365.73 arc
F
.03158 .68686 m
.03158 .68686 5e-005 0 365.73 arc
F
.22631 .12131 m
.22631 .12131 .0001 0 365.73 arc
F
.21778 .20559 m
.21778 .20559 .0004 0 365.73 arc
F
.20925 .28987 m
.20925 .28987 .00019 0 365.73 arc
F
.20073 .37416 m
.20073 .37416 1e-005 0 365.73 arc
F
.1922 .45844 m
.1922 .45844 .00038 0 365.73 arc
F
.18367 .54273 m
.18367 .54273 .00076 0 365.73 arc
F
.17514 .62701 m
.17514 .62701 .00055 0 365.73 arc
F
.29128 .1002 m
.29128 .1002 0 0 365.73 arc
F
.28275 .18448 m
.28275 .18448 5e-005 0 365.73 arc
F
.27422 .26877 m
.27422 .26877 0 0 365.73 arc
F
.26569 .35305 m
.26569 .35305 .00039 0 365.73 arc
F
.25717 .43733 m
.25717 .43733 .00149 0 365.73 arc
F
.24864 .52162 m
.24864 .52162 .00228 0 365.73 arc
F
.24011 .6059 m
.24011 .6059 .00179 0 365.73 arc
F
.23158 .69019 m
.23158 .69019 .00058 0 365.73 arc
F
.35624 .07909 m
.35624 .07909 1e-005 0 365.73 arc
F
.34772 .16337 m
.34772 .16337 0 0 365.73 arc
F
.33919 .24766 m
.33919 .24766 .00013 0 365.73 arc
F
.33066 .33194 m
.33066 .33194 .00113 0 365.73 arc
F
.32213 .41622 m
.32213 .41622 .00314 0 365.73 arc
F
.31361 .50051 m
.31361 .50051 .00466 0 365.73 arc
F
.30508 .58479 m
.30508 .58479 .00407 0 365.73 arc
F
.29655 .66908 m
.29655 .66908 .00183 0 365.73 arc
F
.28802 .75336 m
.28802 .75336 .00021 0 365.73 arc
F
.42121 .05798 m
.42121 .05798 0 0 365.73 arc
F
.41268 .14226 m
.41268 .14226 0 0 365.73 arc
F
.40416 .22655 m
.40416 .22655 .00023 0 365.73 arc
F
.39563 .31083 m
.39563 .31083 .00166 0 365.73 arc
F
.3871 .39512 m
.3871 .39512 .00459 0 365.73 arc
F
.37857 .4794 m
.37857 .4794 .0072 0 365.73 arc
F
.37005 .56368 m
.37005 .56368 .00703 0 365.73 arc
F
.36152 .64797 m
.36152 .64797 .00396 0 365.73 arc
F
.35299 .73225 m
.35299 .73225 .00093 0 365.73 arc
F
.34446 .81654 m
.34446 .81654 0 0 365.73 arc
F
.48618 .03687 m
.48618 .03687 .0001 0 365.73 arc
F
.47765 .12115 m
.47765 .12115 5e-005 0 365.73 arc
F
.46912 .20544 m
.46912 .20544 .00013 0 365.73 arc
F
.4606 .28972 m
.4606 .28972 .00166 0 365.73 arc
F
.45207 .37401 m
.45207 .37401 .00511 0 365.73 arc
F
.44354 .45829 m
.44354 .45829 .00877 0 365.73 arc
F
.43501 .54257 m
.43501 .54257 .00962 0 365.73 arc
F
.42649 .62686 m
.42649 .62686 .00642 0 365.73 arc
F
.41796 .71114 m
.41796 .71114 .00218 0 365.73 arc
F
.40943 .79543 m
.40943 .79543 .00018 0 365.73 arc
F
.4009 .87971 m
.4009 .87971 5e-005 0 365.73 arc
F
.54262 .10004 m
.54262 .10004 .0004 0 365.73 arc
F
.53409 .18433 m
.53409 .18433 0 0 365.73 arc
F
.52556 .26861 m
.52556 .26861 .00113 0 365.73 arc
F
.51704 .3529 m
.51704 .3529 .00459 0 365.73 arc
F
.50851 .43718 m
.50851 .43718 .00877 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.49145 .60575 m
.49145 .60575 .0082 0 365.73 arc
F
.48293 .69003 m
.48293 .69003 .0035 0 365.73 arc
F
.4744 .77432 m
.4744 .77432 .0006 0 365.73 arc
F
.46587 .8586 m
.46587 .8586 0 0 365.73 arc
F
.45734 .94289 m
.45734 .94289 6e-005 0 365.73 arc
F
.59906 .16322 m
.59906 .16322 .00019 0 365.73 arc
F
.59053 .2475 m
.59053 .2475 .00039 0 365.73 arc
F
.582 .33179 m
.582 .33179 .00314 0 365.73 arc
F
.57348 .41607 m
.57348 .41607 .0072 0 365.73 arc
F
.56495 .50036 m
.56495 .50036 .00962 0 365.73 arc
F
.55642 .58464 m
.55642 .58464 .0082 0 365.73 arc
F
.54789 .66892 m
.54789 .66892 .00412 0 365.73 arc
F
.53937 .75321 m
.53937 .75321 .001 0 365.73 arc
F
.53084 .83749 m
.53084 .83749 5e-005 0 365.73 arc
F
.52231 .92178 m
.52231 .92178 1e-005 0 365.73 arc
F
.51378 1.00606 m
.51378 1.00606 1e-005 0 365.73 arc
F
.6555 .22639 m
.6555 .22639 1e-005 0 365.73 arc
F
.64697 .31068 m
.64697 .31068 .00149 0 365.73 arc
F
.63844 .39496 m
.63844 .39496 .00466 0 365.73 arc
F
.62992 .47925 m
.62992 .47925 .00703 0 365.73 arc
F
.62139 .56353 m
.62139 .56353 .00642 0 365.73 arc
F
.61286 .64782 m
.61286 .64782 .0035 0 365.73 arc
F
.60433 .7321 m
.60433 .7321 .001 0 365.73 arc
F
.59581 .81638 m
.59581 .81638 9e-005 0 365.73 arc
F
.58728 .90067 m
.58728 .90067 0 0 365.73 arc
F
.57875 .98495 m
.57875 .98495 0 0 365.73 arc
F
.71194 .28957 m
.71194 .28957 .00038 0 365.73 arc
F
.70341 .37385 m
.70341 .37385 .00228 0 365.73 arc
F
.69488 .45814 m
.69488 .45814 .00407 0 365.73 arc
F
.68636 .54242 m
.68636 .54242 .00396 0 365.73 arc
F
.67783 .62671 m
.67783 .62671 .00218 0 365.73 arc
F
.6693 .71099 m
.6693 .71099 .0006 0 365.73 arc
F
.66077 .79527 m
.66077 .79527 5e-005 0 365.73 arc
F
.65225 .87956 m
.65225 .87956 0 0 365.73 arc
F
.64372 .96384 m
.64372 .96384 0 0 365.73 arc
F
.76838 .35274 m
.76838 .35274 .00076 0 365.73 arc
F
.75985 .43703 m
.75985 .43703 .00179 0 365.73 arc
F
.75132 .52131 m
.75132 .52131 .00183 0 365.73 arc
F
.7428 .6056 m
.7428 .6056 .00093 0 365.73 arc
F
.73427 .68988 m
.73427 .68988 .00018 0 365.73 arc
F
.72574 .77417 m
.72574 .77417 0 0 365.73 arc
F
.71721 .85845 m
.71721 .85845 1e-005 0 365.73 arc
F
.70869 .94273 m
.70869 .94273 0 0 365.73 arc
F
.82482 .41592 m
.82482 .41592 .00055 0 365.73 arc
F
.81629 .5002 m
.81629 .5002 .00058 0 365.73 arc
F
.80776 .58449 m
.80776 .58449 .00021 0 365.73 arc
F
.79924 .66877 m
.79924 .66877 0 0 365.73 arc
F
.79071 .75306 m
.79071 .75306 5e-005 0 365.73 arc
F
.78218 .83734 m
.78218 .83734 6e-005 0 365.73 arc
F
.77365 .92162 m
.77365 .92162 1e-005 0 365.73 arc
F
0 g
.70074 .24514 m
.70074 .24514 .01066 0 365.73 arc
F
.66059 .30041 m
.66059 .30041 .01066 0 365.73 arc
F
.62044 .35567 m
.62044 .35567 .01066 0 365.73 arc
F
.58029 .41094 m
.58029 .41094 .01066 0 365.73 arc
F
.54013 .4662 m
.54013 .4662 .01066 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.45983 .57673 m
.45983 .57673 .01066 0 365.73 arc
F
.41968 .632 m
.41968 .632 .01066 0 365.73 arc
F
.37952 .68726 m
.37952 .68726 .01066 0 365.73 arc
F
.33937 .74252 m
.33937 .74252 .01066 0 365.73 arc
F
.29922 .79779 m
.29922 .79779 .01066 0 365.73 arc
F
.24058 .60575 m
.24058 .60575 .01066 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.75938 .43718 m
.75938 .43718 .01066 0 365.73 arc
F
.82482 .62701 m
.82482 .62701 .01066 0 365.73 arc
F
.75985 .6059 m
.75985 .6059 .01066 0 365.73 arc
F
.69488 .58479 m
.69488 .58479 .01066 0 365.73 arc
F
.62992 .56368 m
.62992 .56368 .01066 0 365.73 arc
F
.56495 .54257 m
.56495 .54257 .01066 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.43501 .50036 m
.43501 .50036 .01066 0 365.73 arc
F
.37005 .47925 m
.37005 .47925 .01066 0 365.73 arc
F
.30508 .45814 m
.30508 .45814 .01066 0 365.73 arc
F
.24011 .43703 m
.24011 .43703 .01066 0 365.73 arc
F
.17514 .41592 m
.17514 .41592 .01066 0 365.73 arc
F
.24058 .43718 m
.24058 .43718 .01066 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.75938 .60575 m
.75938 .60575 .01066 0 365.73 arc
F
.33966 .30081 m
.33966 .30081 .01066 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.6603 .74212 m
.6603 .74212 .01066 0 365.73 arc
F
.49998 .86302 m
.49998 .86302 .01066 0 365.73 arc
F
.49998 .79471 m
.49998 .79471 .01066 0 365.73 arc
F
.49998 .7264 m
.49998 .7264 .01066 0 365.73 arc
F
.49998 .65809 m
.49998 .65809 .01066 0 365.73 arc
F
.49998 .58978 m
.49998 .58978 .01066 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.49998 .45315 m
.49998 .45315 .01066 0 365.73 arc
F
.49998 .38484 m
.49998 .38484 .01066 0 365.73 arc
F
.49998 .31653 m
.49998 .31653 .01066 0 365.73 arc
F
.49998 .24822 m
.49998 .24822 .01066 0 365.73 arc
F
.49998 .17991 m
.49998 .17991 .01066 0 365.73 arc
F
.70074 .79779 m
.70074 .79779 .01066 0 365.73 arc
F
.66059 .74252 m
.66059 .74252 .01066 0 365.73 arc
F
.62044 .68726 m
.62044 .68726 .01066 0 365.73 arc
F
.58029 .632 m
.58029 .632 .01066 0 365.73 arc
F
.54013 .57673 m
.54013 .57673 .01066 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.45983 .4662 m
.45983 .4662 .01066 0 365.73 arc
F
.41968 .41094 m
.41968 .41094 .01066 0 365.73 arc
F
.37952 .35567 m
.37952 .35567 .01066 0 365.73 arc
F
.33937 .30041 m
.33937 .30041 .01066 0 365.73 arc
F
.29922 .24514 m
.29922 .24514 .01066 0 365.73 arc
F
.49998 .24872 m
.49998 .24872 .01066 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.49998 .79422 m
.49998 .79422 .01066 0 365.73 arc
F
.6603 .30081 m
.6603 .30081 .01066 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.33966 .74212 m
.33966 .74212 .01066 0 365.73 arc
F
.17514 .62701 m
.17514 .62701 .01066 0 365.73 arc
F
.24011 .6059 m
.24011 .6059 .01066 0 365.73 arc
F
.30508 .58479 m
.30508 .58479 .01066 0 365.73 arc
F
.37005 .56368 m
.37005 .56368 .01066 0 365.73 arc
F
.43501 .54257 m
.43501 .54257 .01066 0 365.73 arc
F
.49998 .52147 m
.49998 .52147 .01066 0 365.73 arc
F
.56495 .50036 m
.56495 .50036 .01066 0 365.73 arc
F
.62992 .47925 m
.62992 .47925 .01066 0 365.73 arc
F
.69488 .45814 m
.69488 .45814 .01066 0 365.73 arc
F
.75985 .43703 m
.75985 .43703 .01066 0 365.73 arc
F
.82482 .41592 m
.82482 .41592 .01066 0 365.73 arc
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[473]:=",
  ImageSize->{276.125, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004D00017`P10`40000100000?l0003o0?oo0000
ool0o`3ooooooeEEELIaLG76LHj>>75aaXhhSSR>SZZZZTaaWJjT^IbS`UMKKMOJi[NUd>?KkFQNMmoK
hf5LJ9nF/MOCgeMBHJVZ_MgMiEmOJPX:2Q@D51hN7RPX:3<c<cdm?DM7Ae5ADE]KFfIVIW1`L7YjNXB4
Q8j>SYVIVJ>SXjf][KNg]l71`Lc<c=KFe^3Ph>[Zj_Cdm92AXNOTjUMBG7EjT^7SkDiAHNGVjgn0S]CE
gUAEGRTZ;RLW9b40<?oo_hNZb/kMjT]OL@00?iFO_Ooo7W=cLda<C820P9F<W];>eU1;EK:_]Bl]<gmo
OiB;WMKBg2XX;H=kRhjYUM3KddiMD^GQY9no_m[ViUY]KFF0V=_Vkd=EIB4Z<FYoL4mOGbL_;n;/k<oO
ggN?Sl?Ei8EhU000O`00_`0o000o?`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2oO`2o_`2o
o`3o?`3oO`3o_cl003l0?cl0Ocl0_cl0oclo03lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOkno_knookoo0;oo?kooOkoo_kooool0?ol0Ool0
_olo0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOlS3cdDnCFml
S[g3bcU0B]C>N7j0VLG6dD52Cf]]PW5VO]_Ggd8lBVIbVOoo0_oo1mWIhEiPLko0c3m0C1lO9FAJKk>i
c=;EhC<iC1TL9DaELeioI[C3]c11=20M9<:lbTIOC8RZVOl75@L00?l75@L00?l75@L00?l75@L00?l7
5@L00?l75@L008H700=D1`L010L00e@71`241`00o`LE1`00o`LE1`00o`LE1`00Q@L00e@71`051`03
E0L708@7003o1aD7003o1aD7003o1aD7003o1aD7003o1aD7001c1`03E0L702T700=D1`L0LPL00?l7
5@L00?l75@L00?l75@L00?l75@L0068700=D1`L0C0L00e@71`1P1`00o`LE1`00o`LE1`00o`LE1`00
o`LE1`00o`LE1`00D0L00e@71`0Z1`03E0L701D700=D1`L0:PL00e@71`1?1`00o`LE1`00o`LE1`00
?0L00e@71`2H1`03E0L703X7003o1aD7003o1aD7000n1`03E0L7048700=D1`L02@L00e@71`121`03
E0L703d7003o1aD7000f1`03E0L70:<700=D1`L0=@L00?l75@L003P700=D1`L0W`L2E3P7003o1aD7
001a1`03E0L702d700=D1`L0L0L00?l75@L00?l75@L004h700=D1`L0L`L00e@71`1=1`00o`LE1`00
KPL00e@71`0c1`03E0L706d7001O1`03E0L7048700=D1`L030L00e@71`1N1`00o`LE1`00I@L00e@7
1`0O1`@08PL00e@71`1T1`00Q`L408T700261`H0R0L004d700=D1`L0<0L00e@71`031`H01PL00e@7
1`0`1`03E0L704`700271`@0R@L007`700=D1`L05`L00e@71`1k1`00;@L00e@71`2f1`03E0L702/7
003o1aD7003o1aD7000k1`9DA0L00e@71`0>1`03E0L7048700=D1`L0>PL007l700=D1`L04@L00e@7
1`1n1`00@`L00e@71`0^1`03E0L700H70U@E1`9D20L2E2l700=D1`L0@PL007@700=D1`L0W@L00?l7
5@L00?l75@L005X700ED1`L7E0091`9D1@L00e@71`0a1`03E0L700<70U@91`05E0L71e@0F`L00?l7
5@L00?l75@L00507101Z1`D0D@L00507100c1`@0<`L50547001?1`H02`L2E0l700=D1`L04`L401H7
00=D1`L03@L2E0X71P1A1`008PL00e@71`0Z1`H020L3E10700=D1`L04`L601D70U@A1`9D1`L602h7
00=D1`L080L00507100b1`H0<PL4058700271`@0R@L00?l75@L008L70U@00`MDE0281`00>0L00e@7
1`171`03E0L700D700=D1`L00`L00e@71`171`03E0L703L7001;1`03E0L703@700=D1`L02`L00e@7
1`0d1`03E0L704X7003o1aD7003o1aD700191`03E0L702L70U@Y1`9D:@L00e@71`181`00C`L00e@7
1`0Q1`03E0L702P700=D1`L08PL00e@71`1>1`00>@L00e@71`0C1`03E0L702`70U@D1`03E0L702`7
00=D1`L04`L00e@71`0h1`00F`L401l700=D1`L04`L00e@71`0L1`@0G@L004d70U@<1`@0E0L400d7
0UA>1`00FPL600H700=D1`L0B@L605`7000F1`03E0L704471P061`03E0L704<70U@41`H0A0L00e@7
1`0E1`00F`L405@7101M1`00H0L2E0X70U@I1`@06PL2E0X70UAQ1`00QPL508T7000d1`03E0L700l7
00=D1`L05@L2E2H71P0W1`9D5`L00e@71`0?1`03E0L703<7000]1`03E0L704`70U@81`H02@L2E4h7
00=D1`L0;0L008L710291`00o`LE1`00FPL2E1H70U@[1`03E0L701D70UAK1`00OPL2E1<700=D1`L0
OPL004@700=D1`L0=`L2E1<700=D1`L0>0L00e@71`131`00o`LE1`00IPL303l70`1Y1`007PL2E1l7
00=D1`L01`L00e@71`0J1`@020L3E1P70U@>1`9D2@L401d700=D1`L01`L00e@71`0N1`03E0L701d7
000o1`03E0L700H70U@K1`D02@L2E0h70U@71`=D3`L00e@71`061`D07@L2E0P700=D1`L0?PL000P7
00AD1`MDC`L00e@71`071`H08PL2E1P71P0:1`9DCPL015@71e@91`00IPL403h7101X1`00J0L20407
0P1X1`00o`LE1`00=`L00e@71`0G1`9D9`L3E1P70U@91`03E0L701d70eAA1`008PL00e@71`0B1`03
E0L703L70U@81`9D60L2E0P70e@i1`03E0L7018700=D1`L08@L000H700=D1`L0OPL401D700=D1`L0
J@L00e@71`051`002@L00e@71`0X1`03E0L704l71@1C1`03E0L702P700=D1`L020L003/700=D1`L0
80L00e@71`0U1`H09`L00e@71`0P1`03E0L703/7000j1`03E0L704X7101=1`03E0L703T7000i1`03
E0L702H70U@51`9D70L2E08000=D1`L06@L2E0D70U@Y1`03E0L703P7001R1`9D1@L2E1`715@L1`9D
1@L2E6@7003o1aD7001a1`@0:0L407<7000^1`@0?PL502L71@0o1`D0;`L002h7100M1`9D7`L602H7
1P0P1`9D70L502l7000]1`H090L2E1P71@000e@71`0R1`9D1@0n1`D0;`L001h700=D1`L030L601H7
00=D1`L02`L2E1P710000e@71`0T1`03E0000080:0L00e@71`0D1`D03`L00e@71`0M1`00;PL40407
0e@X1`=D@0L40307001K1`9DF0L2E5d7000G1`03E0L702H7100G1`9D20L3E2870e@M1`=D20L2E1L7
1@0X1`03E0L701H700101`@08PL00e@71`0L1`=D0PL3E1h70U@Q1`D0@@L003l71P000`MDE00l1`YD
?PL00e@000040447000o1`H0@0L3E08715@51`AD=PL60447000o1`D0>0L3E0P71002E0H715@g1`D0
@@L002h700=D1`L050L00e@71`0c1`ED1`L400L71E@e1`03E0L701D700=D1`L0;@L000T700=D1`L0
:0L00e@71`0J1`D01`L3E1P70e@00`MDE002E0H71P061`QD6@L00e@71`071`@07@L00e@71`0X1`03
E0L700P7001A1`D01`L2E1T70e@21`9D1`L600L70e@010MDE5@I1`03E0L700H71@1C1`00=0L00e@7
1`0J1`D08@L5E0@01`L400L71005E2471P0L1`03E0L703<7000_1`03E0L701l71@0R1`=D00<70000
0P0B1`@000@7E5AD8`L5024700=D1`L0;PL003@70U@?1`03E0L700T7100V1`H040L602H7100<1`9D
3`L00e@71`0c1`00H`L401@71P0@1`H050L306H7001S1`D000=D1`L04@L40187100E1`@0I@L00687
1P000e@71`0n1`03E00000<0I@L006871P02E0P715@W1`=D2@L00e@0000406@7001K1`03E0L700D7
1002E0T715@W1`=D2@L2E0@01PL3E14700=D1`L0B0L001h700=D1`L0:0L2E10700=D1`L01`L20003
E0L700L71E@V1`ED20L3E0031`0000L700=D1`L040L00e@71`0X1`03E0L701d7001b1`=D100P1`@0
0eAd1`00M@L40207101g1`00<PL00e@71`0P1`9D6PL3E0H07PL600AD6@L2E2<700=D1`L0<@L002<7
00=D1`L0:PL2E0<70U@I1`AD1P0N1`H015@J1`03E0L700870U@/1`03E0L70287000S1`03E0L704X7
1E@402071005E4d700=D1`L08PL007470e@Z1`ADLPL008L710291`00Q`L408T700091`03E0L702P7
00=D1`L00`L00e@71`061`03E0L701L70e@V1`H09`L2E1T70U@81`9D10L00e@71`0X1`03E0L700P7
001M1`9D9`L602L70U@S1`03E0L703T700271`@0R@L00?l75@L007470e@00`L00002020710000`MD
E002E787000S1`03E0L702X70U@N1`ED100P1`@01E@O1`=D:`L00e@71`0R1`00<PL00e@71`0K1`03
E0L700870U@J1`=D1P0N1`H015@I1`9D10L00e@71`0L1`03E0L70347001E1`9D6`L2E0H07PL600AD
6PL00e@71`1E1`00LPL3E0@080L400=DM0L001h700=D1`L0:0L2E2H71E@V1`AD2PL2E1d700=D1`L0
:0L00e@71`0M1`00F`L00e@71`051`D000=D1`L01PL5E2H71E@81`9D10061`=D4@L00e@71`181`00
F`L00e@71`041`H000=D1`L01`L3E2P70e@91`03E00000<01`L00e@71`1K1`00HPL6009D?`L00e@0
000406@7001S1`D000=D1`L04@L40187100C1`9D1@1T1`00H`L401D7100B1`@05@L406D7000d1`9D
3`L00e@71`0c1`H040L603H70U@?1`03E0L703<7000_1`03E0L7008700=D1`L06PL502870e@60107
1P03E2<7100M1`03E0L7008700=D1`L0;PL003@700=D1`L06PL5024715@00`L0000200L710071`@0
15@R1`D07@L00e@71`0c1`00D@L502471E@;1`@02`L5E2471P1B1`002@L00e@71`0X1`03E0L701X7
10081`=D60L3E0041eADE0L71P071`MD6@L2E0P7100M1`03E0L702P700=D1`L020L002h700=D1`L0
8PL200P70U@L1`ED1PL600H71E@X1`808`L00e@71`0]1`00@0L400031eAD03@71E@71`@01`L5E3D7
0U@5044700101`@0>0L3E0H70e@21`=D1PL3E3P71@111`00?`L600031eAD03`72U@n1`03E00000@0
@@L003l71P0o1`YD?`L60447000G1`03E0L702D71@0G1`9D20L3E1d70e@21`=D7@L3E0P70U@G1`D0
:0L00e@71`0F1`00F`L2E0T700=D1`L0@PL2E0P70UAM1`00;PL404070e@X1`=D@0L502l7000N1`03
E0L700d7100G1`03E0L702H715@V1`AD:@L00e@71`0D1`D03`L00e@71`0M1`00;@L601H700=D1`L0
2`L2E1P71002E2@70U@403l71@0_1`00;@L601`70U@61`9D5`L50003E0L702@71@0Q1`9D70L502l7
000^1`@0?PL602H71P0n1`@0<0L00747100X1`@0L`L007<70P0Z1`80L`L008P70eB91`00>@L00e@7
1`0V1`9D1@L2E1`715@L1`9D1@L2E2T700=D1`L0>0L003X700=D1`L09@L2E0D70U@L1`@000=D1`L0
80L2E2P700=D1`L0>@L008H71@291`002@L00e@71`0X1`03E0L700@70U@Q1`9D9PL602L70U@Q1`9D
1PL00e@71`0X1`03E0L700P700061`03E0L707h71@201`03E0L700D7000R1`03E0L704`700=D1`L0
1`L2E0X7100:1`9D20L3E4h700=D1`L08@L003L700=D1`L05`L2E1h700=D1`L01PL3E1P70U@91`03
E0L701d70e@H1`03E0L703H7001k1`9DU`L00?l75@L006H7100n1`@0J0L000/700=D1`L0C@L00e@7
1`071`D0?@L500/70UA>1`03E0L700X700081`03E0L703@700=D1`L01PL2E14700=D1`L01`L601T7
00=D1`L01@L3E1P71P0:1`03E0L700l70U@81`03E0L703@700=D1`L01`L001h70U@O1`03E0L700L7
00=D1`L06PL500L70e@?1`03E0L700H70U@>1`9D2@L501`700=D1`L01`L00e@71`0N1`03E0L701d7
001V1`@02@L2E2T700=D1`L01`L406P7003o1aD700141`03E0L703L70U@C1`03E0L703P700=D1`L0
@`L007d70e@B1`=DO`L005X70U@F1`9D:`L00e@71`0E1`9DF`L0078700=D1`L0:PL00e@71`1b1`00
Q`L308X7000]1`03E0L705L7101J1`03E0L702`7000d1`03E0L700l700=D1`L05@L2E1`700=D1`L0
1`L500X700=D1`L06`L2E1L700=D1`L03`L00e@71`0c1`00GPL00e@71`0U1`H0R0L006070U@:1`9D
6@L401X70U@:1`9DH@L005/7100Z1`80:0L405d7000F1`03E0L7048710071`03E0L704<70U@51`@0
A@L00e@71`0E1`00FPL600H700=D1`L0B@L605`7001=1`9D2`L605871P0<1`9DCPL005/7101D1`@0
G@L003T700=D1`L04`L00e@71`0/1`9D50L00e@71`0/1`03E0L701<700=D1`L0>0L004l700=D1`L0
L@L00e@71`1>1`00B@L00e@71`0W1`9D:@L2E2T700=D1`L0B0L00?l75@L00?l75@L0088700=D1`L0
2`L00e@71`211`00>0L00e@71`0@1`03E0L703@700=D1`L02`L00e@71`0d1`03E0L7010700=D1`L0
=`L008L70U@00`MDE0281`00o`LE1`00Q`L408T7001@1`@0<`L403<71@1A1`008PL00e@71`0[1`@0
2@L3E10700=D1`L04`L601H700=D1`L03`L2E0P71@0^1`03E0L70207001?1`H02`L2E0l700=D1`L0
4PL601D70U@>1`9D2PL60547001?1`H0<PL403871P1A1`00D0L406X7101B1`00o`LE1`00o`LE1`00
FPL01E@71`MD00T70U@51`03E0L7034700=D1`L00`L2E0T700ED1`L7E01K1`00o`LE1`00o`LE1`00
M0L00e@71`2M1`00M0L00e@71`061`9D5@L2E0P70UAd1`00@`L00e@71`0g1`03E0MD01<700=D1`L0
>@L00e@71`121`00>`L2E4@700=D1`L03PL00e@71`121`03E0L703X7003o1aD7003o1aD7000]1`03
E0L70;H700=D1`L0:`L007`700=D1`L05`L00e@71`1k1`00Q`L408T7001=1`03E0L7030700=D1`L0
10L400L700=D1`L0<0L00e@71`1<1`00QPL608P700261`H0R0L006D700=D1`L07`L4028700=D1`L0
I0L00?l75@L00?l75@L005l700=D1`L030L00e@71`0c1`03E0L700`700=D1`L0GPL00?l75@L004h7
00=D1`L0L`L00e@71`1=1`00o`LE1`00o`LE1`00L@L00e@71`0]1`03E0L70707003o1aD7000h1`03
E0L709l70U@h1`00o`LE1`00o`LE1`00=PL00e@71`2S1`03E0L703D7000n1`03E0L7048700=D1`L0
2@L00e@71`121`03E0L703d7003o1aD7003o1aD7000l1`03E0L709P700=D1`L0>PL00?l75@L00?l7
5@L0050700=D1`L0:PL00e@71`0E1`03E0L702X700=D1`L0C`L00?l75@L00?l75@L00?l75@L00?l7
5@L00?l75@L0068700=D1`L0C0L00e@71`1P1`00o`LE1`00o`LE1`00o`LE1`00o`LE1`00o`LE1`00
L`L00e@71`0Y1`03E0L70787003o1aD7003o1aD7003o1aD7003o1aD700251`03E0L700D700=D1`L0
Q0L00?l75@L00?l75@L00?l75@L008H700=D1`L010L00e@71`241`00o`LE1`00o`LE1`00o`LE1`00
o`LE1`00o`LE1`00o`LE1`00\
\>"],
  ImageRangeCache->{{{0, 275.125}, {286.938, 0}} -> {-4.69008, -4.89164, \
0.0340955, 0.0340955}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[473]="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 547}},
CellGrouping->Manual,
WindowSize->{792, 513},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{36, 36}, {36, 36}},
"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"PostScriptOutputFile":>FrontEnd`FileName[{"usr", "people", "joseluis", \
"Mathematica"}, "averageDif-octa.ps", CharacterEncoding -> "WindowsANSI"],
"Magnification"->1},
StyleDefinitions -> "ArticleClassic.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 118, 4, 111, "Title"],
Cell[1838, 55, 26, 0, 31, "Input"],
Cell[1867, 57, 2868, 58, 495, "Section"],

Cell[CellGroupData[{
Cell[4760, 119, 57, 1, 72, "Section"],

Cell[CellGroupData[{
Cell[4842, 124, 55, 0, 27, "Text"],
Cell[4900, 126, 136, 3, 32, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5073, 134, 48, 0, 27, "Text"],
Cell[5124, 136, 88, 2, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5249, 143, 90, 3, 27, "Text"],
Cell[5342, 148, 848, 17, 155, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6227, 170, 165, 4, 27, "Text"],
Cell[6395, 176, 296, 6, 71, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6728, 187, 130, 3, 27, "Text"],
Cell[6861, 192, 627, 11, 71, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7525, 208, 52, 0, 27, "Text"],
Cell[7580, 210, 1091, 20, 151, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8720, 236, 111, 1, 72, "Section"],
Cell[8834, 239, 549, 11, 131, "Input"],

Cell[CellGroupData[{
Cell[9408, 254, 226, 4, 51, "Input"],
Cell[9637, 260, 16500, 387, 296, 2648, 211, "GraphicsData", "PostScript", \
"Graphics"],
Cell[26140, 649, 155, 4, 30, "Output"]
}, Open  ]],
Cell[26310, 656, 132, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[26467, 664, 71, 2, 31, "Input"],
Cell[26541, 668, 1119, 22, 240, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27709, 696, 63, 1, 53, "Subtitle"],

Cell[CellGroupData[{
Cell[27797, 701, 79, 1, 43, "Text"],

Cell[CellGroupData[{
Cell[27901, 706, 500, 10, 54, "DisplayFormula"],
Cell[28404, 718, 225, 5, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28666, 728, 42, 0, 27, "Text"],
Cell[28711, 730, 176, 4, 51, "Input"],

Cell[CellGroupData[{
Cell[28912, 738, 36, 0, 27, "Text"],
Cell[28951, 740, 268, 6, 45, "Input"]
}, Open  ]],
Cell[29234, 749, 310, 7, 74, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29593, 762, 76, 2, 31, "Input"],
Cell[29672, 766, 77, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29786, 773, 1561, 35, 199, "Text"],
Cell[31350, 810, 180, 4, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31567, 819, 50, 1, 27, "Text"],
Cell[31620, 822, 1667, 41, 211, "Input"]
}, Open  ]],
Cell[33302, 866, 169, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[33496, 874, 213, 5, 51, "Input"],
Cell[33712, 881, 42572, 839, 298, 6332, 386, "GraphicsData", "PostScript", \
"Graphics"],
Cell[76287, 1722, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[76480, 1731, 53, 0, 43, "Subsection"],
Cell[76536, 1733, 1540, 40, 211, "Input"],
Cell[78079, 1775, 1540, 40, 211, "Input"],
Cell[79622, 1817, 1610, 40, 211, "Input"],
Cell[81235, 1859, 413, 7, 91, "Input"],

Cell[CellGroupData[{
Cell[81673, 1870, 185, 4, 31, "Input"],
Cell[81861, 1876, 53636, 1409, 291, 16765, 949, "GraphicsData", "PostScript", \
"Graphics"],
Cell[135500, 3287, 156, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[135705, 3297, 99, 2, 31, "Input"],
Cell[135807, 3301, 600528, 26831, 611, 252060, 22524, "GraphicsData", \
"PostScript", "Graphics"],
Cell[736338, 30134, 156, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],
Cell[736521, 30142, 435, 8, 121, "Subtitle"],
Cell[736959, 30152, 113, 2, 31, "Input"],
Cell[737075, 30156, 119, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[737219, 30163, 72, 1, 53, "Subtitle"],

Cell[CellGroupData[{
Cell[737316, 30168, 82, 1, 43, "Text"],

Cell[CellGroupData[{
Cell[737423, 30173, 500, 10, 54, "DisplayFormula"],
Cell[737926, 30185, 224, 5, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[738187, 30195, 52, 0, 27, "Text"],
Cell[738242, 30197, 751, 14, 165, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[739030, 30216, 120, 3, 27, "Text"],
Cell[739153, 30221, 250, 5, 31, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[739452, 30232, 32, 0, 27, "Text"],
Cell[739487, 30234, 190, 4, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[739714, 30243, 56, 1, 27, "Text"],
Cell[739773, 30246, 768, 11, 211, "Input"]
}, Open  ]],
Cell[740556, 30260, 184, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[740765, 30268, 160, 3, 31, "Input"],
Cell[740928, 30273, 39542, 1563, 225, 25118, 1380, "GraphicsData", \
"PostScript", "Graphics"],
Cell[780473, 31838, 155, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[780665, 31847, 53, 0, 43, "Subsection"],
Cell[780721, 31849, 1539, 40, 211, "Input"],
Cell[782263, 31891, 1540, 40, 211, "Input"],
Cell[783806, 31933, 1610, 40, 211, "Input"],
Cell[785419, 31975, 452, 8, 111, "Input"],
Cell[785874, 31985, 213, 4, 51, "Input"],
Cell[786090, 31991, 135, 3, 31, "Input"],

Cell[CellGroupData[{
Cell[786250, 31998, 240, 5, 51, "Input"],
Cell[786493, 32005, 61773, 1982, 296, 29441, 1578, "GraphicsData", \
"PostScript", "Graphics"],
Cell[848269, 33989, 156, 4, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[848474, 33999, 75, 1, 43, "Text"],

Cell[CellGroupData[{
Cell[848574, 34004, 215, 4, 28, "Input"],
Cell[848792, 34010, 40938, 1223, 296, 17219, 926, "GraphicsData", \
"PostScript", "Graphics"],
Cell[889733, 35235, 130, 3, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[889900, 35243, 217, 4, 28, "Input"],
Cell[890120, 35249, 31400, 909, 296, 12423, 670, "GraphicsData", \
"PostScript", "Graphics"],
Cell[921523, 36160, 130, 3, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[921702, 36169, 82, 1, 41, "Text"],

Cell[CellGroupData[{
Cell[921809, 36174, 65, 1, 31, "Input"],
Cell[921877, 36177, 134140, 6780, 296, 78178, 6084, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1056020, 42959, 130, 3, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1056187, 42967, 63, 1, 31, "Input"],
Cell[1056253, 42970, 119712, 6116, 296, 66314, 5452, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1175968, 49088, 130, 3, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1176135, 49096, 64, 1, 31, "Input"],
Cell[1176202, 49099, 114864, 5860, 296, 61434, 5196, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1291069, 54961, 130, 3, 30, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1291260, 54971, 92, 1, 53, "Subtitle"],

Cell[CellGroupData[{
Cell[1291377, 54976, 59, 1, 27, "Text"],

Cell[CellGroupData[{
Cell[1291461, 54981, 229, 4, 28, "Input"],
Cell[1291693, 54987, 15526, 582, 244, 5983, 459, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1307222, 55571, 156, 4, 28, "Output"],

Cell[CellGroupData[{
Cell[1307403, 55579, 338, 8, 44, "Input"],
Cell[1307744, 55589, 168, 4, 28, "Output"],
Cell[1307915, 55595, 110, 2, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1308062, 55602, 87, 2, 28, "Input"],
Cell[1308152, 55606, 147, 4, 28, "Output"]
}, Open  ]],
Cell[1308314, 55613, 165, 4, 34, "Input"],

Cell[CellGroupData[{
Cell[1308504, 55621, 254, 5, 44, "Input"],
Cell[1308761, 55628, 11712, 445, 296, 3752, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1320476, 56075, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1320669, 56084, 121, 3, 28, "Input"],
Cell[1320793, 56089, 25126, 543, 312, 3188, 267, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1345922, 56634, 156, 4, 28, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1346127, 56644, 167, 4, 28, "Input"],
Cell[1346297, 56650, 64247, 1626, 284, 10992, 963, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1410593, 58282, 59, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[1410677, 58287, 229, 4, 28, "Input"],
Cell[1410909, 58293, 13556, 532, 230, 5341, 425, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1424468, 58827, 156, 4, 28, "Output"],

Cell[CellGroupData[{
Cell[1424649, 58835, 338, 8, 44, "Input"],
Cell[1424990, 58845, 161, 3, 28, "Output"],
Cell[1425154, 58850, 114, 2, 28, "Output"]
}, Open  ]],
Cell[1425283, 58855, 165, 4, 34, "Input"],

Cell[CellGroupData[{
Cell[1425473, 58863, 247, 5, 44, "Input"],
Cell[1425723, 58870, 11848, 446, 296, 3763, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1437574, 59318, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1437767, 59327, 117, 2, 28, "Input"],
Cell[1437887, 59331, 32008, 550, 315, 2189, 177, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1469898, 59883, 156, 4, 28, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1470103, 59893, 167, 4, 28, "Input"],
Cell[1470273, 59899, 71178, 1620, 288, 9598, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1541454, 61521, 156, 4, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1541659, 61531, 59, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[1541743, 61536, 223, 4, 28, "Input"],
Cell[1541969, 61542, 15272, 578, 247, 5954, 458, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1557244, 62122, 156, 4, 28, "Output"],

Cell[CellGroupData[{
Cell[1557425, 62130, 338, 8, 44, "Input"],
Cell[1557766, 62140, 172, 4, 28, "Output"],
Cell[1557941, 62146, 107, 2, 28, "Output"]
}, Open  ]],
Cell[1558063, 62151, 153, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[1558241, 62158, 247, 5, 44, "Input"],
Cell[1558491, 62165, 11922, 447, 296, 3764, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1570416, 62614, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1570609, 62623, 128, 3, 28, "Input"],
Cell[1570740, 62628, 21361, 497, 297, 3155, 267, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1592104, 63127, 156, 4, 28, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1592309, 63137, 167, 4, 28, "Input"],
Cell[1592479, 63143, 59901, 1572, 292, 10962, 963, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1652383, 64717, 156, 4, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1652588, 64727, 59, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[1652672, 64732, 223, 4, 28, "Input"],
Cell[1652898, 64738, 13571, 532, 223, 5340, 425, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1666472, 65272, 156, 4, 28, "Output"],

Cell[CellGroupData[{
Cell[1666653, 65280, 338, 8, 44, "Input"],
Cell[1666994, 65290, 166, 3, 28, "Output"],
Cell[1667163, 65295, 108, 2, 28, "Output"]
}, Open  ]],
Cell[1667286, 65300, 153, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[1667464, 65307, 247, 5, 44, "Input"],
Cell[1667714, 65314, 11832, 446, 296, 3763, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1679549, 65762, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1679742, 65771, 121, 3, 28, "Input"],
Cell[1679866, 65776, 32000, 550, 315, 2189, 177, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1711869, 66328, 156, 4, 28, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1712074, 66338, 167, 4, 28, "Input"],
Cell[1712244, 66344, 71159, 1620, 288, 9598, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1783406, 67966, 156, 4, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1783611, 67976, 59, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[1783695, 67981, 223, 4, 28, "Input"],
Cell[1783921, 67987, 14493, 550, 253, 5503, 434, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1798417, 68539, 156, 4, 28, "Output"],

Cell[CellGroupData[{
Cell[1798598, 68547, 338, 8, 44, "Input"],
Cell[1798939, 68557, 174, 4, 28, "Output"],
Cell[1799116, 68563, 109, 2, 28, "Output"]
}, Open  ]],
Cell[1799240, 68568, 153, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[1799418, 68575, 247, 5, 44, "Input"],
Cell[1799668, 68582, 11957, 447, 296, 3763, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1811628, 69031, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1811821, 69040, 121, 3, 28, "Input"],
Cell[1811945, 69045, 18844, 388, 290, 2167, 177, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1830792, 69435, 156, 4, 28, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1830997, 69445, 167, 4, 28, "Input"],
Cell[1831167, 69451, 61473, 1499, 289, 9737, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1892643, 70952, 156, 4, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1892848, 70962, 59, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[1892932, 70967, 223, 4, 28, "Input"],
Cell[1893158, 70973, 15064, 575, 234, 5944, 457, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1908225, 71550, 156, 4, 28, "Output"],

Cell[CellGroupData[{
Cell[1908406, 71558, 338, 8, 44, "Input"],
Cell[1908747, 71568, 164, 3, 28, "Output"],
Cell[1908914, 71573, 107, 2, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[1909048, 71579, 151, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[1909224, 71586, 247, 5, 44, "Input"],
Cell[1909474, 71593, 11983, 448, 296, 3764, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1921460, 72043, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1921653, 72052, 121, 3, 28, "Input"],
Cell[1921777, 72057, 31839, 627, 297, 3129, 267, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1953619, 72686, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1953812, 72695, 167, 4, 28, "Input"],
Cell[1953982, 72701, 80611, 1830, 277, 10809, 963, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2034596, 74533, 156, 4, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2034801, 74543, 59, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[2034885, 74548, 223, 4, 28, "Input"],
Cell[2035111, 74554, 14953, 575, 234, 5983, 459, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2050067, 75131, 156, 4, 28, "Output"],

Cell[CellGroupData[{
Cell[2050248, 75139, 338, 8, 44, "Input"],
Cell[2050589, 75149, 159, 3, 28, "Output"],
Cell[2050751, 75154, 108, 2, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[2050886, 75160, 151, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[2051062, 75167, 247, 5, 44, "Input"],
Cell[2051312, 75174, 12019, 448, 296, 3764, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2063334, 75624, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2063527, 75633, 121, 3, 28, "Input"],
Cell[2063651, 75638, 25136, 543, 311, 3190, 267, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2088790, 76183, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2088983, 76192, 167, 4, 28, "Input"],
Cell[2089153, 76198, 59832, 1571, 270, 10992, 963, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2148988, 77771, 156, 4, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2149193, 77781, 59, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[2149277, 77786, 223, 4, 28, "Input"],
Cell[2149503, 77792, 13508, 530, 234, 5291, 423, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2163014, 78324, 156, 4, 28, "Output"],

Cell[CellGroupData[{
Cell[2163195, 78332, 338, 8, 44, "Input"],
Cell[2163536, 78342, 162, 3, 28, "Output"],
Cell[2163701, 78347, 111, 2, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[2163839, 78353, 151, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[2164015, 78360, 247, 5, 44, "Input"],
Cell[2164265, 78367, 11966, 448, 296, 3763, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2176234, 78817, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2176427, 78826, 121, 3, 28, "Input"],
Cell[2176551, 78831, 10649, 288, 336, 2042, 177, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2187203, 79121, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2187396, 79130, 167, 4, 28, "Input"],
Cell[2187566, 79136, 47973, 1335, 320, 9524, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2235542, 80473, 156, 4, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2235747, 80483, 59, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[2235831, 80488, 223, 4, 28, "Input"],
Cell[2236057, 80494, 14211, 547, 234, 5496, 434, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2250271, 81043, 156, 4, 28, "Output"],

Cell[CellGroupData[{
Cell[2250452, 81051, 338, 8, 44, "Input"],
Cell[2250793, 81061, 162, 3, 28, "Output"],
Cell[2250958, 81066, 104, 2, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[2251089, 81072, 151, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[2251265, 81079, 247, 5, 44, "Input"],
Cell[2251515, 81086, 11957, 447, 296, 3763, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2263475, 81535, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2263668, 81544, 121, 3, 28, "Input"],
Cell[2263792, 81549, 18836, 388, 290, 2173, 177, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2282631, 81939, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2282824, 81948, 167, 4, 28, "Input"],
Cell[2282994, 81954, 57600, 1451, 275, 9736, 855, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2340597, 83407, 156, 4, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2340802, 83417, 59, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[2340886, 83422, 223, 4, 28, "Input"],
Cell[2341112, 83428, 15066, 576, 234, 5954, 458, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2356181, 84006, 156, 4, 28, "Output"],

Cell[CellGroupData[{
Cell[2356362, 84014, 338, 8, 44, "Input"],
Cell[2356703, 84024, 164, 3, 28, "Output"],
Cell[2356870, 84029, 103, 2, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[2357000, 84035, 151, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[2357176, 84042, 247, 5, 44, "Input"],
Cell[2357426, 84049, 11905, 447, 296, 3763, 341, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2369334, 84498, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2369527, 84507, 121, 3, 28, "Input"],
Cell[2369651, 84512, 21373, 497, 297, 3155, 267, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2391027, 85011, 156, 4, 28, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2391220, 85020, 167, 4, 28, "Input"],
Cell[2391390, 85026, 59717, 1570, 292, 10962, 963, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2451110, 86598, 156, 4, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2451315, 86608, 55, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[2451395, 86613, 687, 11, 172, "Input"],
Cell[2452085, 86626, 110, 2, 28, "Output"],
Cell[2452198, 86630, 114, 2, 28, "Output"],
Cell[2452315, 86634, 107, 2, 28, "Output"],
Cell[2452425, 86638, 108, 2, 28, "Output"],
Cell[2452536, 86642, 109, 2, 28, "Output"],
Cell[2452648, 86646, 107, 2, 28, "Output"],
Cell[2452758, 86650, 108, 2, 28, "Output"],
Cell[2452869, 86654, 111, 2, 28, "Output"],
Cell[2452983, 86658, 104, 2, 28, "Output"],
Cell[2453090, 86662, 103, 2, 28, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2453242, 86670, 56, 1, 25, "Text"],

Cell[CellGroupData[{
Cell[2453323, 86675, 87, 1, 27, "Input"],
Cell[2453413, 86678, 121810, 5306, 296, 49349, 4407, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2575226, 91986, 130, 3, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2575393, 91994, 61, 1, 31, "Input"],
Cell[2575457, 91997, 96795, 4087, 296, 37533, 3351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2672255, 96086, 130, 3, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2672422, 96094, 118, 2, 31, "Input"],
Cell[2672543, 96098, 157587, 8595, 296, 86973, 7719, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2830133, 104695, 130, 3, 30, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[2830302, 104703, 72, 1, 53, "Subtitle"],
Cell[2830377, 104706, 86, 1, 43, "Text"],

Cell[CellGroupData[{
Cell[2830488, 104711, 500, 10, 54, "DisplayFormula"],
Cell[2830991, 104723, 224, 5, 51, "Input"],

Cell[CellGroupData[{
Cell[2831240, 104732, 73, 0, 27, "Text"],
Cell[2831316, 104734, 221, 5, 52, "Input"],
Cell[2831540, 104741, 235, 5, 52, "Input"],
Cell[2831778, 104748, 263, 5, 45, "Input"],
Cell[2832044, 104755, 263, 5, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2832344, 104765, 61, 0, 27, "Text"],
Cell[2832408, 104767, 487, 9, 98, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2832932, 104781, 113, 3, 27, "Text"],
Cell[2833048, 104786, 226, 4, 51, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2833323, 104796, 95, 1, 43, "Text"],

Cell[CellGroupData[{
Cell[2833443, 104801, 111, 2, 31, "Input"],
Cell[2833557, 104805, 258, 4, 51, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2833852, 104814, 111, 2, 31, "Input"],
Cell[2833966, 104818, 259, 4, 51, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2834262, 104827, 111, 2, 31, "Input"],
Cell[2834376, 104831, 356, 6, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2834769, 104842, 107, 2, 31, "Input"],
Cell[2834879, 104846, 259, 4, 51, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2835175, 104855, 105, 2, 31, "Input"],
Cell[2835283, 104859, 317, 6, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2835637, 104870, 107, 2, 31, "Input"],
Cell[2835747, 104874, 317, 5, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2836101, 104884, 107, 2, 31, "Input"],
Cell[2836211, 104888, 271, 5, 51, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2836519, 104898, 105, 2, 31, "Input"],
Cell[2836627, 104902, 295, 5, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2836959, 104912, 107, 2, 31, "Input"],
Cell[2837069, 104916, 309, 5, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2837415, 104926, 107, 2, 31, "Input"],
Cell[2837525, 104930, 354, 7, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2837916, 104942, 243, 5, 51, "Input"],
Cell[2838162, 104949, 11058, 339, 296, 2916, 233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2849223, 105290, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2849416, 105299, 243, 5, 51, "Input"],
Cell[2849662, 105306, 11114, 339, 296, 2916, 233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2860779, 105647, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2860972, 105656, 243, 5, 51, "Input"],
Cell[2861218, 105663, 10912, 337, 296, 2916, 233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2872133, 106002, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2872326, 106011, 243, 5, 51, "Input"],
Cell[2872572, 106018, 11114, 339, 296, 2916, 233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2883689, 106359, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2883882, 106368, 243, 5, 51, "Input"],
Cell[2884128, 106375, 11113, 339, 296, 2915, 233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2895244, 106716, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2895437, 106725, 243, 5, 51, "Input"],
Cell[2895683, 106732, 11114, 339, 296, 2916, 233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2906800, 107073, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2906993, 107082, 243, 5, 51, "Input"],
Cell[2907239, 107089, 11090, 339, 296, 2916, 233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2918332, 107430, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2918525, 107439, 243, 5, 51, "Input"],
Cell[2918771, 107446, 11114, 339, 296, 2916, 233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2929888, 107787, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2930081, 107796, 243, 5, 51, "Input"],
Cell[2930327, 107803, 11113, 339, 296, 2915, 233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2941443, 108144, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2941636, 108153, 243, 5, 51, "Input"],
Cell[2941882, 108160, 10912, 337, 296, 2916, 233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2952797, 108499, 156, 4, 30, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2953002, 108509, 34, 0, 27, "Subsection"],
Cell[2953039, 108511, 43, 0, 33, "Subsubsection"],

Cell[CellGroupData[{
Cell[2953107, 108515, 63, 0, 27, "Text"],
Cell[2953173, 108517, 136, 3, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2953346, 108525, 42, 0, 27, "Text"],
Cell[2953391, 108527, 706, 11, 211, "Input"]
}, Open  ]],
Cell[2954112, 108541, 179, 4, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2954328, 108550, 41, 0, 43, "Subsection"],
Cell[2954372, 108552, 261, 5, 31, "Input"],
Cell[2954636, 108559, 42, 0, 25, "InlineFormula"],

Cell[CellGroupData[{
Cell[2954703, 108563, 307, 6, 71, "Input"],
Cell[2955013, 108571, 18124, 438, 296, 4786, 268, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2973140, 109011, 155, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2973332, 109020, 109, 2, 31, "Input"],
Cell[2973444, 109024, 84, 1, 30, "Output"]
}, Open  ]],
Cell[2973543, 109028, 44, 0, 25, "InlineFormula"],

Cell[CellGroupData[{
Cell[2973612, 109032, 309, 6, 71, "Input"],
Cell[2973924, 109040, 14043, 388, 296, 4786, 268, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2987970, 109430, 155, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2988162, 109439, 72, 2, 31, "Input"],
Cell[2988237, 109443, 22341, 669, 296, 9002, 499, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3010581, 110114, 155, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3010773, 110123, 103, 2, 31, "Input"],
Cell[3010879, 110127, 85, 1, 30, "Output"]
}, Open  ]],
Cell[3010979, 110131, 44, 0, 25, "InlineFormula"],

Cell[CellGroupData[{
Cell[3011048, 110135, 309, 6, 71, "Input"],
Cell[3011360, 110143, 8049, 214, 296, 2360, 138, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3019412, 110359, 155, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3019604, 110368, 81, 2, 31, "Input"],
Cell[3019688, 110372, 24121, 769, 296, 10782, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3043812, 111143, 155, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3044004, 111152, 102, 2, 31, "Input"],
Cell[3044109, 111156, 86, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3044244, 111163, 78, 1, 59, "Subsection"],

Cell[CellGroupData[{
Cell[3044347, 111168, 41, 0, 27, "Text"],
Cell[3044391, 111170, 444, 8, 69, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3044872, 111183, 165, 3, 42, "DisplayFormula"],
Cell[3045040, 111188, 489, 9, 69, "Input"]
}, Open  ]],
Cell[3045544, 111200, 55, 0, 27, "Text"],
Cell[3045602, 111202, 318, 6, 51, "Input"],
Cell[3045923, 111210, 988, 20, 211, "Input"],
Cell[3046914, 111232, 177, 4, 31, "Input"],
Cell[3047094, 111238, 1377, 31, 211, "Input"],
Cell[3048474, 111271, 182, 4, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3048693, 111280, 110, 2, 31, "Input"],
Cell[3048806, 111284, 42106, 1884, 309, 28980, 1717, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3090915, 113170, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3091108, 113179, 107, 2, 31, "Input"],
Cell[3091218, 113183, 91, 1, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3091346, 113189, 68, 1, 72, "Section"],
Cell[3091417, 113192, 3369, 72, 631, "Input"],
Cell[3094789, 113266, 200, 4, 31, "Input"],

Cell[CellGroupData[{
Cell[3095014, 113274, 136, 4, 31, "Input"],
Cell[3095153, 113280, 9146, 288, 311, 3553, 214, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3104302, 113570, 156, 4, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3104495, 113579, 77, 2, 31, "Input"],
Cell[3104575, 113583, 42383, 2054, 296, 32602, 1928, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3146961, 115639, 156, 4, 30, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

